@@ -1,4 +1,3 @@
-
 /**
  * \file
  *
@@ -56,6 +55,24 @@
 #include <utils.h>
 #include <utils_assert.h>
 
+// CircuitPython:
+// Use SERCOM settings as prototypes to set
+// the default settings. The asf4_conf/hpl_sercom_config.h file
+// defines these bindings, and chooses a SERCOM (listed as x here).
+// 
+// #define PROTOTYPE_SERCOM_SPI_M_SYNC SERCOMx
+// #define PROTOTYPE_SERCOM_I2CM_SYNC SERCOMx
+// #define PROTOTYPE_SERCOM_USART_ASYNC SERCOMx
+//
+// Use these to choose the right settings from the _spis, _i2cms, and _usarts tables.
+// Look up the prototype instance by using the prototype SERCOM addresses,
+// not the SERCOM number.
+//
+// Note that there are some mentions here of SERCOM6 and SERCOM7. These don't exist on SAMD21,
+// but were put here by Atmel START, and so some of the added code here may also mention these
+// for ease of comparison with the SAMD51 version of this code.
+
+
 #ifndef CONF_SERCOM_0_USART_ENABLE
 #define CONF_SERCOM_0_USART_ENABLE 0
 #endif
@@ -168,7 +185,53 @@ static struct usart_configuration _usarts[] = {
 };
 #endif
 
+static struct _usart_async_device *_sercom0_dev = NULL;
+static struct _usart_async_device *_sercom1_dev = NULL;
 static struct _usart_async_device *_sercom2_dev = NULL;
+static struct _usart_async_device *_sercom3_dev = NULL;
+#ifdef SERCOM4
+static struct _usart_async_device *_sercom4_dev = NULL;
+#endif
+#ifdef SERCOM5
+static struct _usart_async_device *_sercom5_dev = NULL;
+#endif
+#ifdef SERCOM6
+static struct _usart_async_device *_sercom6_dev = NULL;
+#endif
+#ifdef SERCOM7
+static struct _usart_async_device *_sercom7_dev = NULL;
+#endif
+
+static struct {
+    Sercom *sercom;
+    struct _usart_async_device **sercom_dev;
+} sercom_to_sercom_dev[] = {
+    {SERCOM0, &_sercom0_dev},
+    {SERCOM1, &_sercom1_dev},
+    {SERCOM2, &_sercom2_dev},
+    {SERCOM3, &_sercom3_dev},
+#ifdef SERCOM4
+    {SERCOM4, &_sercom4_dev},
+#endif
+#ifdef SERCOM5
+    {SERCOM5, &_sercom5_dev},
+#endif
+#ifdef SERCOM6
+    {SERCOM6, &_sercom6_dev},
+#endif
+#ifdef SERCOM7
+    {SERCOM7, &_sercom7_dev},
+#endif
+};
+
+static struct _usart_async_device** get_dev_for_sercom(Sercom *sercom) {
+    for (size_t i = 0; i < (sizeof(sercom_to_sercom_dev) / sizeof(sercom_to_sercom_dev[0])); i++) {
+        if (sercom_to_sercom_dev[i].sercom == sercom) {
+            return sercom_to_sercom_dev[i].sercom_dev;
+        }
+    }
+    return NULL;
+}
 
 static uint8_t _get_sercom_index(const void *const hw);
 static uint8_t _sercom_get_irq_num(const void *const hw);
@@ -235,6 +298,9 @@ void _usart_async_deinit(struct _usart_async_device *const device)
 {
 	NVIC_DisableIRQ((IRQn_Type)_sercom_get_irq_num(device->hw));
 	_usart_deinit(device->hw);
+
+        // Break association between device handler and given sercom.
+        *(get_dev_for_sercom(device->hw)) = NULL;
 }
 
 /**
@@ -624,10 +690,8 @@ static uint8_t _get_sercom_index(const void *const hw)
  */
 static void _sercom_init_irq_param(const void *const hw, void *dev)
 {
-
-	if (hw == SERCOM2) {
-		_sercom2_dev = (struct _usart_async_device *)dev;
-	}
+    // Remember the hpl object that does with the sercom, for use by the interrupt handlers.
+    *(get_dev_for_sercom((Sercom *) hw)) = (struct _usart_async_device *)dev;
 }
 
 /**
@@ -639,7 +703,9 @@ static void _sercom_init_irq_param(const void *const hw, void *dev)
  */
 static int32_t _usart_init(void *const hw)
 {
-	uint8_t i = _get_sercom_index(hw);
+ 
+	// Use a prototypical instance to get settings, not the given SERCOM (hw).
+        uint8_t i = _get_sercom_index(PROTOTYPE_SERCOM_USART_ASYNC);
 
 	hri_sercomusart_wait_for_sync(hw, SERCOM_USART_SYNCBUSY_SWRST);
 	if (hri_sercomusart_get_CTRLA_ENABLE_bit(hw)) {
@@ -1118,20 +1184,25 @@ int32_t _i2c_m_async_set_baudrate(struct _i2c_m_async_device *const i2c_dev, uin
 		return ERR_DENIED;
 	}
 
-	tmp     = _get_i2cm_index(hw);
+	tmp     = _get_i2cm_index(PROTOTYPE_SERCOM_I2CM_SYNC);
 	clkrate = _i2cms[tmp].clk / 1000;
 
 	if (i2c_dev->service.mode == I2C_STANDARD_MODE) {
 		tmp = (uint32_t)((clkrate - 10 * baudrate - baudrate * clkrate * (i2c_dev->service.trise * 0.000000001))
 		                 / (2 * baudrate));
 		hri_sercomi2cm_write_BAUD_BAUD_bf(hw, tmp);
+		hri_sercomi2cm_write_BAUD_BAUDLOW_bf(hw, 0); // zero means same as BAUD.
 	} else if (i2c_dev->service.mode == I2C_FASTMODE) {
 		tmp = (uint32_t)((clkrate - 10 * baudrate - baudrate * clkrate * (i2c_dev->service.trise * 0.000000001))
 		                 / (2 * baudrate));
 		hri_sercomi2cm_write_BAUD_BAUD_bf(hw, tmp);
+		hri_sercomi2cm_write_BAUD_BAUDLOW_bf(hw, 0); // zero means same as BAUD.
 	} else if (i2c_dev->service.mode == I2C_HIGHSPEED_MODE) {
 		tmp = (clkrate - 2 * baudrate) / (2 * baudrate);
-		hri_sercomi2cm_write_BAUD_HSBAUD_bf(hw, tmp);
+                // not tested
+                // 1:2 high:low ratio 
+		hri_sercomi2cm_write_BAUD_HSBAUD_bf(hw, tmp / 3);
+		hri_sercomi2cm_write_BAUD_HSBAUDLOW_bf(hw, tmp*2 / 3);
 	} else {
 		/* error baudrate */
 		return ERR_INVALID_ARG;
@@ -1404,20 +1475,25 @@ int32_t _i2c_m_sync_set_baudrate(struct _i2c_m_sync_device *const i2c_dev, uint3
 		return ERR_DENIED;
 	}
 
-	tmp     = _get_i2cm_index(hw);
+	tmp     = _get_i2cm_index(PROTOTYPE_SERCOM_I2CM_SYNC);
 	clkrate = _i2cms[tmp].clk / 1000;
 
 	if (i2c_dev->service.mode == I2C_STANDARD_MODE) {
 		tmp = (uint32_t)((clkrate - 10 * baudrate - baudrate * clkrate * (i2c_dev->service.trise * 0.000000001))
 		                 / (2 * baudrate));
 		hri_sercomi2cm_write_BAUD_BAUD_bf(hw, tmp);
+		hri_sercomi2cm_write_BAUD_BAUDLOW_bf(hw, 0); // zero means same as BAUD.
 	} else if (i2c_dev->service.mode == I2C_FASTMODE) {
 		tmp = (uint32_t)((clkrate - 10 * baudrate - baudrate * clkrate * (i2c_dev->service.trise * 0.000000001))
 		                 / (2 * baudrate));
 		hri_sercomi2cm_write_BAUD_BAUD_bf(hw, tmp);
+		hri_sercomi2cm_write_BAUD_BAUDLOW_bf(hw, 0); // zero means same as BAUD.
 	} else if (i2c_dev->service.mode == I2C_HIGHSPEED_MODE) {
 		tmp = (clkrate - 2 * baudrate) / (2 * baudrate);
-		hri_sercomi2cm_write_BAUD_HSBAUD_bf(hw, tmp);
+                // not tested
+                // 1:2 high:low ratio 
+		hri_sercomi2cm_write_BAUD_HSBAUD_bf(hw, tmp / 3);
+		hri_sercomi2cm_write_BAUD_HSBAUDLOW_bf(hw, tmp*2 / 3);
 	} else {
 		/* error baudrate */
 		return ERR_INVALID_ARG;
@@ -1452,7 +1528,7 @@ void _i2c_m_async_set_irq_state(struct _i2c_m_async_device *const device, const
  */
 inline static int32_t _sercom_i2c_sync_wait_bus(struct _i2c_m_sync_device *const i2c_dev, uint32_t *flags)
 {
-	uint32_t timeout = 65535;
+	uint32_t timeout = 4194303;
 	void *   hw      = i2c_dev->hw;
 
 	do {
@@ -1588,7 +1664,8 @@ static inline void _i2c_m_enable_implementation(void *const hw)
 
 static int32_t _i2c_m_sync_init_impl(struct _i2c_m_service *const service, void *const hw)
 {
-	uint8_t i = _get_i2cm_index(hw);
+	// Use a prototypical instance to get settings, not the given SERCOM (hw).
+	uint8_t i = _get_i2cm_index(PROTOTYPE_SERCOM_I2CM_SYNC);
 
 	hri_sercomi2cm_wait_for_sync(hw, SERCOM_I2CM_SYNCBUSY_SWRST);
 	/* Check if module is enabled. */
@@ -2360,14 +2437,37 @@ static inline const struct sercomspi_regs_cfg *_spi_get_regs(const uint32_t hw_a
 	return NULL;
 }
 
-void SERCOM2_Handler(void)
-{
+void SERCOM0_Handler(void) {
+	_sercom_usart_interrupt_handler(_sercom0_dev);
+}
+
+void SERCOM1_Handler(void) {
+	_sercom_usart_interrupt_handler(_sercom1_dev);
+}
+
+void SERCOM2_Handler(void) {
 	_sercom_usart_interrupt_handler(_sercom2_dev);
 }
 
+void SERCOM3_Handler(void) {
+	_sercom_usart_interrupt_handler(_sercom3_dev);
+}
+
+#ifdef SERCOM4
+void SERCOM4_Handler(void) {
+	_sercom_usart_interrupt_handler(_sercom4_dev);
+}
+#endif
+#ifdef SERCOM5
+void SERCOM5_Handler(void) {
+	_sercom_usart_interrupt_handler(_sercom5_dev);
+}
+#endif
+
 int32_t _spi_m_sync_init(struct _spi_m_sync_dev *dev, void *const hw)
 {
-	const struct sercomspi_regs_cfg *regs = _spi_get_regs((uint32_t)hw);
+	// Use a prototypical instance to get settings, not the given SERCOM (hw).
+	const struct sercomspi_regs_cfg *regs = _spi_get_regs((uint32_t) PROTOTYPE_SERCOM_SPI_M_SYNC);
 
 	ASSERT(dev && hw);
 
