@@ -254,7 +254,7 @@ static void handle_sdp_client_query_result(uint8_t packet_type, uint16_t channel
             break;
         case SDP_EVENT_QUERY_COMPLETE:
             if (sdp_event_query_complete_get_status(packet)){
-                printf("SDP query failed 0x%02x\n", sdp_event_query_complete_get_status(packet));
+                printf("SDP query failed, status 0x%02x\n", sdp_event_query_complete_get_status(packet));
                 break;
             } 
             printf("SDP query done.\n");
