@@ -232,7 +232,7 @@ static void hci_packet_handler (uint8_t packet_type, uint16_t channel, uint8_t *
 
                             // request min con interval 15 ms for iOS 11+ 
                             printf("LE Connection - Request 15 ms connection interval\n");
-                            gap_request_connection_parameter_update(con_handle, 12, 12, 0, 0x0048);
+                            gap_request_connection_parameter_update(con_handle, 12, 12, 4, 0x0048);
                             break;
 
                         case HCI_SUBEVENT_LE_CONNECTION_UPDATE_COMPLETE:
@@ -295,7 +295,7 @@ static void rfcomm_packet_handler (uint8_t packet_type, uint16_t channel, uint8_
                 case RFCOMM_EVENT_CHANNEL_OPENED:
                     // data: event(8), len(8), status (8), address (48), server channel(8), rfcomm_cid(16), max frame size(16)
                     if (rfcomm_event_channel_opened_get_status(packet)) {
-                        printf("RFCOMM channel open failed, status %u\n", rfcomm_event_channel_opened_get_status(packet));
+                        printf("RFCOMM channel open failed, status 0x%02x\n", rfcomm_event_channel_opened_get_status(packet));
                     } else {
                         rfcomm_cid = rfcomm_event_channel_opened_get_rfcomm_cid(packet);
                         rfcomm_mtu = rfcomm_event_channel_opened_get_max_frame_size(packet);
