@@ -38,6 +38,7 @@
 #include "btstack_debug.h"
 
 #include <string.h>
+#include <inttypes.h>
 
 // Header:
 // - Magic: 'BTstack'
@@ -56,12 +57,19 @@
 // Most Flash implementations allow to:
 // - erase sector -> all values are 0xff
 // - write value (1s -> 0s)
-// - overwrite value with zero (remaininig 1s -> 0s)
+// - overwrite value with zero (remaining 1s -> 0s)
 //
 // We use the ability to overwrite a value with zeros to mark deleted enttries (by writing zero into the tag field).
-// Some targetes, E.g. Kinetix K64F, do enot allow for that. 
+// Some targets, E.g. Kinetix K64F, do enot allow for that.
 //
 // With ENABLE_TLV_FLASH_EXPLICIT_DELETE_FIELD an extra field is reserved to indicate a deleted tag, while keeping main logic
+//
+// With ENABLE_TLV_FLASH_WRITE_ONCE, tags are never marked as deleted. Instead, an emtpy tag will be written instead.
+//     Also, lookup and migrate requires to always search until the end of the valid bank
+
+#if defined (ENABLE_TLV_FLASH_EXPLICIT_DELETE_FIELD) && defined (ENABLE_TLV_FLASH_WRITE_ONCE)
+#error "Please define either ENABLE_TLV_FLASH_EXPLICIT_DELETE_FIELD or ENABLE_TLV_FLASH_WRITE_ONCE"
+#endif
 
 #define BTSTACK_TLV_HEADER_LEN 8
 
@@ -75,13 +83,14 @@ static const char * btstack_tlv_header_magic = "BTstack";
 typedef struct {
 	int 	 bank;
 	uint32_t offset;
+    uint32_t size;
 	uint32_t tag;
 	uint32_t len;
 } tlv_iterator_t;
 
 static uint32_t btstack_tlv_flash_bank_align_size(btstack_tlv_flash_bank_t * self, uint32_t size){
-	uint32_t aligment = self->hal_flash_bank_impl->get_alignment(self->hal_flash_bank_context);
-	return (size + aligment - 1) & ~(aligment - 1);
+	uint32_t alignment = self->hal_flash_bank_impl->get_alignment(self->hal_flash_bank_context);
+	return (size + alignment - 1) & ~(alignment - 1);
 }
 
 // support unaligned flash read/writes
@@ -133,6 +142,12 @@ static void btstack_tlv_flash_bank_write(btstack_tlv_flash_bank_t * self, int ba
 // iterator
 
 static void btstack_tlv_flash_bank_iterator_fetch_tag_len(btstack_tlv_flash_bank_t * self, tlv_iterator_t * it){
+    // abort if header doesn't fit into remaining space
+    if (it->offset + 8 + self->delete_tag_len >= self->hal_flash_bank_impl->get_size(self->hal_flash_bank_context)){
+        it->tag = 0xffffffff;
+        return;
+    }
+
 	uint8_t entry[8];
 	btstack_tlv_flash_bank_read(self, it->bank, it->offset, entry, 8);
 	it->tag = big_endian_read_32(entry, 0);
@@ -152,12 +167,13 @@ static void btstack_tlv_flash_bank_iterator_init(btstack_tlv_flash_bank_t * self
 	memset(it, 0, sizeof(tlv_iterator_t));
 	it->bank = bank;
 	it->offset = BTSTACK_TLV_HEADER_LEN;
+    it->size = self->hal_flash_bank_impl->get_size(self->hal_flash_bank_context);
 	btstack_tlv_flash_bank_iterator_fetch_tag_len(self, it);
 }
 
-static int btstack_tlv_flash_bank_iterator_has_next(btstack_tlv_flash_bank_t * self, tlv_iterator_t * it){
-	if (it->tag == 0xffffffff) return 0;
-	return 1;
+static bool btstack_tlv_flash_bank_iterator_has_next(btstack_tlv_flash_bank_t * self, tlv_iterator_t * it){
+	UNUSED(self);
+	return it->tag != 0xffffffff;
 }
 
 static void tlv_iterator_fetch_next(btstack_tlv_flash_bank_t * self, tlv_iterator_t * it){
@@ -168,7 +184,7 @@ static void tlv_iterator_fetch_next(btstack_tlv_flash_bank_t * self, tlv_iterato
 	it->offset += self->delete_tag_len;
 #endif
 
-	if (it->offset >= self->hal_flash_bank_impl->get_size(self->hal_flash_bank_context)) {
+	if (it->offset >= it->size) {
 		it->tag = 0xffffffff;
 		it->len = 0;
 		return;
@@ -216,7 +232,7 @@ static int btstack_tlv_flash_bank_test_erased(btstack_tlv_flash_bank_t * self, i
 	while (offset < size){
 		uint32_t copy_size = (offset + sizeof(empty16) < size) ? sizeof(empty16) : (size - offset); 
 		btstack_tlv_flash_bank_read(self, bank, offset, buffer, copy_size);
-		if (memcmp(buffer, empty16, copy_size)) {
+		if (memcmp(buffer, empty16, copy_size) != 0) {
 			log_info("not erased %x - %x", (unsigned int) offset, (unsigned int) (offset + copy_size));
 			return 0;
 		}
@@ -253,32 +269,54 @@ static void btstack_tlv_flash_bank_migrate(btstack_tlv_flash_bank_t * self){
 			uint32_t tag_len = it.len;
 			uint32_t tag_index = it.offset;
 
-			log_info("migrate pos %u, tag '%x' len %u -> new pos %u",
-                (unsigned  int)  tag_index, (unsigned int)  it.tag, (unsigned int) tag_len, next_write_pos);
+            bool tag_valid = true;
 
-			// copy header
-			uint8_t header_buffer[8];
-			btstack_tlv_flash_bank_read(self, self->current_bank, tag_index,      header_buffer, 8);
-			btstack_tlv_flash_bank_write(self, next_bank,         next_write_pos, header_buffer, 8);
-			tag_index      += 8;
-			next_write_pos += 8;
+#ifdef ENABLE_TLV_FLASH_WRITE_ONCE
+            // search until end for newer entry of same tag
+            tlv_iterator_t it2;
+            memcpy(&it2, &it, sizeof(tlv_iterator_t));
+            while (btstack_tlv_flash_bank_iterator_has_next(self, &it2)){
+                if ((it2.offset != it.offset) && (it2.tag == it.tag)){
+                    tag_valid = false;
+                    break;
+                }
+                tlv_iterator_fetch_next(self, &it2);
+            }
+            if (tag_valid == false){
+			    log_info("skip pos %u, tag '%x' as newer entry found at %u", (unsigned int) tag_index, (unsigned int) it.tag,
+                    (unsigned int) it2.offset);
+            }
+#endif
+
+            if (tag_valid) {
+
+                log_info("migrate pos %u, tag '%x' len %u -> new pos %u",
+                         (unsigned int) tag_index, (unsigned int) it.tag, (unsigned int) tag_len, next_write_pos);
+
+                // copy header
+                uint8_t header_buffer[8];
+                btstack_tlv_flash_bank_read(self, self->current_bank, tag_index, header_buffer, 8);
+                btstack_tlv_flash_bank_write(self, next_bank, next_write_pos, header_buffer, 8);
+                tag_index += 8;
+                next_write_pos += 8;
 
 #ifdef ENABLE_TLV_FLASH_EXPLICIT_DELETE_FIELD
-			// skip delete field
-			tag_index      += self->delete_tag_len;
-			next_write_pos += self->delete_tag_len;
+                // skip delete field
+                tag_index      += self->delete_tag_len;
+                next_write_pos += self->delete_tag_len;
 #endif
-			// copy value
-			int bytes_to_copy = tag_len;
-			uint8_t copy_buffer[32];
-			while (bytes_to_copy){
-				int bytes_this_iteration = btstack_min(bytes_to_copy, sizeof(copy_buffer));
-				btstack_tlv_flash_bank_read(self, self->current_bank, tag_index, copy_buffer, bytes_this_iteration);
-				btstack_tlv_flash_bank_write(self, next_bank, next_write_pos, copy_buffer, bytes_this_iteration);
-				tag_index      += bytes_this_iteration;
-				next_write_pos += bytes_this_iteration;
-				bytes_to_copy  -= bytes_this_iteration;
-			}
+                // copy value
+                int bytes_to_copy = tag_len;
+                uint8_t copy_buffer[32];
+                while (bytes_to_copy) {
+                    int bytes_this_iteration = btstack_min(bytes_to_copy, sizeof(copy_buffer));
+                    btstack_tlv_flash_bank_read(self, self->current_bank, tag_index, copy_buffer, bytes_this_iteration);
+                    btstack_tlv_flash_bank_write(self, next_bank, next_write_pos, copy_buffer, bytes_this_iteration);
+                    tag_index += bytes_this_iteration;
+                    next_write_pos += bytes_this_iteration;
+                    bytes_to_copy -= bytes_this_iteration;
+                }
+            }
 		}
 		tlv_iterator_fetch_next(self, &it);
 	}
@@ -291,6 +329,7 @@ static void btstack_tlv_flash_bank_migrate(btstack_tlv_flash_bank_t * self){
 	self->write_offset = next_write_pos;
 }
 
+#ifndef ENABLE_TLV_FLASH_WRITE_ONCE
 static void btstack_tlv_flash_bank_delete_tag_until_offset(btstack_tlv_flash_bank_t * self, uint32_t tag, uint32_t offset){
 	tlv_iterator_t it;
 	btstack_tlv_flash_bank_iterator_init(self, &it, self->current_bank);
@@ -312,6 +351,7 @@ static void btstack_tlv_flash_bank_delete_tag_until_offset(btstack_tlv_flash_ban
 		tlv_iterator_fetch_next(self, &it);
 	}
 }
+#endif
 
 /**
  * Get Value for Tag
@@ -333,7 +373,9 @@ static int btstack_tlv_flash_bank_get_tag(void * context, uint32_t tag, uint8_t
 			log_info("Found tag '%x' at position %u", (unsigned int) tag, (unsigned int) it.offset);
 			tag_index = it.offset;
 			tag_len   = it.len;
+#ifndef ENABLE_TLV_FLASH_WRITE_ONCE
 			break;
+#endif
 		}
 		tlv_iterator_fetch_next(self, &it);
 	}
@@ -375,7 +417,7 @@ static int btstack_tlv_flash_bank_store_tag(void * context, uint32_t tag, const
 	big_endian_store_32(entry, 0, tag);
 	big_endian_store_32(entry, 4, data_size);
 
-	log_info("write '%x', len %u at %u", (unsigned int) tag, (unsigned int) data_size, self->write_offset);
+	log_info("write '%" PRIx32 "', len %" PRIu32 " at %" PRIx32, tag, data_size, self->write_offset);
 
 	uint32_t value_offset = self->write_offset + 8;
 #ifdef ENABLE_TLV_FLASH_EXPLICIT_DELETE_FIELD
@@ -389,8 +431,10 @@ static int btstack_tlv_flash_bank_store_tag(void * context, uint32_t tag, const
 	// then entry
 	btstack_tlv_flash_bank_write(self, self->current_bank, self->write_offset, entry, sizeof(entry));
 
+#ifndef ENABLE_TLV_FLASH_WRITE_ONCE
 	// overwrite old entries (if exists)
 	btstack_tlv_flash_bank_delete_tag_until_offset(self, tag, self->write_offset);
+#endif
 
 	// done
 	self->write_offset += sizeof(entry) + btstack_tlv_flash_bank_align_size(self, data_size);
@@ -408,8 +452,12 @@ static int btstack_tlv_flash_bank_store_tag(void * context, uint32_t tag, const
  * @param tag
  */
 static void btstack_tlv_flash_bank_delete_tag(void * context, uint32_t tag){
-	btstack_tlv_flash_bank_t * self = (btstack_tlv_flash_bank_t *) context;
+#ifdef ENABLE_TLV_FLASH_WRITE_ONCE
+    btstack_tlv_flash_bank_store_tag(context, tag, NULL, 0);
+#else
+    btstack_tlv_flash_bank_t * self = (btstack_tlv_flash_bank_t *) context;
 	btstack_tlv_flash_bank_delete_tag_until_offset(self, tag, self->write_offset);
+#endif
 }
 
 static const btstack_tlv_t btstack_tlv_flash_bank = {
@@ -445,23 +493,29 @@ const btstack_tlv_t * btstack_tlv_flash_bank_init_instance(btstack_tlv_flash_ban
 
 		// find last entry and write offset
 		tlv_iterator_t it;
+#ifndef ENABLE_TLV_FLASH_WRITE_ONCE
 		uint32_t last_tag = 0;
 		uint32_t last_offset = 0;
-		btstack_tlv_flash_bank_iterator_init(self, &it, self->current_bank);
+#endif
+        btstack_tlv_flash_bank_iterator_init(self, &it, self->current_bank);
 		while (btstack_tlv_flash_bank_iterator_has_next(self, &it)){
+#ifndef ENABLE_TLV_FLASH_WRITE_ONCE
 			last_tag = it.tag;
 			last_offset = it.offset;
+#endif
 			tlv_iterator_fetch_next(self, &it);
 		}
 		self->write_offset = it.offset;
 
-		if (self->write_offset < self->hal_flash_bank_impl->get_size(self->hal_flash_bank_context)){
+		if (self->write_offset <= self->hal_flash_bank_impl->get_size(self->hal_flash_bank_context)){
 
+#ifndef ENABLE_TLV_FLASH_WRITE_ONCE
 			// delete older instances of last_tag
 			// this handles the unlikely case where MCU did reset after new value + header was written but before delete did complete
 			if (last_tag){
 				btstack_tlv_flash_bank_delete_tag_until_offset(self, last_tag, last_offset);
 			}
+#endif
 
 			// verify that rest of bank is empty
 			// this handles the unlikely case where MCU did reset after new value was written, but not the tag
@@ -484,7 +538,7 @@ const btstack_tlv_t * btstack_tlv_flash_bank_init_instance(btstack_tlv_flash_ban
 		self->write_offset = 8;
 	}
 
-	log_info("write offset %u", self->write_offset);
+	log_info("write offset %" PRIx32, self->write_offset);
 	return &btstack_tlv_flash_bank;
 }
 
