@@ -48,11 +48,11 @@ extern "C" {
 #endif
 
 typedef struct {
-	const hal_flash_bank_t * hal_flash_bank_impl;
-	void * hal_flash_bank_context;
-	int current_bank;
-	int write_offset;
-	int delete_tag_len;
+	const    hal_flash_bank_t * hal_flash_bank_impl;
+	void *   hal_flash_bank_context;
+    uint32_t write_offset;
+	int8_t   current_bank;
+    uint8_t  delete_tag_len;
 } btstack_tlv_flash_bank_t;
 
 /**
