@@ -27,12 +27,14 @@
 #define HCI_ACL_PAYLOAD_SIZE 1021
 #define MAX_NR_AVDTP_CONNECTIONS 1
 #define MAX_NR_AVDTP_STREAM_ENDPOINTS 1
-#define MAX_NR_AVRCP_CONNECTIONS 1
+#define MAX_NR_AVRCP_CONNECTIONS 2
 #define MAX_NR_BNEP_CHANNELS 1
 #define MAX_NR_BNEP_SERVICES 1
 #define MAX_NR_BTSTACK_LINK_KEY_DB_MEMORY_ENTRIES  2
 #define MAX_NR_GATT_CLIENTS 1
 #define MAX_NR_HCI_CONNECTIONS 1
+#define MAX_NR_HID_HOST_CONNECTIONS 1
+#define MAX_NR_HIDS_CLIENTS 1
 #define MAX_NR_HFP_CONNECTIONS 1
 #define MAX_NR_L2CAP_CHANNELS  3
 #define MAX_NR_L2CAP_SERVICES  3
