@@ -52,6 +52,7 @@
 
 #include "ble/le_device_db_tlv.h"
 #include "bluetooth_company_id.h"
+#include "btstack_audio.h"
 #include "btstack_chipset_zephyr.h"
 #include "btstack_debug.h"
 #include "btstack_event.h"
@@ -172,6 +173,11 @@ int main(int argc, const char * argv[]){
     hci_init(transport, (void*) &config);
     hci_set_chipset(btstack_chipset_zephyr_instance());
 
+#ifdef HAVE_PORTAUDIO
+    btstack_audio_sink_set_instance(btstack_audio_portaudio_sink_get_instance());
+    btstack_audio_source_set_instance(btstack_audio_portaudio_source_get_instance());
+#endif
+
     // inform about BTstack state
     hci_event_callback_registration.callback = &packet_handler;
     hci_add_event_handler(&hci_event_callback_registration);
