@@ -203,11 +203,11 @@ uint16_t att_uuid_for_handle(uint16_t attribute_handle){
 }
 // end of client API
 
-static void att_update_value_len(att_iterator_t *it, hci_con_handle_t con_handle){
+static void att_update_value_len(att_iterator_t *it, uint16_t offset, hci_con_handle_t con_handle) {
     if ((it->flags & (uint16_t)ATT_PROPERTY_DYNAMIC) == 0u){
         return;
     }
-    it->value_len = (*att_read_callback)(con_handle, it->handle, 0, NULL, 0);
+    it->value_len = (*att_read_callback)(con_handle, it->handle, offset, NULL, 0);
     return;
 }
 
@@ -641,7 +641,7 @@ static uint16_t handle_read_by_type_request2(att_connection_t * att_connection,
             break;
         }
 
-        att_update_value_len(&it, att_connection->con_handle);
+        att_update_value_len(&it, 0, att_connection->con_handle);
         
 #ifdef ENABLE_ATT_DELAYED_RESPONSE
         if (it.value_len == (uint16_t)ATT_READ_RESPONSE_PENDING){
@@ -749,7 +749,7 @@ static uint16_t handle_read_request2(att_connection_t * att_connection, uint8_t
         return setup_error(response_buffer, request_type, handle, error_code);
     }
 
-    att_update_value_len(&it, att_connection->con_handle);
+    att_update_value_len(&it, 0, att_connection->con_handle);
 
 #ifdef ENABLE_ATT_DELAYED_RESPONSE
     if (it.value_len == (uint16_t)ATT_READ_RESPONSE_PENDING){
@@ -807,7 +807,7 @@ static uint16_t handle_read_blob_request2(att_connection_t * att_connection, uin
         return setup_error(response_buffer, request_type, handle, error_code);
     }
 
-    att_update_value_len(&it, att_connection->con_handle);
+    att_update_value_len(&it, value_offset, att_connection->con_handle);
 
 #ifdef ENABLE_ATT_DELAYED_RESPONSE
     if (it.value_len == (uint16_t)ATT_READ_RESPONSE_PENDING){
@@ -892,7 +892,7 @@ static uint16_t handle_read_multiple_request2(att_connection_t * att_connection,
             break;
         }
 
-        att_update_value_len(&it, att_connection->con_handle);
+        att_update_value_len(&it, 0, att_connection->con_handle);
         
 #ifdef ENABLE_ATT_DELAYED_RESPONSE
         if (it.value_len == (uint16_t)ATT_READ_RESPONSE_PENDING) {
@@ -1350,6 +1350,7 @@ uint16_t att_handle_request(att_connection_t * att_connection,
 bool gatt_server_get_handle_range_for_service_with_uuid16(uint16_t uuid16, uint16_t * start_handle, uint16_t * end_handle){
     bool in_group    = false;
     uint16_t prev_handle = 0;
+    uint16_t service_start = 0;
 
     uint8_t attribute_value[2];
     int attribute_len = sizeof(attribute_value);
@@ -1364,8 +1365,13 @@ bool gatt_server_get_handle_range_for_service_with_uuid16(uint16_t uuid16, uint1
         // close current tag, if within a group and a new service definition starts or we reach end of att db
         if (in_group &&
             ((it.handle == 0u) || new_service_started)){
-            *end_handle = prev_handle;
-            return true;
+            in_group = false;
+            // check range
+            if ((service_start >= *start_handle) && (prev_handle <= *end_handle)){
+                *start_handle = service_start;
+                *end_handle = prev_handle;
+                return true;
+            }
         }
         
         // keep track of previous handle
@@ -1373,7 +1379,7 @@ bool gatt_server_get_handle_range_for_service_with_uuid16(uint16_t uuid16, uint1
         
         // check if found
         if ( (it.handle != 0u) && new_service_started && (attribute_len == it.value_len) && (memcmp(attribute_value, it.value, it.value_len) == 0)){
-            *start_handle = it.handle;
+            service_start = it.handle;
             in_group = true;
         }
     }
