@@ -286,7 +286,7 @@ void hids_device_init(uint8_t country_code, const uint8_t * descriptor, uint16_t
 
     // get service handle range
     uint16_t start_handle = 0;
-    uint16_t end_handle   = 0xfff;
+    uint16_t end_handle   = 0xffff;
     int service_found = gatt_server_get_handle_range_for_service_with_uuid16(ORG_BLUETOOTH_SERVICE_HUMAN_INTERFACE_DEVICE, &start_handle, &end_handle);
 	btstack_assert(service_found != 0);
 	UNUSED(service_found);
