@@ -20,8 +20,8 @@
  * THIS SOFTWARE IS PROVIDED BY BLUEKITCHEN GMBH AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL MATTHIAS
- * RINGWALD OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL BLUEKITCHEN
+ * GMBH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
  * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
  * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
@@ -121,7 +121,7 @@ static const char * local_tags[] = {
 static void hid_pretty_print_item(btstack_hid_parser_t * parser, hid_descriptor_item_t * item){
 #ifdef HID_PARSER_PRETTY_PRINT
     const char ** item_tag_table;
-    switch (item->item_type){
+    switch ((TagType)item->item_type){
         case Main:
             item_tag_table = main_tags;
             break;
@@ -152,15 +152,15 @@ void btstack_hid_parse_descriptor_item(hid_descriptor_item_t * item, const uint8
     const int hid_item_sizes[] = { 0, 1, 2, 4 };
 
     // parse item header
-    if (hid_descriptor_len < 1) return;
+    if (hid_descriptor_len < 1u) return;
     uint16_t pos = 0;
     uint8_t item_header = hid_descriptor[pos++];
-    item->data_size = hid_item_sizes[item_header & 0x03];
-    item->item_type = (item_header & 0x0c) >> 2;
-    item->item_tag  = (item_header & 0xf0) >> 4;
+    item->data_size = hid_item_sizes[item_header & 0x03u];
+    item->item_type = (item_header & 0x0cu) >> 2u;
+    item->item_tag  = (item_header & 0xf0u) >> 4u;
     // long item
-    if ((item->data_size == 2) && (item->item_tag == 0x0f) && (item->item_type == 3)){
-        if (hid_descriptor_len < 3) return;
+    if ((item->data_size == 2u) && (item->item_tag == 0x0fu) && (item->item_type == 3u)){
+        if (hid_descriptor_len < 3u) return;
         item->data_size = hid_descriptor[pos++];
         item->item_tag  = hid_descriptor[pos++];
     }
@@ -169,25 +169,25 @@ void btstack_hid_parse_descriptor_item(hid_descriptor_item_t * item, const uint8
 
     // read item value
     if (hid_descriptor_len < item->item_size) return;
-    if (item->data_size > 4) return;
+    if (item->data_size > 4u) return;
     int i;
-    int sgnd = (item->item_type == Global) && (item->item_tag > 0) && (item->item_tag < 5);
+    int sgnd = (item->item_type == Global) && (item->item_tag > 0u) && (item->item_tag < 5u);
     int32_t value = 0;
     uint8_t latest_byte = 0;
     for (i=0;i<item->data_size;i++){
         latest_byte = hid_descriptor[pos++];
         value = (latest_byte << (8*i)) | value;
     }
-    if (sgnd && (item->data_size > 0)){
-        if (latest_byte & 0x80) {
-            value -= 1 << (item->data_size*8);
+    if (sgnd && (item->data_size > 0u)){
+        if (latest_byte & 0x80u) {
+            value -= 1u << (item->data_size*8u);
         }
     }
     item->item_value = value;
 }
 
 static void btstack_hid_handle_global_item(btstack_hid_parser_t * parser, hid_descriptor_item_t * item){
-    switch(item->item_tag){
+    switch((GlobalItemTag)item->item_tag){
         case UsagePage:
             parser->global_usage_page = item->item_value;
             break;
@@ -211,13 +211,24 @@ static void btstack_hid_handle_global_item(btstack_hid_parser_t * parser, hid_de
         case ReportCount:
             parser->global_report_count = item->item_value;
             break;
+
+        // TODO handle tags
+        case PhysicalMinimum:
+        case PhysicalMaximum:
+        case UnitExponent:
+        case Unit:
+        case Push:
+        case Pop:
+            break;
+
         default:
+            btstack_assert(false);
             break;
     }
 }
 
 static void hid_find_next_usage(btstack_hid_parser_t * parser){
-    while ((parser->available_usages == 0) && (parser->usage_pos < parser->descriptor_pos)){
+    while ((parser->available_usages == 0u) && (parser->usage_pos < parser->descriptor_pos)){
         hid_descriptor_item_t usage_item;
         // parser->usage_pos < parser->descriptor_pos < parser->descriptor_len
         btstack_hid_parse_descriptor_item(&usage_item, &parser->descriptor[parser->usage_pos], parser->descriptor_len - parser->usage_pos);
@@ -225,7 +236,7 @@ static void hid_find_next_usage(btstack_hid_parser_t * parser){
             parser->usage_page = usage_item.item_value;
         }
         if (usage_item.item_type == Local){
-            uint32_t usage_value = (usage_item.data_size > 2) ? usage_item.item_value : ((parser->usage_page << 16) | usage_item.item_value);
+            uint32_t usage_value = (usage_item.data_size > 2u) ? usage_item.item_value : ((parser->usage_page << 16u) | usage_item.item_value);
             switch (usage_item.item_tag){
                 case Usage:
                     parser->available_usages = 1;
@@ -243,7 +254,7 @@ static void hid_find_next_usage(btstack_hid_parser_t * parser){
                     break;
             }
             if (parser->have_usage_min && parser->have_usage_max){
-                parser->available_usages = parser->usage_maximum - parser->usage_minimum + 1;
+                parser->available_usages = parser->usage_maximum - parser->usage_minimum + 1u;
                 parser->have_usage_min = 0;
                 parser->have_usage_max = 0;
             }
@@ -255,9 +266,9 @@ static void hid_find_next_usage(btstack_hid_parser_t * parser){
 static void hid_process_item(btstack_hid_parser_t * parser, hid_descriptor_item_t * item){
     hid_pretty_print_item(parser, item);
     int valid_field = 0;
-    switch (item->item_type){
+    switch ((TagType)item->item_type){
         case Main:
-            switch (item->item_tag){
+            switch ((MainItemTag)item->item_tag){
                 case Input:
                     valid_field = parser->report_type == HID_REPORT_TYPE_INPUT;
                     break;
@@ -275,6 +286,10 @@ static void hid_process_item(btstack_hid_parser_t * parser, hid_descriptor_item_
             btstack_hid_handle_global_item(parser, item);
             break;
         case Local:
+        case Reserved:
+            break;
+        default:
+            btstack_assert(false);
             break;
     }
     if (!valid_field) return;
@@ -284,7 +299,7 @@ static void hid_process_item(btstack_hid_parser_t * parser, hid_descriptor_item_
         if (parser->report[0] != parser->global_report_id){
             return;
         }
-        parser->report_pos_in_bit += 8;
+        parser->report_pos_in_bit += 8u;
     }
     parser->active_record = 1;
     // handle constant fields used for padding
@@ -297,13 +312,13 @@ static void hid_process_item(btstack_hid_parser_t * parser, hid_descriptor_item_
         return;
     }
     // Empty Item
-    if (parser->global_report_count == 0) return;
+    if (parser->global_report_count == 0u) return;
     // let's start
     parser->required_usages = parser->global_report_count;
 }
 
 static void hid_post_process_item(btstack_hid_parser_t * parser, hid_descriptor_item_t * item){
-    if (item->item_type == Main){
+    if ((TagType)item->item_type == Main){
         // reset usage
         parser->usage_pos  = parser->descriptor_pos;
         parser->usage_page = parser->global_usage_page;
@@ -359,22 +374,22 @@ void btstack_hid_parser_get_field(btstack_hid_parser_t * parser, uint16_t * usag
     *usage_page = parser->usage_minimum >> 16;
 
     // read field (up to 32 bit unsigned, up to 31 bit signed - 32 bit signed behaviour is undefined) - check report len
-    int is_variable   = parser->descriptor_item.item_value & 2;
-    int is_signed     = parser->global_logical_minimum < 0;
+    bool is_variable   = (parser->descriptor_item.item_value & 2) != 0;
+    bool is_signed     = parser->global_logical_minimum < 0;
     int pos_start     = btstack_min(  parser->report_pos_in_bit >> 3, parser->report_len);
-    int pos_end       = btstack_min( (parser->report_pos_in_bit + parser->global_report_size - 1) >> 3, parser->report_len);
+    int pos_end       = btstack_min( (parser->report_pos_in_bit + parser->global_report_size - 1u) >> 3u, parser->report_len);
     int bytes_to_read = pos_end - pos_start + 1;
     int i;
     uint32_t multi_byte_value = 0;
     for (i=0;i < bytes_to_read;i++){
         multi_byte_value |= parser->report[pos_start+i] << (i*8);
     }
-    uint32_t unsigned_value = (multi_byte_value >> (parser->report_pos_in_bit & 0x07)) & ((1<<parser->global_report_size)-1);
+    uint32_t unsigned_value = (multi_byte_value >> (parser->report_pos_in_bit & 0x07u)) & ((1u<<parser->global_report_size)-1u);
     // log_debug("bit pos %2u, report size %u, start %u, end %u, len %u;; unsigned value %08x", parser->report_pos_in_bit, parser->global_report_size, pos_start, pos_end, parser->report_len, unsigned_value);
     if (is_variable){
-        *usage      = parser->usage_minimum & 0xffff;
-        if (is_signed && (unsigned_value & (1<<(parser->global_report_size-1)))){
-            *value = unsigned_value - (1<<parser->global_report_size);
+        *usage      = parser->usage_minimum & 0xffffu;
+        if (is_signed && (unsigned_value & (1u<<(parser->global_report_size-1u)))){
+            *value = unsigned_value - (1u<<parser->global_report_size);
         } else {
             *value = unsigned_value;
         }
@@ -390,20 +405,20 @@ void btstack_hid_parser_get_field(btstack_hid_parser_t * parser, uint16_t * usag
         parser->usage_minimum++;
         parser->available_usages--;
     } else {
-        if (parser->required_usages == 0){
+        if (parser->required_usages == 0u){
             parser->available_usages = 0;
         }
     }
     if (parser->available_usages) {
         return;
     }
-    if (parser->required_usages == 0){
+    if (parser->required_usages == 0u){
         hid_post_process_item(parser, &parser->descriptor_item);
         parser->state = BTSTACK_HID_PARSER_SCAN_FOR_REPORT_ITEM;
         btstack_hid_parser_find_next_usage(parser);
     } else {
         hid_find_next_usage(parser);
-        if (parser->available_usages == 0) {
+        if (parser->available_usages == 0u) {
             parser->state = BTSTACK_HID_PARSER_COMPLETE;
         }
     }
@@ -418,7 +433,6 @@ int btstack_hid_get_report_size_for_id(int report_id, hid_report_type_t report_t
     while (hid_descriptor_len){
         int valid_report_type = 0;
         hid_descriptor_item_t item;
-        // printf("item: 0x%02x (%p)\n", *hid_descriptor, hid_descriptor);
         btstack_hid_parse_descriptor_item(&item, hid_descriptor, hid_descriptor_len);
         switch (item.item_type){
             case Global:
@@ -480,7 +494,6 @@ hid_report_id_status_t btstack_hid_id_valid(int report_id, uint16_t hid_descript
                 switch ((GlobalItemTag)item.item_tag){
                     case ReportID:
                         current_report_id = item.item_value;
-                        // printf("current ID %d, searched ID %d\n", current_report_id, report_id);
                         if (current_report_id != report_id) break;
                         return HID_REPORT_ID_VALID;
                     default:
