@@ -61,7 +61,10 @@ typedef enum {
     AVRCP_CONTROLLER_SUPPORTED_FEATURE_CATEGORY_MENU,
     AVRCP_CONTROLLER_SUPPORTED_FEATURE_RESERVED_4,
     AVRCP_CONTROLLER_SUPPORTED_FEATURE_RESERVED_5,
-    AVRCP_CONTROLLER_SUPPORTED_FEATURE_BROWSING
+    AVRCP_CONTROLLER_SUPPORTED_FEATURE_BROWSING,
+    AVRCP_CONTROLLER_SUPPORTED_FEATURE_COVER_ART_GET_IMAGE_PROPERTIES,
+    AVRCP_CONTROLLER_SUPPORTED_FEATURE_COVER_ART_GET_IMAGE,
+    AVRCP_CONTROLLER_SUPPORTED_FEATURE_COVER_ART_GET_LINKED_THUMBNAIL
 } avrcp_controller_supported_feature_t;
 
 /**
