@@ -58,9 +58,10 @@ typedef enum {
     AVRCP_TARGET_SUPPORTED_FEATURE_CATEGORY_TUNER,
     AVRCP_TARGET_SUPPORTED_FEATURE_CATEGORY_MENU,
     AVRCP_TARGET_SUPPORTED_FEATURE_PLAYER_APPLICATION_SETTINGS, // AVRCP_TARGET_SUPPORTED_FEATURE_CATEGORY_PLAYER_OR_RECORDER must be 1 for this feature to be set
-    AVRCP_TARGET_SUPPORTED_FEATURE_RESERVED_GROUP_NAVIGATION,   // AVRCP_TARGET_SUPPORTED_FEATURE_CATEGORY_PLAYER_OR_RECORDER must be 1 for this feature to be set
+    AVRCP_TARGET_SUPPORTED_FEATURE_GROUP_NAVIGATION,            // AVRCP_TARGET_SUPPORTED_FEATURE_CATEGORY_PLAYER_OR_RECORDER must be 1 for this feature to be set
     AVRCP_TARGET_SUPPORTED_FEATURE_BROWSING,
-    AVRCP_TARGET_SUPPORTED_FEATURE_MULTIPLE_MEDIA_PLAYE_APPLICATIONS
+    AVRCP_TARGET_SUPPORTED_FEATURE_MULTIPLE_MEDIA_PLAYER_APPLICATIONS,
+    AVRCP_TARGET_SUPPORTED_FEATURE_COVER_ART,
 } avrcp_target_supported_feature_t;
 
 /**
