@@ -20,8 +20,8 @@
  * THIS SOFTWARE IS PROVIDED BY BLUEKITCHEN GMBH AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL MATTHIAS
- * RINGWALD OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL BLUEKITCHEN
+ * GMBH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
  * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
  * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
@@ -43,10 +43,13 @@
  */
 
 #include <stdint.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef OCTAVE_OUTPUT
+#include <stdio.h>
+#endif
+
 #include "btstack_cvsd_plc.h"
 #include "btstack_debug.h"
 
@@ -63,9 +66,10 @@ static float rcos[CVSD_OLAL] = {
     0.13049554f,0.03376389f};
 
 float btstack_cvsd_plc_rcos(int index){
-    if (index > CVSD_OLAL) return 0;
+    if (index >= CVSD_OLAL) return 0;
     return rcos[index];
 }
+
 // taken from http://www.codeproject.com/Articles/69941/Best-Square-Root-Method-Algorithm-Function-Precisi
 // Algorithm: Babylonian Method + some manipulations on IEEE 32 bit floating point representation
 static float sqrt3(const float x){
@@ -188,7 +192,10 @@ static void octave_fprintf_array_int16(FILE * oct_file, char * name, int data_le
 static FILE * open_octave_file(btstack_cvsd_plc_state_t *plc_state, octave_frame_type_t frame_type){
     char oct_file_name[1200];
     octave_frame_type = frame_type;
-    sprintf(oct_file_name, "%s_octave_plc_%d_%s.m", octave_base_name, plc_state->frame_count, octave_frame_type2str(octave_frame_type));
+    snprintf(oct_file_name, sizeof(oct_file_name), "%s_octave_plc_%d_%s.m",
+             octave_base_name, plc_state->frame_count,
+             octave_frame_type2str(octave_frame_type));
+    oct_file_name[sizeof(oct_file_name) - 1] = 0;
     
     FILE * oct_file = fopen(oct_file_name, "wb");
     if (oct_file == NULL){
@@ -202,7 +209,8 @@ static FILE * open_octave_file(btstack_cvsd_plc_state_t *plc_state, octave_frame
 static void octave_fprintf_plot_history_frame(btstack_cvsd_plc_state_t *plc_state, FILE * oct_file, int frame_nr){
     char title[100];
     char hist_name[10];
-    sprintf(hist_name, "hist%d", plc_state->nbf);
+    snprintf(hist_name, sizeof(hist_name), "hist%d", plc_state->nbf);
+    hist_name[sizeof(hist_name) - 1] = 0;
             
     octave_fprintf_array_int16(oct_file, hist_name, CVSD_LHIST, plc_state->hist);
 
@@ -227,7 +235,9 @@ static void octave_fprintf_plot_history_frame(btstack_cvsd_plc_state_t *plc_stat
     fprintf(oct_file, "pattern_window_x = x + %d;\n", CVSD_LHIST - CVSD_M);
     
     fprintf(oct_file, "hf = figure();\n");
-    sprintf(title, "PLC %s frame %d", octave_frame_type2str(octave_frame_type), frame_nr);
+    snprintf(title, sizeof(title), "PLC %s frame %d",
+             octave_frame_type2str(octave_frame_type), frame_nr);
+    title[sizeof(title) - 1] = 0;
     
     fprintf(oct_file, "hold on;\n");
     fprintf(oct_file, "h1 = plot(%s); \n", hist_name);
@@ -270,35 +280,41 @@ static void octave_fprintf_plot_history_frame(btstack_cvsd_plc_state_t *plc_stat
 static void octave_fprintf_plot_output(btstack_cvsd_plc_state_t *plc_state, FILE * oct_file){
     if (!oct_file) return;
     char out_name[10];
-    sprintf(out_name, "out%d", plc_state->nbf);
+    snprintf(out_name, sizeof(out_name), "out%d", plc_state->nbf);
+    out_name[sizeof(out_name) - 1] = 0;
     int x0  = CVSD_LHIST;
     int x1  = x0 + CVSD_FS - 1;
     octave_fprintf_array_int16(oct_file, out_name, CVSD_FS, plc_state->hist+x0);
     fprintf(oct_file, "h2 = plot(b(%d:%d), %s, 'cd'); \n", x0, x1, out_name);
 
     char rest_hist_name[10];
-    sprintf(rest_hist_name, "rest%d", plc_state->nbf);
+    snprintf(rest_hist_name, sizeof(rest_hist_name), "rest%d", plc_state->nbf);
+    rest_hist_name[sizeof(rest_hist_name) - 1] = 0;
     x0  = CVSD_LHIST + CVSD_FS;
     x1  = x0 + CVSD_OLAL + CVSD_RT - 1;
     octave_fprintf_array_int16(oct_file, rest_hist_name, CVSD_OLAL + CVSD_RT, plc_state->hist+x0);
     fprintf(oct_file, "h3 = plot(b(%d:%d), %s, 'kd'); \n", x0, x1, rest_hist_name);
 
     char new_hist_name[10];
-    sprintf(new_hist_name, "hist%d", plc_state->nbf);
+    snprintf(new_hist_name, sizeof(new_hist_name), "hist%d", plc_state->nbf);
+    new_hist_name[sizeof(new_hist_name) - 1] = 0;
     octave_fprintf_array_int16(oct_file, new_hist_name, CVSD_LHIST, plc_state->hist);
     fprintf(oct_file, "h4 = plot(%s, 'r--'); \n", new_hist_name);
 
     fprintf(oct_file, "legend ([h1, h2, h3, h4], {\"hist\", \"out\", \"rest\", \"new hist\"}, \"location\", \"northeast\");\n ");
 
     char fig_name[1200];
-    sprintf(fig_name, "../%s_octave_plc_%d_%s", octave_base_name, plc_state->frame_count, octave_frame_type2str(octave_frame_type));
+    snprintf(fig_name, sizeof(fig_name), "../%s_octave_plc_%d_%s",
+             octave_base_name, plc_state->frame_count,
+             octave_frame_type2str(octave_frame_type));
+    fig_name[sizeof(fig_name) - 1] = 0;
     fprintf(oct_file, "print(hf, \"%s.jpg\", \"-djpg\");", fig_name);
 }
 #endif
 
 void btstack_cvsd_plc_bad_frame(btstack_cvsd_plc_state_t *plc_state, uint16_t num_samples, BTSTACK_CVSD_PLC_SAMPLE_FORMAT *out){
     float val;
-    int   i = 0;
+    int   i;
     float sf = 1;
     plc_state->nbf++;
     
@@ -324,38 +340,38 @@ void btstack_cvsd_plc_bad_frame(btstack_cvsd_plc_state_t *plc_state, uint16_t nu
         
         // Compute Scale Factor to Match Amplitude of Substitution Packet to that of Preceding Packet
         sf = btstack_cvsd_plc_amplitude_match(plc_state, num_samples, plc_state->hist, plc_state->bestlag);
-        for (i=0;i<CVSD_OLAL;i++){
+        for (i=0; i<CVSD_OLAL; i++){
             val = sf*plc_state->hist[plc_state->bestlag+i];
             plc_state->hist[CVSD_LHIST+i] = btstack_cvsd_plc_crop_sample(val);
         }
         
-        for (;i<num_samples;i++){
+        for (i=CVSD_OLAL; i<num_samples; i++){
             val = sf*plc_state->hist[plc_state->bestlag+i]; 
             plc_state->hist[CVSD_LHIST+i] = btstack_cvsd_plc_crop_sample(val);
         }
         
-        for (;i<(num_samples+CVSD_OLAL);i++){
+        for (i=num_samples; i<(num_samples+CVSD_OLAL); i++){
             float left  = sf*plc_state->hist[plc_state->bestlag+i];
             float right = plc_state->hist[plc_state->bestlag+i];
             val = (left*rcos[i-num_samples]) + (right*rcos[CVSD_OLAL-1-i+num_samples]);
             plc_state->hist[CVSD_LHIST+i] = btstack_cvsd_plc_crop_sample(val);
         }
 
-        for (;i<(num_samples+CVSD_RT+CVSD_OLAL);i++){
+        for (i=(num_samples+CVSD_OLAL); i<(num_samples+CVSD_RT+CVSD_OLAL); i++){
             plc_state->hist[CVSD_LHIST+i] = plc_state->hist[plc_state->bestlag+i];
         }
     } else {
-        for (;i<(num_samples+CVSD_RT+CVSD_OLAL);i++){
+        for (i=0; i<(num_samples+CVSD_RT+CVSD_OLAL); i++){
             plc_state->hist[CVSD_LHIST+i] = plc_state->hist[plc_state->bestlag+i];
         }
     }
 
-    for (i=0;i<num_samples;i++){
+    for (i=0; i<num_samples; i++){
         out[i] = plc_state->hist[CVSD_LHIST+i];
     }
     
     // shift the history buffer 
-    for (i=0;i<(CVSD_LHIST+CVSD_RT+CVSD_OLAL);i++){
+    for (i=0; i<(CVSD_LHIST+CVSD_RT+CVSD_OLAL); i++){
         plc_state->hist[i] = plc_state->hist[i+num_samples];
     }
 
@@ -444,9 +460,8 @@ static int count_zeros(BTSTACK_CVSD_PLC_SAMPLE_FORMAT * frame, uint16_t size){
     return nr_zeros;
 }
 
-// note: a zero_frame is currently also a 'bad_frame'
 static int zero_frame(BTSTACK_CVSD_PLC_SAMPLE_FORMAT * frame, uint16_t size){
-    return count_zeros(frame, size) > (size/2);
+    return count_zeros(frame, size) == size;
 }
 
 // more than half the samples are the same -> bad frame
@@ -456,23 +471,25 @@ static int bad_frame(btstack_cvsd_plc_state_t *plc_state, BTSTACK_CVSD_PLC_SAMPL
 }
 
 
-void btstack_cvsd_plc_process_data(btstack_cvsd_plc_state_t * plc_state, BTSTACK_CVSD_PLC_SAMPLE_FORMAT * in, uint16_t num_samples, BTSTACK_CVSD_PLC_SAMPLE_FORMAT * out){
+void btstack_cvsd_plc_process_data(btstack_cvsd_plc_state_t * plc_state, bool is_bad_frame, BTSTACK_CVSD_PLC_SAMPLE_FORMAT * in, uint16_t num_samples, BTSTACK_CVSD_PLC_SAMPLE_FORMAT * out){
     if (num_samples == 0) return;
 
     plc_state->frame_count++;
 
-    int is_zero_frame = zero_frame(in, num_samples);
-    int is_bad_frame  = bad_frame(plc_state, in, num_samples);
+    if (!is_bad_frame) {
+        bool is_zero_frame = zero_frame(in, num_samples);
+        if (is_zero_frame){
+            plc_state->zero_frames_nr++;
+        } else {
+            is_bad_frame = bad_frame(plc_state, in, num_samples);
+        }
+    }
 
     if (is_bad_frame){
         (void)memcpy(out, in, num_samples * 2);
         if (plc_state->good_samples > CVSD_LHIST){
             btstack_cvsd_plc_bad_frame(plc_state, num_samples, out);
-            if (is_zero_frame){
-                plc_state->zero_frames_nr++;
-            } else {
-                plc_state->bad_frames_nr++;
-            }
+            plc_state->bad_frames_nr++;
         } else {
             memset(out, 0, num_samples * 2);
         }
