@@ -20,8 +20,8 @@
  * THIS SOFTWARE IS PROVIDED BY BLUEKITCHEN GMBH AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL MATTHIAS
- * RINGWALD OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL BLUEKITCHEN
+ * GMBH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
  * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
  * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
@@ -46,8 +46,6 @@
 #include "btstack_config.h"
 
 #include <stdint.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
 #include "btstack_memory.h"
@@ -66,64 +64,63 @@
 #define HFP_GSM_MAX_NR_CALLS 3
 #define HFP_GSM_MAX_CALL_NUMBER_SIZE 25
 
-static hfp_gsm_call_t gsm_calls[HFP_GSM_MAX_NR_CALLS]; 
-static hfp_callsetup_status_t callsetup_status = HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS;
+static hfp_gsm_call_t         hfp_gsm_model_calls[HFP_GSM_MAX_NR_CALLS];
+static hfp_callsetup_status_t hfp_gsm_model_callsetup_status;
 
-static uint8_t clip_type;
-static char clip_number[HFP_GSM_MAX_CALL_NUMBER_SIZE];
-static char last_dialed_number[HFP_GSM_MAX_CALL_NUMBER_SIZE];
+static uint8_t hfp_gsm_model_clip_type;
+static char    hfp_gsm_model_clip_number[HFP_GSM_MAX_CALL_NUMBER_SIZE];
+static char    hfp_gsm_model_last_dialed_number[HFP_GSM_MAX_CALL_NUMBER_SIZE];
 
-static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t type, const char * number);
-static inline int get_number_active_calls(void);
+static inline int hfp_gsm_model_get_number_active_calls(void);
 
 static void set_callsetup_status(hfp_callsetup_status_t status){
-    callsetup_status = status;
-    if (callsetup_status != HFP_CALLSETUP_STATUS_OUTGOING_CALL_SETUP_IN_ALERTING_STATE) return;
+    hfp_gsm_model_callsetup_status = status;
+    if (hfp_gsm_model_callsetup_status != HFP_CALLSETUP_STATUS_OUTGOING_CALL_SETUP_IN_ALERTING_STATE) return;
     
     int i ;
     for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-        if (gsm_calls[i].direction == HFP_ENHANCED_CALL_DIR_OUTGOING){
-            gsm_calls[i].enhanced_status = HFP_ENHANCED_CALL_STATUS_OUTGOING_ALERTING;
+        if (hfp_gsm_model_calls[i].direction == HFP_ENHANCED_CALL_DIR_OUTGOING){
+            hfp_gsm_model_calls[i].enhanced_status = HFP_ENHANCED_CALL_STATUS_OUTGOING_ALERTING;
         }
     }
 }
 
 static inline void set_enhanced_call_status_active(int index_in_table){
     if ((index_in_table < 0) || (index_in_table > HFP_GSM_MAX_NR_CALLS)) return;
-    gsm_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_ACTIVE;
-    gsm_calls[index_in_table].used_slot = 1;
+    hfp_gsm_model_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_ACTIVE;
+    hfp_gsm_model_calls[index_in_table].used_slot = true;
 }
 
 static inline void set_enhanced_call_status_held(int index_in_table){
     if ((index_in_table < 0) || (index_in_table > HFP_GSM_MAX_NR_CALLS)) return;
-    gsm_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_HELD;
-    gsm_calls[index_in_table].used_slot = 1;
+    hfp_gsm_model_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_HELD;
+    hfp_gsm_model_calls[index_in_table].used_slot = true;
 }
 
 static inline void set_enhanced_call_status_response_hold(int index_in_table){
     if ((index_in_table < 0) || (index_in_table > HFP_GSM_MAX_NR_CALLS)) return;
-    gsm_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_CALL_HELD_BY_RESPONSE_AND_HOLD;
-    gsm_calls[index_in_table].used_slot = 1;
+    hfp_gsm_model_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_CALL_HELD_BY_RESPONSE_AND_HOLD;
+    hfp_gsm_model_calls[index_in_table].used_slot = true;
 }
 
 static inline void set_enhanced_call_status_initiated(int index_in_table){
     if ((index_in_table < 0) || (index_in_table > HFP_GSM_MAX_NR_CALLS)) return;
-    if (gsm_calls[index_in_table].direction == HFP_ENHANCED_CALL_DIR_OUTGOING){
-        gsm_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_OUTGOING_DIALING;
+    if (hfp_gsm_model_calls[index_in_table].direction == HFP_ENHANCED_CALL_DIR_OUTGOING){
+        hfp_gsm_model_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_OUTGOING_DIALING;
     } else {
-        if (get_number_active_calls() > 0){
-            gsm_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_INCOMING_WAITING;
+        if (hfp_gsm_model_get_number_active_calls() > 0){
+            hfp_gsm_model_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_INCOMING_WAITING;
         } else {
-            gsm_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_INCOMING;
+            hfp_gsm_model_calls[index_in_table].enhanced_status = HFP_ENHANCED_CALL_STATUS_INCOMING;
         }
-    } 
-    gsm_calls[index_in_table].used_slot = 1;
+    }
+    hfp_gsm_model_calls[index_in_table].used_slot = true;
 }
 
 static int get_enhanced_call_status(int index_in_table){
     if ((index_in_table < 0) || (index_in_table > HFP_GSM_MAX_NR_CALLS)) return -1;
-    if (!gsm_calls[index_in_table].used_slot) return -1;
-    return gsm_calls[index_in_table].enhanced_status;
+    if (!hfp_gsm_model_calls[index_in_table].used_slot) return -1;
+    return hfp_gsm_model_calls[index_in_table].enhanced_status;
 }
 
 static inline int is_enhanced_call_status_active(int index_in_table){
@@ -146,20 +143,28 @@ static inline int is_enhanced_call_status_initiated(int index_in_table){
 
 static void free_call_slot(int index_in_table){
     if ((index_in_table < 0) || (index_in_table > HFP_GSM_MAX_NR_CALLS)) return;
-    gsm_calls[index_in_table].used_slot = 0;
+    hfp_gsm_model_calls[index_in_table].used_slot = false;
 }
 
 void hfp_gsm_init(void){
-    set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
-    clip_type = 0;
-    memset(clip_number, 0, sizeof(clip_number));
-    memset(last_dialed_number, 0, sizeof(last_dialed_number));
-    memset(gsm_calls, 0, sizeof(gsm_calls));
+    hfp_gsm_model_callsetup_status = HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS;
+    hfp_gsm_model_clip_type = 0;
+    memset(hfp_gsm_model_clip_number, 0, sizeof(hfp_gsm_model_clip_number));
+    memset(hfp_gsm_model_last_dialed_number, 0, sizeof(hfp_gsm_model_last_dialed_number));
+    memset(hfp_gsm_model_calls, 0, sizeof(hfp_gsm_model_calls));
     int i;
     for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
         free_call_slot(i);
     }
-} 
+}
+
+void hfp_gsm_deinit(void){
+    (void) memset(hfp_gsm_model_calls, 0, sizeof(hfp_gsm_model_calls));
+    hfp_gsm_model_callsetup_status = HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS;
+    hfp_gsm_model_clip_type = 0;
+    (void) memset(hfp_gsm_model_clip_number, 0, sizeof(hfp_gsm_model_clip_number));
+    (void) memset(hfp_gsm_model_last_dialed_number, 0, sizeof(hfp_gsm_model_last_dialed_number));
+}
 
 static int get_number_calls_with_enhanced_status(hfp_enhanced_call_status_t enhanced_status){
     int i, count = 0;
@@ -188,7 +193,7 @@ static inline int get_initiated_call_index(void){
 static inline int get_next_free_slot(void){
     int i ;
     for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-        if (!gsm_calls[i].used_slot) return i;
+        if (!hfp_gsm_model_calls[i].used_slot) return i;
     }
     return -1;
 }
@@ -197,6 +202,10 @@ static inline int get_active_call_index(void){
     return get_call_index_with_enhanced_status(HFP_ENHANCED_CALL_STATUS_ACTIVE);
 }
 
+static inline int get_dialing_call_index(void){
+    return get_call_index_with_enhanced_status(HFP_ENHANCED_CALL_STATUS_OUTGOING_DIALING);
+}
+
 static inline int get_held_call_index(void){
     return get_call_index_with_enhanced_status(HFP_ENHANCED_CALL_STATUS_HELD);
 }
@@ -208,12 +217,12 @@ static inline int get_response_held_call_index(void){
 static inline int get_number_none_calls(void){
     int i, count = 0;
     for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-        if (!gsm_calls[i].used_slot) count++;
+        if (!hfp_gsm_model_calls[i].used_slot) count++;
     }
     return count;
 }
 
-static inline int get_number_active_calls(void){
+static inline int hfp_gsm_model_get_number_active_calls(void){
     return get_number_calls_with_enhanced_status(HFP_ENHANCED_CALL_STATUS_ACTIVE);
 }
 
@@ -232,44 +241,40 @@ static int next_call_index(void){
 static void hfp_gsm_set_clip(int index_in_table, uint8_t type, const char * number){
     uint16_t number_str_len = (uint16_t) strlen(number);
     if (number_str_len == 0) return;
-    
-    gsm_calls[index_in_table].clip_type = type;
-    int clip_number_size = btstack_min(number_str_len, HFP_GSM_MAX_CALL_NUMBER_SIZE - 1);
-    strncpy(gsm_calls[index_in_table].clip_number, number, clip_number_size);
-    gsm_calls[index_in_table].clip_number[clip_number_size] = '\0';
-    strncpy(last_dialed_number, number, clip_number_size);
-    last_dialed_number[clip_number_size] = '\0';
-    
-    clip_type = 0;
-    memset(clip_number, 0, sizeof(clip_number));
+
+    hfp_gsm_model_calls[index_in_table].clip_type = type;
+    btstack_strcpy(hfp_gsm_model_calls[index_in_table].clip_number, HFP_GSM_MAX_CALL_NUMBER_SIZE, number);
+    btstack_strcpy(hfp_gsm_model_last_dialed_number, HFP_GSM_MAX_CALL_NUMBER_SIZE, number);
+    hfp_gsm_model_clip_type = 0;
+    memset(hfp_gsm_model_clip_number, 0, sizeof(hfp_gsm_model_clip_number));
 }
 
 static void delete_call(int delete_index_in_table){
     int i ;
     for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-        if (gsm_calls[i].index > gsm_calls[delete_index_in_table].index){
-            gsm_calls[i].index--;
+        if (hfp_gsm_model_calls[i].index > hfp_gsm_model_calls[delete_index_in_table].index){
+            hfp_gsm_model_calls[i].index--;
         }
     }
     free_call_slot(delete_index_in_table);
-    
-    gsm_calls[delete_index_in_table].clip_type = 0;
-    gsm_calls[delete_index_in_table].index = 0;
-    gsm_calls[delete_index_in_table].clip_number[0] = '\0';
-    gsm_calls[delete_index_in_table].mpty = HFP_ENHANCED_CALL_MPTY_NOT_A_CONFERENCE_CALL;
+
+    hfp_gsm_model_calls[delete_index_in_table].clip_type = 0;
+    hfp_gsm_model_calls[delete_index_in_table].index = 0;
+    hfp_gsm_model_calls[delete_index_in_table].clip_number[0] = '\0';
+    hfp_gsm_model_calls[delete_index_in_table].mpty = HFP_ENHANCED_CALL_MPTY_NOT_A_CONFERENCE_CALL;
 }
 
 
 static void create_call(hfp_enhanced_call_dir_t direction){
     int next_free_slot = get_next_free_slot();
-    gsm_calls[next_free_slot].direction = direction;
-    gsm_calls[next_free_slot].index = next_call_index();
+    hfp_gsm_model_calls[next_free_slot].direction = direction;
+    hfp_gsm_model_calls[next_free_slot].index = next_call_index();
     set_enhanced_call_status_initiated(next_free_slot);
-    gsm_calls[next_free_slot].clip_type = 0;
-    gsm_calls[next_free_slot].clip_number[0] = '\0';
-    gsm_calls[next_free_slot].mpty = HFP_ENHANCED_CALL_MPTY_NOT_A_CONFERENCE_CALL;
+    hfp_gsm_model_calls[next_free_slot].clip_type = 0;
+    hfp_gsm_model_calls[next_free_slot].clip_number[0] = '\0';
+    hfp_gsm_model_calls[next_free_slot].mpty = HFP_ENHANCED_CALL_MPTY_NOT_A_CONFERENCE_CALL;
     
-    hfp_gsm_set_clip(next_free_slot, clip_type, clip_number);
+    hfp_gsm_set_clip(next_free_slot, hfp_gsm_model_clip_type, hfp_gsm_model_clip_number);
 }
 
 
@@ -278,18 +283,22 @@ int hfp_gsm_get_number_of_calls(void){
 }
 
 void hfp_gsm_clear_last_dialed_number(void){
-    memset(last_dialed_number, 0, sizeof(last_dialed_number));
+    memset(hfp_gsm_model_last_dialed_number, 0, sizeof(hfp_gsm_model_last_dialed_number));
 }
 
 char * hfp_gsm_last_dialed_number(void){
-    return &last_dialed_number[0];
+    return &hfp_gsm_model_last_dialed_number[0];
+}
+
+void hfp_gsm_set_last_dialed_number(const char* number){
+    btstack_strcpy(hfp_gsm_model_last_dialed_number, sizeof(hfp_gsm_model_last_dialed_number), number);
 }
 
 hfp_gsm_call_t * hfp_gsm_call(int call_index){
     int i;
 
     for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-        hfp_gsm_call_t * call = &gsm_calls[i];
+        hfp_gsm_call_t * call = &hfp_gsm_model_calls[i];
         if (call->index != call_index) continue;
         return call;
     }
@@ -297,46 +306,46 @@ hfp_gsm_call_t * hfp_gsm_call(int call_index){
 }
 
 uint8_t hfp_gsm_clip_type(void){
-    if (clip_type != 0) return clip_type;
+    if (hfp_gsm_model_clip_type != 0) return hfp_gsm_model_clip_type;
 
     int initiated_call_index = get_initiated_call_index();
     if (initiated_call_index != -1){
-        if (gsm_calls[initiated_call_index].clip_type != 0) {
-            return gsm_calls[initiated_call_index].clip_type;
+        if (hfp_gsm_model_calls[initiated_call_index].clip_type != 0) {
+            return hfp_gsm_model_calls[initiated_call_index].clip_type;
         } 
     }
 
     int active_call_index = get_active_call_index();
     if (active_call_index != -1){
-        if (gsm_calls[active_call_index].clip_type != 0) {
-            return gsm_calls[active_call_index].clip_type;
+        if (hfp_gsm_model_calls[active_call_index].clip_type != 0) {
+            return hfp_gsm_model_calls[active_call_index].clip_type;
         } 
     }
     return 0;
 }
 
 char *  hfp_gsm_clip_number(void){
-    if (strlen(clip_number) != 0) return clip_number;
+    if (strlen(hfp_gsm_model_clip_number) != 0) return hfp_gsm_model_clip_number;
     
     int initiated_call_index = get_initiated_call_index();
     if (initiated_call_index != -1){
-        if (gsm_calls[initiated_call_index].clip_type != 0) {
-            return gsm_calls[initiated_call_index].clip_number;
+        if (hfp_gsm_model_calls[initiated_call_index].clip_type != 0) {
+            return hfp_gsm_model_calls[initiated_call_index].clip_number;
         } 
     }
 
     int active_call_index = get_active_call_index();
     if (active_call_index != -1){
-        if (gsm_calls[active_call_index].clip_type != 0) {
-            return gsm_calls[active_call_index].clip_number;
+        if (hfp_gsm_model_calls[active_call_index].clip_type != 0) {
+            return hfp_gsm_model_calls[active_call_index].clip_number;
         } 
     }
-    clip_number[0] = 0;
-    return clip_number;
+    hfp_gsm_model_clip_number[0] = 0;
+    return hfp_gsm_model_clip_number;
 }
 
 hfp_call_status_t hfp_gsm_call_status(void){
-    if (get_number_active_calls() + get_number_held_calls() + get_number_response_held_calls()){
+    if (hfp_gsm_model_get_number_active_calls() + get_number_held_calls() + get_number_response_held_calls()){
         return HFP_CALL_STATUS_ACTIVE_OR_HELD_CALL_IS_PRESENT;
     }
     return HFP_CALL_STATUS_NO_HELD_OR_ACTIVE_CALLS;
@@ -347,14 +356,14 @@ hfp_callheld_status_t hfp_gsm_callheld_status(void){
     if (get_number_held_calls() == 0){
         return HFP_CALLHELD_STATUS_NO_CALLS_HELD;
     }
-    if (get_number_active_calls() == 0) {
+    if (hfp_gsm_model_get_number_active_calls() == 0) {
         return HFP_CALLHELD_STATUS_CALL_ON_HOLD_AND_NO_ACTIVE_CALLS;
     }
     return HFP_CALLHELD_STATUS_CALL_ON_HOLD_OR_SWAPPED;
 }
 
 hfp_callsetup_status_t hfp_gsm_callsetup_status(void){
-    return callsetup_status;
+    return hfp_gsm_model_callsetup_status;
 }
 
 static int hfp_gsm_response_held_active(void){
@@ -365,23 +374,7 @@ int hfp_gsm_call_possible(void){
     return get_number_none_calls() > 0;
 }
 
-void hfp_gsm_handle_event(hfp_ag_call_event_t event){
-    hfp_gsm_handler(event, 0, 0, NULL);
-}
-
-void hfp_gsm_handle_event_with_clip(hfp_ag_call_event_t event, uint8_t type, const char * number){
-    hfp_gsm_handler(event, 0, type, number);
-}
-
-void hfp_gsm_handle_event_with_call_index(hfp_ag_call_event_t event, uint8_t index){
-    hfp_gsm_handler(event, index, 0, NULL);
-}
-
-void hfp_gsm_handle_event_with_call_number(hfp_ag_call_event_t event, const char * number){
-    hfp_gsm_handler(event, 0, 0, number);
-}
-
-static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t type, const char * number){
+void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t type, const char * number){
     int next_free_slot = get_next_free_slot();
     int current_call_index = get_active_call_index();
     int initiated_call_index = get_initiated_call_index();
@@ -389,7 +382,8 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
     int i;
 
     switch (event){
-        case HFP_AG_OUTGOING_CALL_INITIATED:
+        case HFP_AG_OUTGOING_CALL_INITIATED_BY_HF:
+        case HFP_AG_OUTGOING_CALL_INITIATED_BY_AG:
         case HFP_AG_OUTGOING_REDIAL_INITIATED:
             if (next_free_slot == -1){
                 log_error("gsm: max call nr exceeded");
@@ -413,6 +407,7 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
             break;
         
         case HFP_AG_OUTGOING_CALL_RINGING:
+            current_call_index = get_dialing_call_index();
             if (current_call_index == -1){
                 log_error("gsm: no active call");
                 return;
@@ -444,7 +439,7 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
             if (hfp_gsm_call_status() != HFP_CALL_STATUS_ACTIVE_OR_HELD_CALL_IS_PRESENT) break;
             
             // TODO: is following condition correct? Can we join incoming call before it is answered?
-            if (callsetup_status == HFP_CALLSETUP_STATUS_INCOMING_CALL_SETUP_IN_PROGRESS){
+            if (hfp_gsm_model_callsetup_status == HFP_CALLSETUP_STATUS_INCOMING_CALL_SETUP_IN_PROGRESS){
                 set_enhanced_call_status_active(initiated_call_index);
                 set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
             } else if (hfp_gsm_callheld_status() == HFP_CALLHELD_STATUS_CALL_ON_HOLD_OR_SWAPPED) {
@@ -453,7 +448,7 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
 
             for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
                 if (is_enhanced_call_status_active(i)){
-                    gsm_calls[i].mpty = HFP_ENHANCED_CALL_MPTY_CONFERENCE_CALL;
+                    hfp_gsm_model_calls[i].mpty = HFP_ENHANCED_CALL_MPTY_CONFERENCE_CALL;
                 }
             }
             break;
@@ -470,7 +465,7 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
             if (hfp_gsm_callsetup_status() != HFP_CALLSETUP_STATUS_INCOMING_CALL_SETUP_IN_PROGRESS) break;
             if (hfp_gsm_call_status() != HFP_CALL_STATUS_NO_HELD_OR_ACTIVE_CALLS) break;
             set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
-            set_enhanced_call_status_response_hold(initiated_call_index); 
+            set_enhanced_call_status_response_hold(initiated_call_index);
             break;
 
         case HFP_AG_RESPONSE_AND_HOLD_ACCEPT_HELD_CALL_BY_AG:
@@ -494,28 +489,24 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
                 case HFP_CALL_STATUS_ACTIVE_OR_HELD_CALL_IS_PRESENT:
                     delete_call(current_call_index);
                     break;
-            }
-            break;
-
-        case HFP_AG_TERMINATE_CALL_BY_AG:
-            switch (hfp_gsm_call_status()){
-                case HFP_CALL_STATUS_NO_HELD_OR_ACTIVE_CALLS:
-                    if (hfp_gsm_callsetup_status() != HFP_CALLSETUP_STATUS_INCOMING_CALL_SETUP_IN_PROGRESS) break;
-                    set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
-                    break;
-                case HFP_CALL_STATUS_ACTIVE_OR_HELD_CALL_IS_PRESENT:
-                    set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
-                    delete_call(current_call_index);
-                    break;
                 default:
                     break;
             }
             break;
 
+        case HFP_AG_TERMINATE_CALL_BY_AG:
+            set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
+            if (current_call_index != -1){
+                delete_call(current_call_index);
+                break;
+            }
+            if (initiated_call_index != -1){
+                delete_call(initiated_call_index);
+            }
+            break;
+
         case HFP_AG_CALL_DROPPED:
             set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
-            if (hfp_gsm_call_status() != HFP_CALL_STATUS_ACTIVE_OR_HELD_CALL_IS_PRESENT) break;
-            
             for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
                 delete_call(i);
             }
@@ -531,7 +522,7 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
         case HFP_AG_CALL_HOLD_RELEASE_ACTIVE_ACCEPT_HELD_OR_WAITING_CALL:
             if ((index != 0) && (index <= HFP_GSM_MAX_NR_CALLS) ){
                 for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-                    if (gsm_calls[i].index == index){
+                    if (hfp_gsm_model_calls[i].index == index){
                         delete_call(i);
                         continue;
                     }
@@ -544,23 +535,23 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
                 }    
             }
             
-            if (callsetup_status != HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS){
+            if (hfp_gsm_model_callsetup_status != HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS){
                 set_enhanced_call_status_active(initiated_call_index);
             } else {
                 set_enhanced_call_status_active(held_call_index);
             }
-            
+
             set_callsetup_status(HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS);
             break;
         
         case HFP_AG_CALL_HOLD_PARK_ACTIVE_ACCEPT_HELD_OR_WAITING_CALL:
             for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-                if (is_enhanced_call_status_active(i) && (gsm_calls[i].index != index)){
+                if (is_enhanced_call_status_active(i) && (hfp_gsm_model_calls[i].index != index)){
                     set_enhanced_call_status_held(i);
                 }
             }
             
-            if (callsetup_status != HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS){
+            if (hfp_gsm_model_callsetup_status != HFP_CALLSETUP_STATUS_NO_CALL_SETUP_IN_PROGRESS){
                 set_enhanced_call_status_active(initiated_call_index);
             } else {
                 set_enhanced_call_status_active(held_call_index);
@@ -571,9 +562,9 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
         case HFP_AG_CALL_HOLD_ADD_HELD_CALL:
             if (hfp_gsm_callheld_status() != HFP_CALLHELD_STATUS_NO_CALLS_HELD){
                 for (i = 0; i < HFP_GSM_MAX_NR_CALLS; i++){
-                    if (gsm_calls[i].used_slot){
+                    if (hfp_gsm_model_calls[i].used_slot){
                         set_enhanced_call_status_active(i);
-                        gsm_calls[i].mpty = HFP_ENHANCED_CALL_MPTY_CONFERENCE_CALL;
+                        hfp_gsm_model_calls[i].mpty = HFP_ENHANCED_CALL_MPTY_CONFERENCE_CALL;
                     }
                 }
             }
@@ -591,10 +582,8 @@ static void hfp_gsm_handler(hfp_ag_call_event_t event, uint8_t index, uint8_t ty
                 break;
             }
 
-            clip_type = type;
-            strncpy(clip_number, number, sizeof(clip_number));
-            clip_number[sizeof(clip_number)-1] = '\0';
-
+            hfp_gsm_model_clip_type = type;
+            btstack_strcpy(hfp_gsm_model_clip_number, sizeof(hfp_gsm_model_clip_number), number);
             break;
         default:
             break;
