@@ -2,8 +2,8 @@
 // btstack_config.h for Arduino port
 //
 
-#ifndef __BTSTACK_CONFIG
-#define __BTSTACK_CONFIG
+#ifndef BTSTACK_CONFIG_H
+#define BTSTACK_CONFIG_H
 
 // Port related features
 #define HAVE_POSIX_TIME
@@ -13,7 +13,8 @@
 #define ENABLE_CLASSIC
 #define ENABLE_LOG_DEBUG
 #define ENABLE_LOG_ERROR
-#define ENABLE_LOG_INFO 
+#define ENABLE_LOG_INFO
+#define ENABLE_PRINTF_HEXDUMP
 #define ENABLE_SDP_DES_DUMP
 #define ENABLE_SDP_EXTRA_QUERIES
 
@@ -21,20 +22,20 @@
 #define HCI_ACL_PAYLOAD_SIZE 52
 #define HCI_INCOMING_PRE_BUFFER_SIZE 4
 
-#define MAX_NR_HCI_CONNECTIONS 0
+#define MAX_NR_BNEP_CHANNELS 0
+#define MAX_NR_BNEP_SERVICES 0
+#define MAX_NR_BTSTACK_LINK_KEY_DB_MEMORY_ENTRIES  2
 #define MAX_NR_GATT_CLIENTS 0
 #define MAX_NR_GATT_SUBCLIENTS 0
-#define MAX_NR_L2CAP_SERVICES  0
+#define MAX_NR_HCI_CONNECTIONS 0
+#define MAX_NR_HFP_CONNECTIONS 0
 #define MAX_NR_L2CAP_CHANNELS  0
+#define MAX_NR_L2CAP_SERVICES  0
+#define MAX_NR_RFCOMM_CHANNELS 0
 #define MAX_NR_RFCOMM_MULTIPLEXERS 0
 #define MAX_NR_RFCOMM_SERVICES 0
-#define MAX_NR_RFCOMM_CHANNELS 0
-#define MAX_NR_BNEP_SERVICES 0
-#define MAX_NR_BNEP_CHANNELS 0
-#define MAX_NR_BTSTACK_LINK_KEY_DB_MEMORY_ENTRIES  2
-#define MAX_NR_HFP_CONNECTIONS 0
-#define MAX_NR_WHITELIST_ENTRIES 0
-#define MAX_NR_SM_LOOKUP_ENTRIES 0
 #define MAX_NR_SERVICE_RECORD_ITEMS 0
+#define MAX_NR_SM_LOOKUP_ENTRIES 0
+#define MAX_NR_WHITELIST_ENTRIES 0
 
 #endif
