@@ -44,7 +44,9 @@
 #include "CppUTest/TestHarness.h"
 #include "CppUTest/CommandLineTestRunner.h"
 
+#include "btstack_event.h"
 #include "classic/hfp.h"
+#include "classic/hfp_hf.h"
 #include "classic/hfp_ag.h"
 
 void hfp_parse(hfp_connection_t * context, uint8_t byte, int isHandsFree);
@@ -65,6 +67,14 @@ static uint8_t call_status_index = 2;
 static uint8_t callsetup_status_index = 3;
 static uint8_t callheld_status_index = 7;
 
+// #define LOG_LINE_BUFFER
+static void hfp_at_parser_test_dump_line_buffer(void){
+#ifdef LOG_LINE_BUFFER
+    uint16_t line_len = strlen(reinterpret_cast<const char *>(context.line_buffer));
+    printf("\nLine buffer: %s\n", context.line_buffer);
+    printf_hexdump(context.line_buffer, line_len);
+#endif
+}
 
 static void parse_ag(const char * packet){
     for (uint16_t pos = 0; pos < strlen(packet); pos++){
@@ -84,6 +94,7 @@ TEST_GROUP(HFPParser){
     int offset;
 
     void setup(void){
+        hfp_init();
         memset(&context, 0, sizeof(hfp_connection_t));
         context.parser_state = HFP_PARSER_CMD_HEADER;
         context.parser_item_index = 0;
@@ -94,29 +105,33 @@ TEST_GROUP(HFPParser){
         context.bnip_type = 0;
         memset(packet,0, sizeof(packet));
     }
+
+    void teardown(void){
+        hfp_deinit();
+    }
 };
 
 TEST(HFPParser, HFP_HF_OK){
-    sprintf(packet, "\r\n%s\r\n", HFP_OK);
+    snprintf(packet, sizeof(packet), "\r\n%s\r\n", HFP_OK);
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_OK, context.command);
 }
 
 TEST(HFPParser, HFP_HF_SUPPORTED_FEATURES){
-    sprintf(packet, "\r\n%s:1007\r\n\r\nOK\r\n", HFP_SUPPORTED_FEATURES);
+    snprintf(packet, sizeof(packet), "\r\n%s:1007\r\n\r\nOK\r\n", HFP_SUPPORTED_FEATURES);
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_OK, context.command);
     CHECK_EQUAL(1007, context.remote_supported_features);
 }
 
 TEST(HFPParser, HFP_CMD_INDICATORS_QUERY){
-    sprintf(packet, "\r\nAT%s?\r\n", HFP_INDICATOR);
+    snprintf(packet, sizeof(packet), "\r\nAT%s?\r\n", HFP_INDICATOR);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_RETRIEVE_AG_INDICATORS_STATUS, context.command);
 }
 
 TEST(HFPParser, HFP_CMD_INDICATORS_RETRIEVE){
-    sprintf(packet, "\r\nAT%s=?\r\n", HFP_INDICATOR);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=?\r\n", HFP_INDICATOR);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_RETRIEVE_AG_INDICATORS, context.command);
 }
@@ -187,7 +202,7 @@ TEST(HFPParser, HFP_HF_INDICATOR_STATUS){
 }
 
 TEST(HFPParser, HFP_HF_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES_TEST){
-    sprintf(packet, "\r\nAT%s=?\r\n", HFP_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=?\r\n", HFP_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES, context.command);
 }
@@ -195,7 +210,7 @@ TEST(HFPParser, HFP_HF_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES_TEST){
 TEST(HFPParser, HFP_HF_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES_SET){
     int action = 1;
     int call_index = 2;
-    sprintf(packet, "\r\nAT%s=%u%u\r\n", HFP_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES, action, call_index);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=%u%u\r\n", HFP_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES, action, call_index);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_CALL_HOLD, context.command);
     CHECK_EQUAL(action, context.ag_call_hold_action);
@@ -203,7 +218,7 @@ TEST(HFPParser, HFP_HF_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES_SET){
 }
 
 TEST(HFPParser, HFP_HF_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES){
-    sprintf(packet, "\r\n%s:(1,1x,2,2x,3)\r\n\r\nOK\r\n", HFP_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES);
+    snprintf(packet, sizeof(packet), "\r\n%s:(1,1x,2,2x,3)\r\n\r\nOK\r\n", HFP_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES);
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_OK, context.command);
     CHECK_EQUAL(5, context.remote_call_services_index);
@@ -216,26 +231,28 @@ TEST(HFPParser, HFP_HF_SUPPORT_CALL_HOLD_AND_MULTIPARTY_SERVICES){
 } 
 
 TEST(HFPParser, HFP_GENERIC_STATUS_INDICATOR_TEST){
-    sprintf(packet, "\r\nAT%s=?\r\n", HFP_GENERIC_STATUS_INDICATOR);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=?\r\n", HFP_GENERIC_STATUS_INDICATOR);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_RETRIEVE_GENERIC_STATUS_INDICATORS, context.command);
 }
 
 TEST(HFPParser, HFP_GENERIC_STATUS_INDICATOR_SET){
-    int param = 1;
-    sprintf(packet, "\r\nAT%s=%u\r\n", HFP_GENERIC_STATUS_INDICATOR, param);
+    int param1 = 1;
+    int param2 = 2;
+    int param3 = 3;
+    snprintf(packet, sizeof(packet), "\r\nAT%s= %u,%u,%u\r\n", HFP_GENERIC_STATUS_INDICATOR, param1, param2, param3);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_LIST_GENERIC_STATUS_INDICATORS, context.command);
 }
 
 TEST(HFPParser, HFP_GENERIC_STATUS_INDICATOR_READ){
-    sprintf(packet, "\r\nAT%s?\r\n", HFP_GENERIC_STATUS_INDICATOR);
+    snprintf(packet, sizeof(packet), "\r\nAT%s?\r\n", HFP_GENERIC_STATUS_INDICATOR);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_RETRIEVE_GENERIC_STATUS_INDICATORS_STATE, context.command);
 }
 
 TEST(HFPParser, HFP_HF_GENERIC_STATUS_INDICATOR_STATE){
-    sprintf(packet, "\r\n%s:0,1\r\n\r\nOK\r\n", HFP_GENERIC_STATUS_INDICATOR);
+    snprintf(packet, sizeof(packet), "\r\n%s:0,1\r\n\r\nOK\r\n", HFP_GENERIC_STATUS_INDICATOR);
     // context.command = HFP_CMD_RETRIEVE_GENERIC_STATUS_INDICATORS_STATE;
     context.state = HFP_W4_RETRIEVE_INITITAL_STATE_GENERIC_STATUS_INDICATORS;
 
@@ -251,7 +268,7 @@ TEST(HFPParser, HFP_HF_AG_INDICATOR_STATUS_UPDATE){
     uint8_t index = 4;
     uint8_t status = 5;
 
-    sprintf(packet, "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
+    snprintf(packet, sizeof(packet), "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
 
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_OK, context.command);
@@ -259,7 +276,7 @@ TEST(HFPParser, HFP_HF_AG_INDICATOR_STATUS_UPDATE){
 }
 
 TEST(HFPParser, HFP_HF_AG_QUERY_OPERATOR_SELECTION){
-    sprintf(packet, "\r\n%s:1,0,\"sunrise\"\r\n\r\nOK\r\n", HFP_QUERY_OPERATOR_SELECTION);
+    snprintf(packet, sizeof(packet), "\r\n%s:1,0,\"sunrise\"\r\n\r\nOK\r\n", HFP_QUERY_OPERATOR_SELECTION);
     
     context.command = HFP_CMD_QUERY_OPERATOR_SELECTION_NAME;
 
@@ -270,14 +287,14 @@ TEST(HFPParser, HFP_HF_AG_QUERY_OPERATOR_SELECTION){
 }
 
 TEST(HFPParser, HFP_HF_ERROR){
-    sprintf(packet, "\r\n%s\r\n", HFP_ERROR);
+    snprintf(packet, sizeof(packet), "\r\n%s\r\n", HFP_ERROR);
 
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_ERROR, context.command);
 }
 
 TEST(HFPParser, HFP_HF_EXTENDED_AUDIO_GATEWAY_ERROR){
-    sprintf(packet, "\r\n%s:%d\r\n", HFP_EXTENDED_AUDIO_GATEWAY_ERROR, HFP_CME_ERROR_NO_NETWORK_SERVICE);
+    snprintf(packet, sizeof(packet), "\r\n%s:%d\r\n", HFP_EXTENDED_AUDIO_GATEWAY_ERROR, HFP_CME_ERROR_NO_NETWORK_SERVICE);
 
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_EXTENDED_AUDIO_GATEWAY_ERROR, context.command);
@@ -291,21 +308,21 @@ TEST(HFPParser, HFP_HF_AG_INDICATOR_CALLS_STATUS_UPDATE){
 
     // call status
     uint8_t index = call_status_index;
-    sprintf(packet, "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
+    snprintf(packet, sizeof(packet), "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_OK, context.command);
     CHECK_EQUAL(status, context.ag_indicators[index - 1].status);
 
     // callsetup status
     index = callsetup_status_index;
-    sprintf(packet, "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
+    snprintf(packet, sizeof(packet), "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_OK, context.command);
     CHECK_EQUAL(status, context.ag_indicators[index - 1].status);
 
     // callheld status
     index = callheld_status_index;
-    sprintf(packet, "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
+    snprintf(packet, sizeof(packet), "\r\n%s:%d,%d\r\n\r\nOK\r\n", HFP_TRANSFER_AG_INDICATOR_STATUS, index, status);
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_OK, context.command);
     CHECK_EQUAL(status, context.ag_indicators[index - 1].status);
@@ -338,7 +355,7 @@ TEST(HFPParser, HFP_LIST_CURRENT_CALLS_2){
 }
 
 TEST(HFPParser, HFP_AG_SUPPORTED_FEATURES){
-    sprintf(packet, "\r\nAT%s=159\r\n", HFP_SUPPORTED_FEATURES);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=159\r\n", HFP_SUPPORTED_FEATURES);
     //context.keep_separator = 0;
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_SUPPORTED_FEATURES, context.command);
@@ -346,7 +363,7 @@ TEST(HFPParser, HFP_AG_SUPPORTED_FEATURES){
 }
 
 TEST(HFPParser, HFP_AG_AVAILABLE_CODECS){
-    sprintf(packet, "\r\nAT%s=0,1,2\r\n", HFP_AVAILABLE_CODECS);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=0,1,2\r\n", HFP_AVAILABLE_CODECS);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_AVAILABLE_CODECS, context.command);
     CHECK_EQUAL(3, context.remote_codecs_nr);
@@ -356,7 +373,7 @@ TEST(HFPParser, HFP_AG_AVAILABLE_CODECS){
 }
 
 TEST(HFPParser, HFP_AG_GENERIC_STATUS_INDICATOR){
-    sprintf(packet, "\r\nAT%s=0,1,2,3,4\r\n", HFP_GENERIC_STATUS_INDICATOR);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=0,1,2,3,4\r\n", HFP_GENERIC_STATUS_INDICATOR);
     parse_ag(packet);
     CHECK_EQUAL(context.command, HFP_CMD_LIST_GENERIC_STATUS_INDICATORS);
     CHECK_EQUAL(5, context.generic_status_indicators_nr);
@@ -367,7 +384,7 @@ TEST(HFPParser, HFP_AG_GENERIC_STATUS_INDICATOR){
 }
 
 TEST(HFPParser, HFP_AG_ENABLE_INDICATOR_STATUS_UPDATE){
-    sprintf(packet, "\r\nAT%s=3,0,0,1\r\n", HFP_ENABLE_STATUS_UPDATE_FOR_AG_INDICATORS);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=3,0,0,1\r\n", HFP_ENABLE_STATUS_UPDATE_FOR_AG_INDICATORS);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_ENABLE_INDICATOR_STATUS_UPDATE, context.command);
     CHECK_EQUAL(1, context.enable_status_update_for_ag_indicators);
@@ -384,7 +401,7 @@ TEST(HFPParser, HFP_AG_ENABLE_INDIVIDUAL_INDICATOR_STATUS_UPDATE){
         CHECK_EQUAL(hfp_ag_indicators[pos].index,   context.ag_indicators[pos].index);
         CHECK_EQUAL(hfp_ag_indicators[pos].enabled, context.ag_indicators[pos].enabled);
     }
-    sprintf(packet, "\r\nAT%s=0,0,0,0,0,0,0\r\n", 
+    snprintf(packet, sizeof(packet), "\r\nAT%s=0,0,0,0,0,0,0\r\n", 
         HFP_UPDATE_ENABLE_STATUS_FOR_INDIVIDUAL_AG_INDICATORS);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_ENABLE_INDIVIDUAL_AG_INDICATOR_STATUS_UPDATE, context.command);
@@ -405,7 +422,7 @@ TEST(HFPParser, HFP_AG_ENABLE_INDIVIDUAL_INDICATOR_STATUS_UPDATE_OPT_VALUES3){
     context.ag_indicators_nr = hfp_ag_indicators_nr;
     memcpy(context.ag_indicators, hfp_ag_indicators, hfp_ag_indicators_nr * sizeof(hfp_ag_indicator_t));
 
-    sprintf(packet, "\r\nAT%s=,1,,,,,1\r\n", 
+    snprintf(packet, sizeof(packet), "\r\nAT%s=,1,,,,,1\r\n", 
         HFP_UPDATE_ENABLE_STATUS_FOR_INDIVIDUAL_AG_INDICATORS);
     parse_ag(packet);
 
@@ -424,7 +441,7 @@ TEST(HFPParser, HFP_AG_ENABLE_INDIVIDUAL_INDICATOR_STATUS_UPDATE_OPT_VALUES2){
     context.ag_indicators_nr = hfp_ag_indicators_nr;
     memcpy(context.ag_indicators, hfp_ag_indicators, hfp_ag_indicators_nr * sizeof(hfp_ag_indicator_t));
 
-    sprintf(packet, "\r\nAT%s=1,,,1,1,1,\r\n", 
+    snprintf(packet, sizeof(packet), "\r\nAT%s=1,,,1,1,1,\r\n", 
         HFP_UPDATE_ENABLE_STATUS_FOR_INDIVIDUAL_AG_INDICATORS);
     parse_ag(packet);
 
@@ -441,7 +458,7 @@ TEST(HFPParser, HFP_AG_ENABLE_INDIVIDUAL_INDICATOR_STATUS_UPDATE_OPT_VALUES1){
     context.ag_indicators_nr = hfp_ag_indicators_nr;
     memcpy(context.ag_indicators, hfp_ag_indicators, hfp_ag_indicators_nr * sizeof(hfp_ag_indicator_t));
 
-    sprintf(packet, "\r\nAT%s=1,,,1,1,1,\r\n", 
+    snprintf(packet, sizeof(packet), "\r\nAT%s=1,,,1,1,1,\r\n", 
         HFP_UPDATE_ENABLE_STATUS_FOR_INDIVIDUAL_AG_INDICATORS);
     parse_ag(packet);
 
@@ -455,13 +472,13 @@ TEST(HFPParser, HFP_AG_ENABLE_INDIVIDUAL_INDICATOR_STATUS_UPDATE_OPT_VALUES1){
 
 TEST(HFPParser, HFP_AG_HF_QUERY_OPERATOR_SELECTION){
     context.network_operator.format = 0xff;
-    sprintf(packet, "\r\nAT%s=3,0\r\n", HFP_QUERY_OPERATOR_SELECTION);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=3,0\r\n", HFP_QUERY_OPERATOR_SELECTION);
 
     parse_ag(packet);
     CHECK_EQUAL(0, context.operator_name_changed);
     CHECK_EQUAL(HFP_CMD_QUERY_OPERATOR_SELECTION_NAME_FORMAT, context.command);
     
-    sprintf(packet, "\r\nAT%s?\r\n", HFP_QUERY_OPERATOR_SELECTION);
+    snprintf(packet, sizeof(packet), "\r\nAT%s?\r\n", HFP_QUERY_OPERATOR_SELECTION);
 
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_QUERY_OPERATOR_SELECTION_NAME, context.command);
@@ -469,7 +486,7 @@ TEST(HFPParser, HFP_AG_HF_QUERY_OPERATOR_SELECTION){
 }
 
 TEST(HFPParser, HFP_AG_EXTENDED_AUDIO_GATEWAY_ERROR){
-    sprintf(packet, "\r\nAT%s=1\r\n", HFP_ENABLE_EXTENDED_AUDIO_GATEWAY_ERROR);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=1\r\n", HFP_ENABLE_EXTENDED_AUDIO_GATEWAY_ERROR);
 
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_ENABLE_EXTENDED_AUDIO_GATEWAY_ERROR, context.command );
@@ -477,14 +494,14 @@ TEST(HFPParser, HFP_AG_EXTENDED_AUDIO_GATEWAY_ERROR){
 }
 
 TEST(HFPParser, HFP_AG_TRIGGER_CODEC_CONNECTION_SETUP){
-    sprintf(packet, "\r\nAT%s\r\n", HFP_TRIGGER_CODEC_CONNECTION_SETUP);
+    snprintf(packet, sizeof(packet), "\r\nAT%s\r\n", HFP_TRIGGER_CODEC_CONNECTION_SETUP);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_TRIGGER_CODEC_CONNECTION_SETUP, context.command);
 }
 
 TEST(HFPParser, HFP_AG_CONFIRM_COMMON_CODEC){
     int codec = 2;
-    sprintf(packet, "\r\nAT%s=%d\r\n", HFP_CONFIRM_COMMON_CODEC, codec);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=%d\r\n", HFP_CONFIRM_COMMON_CODEC, codec);
 
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_HF_CONFIRMED_CODEC, context.command );
@@ -500,20 +517,20 @@ TEST(HFPParser, HFP_AG_DIAL){
 }
 
 TEST(HFPParser, HFP_ANSWER_CALL){
-    sprintf(packet, "\r\n%s\r\n", HFP_ANSWER_CALL);
+    snprintf(packet, sizeof(packet), "\r\n%s\r\n", HFP_ANSWER_CALL);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_CALL_ANSWERED, context.command);
 }
 
 TEST(HFPParser, HFP_CMD_RESPONSE_AND_HOLD_QUERY){
-    sprintf(packet, "\r\nAT%s?\r\n", HFP_RESPONSE_AND_HOLD);
+    snprintf(packet, sizeof(packet), "\r\nAT%s?\r\n", HFP_RESPONSE_AND_HOLD);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_RESPONSE_AND_HOLD_QUERY, context.command);
 }
 
 TEST(HFPParser, HFP_CMD_RESPONSE_AND_HOLD_COMMAND){
     int param = 1;
-    sprintf(packet, "\r\nAT%s=%u\r\n", HFP_RESPONSE_AND_HOLD, param);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=%u\r\n", HFP_RESPONSE_AND_HOLD, param);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_RESPONSE_AND_HOLD_COMMAND, context.command);
     CHECK_EQUAL(param, context.ag_response_and_hold_action);
@@ -521,14 +538,14 @@ TEST(HFPParser, HFP_CMD_RESPONSE_AND_HOLD_COMMAND){
 
 TEST(HFPParser, HFP_CMD_RESPONSE_AND_HOLD_STATUS){
     int status = 1;
-    sprintf(packet, "\r\n%s:%u\r\n", HFP_RESPONSE_AND_HOLD, status);
+    snprintf(packet, sizeof(packet), "\r\n%s:%u\r\n", HFP_RESPONSE_AND_HOLD, status);
     parse_hf(packet);
     CHECK_EQUAL(HFP_CMD_RESPONSE_AND_HOLD_STATUS, context.command);
 }
 
 TEST(HFPParser, HFP_CMD_ENABLE_CLIP){
     int param = 1;
-    sprintf(packet, "\r\nAT%s=%u\r\n", HFP_ENABLE_CLIP, param);
+    snprintf(packet, sizeof(packet), "\r\nAT%s=%u\r\n", HFP_ENABLE_CLIP, param);
     parse_ag(packet);
     CHECK_EQUAL(HFP_CMD_ENABLE_CLIP, context.command);
     CHECK_EQUAL(param, context.clip_enabled);
@@ -582,6 +599,58 @@ TEST(HFPParser, HFP_CMD_AG_SENT_CALL_WAITING_INFORMATION){
     STRCMP_EQUAL("BlueKitchen GmbH", (const char *)context.line_buffer);
 }
 
+TEST(HFPParser, custom_command_hf){
+    hfp_custom_at_command_t custom_hf_command = {
+            .command = "+FOO:",
+            .command_id = 1
+    };
+    const char * custom_hf_command_string = "\r\n+FOO:1,2,3\r\n";
+    hfp_register_custom_hf_command(&custom_hf_command);
+    parse_hf(custom_hf_command_string);
+    CHECK_EQUAL(1, context.custom_at_command_id);
+    STRCMP_EQUAL("+FOO:1,2,3", (const char *)context.line_buffer);
+    hfp_at_parser_test_dump_line_buffer();
+}
+
+TEST(HFPParser, custom_command_ag_with_colon){
+    hfp_custom_at_command_t custom_ag_command = {
+            .command = "AT+FOO:",
+            .command_id = 2
+    };
+    const char * custom_hf_command_string = "\r\nAT+FOO:1,2,3\r\n";
+    hfp_register_custom_ag_command(&custom_ag_command);
+    parse_ag(custom_hf_command_string);
+    CHECK_EQUAL(2, context.custom_at_command_id);
+    STRCMP_EQUAL("AT+FOO:1,2,3", (const char *)context.line_buffer);
+    hfp_at_parser_test_dump_line_buffer();
+}
+
+TEST(HFPParser, custom_command_ag_with_question){
+    hfp_custom_at_command_t custom_ag_command = {
+            .command = "AT+FOO?",
+            .command_id = 3
+    };
+    const char * custom_hf_command_string = "\r\nAT+FOO?\r\n";
+    hfp_register_custom_ag_command(&custom_ag_command);
+    parse_ag(custom_hf_command_string);
+    CHECK_EQUAL(3, context.custom_at_command_id);
+    STRCMP_EQUAL("AT+FOO?", (const char *)context.line_buffer);
+    hfp_at_parser_test_dump_line_buffer();
+}
+
+TEST(HFPParser, custom_command_hf_with_assignment){
+    hfp_custom_at_command_t custom_ag_command = {
+            .command = "AT+TEST=",
+            .command_id = 3
+    };
+    const char * custom_hf_command_string = "\r\nAT+TEST=ABCDE\r\n";
+    hfp_register_custom_ag_command(&custom_ag_command);
+    parse_ag(custom_hf_command_string);
+    CHECK_EQUAL(3, context.custom_at_command_id);
+    STRCMP_EQUAL("AT+TEST=ABCDE", (const char *)context.line_buffer);
+    hfp_at_parser_test_dump_line_buffer();
+}
+
 int main (int argc, const char * argv[]){
     return CommandLineTestRunner::RunAllTests(argc, argv);
 }
