@@ -359,7 +359,7 @@ const char * TC_AG_SLC_BV_09_I[] = {
     "AT+BIND=1,99" ,
     "OK" ,
     "AT+BIND=?" ,
-    "+BIND:(1,2,)" ,
+    "+BIND:(1,2)" ,
     "OK" ,
     "AT+BIND?" ,
     "+BIND:1,1",
@@ -431,7 +431,7 @@ const char * TC_HF_SLC_BV_01_C[] = {
     "AT+CMER=3,0,0,1" ,
     "OK" ,
     "AT+CHLD=?" ,
-    "+CHLD: (0,1,1x,2,2x,3,4)" ,
+    "+CHLD: (0,1,1x,2,2x,3,f4)" ,
     "OK" ,
     "USER:Q", 
     "+BSIR: 0" ,
@@ -2412,10 +2412,10 @@ const char * TC_AG_RHH_BV_01_I[] = {
     "AT+CMEE=1" ,
     "OK" ,
     "AT+BTRH?" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "USER:X" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV:2,0" ,
     "USER:t"
 };
@@ -2451,12 +2451,12 @@ const char * TC_AG_RHH_BV_02_I[] = {
     "RING" ,
     "+CLIP: \"1234567\",129" ,
     "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV:2,1" ,
     "+CIEV:3,0" ,
     "OK",
     "USER:X" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV:2,0" ,
     "USER:t"
 };
@@ -2492,11 +2492,11 @@ const char * TC_AG_RHH_BV_03_I[] = {
     "RING" ,
     "+CLIP: \"1234567\",129" ,
     "USER:w" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV:2,1" ,
     "+CIEV:3,0" ,
     "USER:X" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV:2,0" ,
     "USER:t"
 };
@@ -2530,10 +2530,10 @@ const char * TC_AG_RHH_BV_04_I[] = {
     "AT+CMEE=1" ,
     "OK" ,
     "AT+BTRH?" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "AT+BTRH=1" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "OK" ,
     "USER:b" ,
     "USER:C" ,
@@ -2570,10 +2570,10 @@ const char * TC_AG_RHH_BV_05_I[] = {
     "AT+CMEE=1" ,
     "OK" ,
     "AT+BTRH?" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "USER:x" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "USER:C" ,
     "+CIEV:2,0" ,
     "USER:t"
@@ -2608,10 +2608,10 @@ const char * TC_AG_RHH_BV_06_I[] = {
     "AT+CMEE=1" ,
     "OK" ,
     "AT+BTRH?" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "AT+BTRH=2" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV:2,0" ,
     "OK" ,
     "USER:t"
@@ -2646,10 +2646,10 @@ const char * TC_AG_RHH_BV_07_I[] = {
     "AT+CMEE=1" ,
     "OK" ,
     "AT+BTRH?" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "USER:X" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV:2,0" ,
     "USER:t"
 };
@@ -2683,10 +2683,10 @@ const char * TC_AG_RHH_BV_08_I[] = {
     "AT+CMEE=1" ,
     "OK" ,
     "AT+BTRH?" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "USER:C" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV:2,0" ,
     "USER:t"
 };
@@ -2724,7 +2724,7 @@ const char * TC_HF_RHH_BV_01_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0"
 };
 
@@ -2749,7 +2749,7 @@ const char * TC_HF_RHH_BV_02_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -2847,11 +2847,11 @@ const char * TC_HF_RHH_BV_02_I[] = {
     "RING" ,
     "RING" ,
     "USER:]" , // "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0"
 };
 
@@ -2876,7 +2876,7 @@ const char * TC_HF_RHH_BV_03_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -2974,11 +2974,11 @@ const char * TC_HF_RHH_BV_03_I[] = {
     "RING" ,
     "RING" ,
     "USER:]" , // "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3002,10 +3002,10 @@ const char * TC_HF_RHH_BV_03_I[] = {
     "+CIEV: 3,1" ,
     "RING" ,
     "+CLIP: \"1234567\",129" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0"
 };
 
@@ -3030,7 +3030,7 @@ const char * TC_HF_RHH_BV_04_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3128,11 +3128,11 @@ const char * TC_HF_RHH_BV_04_I[] = {
     "RING" ,
     "RING" ,
     "USER:]" , // "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3156,10 +3156,10 @@ const char * TC_HF_RHH_BV_04_I[] = {
     "+CIEV: 3,1" ,
     "RING" ,
     "+CLIP: \"1234567\",129" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3181,7 +3181,7 @@ const char * TC_HF_RHH_BV_04_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:{" , // "AT+BTRH=1" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "OK" ,
     "+CIEV: 2,0"
 };
@@ -3207,7 +3207,7 @@ const char * TC_HF_RHH_BV_05_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3305,11 +3305,11 @@ const char * TC_HF_RHH_BV_05_I[] = {
     "RING" ,
     "RING" ,
     "USER:]" , // "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3333,10 +3333,10 @@ const char * TC_HF_RHH_BV_05_I[] = {
     "+CIEV: 3,1" ,
     "RING" ,
     "+CLIP: \"1234567\",129" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3358,7 +3358,7 @@ const char * TC_HF_RHH_BV_05_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:{" , // "AT+BTRH=1" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "OK" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
@@ -3380,7 +3380,7 @@ const char * TC_HF_RHH_BV_05_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "+CIEV: 2,0"
 };
 
@@ -3405,7 +3405,7 @@ const char * TC_HF_RHH_BV_06_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3503,11 +3503,11 @@ const char * TC_HF_RHH_BV_06_I[] = {
     "RING" ,
     "RING" ,
     "USER:]" , // "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3531,10 +3531,10 @@ const char * TC_HF_RHH_BV_06_I[] = {
     "+CIEV: 3,1" ,
     "RING" ,
     "+CLIP: \"1234567\",129" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3556,7 +3556,7 @@ const char * TC_HF_RHH_BV_06_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:{" , // "AT+BTRH=1" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "OK" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
@@ -3578,7 +3578,7 @@ const char * TC_HF_RHH_BV_06_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3600,7 +3600,7 @@ const char * TC_HF_RHH_BV_06_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:}" , // "AT+BTRH=2" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "OK" ,
     "+CIEV: 2,0"
 };
@@ -3627,7 +3627,7 @@ const char * TC_HF_RHH_BV_07_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3725,11 +3725,11 @@ const char * TC_HF_RHH_BV_07_I[] = {
     "RING" ,
     "RING" ,
     "USER:]" , // "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3753,10 +3753,10 @@ const char * TC_HF_RHH_BV_07_I[] = {
     "+CIEV: 3,1" ,
     "RING" ,
     "+CLIP: \"1234567\",129" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3778,7 +3778,7 @@ const char * TC_HF_RHH_BV_07_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:{" , // "AT+BTRH=1" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "OK" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
@@ -3800,7 +3800,7 @@ const char * TC_HF_RHH_BV_07_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3822,7 +3822,7 @@ const char * TC_HF_RHH_BV_07_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:}" , // "AT+BTRH=2" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "OK" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
@@ -3844,7 +3844,7 @@ const char * TC_HF_RHH_BV_07_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0"
 };
 
@@ -3869,7 +3869,7 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3967,11 +3967,11 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "RING" ,
     "RING" ,
     "USER:]" , // "AT+BTRH=0" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "OK" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -3995,10 +3995,10 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "+CIEV: 3,1" ,
     "RING" ,
     "+CLIP: \"1234567\",129" ,
-    "+BTRH:0" ,
+    "+BTRH: 0" ,
     "+CIEV: 2,1" ,
     "+CIEV: 3,0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -4020,7 +4020,7 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:{" , // "AT+BTRH=1" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "OK" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
@@ -4042,7 +4042,7 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:1" ,
+    "+BTRH: 1" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -4064,7 +4064,7 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "OK",
     "+BSIR: 0" ,
     "USER:}" , // "AT+BTRH=2" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "OK" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
@@ -4086,7 +4086,7 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0" ,
     "AT+BRSF=951" ,
     "+BRSF: 511" ,
@@ -4107,7 +4107,7 @@ const char * TC_HF_RHH_BV_08_I[] = {
     "AT+VGS=9" ,
     "OK",
     "+BSIR: 0" ,
-    "+BTRH:2" ,
+    "+BTRH: 2" ,
     "+CIEV: 2,0"
 };
 
