@@ -45,8 +45,6 @@
 
 #include CYW43_WIFI_NVRAM_INCLUDE_FILE
 
-#define F1_OVERFLOW_CHANGE 0
-
 #if CYW43_USE_SPI
 #include "cyw43_spi.h"
 #include "cyw43_debug_pins.h"
@@ -80,6 +78,17 @@ extern bool enable_spi_packet_dumping;
 #define CYW43_WRITE_BYTES_PAD(len) ALIGN_UINT((len), 64)
 #endif
 
+// Configure the active level of the host interrupt pin.
+#if CYW43_USE_SPI
+#if defined(CYW43_PIN_WL_HOST_WAKE)
+static const int host_interrupt_pin_active = 1;
+#elif defined(CYW43_PIN_WL_IRQ)
+static const int host_interrupt_pin_active = 0;
+#endif
+#else
+static const int host_interrupt_pin_active = 0;
+#endif
+
 #if CYW43_USE_STATS
 // Storage for some debug stats
 uint32_t cyw43_stats[CYW43_STAT_LAST];
@@ -103,7 +112,7 @@ static inline void cyw43_put_le32(uint8_t *buf, uint32_t x) {
 
 #if CYW43_RESOURCE_VERIFY_DOWNLOAD
 static void cyw43_xxd(size_t len, const uint8_t *buf) {
-    for (int i = 0; i < len; ++i) {
+    for (size_t i = 0; i < len; ++i) {
         CYW43_PRINTF(" %02x", buf[i]);
         if (i % 32 == 31) {
             CYW43_PRINTF("\n");
@@ -268,6 +277,23 @@ static void cyw43_xxd(size_t len, const uint8_t *buf) {
 // Errors generated by sdpcm_process_rx_packet.
 #define CYW43_ERROR_WRONG_PAYLOAD_TYPE (-9)
 
+#define AUTH_TYPE_OPEN 0
+#define AUTH_TYPE_SAE 3
+
+// management frame protection
+#define MFP_NONE 0
+#define MFP_CAPABLE 1
+#define MFP_REQUIRED 2
+
+// Values used for STA and AP auth settings
+#define CYW43_WPA_AUTH_PSK (0x0004)
+#define CYW43_WPA2_AUTH_PSK (0x0080)
+#define CYW43_WPA3_AUTH_SAE_PSK (0x40000)
+
+// Max password length
+#define CYW43_WPA_MAX_PASSWORD_LEN 64
+#define CYW43_WPA_SAE_MAX_PASSWORD_LEN 128
+
 static int cyw43_ll_sdpcm_poll_device(cyw43_int_t *self, size_t *len, uint8_t **buf);
 static void cyw43_write_iovar_n(cyw43_int_t *self, const char *var, size_t len, const void *buf, uint32_t iface);
 
@@ -289,6 +315,8 @@ void cyw43_ll_deinit(cyw43_ll_t *self_in) {
     #if CYW43_USE_SPI
     cyw43_int_t *self = CYW_INT_FROM_LL(self_in);
     cyw43_spi_deinit(self);
+    #else
+    (void)self_in;
     #endif
 }
 
@@ -365,6 +393,7 @@ static void cyw43_write_backplane(cyw43_int_t *self, uint32_t addr, size_t size,
 }
 
 static int cyw43_check_valid_chipset_firmware(cyw43_int_t *self, size_t len, uintptr_t source) {
+    (void)self;
     // get the last bit of the firmware, the last 800 bytes
     uint32_t fw_end = 800;
     const uint8_t *b = (const uint8_t *)source + len - fw_end;
@@ -927,7 +956,7 @@ static int sdpcm_process_rx_packet(cyw43_int_t *self, uint8_t *buf, size_t *out_
 
 static int cyw43_ll_sdpcm_poll_device(cyw43_int_t *self, size_t *len, uint8_t **buf) {
     // First check the SDIO interrupt line to see if the WLAN notified us
-    if (!self->had_successful_packet && cyw43_cb_read_host_interrupt_pin(self->cb_data) == 1) {
+    if (!self->had_successful_packet && cyw43_cb_read_host_interrupt_pin(self->cb_data) != host_interrupt_pin_active) {
         return -1;
     }
 
@@ -974,26 +1003,9 @@ static int cyw43_ll_sdpcm_poll_device(cyw43_int_t *self, size_t *len, uint8_t **
 
 #else // SPI version follows
 
-#if F1_OVERFLOW_CHANGE
-static int cyw43_spi_resync_f1(cyw43_int_t *self) {
-    if (self->last_size > 0) {
-        uint32_t cbw = self->cur_backplane_window;
-        CYW43_PRINTF("Resync F1 size: %d cbw: 0x%lx lbw: 0x%lx data: %04lx,%04lx\n",
-            self->last_size, cbw, self->last_backplane_window, self->last_header[0], self->last_header[1]);
-        cyw43_set_backplane_window(self, self->last_backplane_window);
-        int err = cyw43_spi_transfer(self, (uint8_t *)self->last_header, self->last_size, NULL, 0);
-        cyw43_set_backplane_window(self, cbw);
-        self->last_size = 0;
-        CYW43_STAT_INC(F1_RESYNC);
-        return err;
-    }
-    return 0;
-}
-#endif
-
 static int cyw43_ll_sdpcm_poll_device(cyw43_int_t *self, size_t *len, uint8_t **buf) {
     // First check the SDIO interrupt line to see if the WLAN notified us
-    if (!self->had_successful_packet && !cyw43_cb_read_host_interrupt_pin(self->cb_data)) {
+    if (!self->had_successful_packet && cyw43_cb_read_host_interrupt_pin(self->cb_data) != host_interrupt_pin_active) {
         return -1;
     }
 
@@ -1045,24 +1057,6 @@ static int cyw43_ll_sdpcm_poll_device(cyw43_int_t *self, size_t *len, uint8_t **
             CYW43_STAT_INC(SPI_INT_CLEAR);
             cyw43_write_reg_u16(self, BUS_FUNCTION, SPI_INTERRUPT_REGISTER, spi_int);
         }
-        #if F1_OVERFLOW_CHANGE
-        // This doesn't work correctly.
-        if (spi_int & F1_OVERFLOW) {
-            logic_debug_set(pin_F1_OVERFLOW, 1);
-
-            assert(self->last_size);
-
-            // Wait for f1 to be ready before resync
-            uint16_t f1_info_reg;
-            do {
-                f1_info_reg = cyw43_read_reg_u16(self, BUS_FUNCTION, SPI_FUNCTION1_INFO);
-            } while ((f1_info_reg & SPI_FUNCTIONX_READY) == 0);
-
-            logic_debug_set(pin_F1_OVERFLOW, 0);
-
-            cyw43_spi_resync_f1(self);
-        }
-        #endif
         last_spi_int = spi_int;
         if (!(spi_int & F2_PACKET_AVAILABLE)) {
             return -1;
@@ -1094,7 +1088,7 @@ static int cyw43_ll_sdpcm_poll_device(cyw43_int_t *self, size_t *len, uint8_t **
         bytes_pending = (bus_gspi_status >> 9) & 0x7FF;
         if (bytes_pending == 0 || bytes_pending > (LINK_MTU - GSPI_PACKET_OVERHEAD) ||
             bus_gspi_status & F2_F3_FIFO_RD_UNDERFLOW) {
-            CYW43_DEBUG("SPI invalid bytes pending %u\n", bytes_pending);
+            CYW43_DEBUG("SPI invalid bytes pending %" PRIu32 "\n", bytes_pending);
             cyw43_write_reg_u8(self, BACKPLANE_FUNCTION, SPI_FRAME_CONTROL, (1 << 0));
             self->had_successful_packet = false;
             return -1;
@@ -1111,7 +1105,7 @@ static int cyw43_ll_sdpcm_poll_device(cyw43_int_t *self, size_t *len, uint8_t **
     }
     #pragma GCC diagnostic push
     #pragma GCC diagnostic ignored "-Wcast-align"
-    uint16_t *hdr = (__uint16_t *)self->spid_buf;
+    uint16_t *hdr = (uint16_t *)self->spid_buf;
     #pragma GCC diagnostic pop
     if (hdr[0] == 0 && hdr[1] == 0) {
         // no packets
@@ -1436,8 +1430,11 @@ int cyw43_ll_bus_init(cyw43_ll_t *self_in, const uint8_t *mac) {
 
     bool success = false;
     do {
-        uint32_t val = WORD_LENGTH_32 | ENDIAN_BIG | HIGH_SPEED_MODE | INTERRUPT_POLARITY_HIGH | WAKE_UP |
+        uint32_t val = WORD_LENGTH_32 | ENDIAN_BIG | HIGH_SPEED_MODE | WAKE_UP |
             0x4 << (8 * SPI_RESPONSE_DELAY) | INTR_WITH_STATUS << (8 * SPI_STATUS_ENABLE);
+        #if defined(CYW43_PIN_WL_HOST_WAKE)
+        val |= INTERRUPT_POLARITY_HIGH;
+        #endif
 
         // Initialise
         if (cyw43_spi_init(self) != 0) {
@@ -2054,7 +2051,7 @@ int cyw43_ll_wifi_scan(cyw43_ll_t *self_in, cyw43_wifi_scan_options_t *opts) {
 int cyw43_ll_wifi_join(cyw43_ll_t *self_in, size_t ssid_len, const uint8_t *ssid, size_t key_len, const uint8_t *key, uint32_t auth_type, const uint8_t *bssid, uint32_t channel) {
     cyw43_int_t *self = CYW_INT_FROM_LL(self_in);
 
-    uint8_t buf[128];
+    uint8_t buf[2 + CYW43_WPA_SAE_MAX_PASSWORD_LEN];
 
     cyw43_write_iovar_u32(self, "ampdu_ba_wsize", 8, WWD_STA_INTERFACE);
 
@@ -2065,11 +2062,20 @@ int cyw43_ll_wifi_join(cyw43_ll_t *self_in, size_t ssid_len, const uint8_t *ssid
         wpa_auth = CYW43_WPA2_AUTH_PSK;
     } else if (auth_type == CYW43_AUTH_WPA_TKIP_PSK) {
         wpa_auth = CYW43_WPA_AUTH_PSK;
+    } else if (auth_type == CYW43_AUTH_WPA3_SAE_AES_PSK || auth_type == CYW43_AUTH_WPA3_WPA2_AES_PSK) {
+        wpa_auth = CYW43_WPA3_AUTH_SAE_PSK;
     } else {
         // Unsupported auth_type (security) value.
         return -CYW43_EINVAL;
     }
 
+    // Check key length
+    if (auth_type != CYW43_AUTH_OPEN && auth_type != CYW43_AUTH_WPA3_SAE_AES_PSK && key_len > CYW43_WPA_MAX_PASSWORD_LEN) {
+        return -CYW43_EINVAL;
+    } else if (auth_type == CYW43_AUTH_WPA3_SAE_AES_PSK && key_len > CYW43_WPA_SAE_MAX_PASSWORD_LEN) {
+        return -CYW43_EINVAL;
+    }
+
     CYW43_VDEBUG("Setting wsec=0x%x\n", auth_type & 0xff);
     cyw43_set_ioctl_u32(self, WLC_SET_WSEC, auth_type & 0xff, WWD_STA_INTERFACE);
 
@@ -2085,7 +2091,7 @@ int cyw43_ll_wifi_join(cyw43_ll_t *self_in, size_t ssid_len, const uint8_t *ssid
     CYW43_VDEBUG("Setting sup_wpa_tmo %d\n", CYW_EAPOL_KEY_TIMEOUT);
     cyw43_write_iovar_u32_u32(self, "bsscfg:sup_wpa_tmo", 0, CYW_EAPOL_KEY_TIMEOUT, WWD_STA_INTERFACE);
 
-    if (auth_type != CYW43_AUTH_OPEN) {
+    if (auth_type != CYW43_AUTH_OPEN && auth_type != CYW43_AUTH_WPA3_SAE_AES_PSK) {
         // wwd_wifi_set_passphrase
         cyw43_put_le16(buf, key_len);
         cyw43_put_le16(buf + 2, 1);
@@ -2093,16 +2099,25 @@ int cyw43_ll_wifi_join(cyw43_ll_t *self_in, size_t ssid_len, const uint8_t *ssid
         cyw43_delay_ms(2); // Delay required to allow radio firmware to be ready to receive PMK and avoid intermittent failure
 
         CYW43_VDEBUG("Setting wsec_pmk %d\n", key_len);
-        cyw43_do_ioctl(self, SDPCM_SET, WLC_SET_WSEC_PMK, 68, buf, WWD_STA_INTERFACE); // 68, see wsec_pmk_t
+        cyw43_do_ioctl(self, SDPCM_SET, WLC_SET_WSEC_PMK, 4 + CYW43_WPA_MAX_PASSWORD_LEN, buf, WWD_STA_INTERFACE); // 68, see wsec_pmk_t
+    }
+
+    if (wpa_auth == CYW43_WPA3_AUTH_SAE_PSK) {
+        memset(buf, 0, 2 + CYW43_WPA_SAE_MAX_PASSWORD_LEN);
+        cyw43_put_le16(buf, key_len);
+        memcpy(buf + 2, key, key_len);
+        cyw43_delay_ms(2); // Delay required to allow radio firmware to be ready to receive PMK and avoid intermittent failure
+        cyw43_write_iovar_n(self, "sae_password", 2 + CYW43_WPA_SAE_MAX_PASSWORD_LEN, buf, WWD_STA_INTERFACE);
     }
 
     // set infrastructure mode
     CYW43_VDEBUG("Setting infra\n");
     cyw43_set_ioctl_u32(self, WLC_SET_INFRA, 1, WWD_STA_INTERFACE);
 
-    // set auth type (open system)
+    // set auth type
     CYW43_VDEBUG("Setting auth\n");
-    cyw43_set_ioctl_u32(self, WLC_SET_AUTH, 0, WWD_STA_INTERFACE);
+    cyw43_set_ioctl_u32(self, WLC_SET_AUTH, (wpa_auth == CYW43_WPA3_AUTH_SAE_PSK) ? AUTH_TYPE_SAE : AUTH_TYPE_OPEN, WWD_STA_INTERFACE);
+    cyw43_write_iovar_u32(self, "mfp", (wpa_auth == CYW43_WPA2_AUTH_PSK || wpa_auth == CYW43_WPA3_AUTH_SAE_PSK) ? MFP_CAPABLE : MFP_NONE, WWD_STA_INTERFACE);
 
     // set WPA auth mode
     CYW43_VDEBUG("Setting wpa auth 0x%x\n", wpa_auth);
@@ -2197,6 +2212,13 @@ int cyw43_ll_wifi_ap_init(cyw43_ll_t *self_in, size_t ssid_len, const uint8_t *s
         return 0;
     }
 
+    // Check key length
+    if (auth != CYW43_AUTH_OPEN && auth != CYW43_AUTH_WPA3_SAE_AES_PSK && key_len > CYW43_WPA_MAX_PASSWORD_LEN) {
+        return -CYW43_EINVAL;
+    } else if (auth == CYW43_AUTH_WPA3_SAE_AES_PSK && key_len > CYW43_WPA_SAE_MAX_PASSWORD_LEN) {
+        return -CYW43_EINVAL;
+    }
+
     // set the AMPDU parameter for AP (window size = 2)
     cyw43_write_iovar_u32(self, "ampdu_ba_wsize", 2, WWD_STA_INTERFACE);
 
@@ -2213,25 +2235,52 @@ int cyw43_ll_wifi_ap_init(cyw43_ll_t *self_in, size_t ssid_len, const uint8_t *s
     // set security type
     cyw43_write_iovar_u32_u32(self, "bsscfg:wsec", WWD_AP_INTERFACE, auth, WWD_STA_INTERFACE);
 
+    // set management frame protection
+    uint32_t auth_mfp = MFP_NONE;
+    if (auth == CYW43_AUTH_WPA3_SAE_AES_PSK) {
+        auth_mfp = MFP_REQUIRED;
+    } else if (auth == CYW43_AUTH_WPA3_WPA2_AES_PSK) {
+        auth_mfp = MFP_CAPABLE;
+    }
+    cyw43_write_iovar_u32(self, "mfp", auth_mfp, WWD_AP_INTERFACE);
+
     if (auth == CYW43_AUTH_OPEN) {
         // nothing to do
     } else {
         // set WPA/WPA2 auth params
-        uint16_t val;
+        uint32_t val = 0;
         if (auth == CYW43_AUTH_WPA_TKIP_PSK) {
             val = CYW43_WPA_AUTH_PSK;
-        } else {
+        } else if (auth == CYW43_AUTH_WPA2_AES_PSK || auth == CYW43_AUTH_WPA2_MIXED_PSK) {
             val = CYW43_WPA_AUTH_PSK | CYW43_WPA2_AUTH_PSK;
+        } else if (auth == CYW43_AUTH_WPA3_SAE_AES_PSK) {
+            val = CYW43_WPA3_AUTH_SAE_PSK;
+        } else if (auth == CYW43_AUTH_WPA3_WPA2_AES_PSK) {
+            val = CYW43_WPA3_AUTH_SAE_PSK | CYW43_WPA2_AUTH_PSK;
         }
+        assert(val);
         cyw43_write_iovar_u32_u32(self, "bsscfg:wpa_auth", WWD_AP_INTERFACE, val, WWD_STA_INTERFACE);
 
         // set password
-        cyw43_put_le16(buf, key_len);
-        cyw43_put_le16(buf + 2, 1);
-        memset(buf + 4, 0, 64);
-        memcpy(buf + 4, key, key_len);
-        cyw43_delay_ms(2); // WICED has this
-        cyw43_do_ioctl(self, SDPCM_SET, WLC_SET_WSEC_PMK, 2 + 2 + 64, buf, WWD_AP_INTERFACE);
+        if (val & CYW43_WPA3_AUTH_SAE_PSK) {
+            cyw43_put_le16(buf, key_len);
+            memset(buf + 2, 0, CYW43_WPA_SAE_MAX_PASSWORD_LEN);
+            memcpy(buf + 2, key, key_len);
+            cyw43_delay_ms(2); // Delay required to allow radio firmware to be ready to receive PMK and avoid intermittent failure
+            cyw43_write_iovar_n(self, "sae_password", 2 + CYW43_WPA_SAE_MAX_PASSWORD_LEN, buf, WWD_AP_INTERFACE);
+        }
+        if (val & (CYW43_WPA_AUTH_PSK | CYW43_WPA2_AUTH_PSK)) {
+            cyw43_put_le16(buf, key_len);
+            cyw43_put_le16(buf + 2, 1);
+            memset(buf + 4, 0, CYW43_WPA_MAX_PASSWORD_LEN);
+            memcpy(buf + 4, key, key_len);
+            cyw43_delay_ms(2); // WICED has this
+            cyw43_do_ioctl(self, SDPCM_SET, WLC_SET_WSEC_PMK, 2 + 2 + CYW43_WPA_MAX_PASSWORD_LEN, buf, WWD_AP_INTERFACE);
+        }
+    }
+
+    if (auth == CYW43_AUTH_WPA3_SAE_AES_PSK || auth == CYW43_AUTH_WPA3_WPA2_AES_PSK) {
+        cyw43_write_iovar_u32(self, "sae_max_pwe_loop", WWD_AP_INTERFACE, 5);
     }
 
     // set GMode to auto (value of 1)
@@ -2329,11 +2378,7 @@ int cyw43_ll_gpio_get(cyw43_ll_t *self_in, int gpio_n, bool *gpio_en) {
 bool cyw43_ll_has_work(cyw43_ll_t *self_in) {
     cyw43_int_t *self = CYW_INT_FROM_LL(self_in);
     int int_pin = cyw43_cb_read_host_interrupt_pin(self->cb_data);
-    #if CYW43_USE_SPI
-    return int_pin == 1;
-    #else
-    return int_pin == 0;
-    #endif
+    return int_pin == host_interrupt_pin_active;
 }
 
 #if CYW43_ENABLE_BLUETOOTH
