@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -56,10 +56,6 @@ FSP_HEADER
  * Macro definitions
  **********************************************************************************************************************/
 
-/* Version Number of API. */
-#define CGC_API_VERSION_MAJOR    (1U)  // DEPRECATED
-#define CGC_API_VERSION_MINOR    (1U)  // DEPRECATED
-
 /**********************************************************************************************************************
  * Typedef definitions
  **********************************************************************************************************************/
@@ -99,54 +95,18 @@ typedef enum e_cgc_pll_div
     CGC_PLL_DIV_4 = 3,                 ///< PLL divider of 4 (S3 only)
 } cgc_pll_div_t;
 
-/** PLL multiplier values */
-typedef enum e_cgc_pll_mul
+/** PLL clock output divisor. */
+typedef enum e_cgc_pll_out_div
 {
-    CGC_PLL_MUL_8_0  = 0xF,            ///< PLL multiplier of 8.0
-    CGC_PLL_MUL_9_0  = 0x11,           ///< PLL multiplier of 9.0
-    CGC_PLL_MUL_10_0 = 0x13,           ///< PLL multiplier of 10.0
-    CGC_PLL_MUL_10_5 = 0x14,           ///< PLL multiplier of 10.5
-    CGC_PLL_MUL_11_0 = 0x15,           ///< PLL multiplier of 11.0
-    CGC_PLL_MUL_11_5 = 0x16,           ///< PLL multiplier of 11.5
-    CGC_PLL_MUL_12_0 = 0x17,           ///< PLL multiplier of 12.0
-    CGC_PLL_MUL_12_5 = 0x18,           ///< PLL multiplier of 12.5
-    CGC_PLL_MUL_13_0 = 0x19,           ///< PLL multiplier of 13.0
-    CGC_PLL_MUL_13_5 = 0x1A,           ///< PLL multiplier of 13.5
-    CGC_PLL_MUL_14_0 = 0x1B,           ///< PLL multiplier of 14.0
-    CGC_PLL_MUL_14_5 = 0x1D,           ///< PLL multiplier of 14.5
-    CGC_PLL_MUL_15_0 = 0x1D,           ///< PLL multiplier of 15.0
-    CGC_PLL_MUL_15_5 = 0x1E,           ///< PLL multiplier of 15.5
-    CGC_PLL_MUL_16_0 = 0x1F,           ///< PLL multiplier of 16.0
-    CGC_PLL_MUL_16_5 = 0x20,           ///< PLL multiplier of 16.5
-    CGC_PLL_MUL_17_0 = 0x21,           ///< PLL multiplier of 17.0
-    CGC_PLL_MUL_17_5 = 0x22,           ///< PLL multiplier of 17.5
-    CGC_PLL_MUL_18_0 = 0x23,           ///< PLL multiplier of 18.0
-    CGC_PLL_MUL_18_5 = 0x24,           ///< PLL multiplier of 18.5
-    CGC_PLL_MUL_19_0 = 0x25,           ///< PLL multiplier of 19.0
-    CGC_PLL_MUL_19_5 = 0x26,           ///< PLL multiplier of 19.5
-    CGC_PLL_MUL_20_0 = 0x27,           ///< PLL multiplier of 20.0
-    CGC_PLL_MUL_20_5 = 0x28,           ///< PLL multiplier of 20.5
-    CGC_PLL_MUL_21_0 = 0x29,           ///< PLL multiplier of 21.0
-    CGC_PLL_MUL_21_5 = 0x2A,           ///< PLL multiplier of 21.5
-    CGC_PLL_MUL_22_0 = 0x2B,           ///< PLL multiplier of 22.0
-    CGC_PLL_MUL_22_5 = 0x2C,           ///< PLL multiplier of 22.5
-    CGC_PLL_MUL_23_0 = 0x2D,           ///< PLL multiplier of 23.0
-    CGC_PLL_MUL_23_5 = 0x2E,           ///< PLL multiplier of 23.5
-    CGC_PLL_MUL_24_0 = 0x2F,           ///< PLL multiplier of 24.0
-    CGC_PLL_MUL_24_5 = 0x30,           ///< PLL multiplier of 24.5
-    CGC_PLL_MUL_25_0 = 0x31,           ///< PLL multiplier of 25.0
-    CGC_PLL_MUL_25_5 = 0x32,           ///< PLL multiplier of 25.5
-    CGC_PLL_MUL_26_0 = 0x33,           ///< PLL multiplier of 26.0
-    CGC_PLL_MUL_26_5 = 0x34,           ///< PLL multiplier of 26.5
-    CGC_PLL_MUL_27_0 = 0x35,           ///< PLL multiplier of 27.0
-    CGC_PLL_MUL_27_5 = 0x36,           ///< PLL multiplier of 27.5
-    CGC_PLL_MUL_28_0 = 0x37,           ///< PLL multiplier of 28.0
-    CGC_PLL_MUL_28_5 = 0x38,           ///< PLL multiplier of 28.5
-    CGC_PLL_MUL_29_0 = 0x39,           ///< PLL multiplier of 29.0
-    CGC_PLL_MUL_29_5 = 0x3A,           ///< PLL multiplier of 29.5
-    CGC_PLL_MUL_30_0 = 0x3B,           ///< PLL multiplier of 30.0
-    CGC_PLL_MUL_31_0 = 0x3D,           ///< PLL multiplier of 31.0
-} cgc_pll_mul_t;
+    CGC_PLL_OUT_DIV_2  = 2,            ///< PLL output clock divided by 2
+    CGC_PLL_OUT_DIV_3  = 3,            ///< PLL output clock divided by 3
+    CGC_PLL_OUT_DIV_4  = 4,            ///< PLL output clock divided by 4
+    CGC_PLL_OUT_DIV_5  = 5,            ///< PLL output clock divided by 5
+    CGC_PLL_OUT_DIV_6  = 6,            ///< PLL output clock divided by 6
+    CGC_PLL_OUT_DIV_8  = 8,            ///< PLL output clock divided by 8
+    CGC_PLL_OUT_DIV_9  = 9,            ///< PLL output clock divided by 9
+    CGC_PLL_OUT_DIV_16 = 16,           ///< PLL output clock divided by 16
+} cgc_pll_out_div_t;
 
 /** System clock divider vlues - The individually selectable divider of each of the system clocks, ICLK, BCLK, FCLK,
  * PCLKS A-D.  */
@@ -164,32 +124,44 @@ typedef enum e_cgc_sys_clock_div
 /** Clock configuration structure - Used as an input parameter to the @ref cgc_api_t::clockStart function for the PLL clock. */
 typedef struct st_cgc_pll_cfg
 {
-    cgc_clock_t   source_clock;        ///< PLL source clock (main oscillator or HOCO)
-    cgc_pll_div_t divider;             ///< PLL divider
-    cgc_pll_mul_t multiplier;          ///< PLL multiplier
+    cgc_clock_t       source_clock;    ///< PLL source clock (main oscillator or HOCO)
+    cgc_pll_div_t     divider;         ///< PLL divider
+    cgc_pll_mul_t     multiplier;      ///< PLL multiplier
+    cgc_pll_out_div_t out_div_p;       ///< PLL divisor for output clock P
+    cgc_pll_out_div_t out_div_q;       ///< PLL divisor for output clock Q
+    cgc_pll_out_div_t out_div_r;       ///< PLL divisor for output clock R
 } cgc_pll_cfg_t;
 
 /** Clock configuration structure - Used as an input parameter to the @ref cgc_api_t::systemClockSet and @ref cgc_api_t::systemClockGet
  * functions. */
-typedef union u_cgc_divider_cfg
+typedef struct u_cgc_divider_cfg
 {
-    uint32_t sckdivcr_w;                   ///< (@ 0x4001E020) System clock Division control register
-
-    struct
+    union
     {
-        cgc_sys_clock_div_t pclkd_div : 3; ///< Divider value for PCLKD
-        uint32_t                      : 1;
-        cgc_sys_clock_div_t pclkc_div : 3; ///< Divider value for PCLKC
-        uint32_t                      : 1;
-        cgc_sys_clock_div_t pclkb_div : 3; ///< Divider value for PCLKB
-        uint32_t                      : 1;
-        cgc_sys_clock_div_t pclka_div : 3; ///< Divider value for PCLKA
-        uint32_t                      : 1;
-        cgc_sys_clock_div_t bclk_div  : 3; ///< Divider value for BCLK
-        uint32_t                      : 5;
-        cgc_sys_clock_div_t iclk_div  : 3; ///< Divider value for ICLK
-        uint32_t                      : 1;
-        cgc_sys_clock_div_t fclk_div  : 3; ///< Divider value for FCLK
+        uint32_t sckdivcr_w;                   ///< System clock Division control register
+
+        struct
+        {
+            cgc_sys_clock_div_t pclkd_div : 4; ///< Divider value for PCLKD
+            cgc_sys_clock_div_t pclkc_div : 4; ///< Divider value for PCLKC
+            cgc_sys_clock_div_t pclkb_div : 4; ///< Divider value for PCLKB
+            cgc_sys_clock_div_t pclka_div : 4; ///< Divider value for PCLKA
+            cgc_sys_clock_div_t bclk_div  : 4; ///< Divider value for BCLK
+            cgc_sys_clock_div_t pclke_div : 4; ///< Divider value for PCLKE
+            cgc_sys_clock_div_t iclk_div  : 4; ///< Divider value for ICLK
+            cgc_sys_clock_div_t fclk_div  : 4; ///< Divider value for FCLK
+        } sckdivcr_b;
+    };
+
+    union
+    {
+        uint8_t sckdivcr2;                      ///< System clock Division control register 2
+
+        struct
+        {
+            cgc_sys_clock_div_t cpuclk_div : 4; ///< Divider value for CPUCLK
+            uint8_t             reserved   : 4;
+        } sckdivcr2_b;
     };
 } cgc_divider_cfg_t;
 
@@ -347,13 +319,6 @@ typedef struct
      * @param[in]   p_ctrl          Pointer to instance control block
      */
     fsp_err_t (* close)(cgc_ctrl_t * const p_ctrl);
-
-    /* DEPRECATED Gets the CGC driver version.
-     * @par Implemented as
-     * - @ref R_CGC_VersionGet()
-     * @param[out]  p_version   Code and API version used
-     */
-    fsp_err_t (* versionGet)(fsp_version_t * p_version);
 } cgc_api_t;
 
 /** This structure encompasses everything that is needed to use an instance of this interface. */
