@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -48,8 +48,6 @@ FSP_HEADER
 /**********************************************************************************************************************
  * Macro definitions
  **********************************************************************************************************************/
-#define SPI_FLASH_API_VERSION_MAJOR        (1U) // DEPRECATED
-#define SPI_FLASH_API_VERSION_MINOR        (0U) // DEPRECATED
 
 #define SPI_FLASH_ERASE_SIZE_CHIP_ERASE    (UINT32_MAX)
 
@@ -141,15 +139,16 @@ typedef struct st_spi_flash_erase_command
     uint32_t size;                     ///< Size of erase for associated command, set to SPI_FLASH_ERASE_SIZE_CHIP_ERASE for chip erase
 } spi_flash_erase_command_t;
 
+/** Structure to define a direct transfer. */
 typedef struct st_spi_flash_direct_transfer
 {
-    uint32_t address;
-    uint32_t data;
-    uint16_t command;
-    uint8_t  dummy_cycles;
-    uint8_t  command_length;
-    uint8_t  address_length;
-    uint8_t  data_length;
+    uint32_t address;                  ///< Starting address
+    uint32_t data;                     ///< Data
+    uint16_t command;                  ///< Transfer command
+    uint8_t  dummy_cycles;             ///< Number of dummy cycles
+    uint8_t  command_length;           ///< Command length
+    uint8_t  address_length;           ///< Address lengrh
+    uint8_t  data_length;              ///< Data length
 } spi_flash_direct_transfer_t;
 
 /** User configuration structure used by the open function */
@@ -165,7 +164,7 @@ typedef struct st_spi_flash_cfg
     spi_flash_data_lines_t            page_program_address_lines;
     uint8_t                           write_status_bit;          ///< Which bit determines write status
     uint8_t                           write_enable_bit;          ///< Which bit determines write status
-    uint32_t                          page_size_bytes;           ///< Page size in bytes (maximum number of bytes for page program)
+    uint32_t                          page_size_bytes;           ///< Page size in bytes (maximum number of bytes for page program). Used to specify single continuous write size (bytes) in case of OSPI RAM.
     uint8_t                           page_program_command;      ///< Page program command
     uint8_t                           write_enable_command;      ///< Command to enable write or erase, typically 0x06
     uint8_t                           status_command;            ///< Command to read the write status
@@ -180,6 +179,7 @@ typedef struct st_spi_flash_cfg
 /** SPI flash control block.  Allocate an instance specific control block to pass into the SPI flash API calls.
  * @par Implemented as
  * - qspi_instance_ctrl_t
+ * - ospi_instance_ctrl_t
  */
 typedef void spi_flash_ctrl_t;
 
@@ -196,6 +196,7 @@ typedef struct st_spi_flash_api
 {
     /** Open the SPI flash driver module.
      * @par Implemented as
+     * - @ref R_OSPI_Open()
      * - @ref R_QSPI_Open()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
@@ -205,6 +206,7 @@ typedef struct st_spi_flash_api
 
     /** Write raw data to the SPI flash.
      * @par Implemented as
+     * - @ref R_OSPI_DirectWrite()
      * - @ref R_QSPI_DirectWrite()
      *
      * @param[in] p_ctrl                Pointer to a driver handle
@@ -220,6 +222,7 @@ typedef struct st_spi_flash_api
 
     /** Read raw data from the SPI flash. Must follow a call to @ref spi_flash_api_t::directWrite.
      * @par Implemented as
+     * - @ref R_OSPI_DirectRead()
      * - @ref R_QSPI_DirectRead()
      *
      * @param[in]  p_ctrl               Pointer to a driver handle
@@ -231,6 +234,7 @@ typedef struct st_spi_flash_api
     /** Direct Read/Write raw data to the SPI flash.
      * @par Implemented as
      * - @ref R_OSPI_DirectTransfer()
+     * - @ref R_QSPI_DirectTransfer()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
      * @param[in] p_data               Pointer to command, address and data values and lengths
@@ -241,6 +245,7 @@ typedef struct st_spi_flash_api
 
     /** Change the SPI protocol in the driver. The application must change the SPI protocol on the device.
      * @par Implemented as
+     * - @ref R_OSPI_SpiProtocolSet()
      * - @ref R_QSPI_SpiProtocolSet()
      *
      * @param[in] p_ctrl                Pointer to a driver handle
@@ -250,6 +255,7 @@ typedef struct st_spi_flash_api
 
     /** Program a page of data to the flash.
      * @par Implemented as
+     * - @ref R_OSPI_Write()
      * - @ref R_QSPI_Write()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
@@ -262,6 +268,7 @@ typedef struct st_spi_flash_api
 
     /** Erase a certain number of bytes of the flash.
      * @par Implemented as
+     * - @ref R_OSPI_Erase()
      * - @ref R_QSPI_Erase()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
@@ -273,6 +280,7 @@ typedef struct st_spi_flash_api
 
     /** Get the write or erase status of the flash.
      * @par Implemented as
+     * - @ref R_OSPI_StatusGet()
      * - @ref R_QSPI_StatusGet()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
@@ -282,6 +290,7 @@ typedef struct st_spi_flash_api
 
     /** Enter XIP mode.
      * @par Implemented as
+     * - @ref R_OSPI_XipEnter()
      * - @ref R_QSPI_XipEnter()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
@@ -290,6 +299,7 @@ typedef struct st_spi_flash_api
 
     /** Exit XIP mode.
      * @par Implemented as
+     * - @ref R_OSPI_XipExit()
      * - @ref R_QSPI_XipExit()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
@@ -298,6 +308,7 @@ typedef struct st_spi_flash_api
 
     /** Select the bank to access.  See implementation for details.
      * @par Implemented as
+     * - @ref R_OSPI_BankSet()
      * - @ref R_QSPI_BankSet()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
@@ -305,21 +316,23 @@ typedef struct st_spi_flash_api
      **/
     fsp_err_t (* bankSet)(spi_flash_ctrl_t * p_ctrl, uint32_t bank);
 
+    /** AutoCalibrate the SPI flash driver module. Expected to be used when auto-calibrating OSPI RAM device.
+     * @par Implemented as
+     * - @ref R_OSPI_AutoCalibrate()
+     * - @ref R_QSPI_AutoCalibrate()
+     *
+     * @param[in] p_ctrl               Pointer to a driver handle
+     **/
+    fsp_err_t (* autoCalibrate)(spi_flash_ctrl_t * p_ctrl);
+
     /** Close the SPI flash driver module.
      * @par Implemented as
+     * - @ref R_OSPI_Close()
      * - @ref R_QSPI_Close()
      *
      * @param[in] p_ctrl               Pointer to a driver handle
      **/
     fsp_err_t (* close)(spi_flash_ctrl_t * p_ctrl);
-
-    /* DEPRECATED Get the driver version based on compile time macros.
-     * @par Implemented as
-     * - @ref R_QSPI_VersionGet()
-     *
-     * @param[out]  p_version          Code and API version stored here.
-     **/
-    fsp_err_t (* versionGet)(fsp_version_t * const p_version);
 } spi_flash_api_t;
 
 /** This structure encompasses everything that is needed to use an instance of this interface. */
