@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -44,6 +44,9 @@
  * @{
  **********************************************************************************************************************/
 
+/* Common macro for FSP header files. There is also a corresponding FSP_FOOTER macro at the end of this file. */
+FSP_HEADER
+
 /***********************************************************************************************************************
  * Typedef definitions
  **********************************************************************************************************************/
@@ -114,6 +117,11 @@ typedef enum e_fsp_ip
     FSP_IP_DAC8   = 70,                ///< 8-Bit D/A Converter
     FSP_IP_USBHS  = 71,                ///< USB High Speed
     FSP_IP_OSPI   = 72,                ///< Octa Serial Peripheral Interface
+    FSP_IP_CEC    = 73,                ///< HDMI CEC
+    FSP_IP_TFU    = 74,                ///< Trigonometric Function Unit
+    FSP_IP_IIRFA  = 75,                ///< IIR Filter Accelerator
+    FSP_IP_CANFD  = 76,                ///< CAN-FD
+    FSP_IP_ULPT   = 77,                ///< Ultra Low Power Timer ULPT
 } fsp_ip_t;
 
 /** Signals that can be mapped to an interrupt. */
@@ -220,6 +228,10 @@ typedef enum e_fsp_signal
     FSP_SIGNAL_IOPORT_EVENT_2,                    ///< IOPORT EVENT 2
     FSP_SIGNAL_IOPORT_EVENT_3,                    ///< IOPORT EVENT 3
     FSP_SIGNAL_IOPORT_EVENT_4,                    ///< IOPORT EVENT 4
+    FSP_SIGNAL_IOPORT_EVENT_B = 0,                ///< IOPORT EVENT B
+    FSP_SIGNAL_IOPORT_EVENT_C,                    ///< IOPORT EVENT C
+    FSP_SIGNAL_IOPORT_EVENT_D,                    ///< IOPORT EVENT D
+    FSP_SIGNAL_IOPORT_EVENT_E,                    ///< IOPORT EVENT E
     FSP_SIGNAL_IWDT_UNDERFLOW = 0,                ///< IWDT UNDERFLOW
     FSP_SIGNAL_JPEG_JDTI      = 0,                ///< JPEG JDTI
     FSP_SIGNAL_JPEG_JEDI,                         ///< JPEG JEDI
@@ -277,10 +289,16 @@ typedef enum e_fsp_signal
     FSP_SIGNAL_USB_RESUME,                        ///< USB RESUME
     FSP_SIGNAL_USB_USB_INT_RESUME,                ///< USB USB INT RESUME
     FSP_SIGNAL_WDT_UNDERFLOW = 0,                 ///< WDT UNDERFLOW
+    FSP_SIGNAL_ULPT_COMPARE_A = 0,                ///< ULPT COMPARE A
+    FSP_SIGNAL_ULPT_COMPARE_B,                    ///< ULPT COMPARE B
+    FSP_SIGNAL_ULPT_INT,                          ///< ULPT INT
 } fsp_signal_t;
 
 typedef void (* fsp_vector_t)(void);
 
 /** @} (end addtogroup BSP_MCU) */
 
+/** Common macro for FSP header files. There is also a corresponding FSP_HEADER macro at the top of this file. */
+FSP_FOOTER
+
 #endif
