@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -73,11 +73,16 @@
 /* Stabilization time when BGR is enabled */
 #define ADC_BGR_STABILIZATION_DELAY_US              (150U)
 
+/* Bit set in adc_vref_control if the internal voltage reference is used for VREFH. */
+#define ADC_PRV_ADHVREFCNT_VREF_INTERNAL_BIT_1      (1U << 1)
+
 #define ADC_PRV_ADCSR_ADST_TRGE_MASK                (R_ADC0_ADCSR_ADST_Msk | R_ADC0_ADCSR_TRGE_Msk)
 #define ADC_PRV_ADCSR_CLEAR_ADST_TRGE               (~ADC_PRV_ADCSR_ADST_TRGE_MASK)
 
 #define ADC_PRV_TSCR_TSN_ENABLE                     (R_TSN_CTRL_TSCR_TSEN_Msk | R_TSN_CTRL_TSCR_TSOE_Msk)
 
+#define ADC_PRV_ADBUF_ENABLED                       (1U)
+
 /***********************************************************************************************************************
  * Typedef definitions
  **********************************************************************************************************************/
@@ -131,18 +136,12 @@ static void r_adc_scan_cfg(adc_instance_ctrl_t * const     p_instance_ctrl,
 static void    r_adc_sensor_sample_state_calculation(uint32_t * const p_sample_states);
 void           adc_scan_end_b_isr(void);
 void           adc_scan_end_isr(void);
+void           adc_window_compare_isr(void);
+static void    r_adc_irq_enable(IRQn_Type irq, uint8_t ipl, void * p_context);
+static void    r_adc_irq_disable(IRQn_Type irq);
 static int32_t r_adc_lowest_channel_get(uint32_t adc_mask);
 static void    r_adc_scan_end_common_isr(adc_event_t event);
 
-/** Version data structure used by error logger macro. */
-static const fsp_version_t g_adc_version =
-{
-    .api_version_minor  = ADC_API_VERSION_MINOR,
-    .api_version_major  = ADC_API_VERSION_MAJOR,
-    .code_version_major = ADC_CODE_VERSION_MAJOR,
-    .code_version_minor = ADC_CODE_VERSION_MINOR
-};
-
 /** Look-up table for ADSTRGR values */
 static const uint32_t adc_elc_trigger_lut[] =
 {
@@ -171,19 +170,19 @@ static const uint32_t g_adc_valid_channels[] =
 /** ADC Implementation of ADC. */
 const adc_api_t g_adc_on_adc =
 {
-    .open          = R_ADC_Open,
-    .scanCfg       = R_ADC_ScanCfg,
-    .infoGet       = R_ADC_InfoGet,
-    .scanStart     = R_ADC_ScanStart,
-    .scanStop      = R_ADC_ScanStop,
-    .scanStatusGet = R_ADC_StatusGet,
-    .read          = R_ADC_Read,
-    .read32        = R_ADC_Read32,
-    .close         = R_ADC_Close,
-    .versionGet    = R_ADC_VersionGet,
-    .calibrate     = R_ADC_Calibrate,
-    .offsetSet     = R_ADC_OffsetSet,
-    .callbackSet   = R_ADC_CallbackSet,
+    .open           = R_ADC_Open,
+    .scanCfg        = R_ADC_ScanCfg,
+    .infoGet        = R_ADC_InfoGet,
+    .scanStart      = R_ADC_ScanStart,
+    .scanGroupStart = R_ADC_ScanGroupStart,
+    .scanStop       = R_ADC_ScanStop,
+    .scanStatusGet  = R_ADC_StatusGet,
+    .read           = R_ADC_Read,
+    .read32         = R_ADC_Read32,
+    .close          = R_ADC_Close,
+    .calibrate      = R_ADC_Calibrate,
+    .offsetSet      = R_ADC_OffsetSet,
+    .callbackSet    = R_ADC_CallbackSet,
 };
 
 /*******************************************************************************************************************//**
@@ -228,14 +227,19 @@ fsp_err_t R_ADC_Open (adc_ctrl_t * p_ctrl, adc_cfg_t const * const p_cfg)
     /* Verify this unit has not already been initialized   */
     FSP_ERROR_RETURN(ADC_OPEN != p_instance_ctrl->opened, FSP_ERR_ALREADY_OPEN);
 
-    /* If a callback is used, then make sure the scan end interrupt is enabled */
+    /* If a callback is used, then make sure an interrupt is enabled */
+    adc_extended_cfg_t const * p_extend = (adc_extended_cfg_t const *) p_cfg->p_extend;
     if (NULL != p_cfg->p_callback)
     {
-        FSP_ERROR_RETURN(p_cfg->scan_end_irq >= 0, FSP_ERR_IRQ_BSP_DISABLED);
+        FSP_ERROR_RETURN((p_cfg->scan_end_irq >= 0) || (p_extend->window_a_irq >= 0) || (p_extend->window_b_irq >= 0),
+                         FSP_ERR_IRQ_BSP_DISABLED);
 
         /* Group B interrupts are never required since group B can be configured in continuous scan mode when group A
          * has priority over group B. */
     }
+
+#else
+    adc_extended_cfg_t const * p_extend = (adc_extended_cfg_t const *) p_cfg->p_extend;
 #endif
 
     /* Save configurations. */
@@ -251,16 +255,11 @@ fsp_err_t R_ADC_Open (adc_ctrl_t * p_ctrl, adc_cfg_t const * const p_cfg)
     /* Initialize the hardware based on the configuration. */
     r_adc_open_sub(p_instance_ctrl, p_cfg);
 
-    /* Set the interrupt priorities. */
-    if (p_instance_ctrl->p_cfg->scan_end_irq >= 0)
-    {
-        R_BSP_IrqCfgEnable(p_instance_ctrl->p_cfg->scan_end_irq, p_cfg->scan_end_ipl, p_instance_ctrl);
-    }
-
-    if (p_instance_ctrl->p_cfg->scan_end_b_irq >= 0)
-    {
-        R_BSP_IrqCfgEnable(p_instance_ctrl->p_cfg->scan_end_b_irq, p_cfg->scan_end_b_ipl, p_instance_ctrl);
-    }
+    /* Enable interrupts */
+    r_adc_irq_enable(p_cfg->scan_end_irq, p_cfg->scan_end_ipl, p_instance_ctrl);
+    r_adc_irq_enable(p_cfg->scan_end_b_irq, p_cfg->scan_end_b_ipl, p_instance_ctrl);
+    r_adc_irq_enable(p_extend->window_a_irq, p_extend->window_a_ipl, p_instance_ctrl);
+    r_adc_irq_enable(p_extend->window_b_irq, p_extend->window_b_ipl, p_instance_ctrl);
 
     /* Invalid scan mask (initialized for later). */
     p_instance_ctrl->scan_mask = 0U;
@@ -371,6 +370,7 @@ fsp_err_t R_ADC_CallbackSet (adc_ctrl_t * const          p_api_ctrl,
  * @retval FSP_SUCCESS                 Scan started (software trigger) or hardware triggers enabled.
  * @retval FSP_ERR_ASSERTION           An input argument is invalid.
  * @retval FSP_ERR_NOT_OPEN            Unit is not open.
+ * @retval FSP_ERR_NOT_INITIALIZED     Unit is not initialized.
  * @retval FSP_ERR_IN_USE              Another scan is still in progress (software trigger).
  **********************************************************************************************************************/
 fsp_err_t R_ADC_ScanStart (adc_ctrl_t * p_ctrl)
@@ -383,6 +383,7 @@ fsp_err_t R_ADC_ScanStart (adc_ctrl_t * p_ctrl)
     /* Verify the pointers are valid */
     FSP_ASSERT(NULL != p_instance_ctrl);
     FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->opened, FSP_ERR_NOT_OPEN);
+    FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->initialized, FSP_ERR_NOT_INITIALIZED);
     if (ADC_GROUP_A_GROUP_B_CONTINUOUS_SCAN != p_instance_ctrl->p_reg->ADGSPCR)
     {
         FSP_ERROR_RETURN(0U == p_instance_ctrl->p_reg->ADCSR_b.ADST, FSP_ERR_IN_USE);
@@ -395,6 +396,20 @@ fsp_err_t R_ADC_ScanStart (adc_ctrl_t * p_ctrl)
     return FSP_SUCCESS;
 }
 
+/*******************************************************************************************************************//**
+ * @ref adc_api_t::scanStart is not supported on the ADCH. Use scanStart instead.
+ *
+ * @retval FSP_ERR_UNSUPPORTED         Function not supported in this implementation.
+ **********************************************************************************************************************/
+fsp_err_t R_ADC_ScanGroupStart (adc_ctrl_t * p_ctrl, adc_group_mask_t group_id)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+    FSP_PARAMETER_NOT_USED(group_id);
+
+    /* Return the unsupported error. */
+    return FSP_ERR_UNSUPPORTED;
+}
+
 /*******************************************************************************************************************//**
  * Stops the software scan or disables the unit from being triggered by the hardware trigger (ELC or external) based on
  * what type of trigger the unit was configured for in the R_ADC_Open function. Stopping a hardware triggered scan via
@@ -404,6 +419,7 @@ fsp_err_t R_ADC_ScanStart (adc_ctrl_t * p_ctrl)
  * @retval FSP_SUCCESS                 Scan stopped (software trigger) or hardware triggers disabled.
  * @retval FSP_ERR_ASSERTION           An input argument is invalid.
  * @retval FSP_ERR_NOT_OPEN            Unit is not open.
+ * @retval FSP_ERR_NOT_INITIALIZED     Unit is not initialized.
  **********************************************************************************************************************/
 fsp_err_t R_ADC_ScanStop (adc_ctrl_t * p_ctrl)
 {
@@ -415,6 +431,7 @@ fsp_err_t R_ADC_ScanStop (adc_ctrl_t * p_ctrl)
     /* Verify the pointers are valid */
     FSP_ASSERT(NULL != p_instance_ctrl);
     FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->opened, FSP_ERR_NOT_OPEN);
+    FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->initialized, FSP_ERR_NOT_INITIALIZED);
 #endif
 
     /* Disable hardware trigger or stop software scan depending on mode. */
@@ -454,6 +471,7 @@ fsp_err_t R_ADC_StatusGet (adc_ctrl_t * p_ctrl, adc_status_t * p_status)
  * @retval FSP_SUCCESS                 Data read into provided p_data.
  * @retval FSP_ERR_ASSERTION           An input argument is invalid.
  * @retval FSP_ERR_NOT_OPEN            Unit is not open.
+ * @retval FSP_ERR_NOT_INITIALIZED     Unit is not initialized.
  **********************************************************************************************************************/
 fsp_err_t R_ADC_Read (adc_ctrl_t * p_ctrl, adc_channel_t const reg_id, uint16_t * const p_data)
 {
@@ -466,6 +484,7 @@ fsp_err_t R_ADC_Read (adc_ctrl_t * p_ctrl, adc_channel_t const reg_id, uint16_t
     FSP_ASSERT(NULL != p_instance_ctrl);
     FSP_ASSERT(NULL != p_data);
     FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->opened, FSP_ERR_NOT_OPEN);
+    FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->initialized, FSP_ERR_NOT_INITIALIZED);
 
     /* Verify that the channel is valid for this MCU */
     if ((reg_id >= ADC_CHANNEL_0) && ((uint32_t) reg_id <= 31U))
@@ -479,6 +498,10 @@ fsp_err_t R_ADC_Read (adc_ctrl_t * p_ctrl, adc_channel_t const reg_id, uint16_t
                    (reg_id == ADC_CHANNEL_DUPLEX) || (reg_id == ADC_CHANNEL_DUPLEX_A) ||
                    (reg_id == ADC_CHANNEL_DUPLEX_B));
     }
+
+    /* Data is not available to be read from ADDRn registers when ADBUF is enabled. Read API cannot be used with ADBUF enabled. */
+    adc_extended_cfg_t * p_extend = (adc_extended_cfg_t *) p_instance_ctrl->p_cfg->p_extend;
+    FSP_ASSERT(1U != p_extend->enable_adbuf);
 #endif
 
     /* Read the data from the requested ADC conversion register and return it */
@@ -494,6 +517,7 @@ fsp_err_t R_ADC_Read (adc_ctrl_t * p_ctrl, adc_channel_t const reg_id, uint16_t
  * @retval FSP_SUCCESS                 Data read into provided p_data.
  * @retval FSP_ERR_ASSERTION           An input argument is invalid.
  * @retval FSP_ERR_NOT_OPEN            Unit is not open.
+ * @retval FSP_ERR_NOT_INITIALIZED     Unit is not initialized.
  **********************************************************************************************************************/
 fsp_err_t R_ADC_Read32 (adc_ctrl_t * p_ctrl, adc_channel_t const reg_id, uint32_t * const p_data)
 {
@@ -529,6 +553,7 @@ fsp_err_t R_ADC_Read32 (adc_ctrl_t * p_ctrl, adc_channel_t const reg_id, uint32_
  *
  * @retval FSP_SUCCESS                 Sample state count updated.
  * @retval FSP_ERR_ASSERTION           An input argument is invalid.
+ * @retval FSP_ERR_NOT_INITIALIZED     Unit is not initialized.
  * @retval FSP_ERR_NOT_OPEN            Unit is not open.
  **********************************************************************************************************************/
 fsp_err_t R_ADC_SampleStateCountSet (adc_ctrl_t * p_ctrl, adc_sample_state_t * p_sample)
@@ -543,6 +568,7 @@ fsp_err_t R_ADC_SampleStateCountSet (adc_ctrl_t * p_ctrl, adc_sample_state_t * p
     FSP_ASSERT(NULL != p_instance_ctrl);
     FSP_ASSERT(NULL != p_sample);
     FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->opened, FSP_ERR_NOT_OPEN);
+    FSP_ERROR_RETURN(ADC_OPEN == p_instance_ctrl->initialized, FSP_ERR_NOT_INITIALIZED);
 
     /* Verify arguments are legal */
     err = r_adc_sample_state_cfg_check(p_instance_ctrl, p_sample);
@@ -675,20 +701,15 @@ fsp_err_t R_ADC_Close (adc_ctrl_t * p_ctrl)
 #endif
 
     /* Mark driver as closed   */
-    p_instance_ctrl->opened = 0U;
+    p_instance_ctrl->opened      = 0U;
+    p_instance_ctrl->initialized = 0U;
 
     /* Disable interrupts. */
-    if (p_instance_ctrl->p_cfg->scan_end_irq >= 0)
-    {
-        R_BSP_IrqDisable(p_instance_ctrl->p_cfg->scan_end_irq);
-        R_FSP_IsrContextSet(p_instance_ctrl->p_cfg->scan_end_irq, NULL);
-    }
-
-    if (p_instance_ctrl->p_cfg->scan_end_b_irq >= 0)
-    {
-        R_BSP_IrqDisable(p_instance_ctrl->p_cfg->scan_end_b_irq);
-        R_FSP_IsrContextSet(p_instance_ctrl->p_cfg->scan_end_b_irq, NULL);
-    }
+    adc_extended_cfg_t * p_extend = (adc_extended_cfg_t *) p_instance_ctrl->p_cfg->p_extend;
+    r_adc_irq_disable(p_instance_ctrl->p_cfg->scan_end_irq);
+    r_adc_irq_disable(p_instance_ctrl->p_cfg->scan_end_b_irq);
+    r_adc_irq_disable(p_extend->window_a_irq);
+    r_adc_irq_disable(p_extend->window_b_irq);
 
     /* Disable triggers. */
     p_instance_ctrl->p_reg->ADSTRGR = 0U;
@@ -716,26 +737,6 @@ fsp_err_t R_ADC_Close (adc_ctrl_t * p_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Retrieve the API version number.
- *
- * @retval FSP_SUCCESS                 Version stored in the provided p_version.
- * @retval FSP_ERR_ASSERTION           An input argument is invalid.
- **********************************************************************************************************************/
-fsp_err_t R_ADC_VersionGet (fsp_version_t * const p_version)
-{
-#if ADC_CFG_PARAM_CHECKING_ENABLE
-
-    /* Verify parameters are valid */
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    /* Return the version number */
-    p_version->version_id = g_adc_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * Initiates calibration of the ADC on MCUs that require calibration.  This function must be called before starting
  * a scan on MCUs that require calibration.
@@ -760,7 +761,7 @@ fsp_err_t R_ADC_VersionGet (fsp_version_t * const p_version)
  * @retval FSP_ERR_ASSERTION               An input argument is invalid.
  * @retval FSP_ERR_NOT_OPEN                Unit is not open.
  **********************************************************************************************************************/
-fsp_err_t R_ADC_Calibrate (adc_ctrl_t * const p_ctrl, void * const p_extend)
+fsp_err_t R_ADC_Calibrate (adc_ctrl_t * const p_ctrl, void const * p_extend)
 {
     FSP_PARAMETER_NOT_USED(p_extend);
 
@@ -1001,6 +1002,42 @@ static fsp_err_t r_adc_scan_cfg_check_sample_hold (adc_instance_ctrl_t * const
     return FSP_SUCCESS;
 }
 
+/*******************************************************************************************************************//**
+ * Enforces constraints on Window Compare function usage per section 47.3.5.3 "Constraints on the compare function" in
+ * the RA6M3 User's Manual (R01UH0886EJ0100)
+ *
+ * @param[in]  p_window_cfg            Pointer to window compare configuration
+ *
+ * @retval FSP_SUCCESS                 No configuration errors detected
+ * @retval FSP_ERR_ASSERTION           An input argument is invalid.
+ **********************************************************************************************************************/
+static fsp_err_t r_adc_scan_cfg_check_window_compare (adc_window_cfg_t const * const p_window_cfg)
+{
+    if (p_window_cfg)
+    {
+        uint32_t compare_cfg = p_window_cfg->compare_cfg;
+        if (0U != compare_cfg)
+        {
+            if ((compare_cfg & R_ADC0_ADCMPCR_CMPAE_Msk) && (compare_cfg & R_ADC0_ADCMPCR_CMPBE_Msk))
+            {
+                /* Ensure channels selected for Window A do not conflict with Window B */
+                uint32_t compare_b_ch = p_window_cfg->compare_b_channel;
+                compare_b_ch -= compare_b_ch > 31 ? 4 : 0;
+                FSP_ASSERT(!(p_window_cfg->compare_mask & (uint32_t) (1 << compare_b_ch)));
+            }
+
+            if (compare_cfg & R_ADC0_ADCMPCR_WCMPE_Msk)
+            {
+                /* Ensure lower reference values are less than or equal to the high reference values */
+                FSP_ASSERT((p_window_cfg->compare_ref_low <= p_window_cfg->compare_ref_high) &&
+                           (p_window_cfg->compare_b_ref_low <= p_window_cfg->compare_b_ref_high));
+            }
+        }
+    }
+
+    return FSP_SUCCESS;
+}
+
 #endif
 
 #if ADC_CFG_PARAM_CHECKING_ENABLE
@@ -1068,6 +1105,8 @@ static void r_adc_open_sub (adc_instance_ctrl_t * const p_instance_ctrl, adc_cfg
 
     /* Determine the value for ADCSR:
      *   * The configured mode is set in ADCSR.ADCS.
+     *   * Low-power conversion mode must be selected when internal reference voltage is selected as the high-potential
+     *     reference voltage.
      *   * ADCSR.GBADIE is always set by this driver. It will only trigger an interrupt in group mode if the group B
      *     interrupt is enabled.
      *   * If double-trigger mode is selected ADCSR.DBLANS is set to the chosen double-trigger scan channel and
@@ -1080,6 +1119,13 @@ static void r_adc_open_sub (adc_instance_ctrl_t * const p_instance_ctrl, adc_cfg
     adcsr |= (uint32_t) (R_ADC0_ADCSR_GBADIE_Msk);
     adcsr |= ((uint32_t) p_cfg->trigger << R_ADC0_ADCSR_EXTRG_Pos);
 
+#if BSP_FEATURE_ADC_HAS_ADHVREFCNT
+    if (ADC_PRV_ADHVREFCNT_VREF_INTERNAL_BIT_1 & p_cfg_extend->adc_vref_control)
+    {
+        adcsr |= R_ADC0_ADCSR_ADHSC_Msk;
+    }
+#endif
+
     if (ADC_DOUBLE_TRIGGER_DISABLED != p_cfg_extend->double_trigger_mode)
     {
         adcsr |= R_ADC0_ADCSR_TRGE_Msk | R_ADC0_ADCSR_DBLE_Msk;
@@ -1181,6 +1227,31 @@ static void r_adc_open_sub (adc_instance_ctrl_t * const p_instance_ctrl, adc_cfg
         p_instance_ctrl->p_reg->VREFAMPCNT = (uint8_t) (p_cfg_extend->adc_vref_control);
     }
 #endif
+
+#if BSP_FEATURE_ADC_HAS_ADHVREFCNT
+
+    /* If the internal voltage is set as VREFH, discharge the VREF node for 1 us before setting ADHVREFCNT.HVSEL to 2.
+     * Reference section 35.7 "A/D Conversion Procedure when Selecting Internal Reference Voltage as High-Potential
+     * Reference Voltage" in the RA4M1 manual R01UH0887EJ0100.
+     *
+     * Also wait 5 us before using the ADC. This wait is the responsibility of the application. */
+    if (ADC_PRV_ADHVREFCNT_VREF_INTERNAL_BIT_1 & p_cfg_extend->adc_vref_control)
+    {
+        p_instance_ctrl->p_reg->ADHVREFCNT = (uint8_t) (p_cfg_extend->adc_vref_control | R_ADC0_ADHVREFCNT_HVSEL_Msk);
+
+        R_BSP_SoftwareDelay(1U, BSP_DELAY_UNITS_MICROSECONDS);
+    }
+    p_instance_ctrl->p_reg->ADHVREFCNT = (uint8_t) p_cfg_extend->adc_vref_control;
+#endif
+
+#if BSP_FEATURE_ADC_HAS_ADBUF
+    uint8_t adbuf = 0;
+    if (1U == p_cfg_extend->enable_adbuf)
+    {
+        adbuf = R_ADC0_ADBUFEN_BUFEN_Msk;
+    }
+    p_instance_ctrl->p_reg->ADBUFEN = adbuf;
+#endif
 }
 
 /*******************************************************************************************************************//**
@@ -1367,6 +1438,10 @@ static fsp_err_t r_adc_scan_cfg_check (adc_instance_ctrl_t * const     p_instanc
 
     /* Check sample and hold settings. */
     err = r_adc_scan_cfg_check_sample_hold(p_instance_ctrl, p_channel_cfg);
+    FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
+
+    /* Check window compare settings. */
+    err = r_adc_scan_cfg_check_window_compare(p_channel_cfg->p_window_cfg);
 
     return err;
 }
@@ -1419,6 +1494,49 @@ static void r_adc_scan_cfg (adc_instance_ctrl_t * const p_instance_ctrl, adc_cha
     p_instance_ctrl->p_reg->ADSHCR = (uint16_t) adshcr;
 #endif
 
+    /* Get window compare configuration */
+    adc_window_cfg_t * p_window_cfg = p_channel_cfg->p_window_cfg;
+
+    uint16_t adcmpcr = 0;
+
+    if (p_window_cfg)
+    {
+        /* Save window compare config */
+        adcmpcr = (uint16_t) p_window_cfg->compare_cfg;
+
+        if (p_window_cfg->compare_cfg & R_ADC0_ADCMPCR_CMPAE_Msk)
+        {
+            /* Set Window A boundary values */
+            p_instance_ctrl->p_reg->ADCMPCR  = p_window_cfg->compare_cfg & UINT16_MAX;
+            p_instance_ctrl->p_reg->ADCMPDR0 = p_window_cfg->compare_ref_low;
+            p_instance_ctrl->p_reg->ADCMPDR1 = p_window_cfg->compare_ref_high;
+
+            /* Set Window A channel mask */
+            p_instance_ctrl->p_reg->ADCMPANSR[0] = p_window_cfg->compare_mask & UINT16_MAX;
+            p_instance_ctrl->p_reg->ADCMPANSR[1] = (uint16_t) ((p_window_cfg->compare_mask << 4) >> 20);
+            p_instance_ctrl->p_reg->ADCMPANSER   = (uint8_t) (p_window_cfg->compare_mask >> 28);
+
+            /* Set Window A channel inequality mode mask */
+            p_instance_ctrl->p_reg->ADCMPLR[0] = p_window_cfg->compare_mode_mask & UINT16_MAX;
+            p_instance_ctrl->p_reg->ADCMPLR[1] = (uint16_t) ((p_window_cfg->compare_mode_mask << 4) >> 20);
+            p_instance_ctrl->p_reg->ADCMPLER   = (uint8_t) (p_window_cfg->compare_mode_mask >> 28);
+        }
+
+        if (p_window_cfg->compare_cfg & R_ADC0_ADCMPCR_CMPBE_Msk)
+        {
+            /* Set Window B channel and mode */
+            p_instance_ctrl->p_reg->ADCMPBNSR = (uint8_t) ((adc_window_b_mode_t) p_window_cfg->compare_b_channel |
+                                                           p_window_cfg->compare_b_mode);
+
+            /* Set Window B boundary values */
+            p_instance_ctrl->p_reg->ADWINLLB = p_window_cfg->compare_b_ref_low;
+            p_instance_ctrl->p_reg->ADWINULB = p_window_cfg->compare_b_ref_high;
+        }
+    }
+
+    /* Set window compare config */
+    p_instance_ctrl->p_reg->ADCMPCR = adcmpcr;
+
     /* Set group A priority action (not interrupt priority!)
      * This will also start the Group B scans if configured for ADC_GROUP_A_GROUP_B_CONTINUOUS_SCAN.
      */
@@ -1433,6 +1551,37 @@ static void r_adc_scan_cfg (adc_instance_ctrl_t * const p_instance_ctrl, adc_cha
         p_instance_ctrl->p_reg->ADCSR      = (uint16_t) adcsr;
         p_instance_ctrl->scan_start_adcsr |= (uint16_t) adcsr;
     }
+
+    p_instance_ctrl->initialized = ADC_OPEN;
+}
+
+/*******************************************************************************************************************//**
+ * Disables and clears context for the requested IRQ.
+ *
+ * @param[in]  irq        IRQ to enable
+ * @param[in]  ipl        Interrupt priority
+ * @param[in]  p_context  Pointer to interrupt context
+ **********************************************************************************************************************/
+static void r_adc_irq_enable (IRQn_Type irq, uint8_t ipl, void * p_context)
+{
+    if (irq >= 0)
+    {
+        R_BSP_IrqCfgEnable(irq, ipl, p_context);
+    }
+}
+
+/*******************************************************************************************************************//**
+ * Disables and clears context for the requested IRQ.
+ *
+ * @param[in]  irq  IRQ to disable
+ **********************************************************************************************************************/
+static void r_adc_irq_disable (IRQn_Type irq)
+{
+    if (irq >= 0)
+    {
+        R_BSP_IrqDisable(irq);
+        R_FSP_IsrContextSet(irq, NULL);
+    }
 }
 
 /*******************************************************************************************************************//**
@@ -1457,6 +1606,61 @@ static int32_t r_adc_lowest_channel_get (uint32_t adc_mask)
     return adc_mask_count;
 }
 
+/*******************************************************************************************************************//**
+ * Calls user callback.
+ *
+ * @param[in]     p_ctrl     Pointer to ADC instance control block
+ * @param[in]     p_args     Pointer to arguments on stack
+ **********************************************************************************************************************/
+static void r_adc_call_callback (adc_instance_ctrl_t * p_ctrl, adc_callback_args_t * p_args)
+{
+    adc_callback_args_t args;
+
+    /* Store callback arguments in memory provided by user if available.  This allows callback arguments to be
+     * stored in non-secure memory so they can be accessed by a non-secure callback function. */
+    adc_callback_args_t * p_args_memory = p_ctrl->p_callback_memory;
+    if (NULL == p_args_memory)
+    {
+        /* Use provided args struct on stack */
+        p_args_memory = p_args;
+    }
+    else
+    {
+        /* Save current arguments on the stack in case this is a nested interrupt. */
+        args = *p_args_memory;
+
+        /* Copy the stacked args to callback memory */
+        *p_args_memory = *p_args;
+    }
+
+#if BSP_TZ_SECURE_BUILD
+
+    /* p_callback can point to a secure function or a non-secure function. */
+    if (!cmse_is_nsfptr(p_ctrl->p_callback))
+    {
+        /* If p_callback is secure, then the project does not need to change security state. */
+        p_ctrl->p_callback(p_args_memory);
+    }
+    else
+    {
+        /* If p_callback is Non-secure, then the project must change to Non-secure state in order to call the callback. */
+        adc_prv_ns_callback p_callback = (adc_prv_ns_callback) (p_ctrl->p_callback);
+        p_callback(p_args_memory);
+    }
+
+#else
+
+    /* If the project is not Trustzone Secure, then it will never need to change security state in order to call the callback. */
+    p_ctrl->p_callback(p_args_memory);
+#endif
+
+    if (NULL != p_ctrl->p_callback_memory)
+    {
+        /* Restore callback memory in case this is a nested interrupt. */
+        *p_ctrl->p_callback_memory = args;
+    }
+}
+
 /*******************************************************************************************************************//**
  * Clears interrupt flag and calls a callback to notify application of the event.
  *
@@ -1465,35 +1669,21 @@ static int32_t r_adc_lowest_channel_get (uint32_t adc_mask)
 static void r_adc_scan_end_common_isr (adc_event_t event)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     adc_instance_ctrl_t * p_instance_ctrl = (adc_instance_ctrl_t *) R_FSP_IsrContextGet(R_FSP_CurrentIrqGet());
-    adc_callback_args_t   args;
-
-    /* Store callback arguments in memory provided by user if available.  This allows callback arguments to be
-     * stored in non-secure memory so they can be accessed by a non-secure callback function. */
-    adc_callback_args_t * p_args = p_instance_ctrl->p_callback_memory;
-    if (NULL == p_args)
-    {
-        /* Store on stack */
-        p_args = &args;
-    }
-    else
-    {
-        /* Save current arguments on the stack in case this is a nested interrupt. */
-        args = *p_args;
-    }
 
     /* Clear the BSP IRQ Flag     */
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
 
-    p_args->event = event;
+    adc_callback_args_t args;
+    args.event = event;
 #if BSP_FEATURE_ADC_CALIBRATION_REG_AVAILABLE
 
     /* Store the correct event into the callback argument */
     if (ADC_ADICR_CALIBRATION_INTERRUPT_DISABLED != p_instance_ctrl->p_reg->ADICR)
     {
-        p_args->event = ADC_EVENT_CALIBRATION_COMPLETE;
+        args.event = ADC_EVENT_CALIBRATION_COMPLETE;
 
         /* Restore the interrupt source to disable interrupts after calibration is done. */
         p_instance_ctrl->p_reg->ADICR = 0U;
@@ -1501,47 +1691,22 @@ static void r_adc_scan_end_common_isr (adc_event_t event)
 #endif
 
     /* Store the unit number into the callback argument */
-    p_args->unit = p_instance_ctrl->p_cfg->unit;
+    args.unit = p_instance_ctrl->p_cfg->unit;
 
     /* Initialize the channel to 0.  It is not used in this implementation. */
-    p_args->channel = ADC_CHANNEL_0;
+    args.channel = ADC_CHANNEL_0;
 
     /* Populate the context field. */
-    p_args->p_context = p_instance_ctrl->p_context;
+    args.p_context = p_instance_ctrl->p_context;
 
     /* If a callback was provided, call it with the argument */
     if (NULL != p_instance_ctrl->p_callback)
     {
-#if BSP_TZ_SECURE_BUILD
-
-        /* p_callback can point to a secure function or a non-secure function. */
-        if (!cmse_is_nsfptr(p_instance_ctrl->p_callback))
-        {
-            /* If p_callback is secure, then the project does not need to change security state. */
-            p_instance_ctrl->p_callback(p_args);
-        }
-        else
-        {
-            /* If p_callback is Non-secure, then the project must change to Non-secure state in order to call the callback. */
-            adc_prv_ns_callback p_callback = (adc_prv_ns_callback) (p_instance_ctrl->p_callback);
-            p_callback(p_args);
-        }
-
-#else
-
-        /* If the project is not Trustzone Secure, then it will never need to change security state in order to call the callback. */
-        p_instance_ctrl->p_callback(p_args);
-#endif
-    }
-
-    if (NULL != p_instance_ctrl->p_callback_memory)
-    {
-        /* Restore callback memory in case this is a nested interrupt. */
-        *p_instance_ctrl->p_callback_memory = args;
+        r_adc_call_callback(p_instance_ctrl, &args);
     }
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1559,3 +1724,88 @@ void adc_scan_end_b_isr (void)
 {
     r_adc_scan_end_common_isr(ADC_EVENT_SCAN_COMPLETE_GROUP_B);
 }
+
+/*******************************************************************************************************************//**
+ * This function implements the interrupt handler for window compare events.
+ **********************************************************************************************************************/
+void adc_window_compare_isr (void)
+{
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
+
+    IRQn_Type irq = R_FSP_CurrentIrqGet();
+
+    adc_instance_ctrl_t * p_instance_ctrl = (adc_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
+    adc_extended_cfg_t  * p_extend        = (adc_extended_cfg_t *) p_instance_ctrl->p_cfg->p_extend;
+
+    adc_callback_args_t args;
+    args.event = (irq == p_extend->window_a_irq) ? ADC_EVENT_WINDOW_COMPARE_A : ADC_EVENT_WINDOW_COMPARE_B;
+
+    /* Store the unit number into the callback argument */
+    args.unit = p_instance_ctrl->p_cfg->unit;
+
+    if (ADC_EVENT_WINDOW_COMPARE_A == args.event)
+    {
+        args.channel = (adc_channel_t) 0;
+
+        R_ADC0_Type * p_reg = p_instance_ctrl->p_reg;
+
+        /* Get all Window A status registers */
+        uint16_t adcmpsr0 = p_reg->ADCMPSR[0];
+        uint16_t adcmpsr1 = p_reg->ADCMPSR[1];
+        uint8_t  adcmpser = p_reg->ADCMPSER;
+
+        /* Get the lowest channel that meets Window A criteria */
+        uint32_t lowest_channel = __CLZ(__RBIT(adcmpsr0 + (uint32_t) (adcmpsr1 << 16) + (uint32_t) (adcmpser << 28)));
+
+        /* Clear the status flag corresponding to the lowest channel */
+        if (lowest_channel < 16)
+        {
+            p_reg->ADCMPSR[0] = (uint16_t) (adcmpsr0 & ~(1 << (lowest_channel & 0xF)));
+        }
+        else if (lowest_channel < 28)
+        {
+            p_reg->ADCMPSR[1] = (uint16_t) (adcmpsr1 & ~(1 << (lowest_channel & 0xF)));
+        }
+        else
+        {
+            p_reg->ADCMPSER = (uint8_t) (adcmpser & ~(1 << (lowest_channel & 0x3)));
+        }
+
+        args.channel = (adc_channel_t) lowest_channel;
+
+        if (args.channel > 28)
+        {
+            /* Adjust sensor channels to align with the adc_channel_t enumeration */
+            args.channel = (adc_channel_t) (ADC_CHANNEL_TEMPERATURE + (args.channel - 28));
+        }
+    }
+    else
+    {
+        /* Get channel selected for Window B */
+        args.channel = (adc_channel_t) p_instance_ctrl->p_reg->ADCMPBNSR_b.CMPCHB;
+
+        if (args.channel > 31)
+        {
+            /* Adjust sensor channels to align with the adc_channel_t enumeration */
+            args.channel = (adc_channel_t) (ADC_CHANNEL_TEMPERATURE + (args.channel & 0xF));
+        }
+
+        /* Clear IRQ */
+        p_instance_ctrl->p_reg->ADCMPBSR_b.CMPSTB = 0;
+    }
+
+    /* Populate the context field. */
+    args.p_context = p_instance_ctrl->p_context;
+
+    /* If a callback was provided, call it with the argument */
+    if (NULL != p_instance_ctrl->p_callback)
+    {
+        r_adc_call_callback(p_instance_ctrl, &args);
+    }
+
+    R_BSP_IrqStatusClear(irq);
+
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
+}
