@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -21,7 +21,6 @@
 /***********************************************************************************************************************
  * Includes
  **********************************************************************************************************************/
-#include "r_wdt_api.h"
 #include "r_iwdt.h"
 #include "bsp_api.h"
 #include "bsp_cfg.h"
@@ -29,38 +28,77 @@
 /***********************************************************************************************************************
  * Macro definitions
  **********************************************************************************************************************/
-#define IWDT_OPEN                           (0X49574454ULL)
-#define IWDT_PRV_OFS0_AUTO_START_MASK       (0x00000002U)
-#define IWDT_PRV_OFS0_NMI_REQUEST_MASK      (0x00001000U)
-#define IWDT_PRV_OFS0_TIMEOUT_MASK          (0x0000000CU)
-#define IWDT_PRV_OFS0_CLOCK_DIVIDER_MASK    (0x000000F0U)
-#define IWDT_PRV_OFS0_WINDOW_END_MASK       (0x00000300U)
-#define IWDT_PRV_OFS0_WINDOW_START_MASK     (0x00000C00U)
-#define IWDT_PRV_OFS0_RESET_CONTROL_MASK    (0x00001000U)
-#define IWDT_PRV_OFS0_STOP_CONTROL_MASK     (0x00004000U)
-#define IWDT_PRV_IWDTSR_COUNTER_MASK        (0x3FFFU)
-#define IWDT_PRV_IWDTSR_FLAGS_MASK          (0x0000C000U)
-#define IWDT_PRV_STATUS_START_BIT           (14U) /*Bit 14 and Bit 15*/
+
+/* "IWDT" in ASCII.  Used to determine if the control block is open. */
+#define IWDT_OPEN    (0X49574454ULL)
+
+/* Lookup functions for IWDT settings.  Using function like macro for stringification. */
+#define IWDT_PRV_OFS0_SETTING_GET(setting)     (((uint32_t) BSP_CFG_ROM_REG_OFS0 >>   \
+                                                 IWDT_PRV_OFS0_ ## setting ## _BIT) & \
+                                                IWDT_PRV_OFS0_ ## setting ## _MASK);
+#define IWDT_PRV_IWDTCR_SETTING_GET(setting,                                                       \
+                                    iwdtcr)    (((iwdtcr >> IWDT_PRV_IWDTCR_ ## setting ## _BIT) & \
+                                                 IWDT_PRV_IWDTCR_ ## setting ## _MASK));
+#define IWDT_PRV_IWDTCR_SETTING_SET(setting,                                                      \
+                                    value)     ((value & IWDT_PRV_IWDTCR_ ## setting ## _MASK) << \
+                                                IWDT_PRV_IWDTCR_ ## setting ## _BIT);
+
+/* OFS0 register settings. */
+#define IWDT_PRV_OFS0_AUTO_START_MASK          (0x00000002U)
+#define IWDT_PRV_OFS0_TIMEOUT_BIT              (2U)
+#define IWDT_PRV_OFS0_TIMEOUT_MASK             (0x00000003U)
+#define IWDT_PRV_OFS0_NMI_REQUEST_MASK         (0x00001000U)
+#define IWDT_PRV_OFS0_CLOCK_DIVISION_BIT       (4U)
+#define IWDT_PRV_OFS0_CLOCK_DIVISION_MASK      (0x0000000FU)
+
+/* Status register settings. */
+#define IWDT_PRV_STATUS_START_BIT              (14U) /*Bit 14 and Bit 15*/
+
+/* Reset Control register settings. */
+#define IWDT_PRV_IWDTRCR_RESET_CONTROL_BIT     (7U)
+
+/* Count Stop Count Control register settings. */
+#define IWDT_PRV_IWDTCSTPR_STOP_CONTROL_BIT    (7U)
+
+/* Status register settings. */
+#define IWDT_PRV_IWDTSR_COUNTER_MASK           (0x3FFFU)
+
+/* Control register settings. */
+#define IWDT_PRV_IWDTCR_TIMEOUT_BIT            (0)  // Bits 0-1
+#define IWDT_PRV_IWDTCR_TIMEOUT_MASK           (0x3U)
+#define IWDT_PRV_IWDTCR_CLOCK_DIVISION_BIT     (4)  // Bits 4-7
+#define IWDT_PRV_IWDTCR_CLOCK_DIVISION_MASK    (0xFU)
+#define IWDT_PRV_IWDTCR_WINDOW_END_BIT         (8)  // Bits 8-9
+#define IWDT_PRV_IWDTCR_WINDOW_END_MASK        (0x3U)
+#define IWDT_PRV_IWDTCR_WINDOW_START_BIT       (12) // Bits 12-13
+#define IWDT_PRV_IWDTCR_WINDOW_START_MASK      (0x3U)
 
 /* Refresh register values */
-#define IWDT_PRV_REFRESH_STEP_1             (0U)
-#define IWDT_PRV_REFRESH_STEP_2             (0xFFU)
-
-/* Clock frequency of IWDT */
-#define IWDT_CLOCK_FREQUENCY                15000UL
+#define IWDT_PRV_REFRESH_STEP_1                (0U)
+#define IWDT_PRV_REFRESH_STEP_2                (0xFFU)
 
 /* Macros for start mode and NMI support. */
-#if ((BSP_CFG_ROM_REG_OFS0 & IWDT_PRV_OFS0_AUTO_START_MASK) == 0)
- #define IWDT_PRV_AUTO_START_MODE           (1)
+#if (BSP_CFG_ROM_REG_OFS0 & IWDT_PRV_OFS0_AUTO_START_MASK)
+ #if (BSP_FEATURE_IWDT_SUPPORTS_REGISTER_START_MODE)
+
+/* Register start mode */
+  #define IWDT_PRV_REGISTER_START_MODE    (1U)
+  #define IWDT_PRV_NMI_SUPPORTED          (IWDT_CFG_REGISTER_START_NMI_SUPPORTED)
+ #else
+  #define IWDT_PRV_REGISTER_START_MODE    (0U)
+  #define IWDT_PRV_NMI_SUPPORTED          (0U)
+ #endif
+ #define IWDT_PRV_AUTO_START_MODE         (0U)
 #else
 
 /* Auto start mode */
- #define IWDT_PRV_AUTO_START_MODE           (0)
-#endif
-#if ((BSP_CFG_ROM_REG_OFS0 & IWDT_PRV_OFS0_NMI_REQUEST_MASK) == 0)
- #define IWDT_PRV_NMI_SUPPORTED             (1)
-#else
- #define IWDT_PRV_NMI_SUPPORTED             (0)
+ #define IWDT_PRV_AUTO_START_MODE         (1)
+ #define IWDT_PRV_REGISTER_START_MODE     (0)
+ #if (BSP_CFG_ROM_REG_OFS0 & IWDT_PRV_OFS0_NMI_REQUEST_MASK)
+  #define IWDT_PRV_NMI_SUPPORTED          (0)
+ #else
+  #define IWDT_PRV_NMI_SUPPORTED          (1)
+ #endif
 #endif
 
 /***********************************************************************************************************************
@@ -76,48 +114,34 @@ typedef BSP_CMSE_NONSECURE_CALL void (*volatile iwdt_prv_ns_callback)(wdt_callba
 /***********************************************************************************************************************
  * Private function prototypes
  **********************************************************************************************************************/
-static void iwdt_nmi_internal_callback(bsp_grp_irq_t irq);
+static uint32_t iwdt_clock_divider_get(wdt_clock_division_t division);
 
-static uint32_t wdt_clock_divider_get(wdt_clock_division_t division);
+#if IWDT_CFG_PARAM_CHECKING_ENABLE
+static fsp_err_t iwdt_parameter_checking(iwdt_instance_ctrl_t * const p_instance_ctrl, wdt_cfg_t const * const p_cfg);
+
+#endif
+
+#if IWDT_PRV_NMI_SUPPORTED
+static void iwdt_nmi_internal_callback(bsp_grp_irq_t irq);
+static void iwdt_nmi_initialize(iwdt_instance_ctrl_t * const p_instance_ctrl, wdt_cfg_t const * const p_cfg);
+
+#endif
 
 /***********************************************************************************************************************
  * Private global variables
  **********************************************************************************************************************/
 
-/* Version data structure used by error logger macro. */
-static const fsp_version_t g_iwdt_version =
+/* Convert IWDT timeout value to an integer */
+static const uint32_t g_iwdt_timeout[] =
 {
-    .api_version_minor  = WDT_API_VERSION_MINOR,
-    .api_version_major  = WDT_API_VERSION_MAJOR,
-    .code_version_major = IWDT_CODE_VERSION_MAJOR,
-    .code_version_minor = IWDT_CODE_VERSION_MINOR
-};
-
-static const uint8_t g_ofs0_timeout[] =
-{
-    0x00U,                             ///< IWDTCR value for WDT_TIMEOUT_128
-    0x04U,                             ///< IWDTCR value for WDT_TIMEOUT_512
-    0x08U,                             ///< IWDTCR value for WDT_TIMEOUT_1024
-    0x0CU,                             ///< WDTCR value for WDT_TIMEOUT_2048
-    0xFFU,                             ///< WDTCR value for WDT_TIMEOUT_4096 (not supported by IWDT)
-    0xFFU,                             ///< WDTCR value for WDT_TIMEOUT_8192 (not supported by IWDT)
-    0xFFU,                             ///< WDTCR value for WDT_TIMEOUT_16384 (not supported by IWDT)
-};
-
-/* Convert WDT/IWDT timeout value to an integer */
-static const uint32_t g_wdt_timeout[] =
-{
-    128U,
-    512U,
-    1024U,
-    2048U,
-    4096U,
-    8192U,
-    16384U
+    128U,                              ///< OFS0[3:0] value for WDT_TIMEOUT_128
+    512U,                              ///< OFS0[3:0] value for WDT_TIMEOUT_512
+    1024U,                             ///< OFS0[3:0] value for WDT_TIMEOUT_1024
+    2048U,                             ///< OFS0[3:0] value for WDT_TIMEOUT_2048
 };
 
 /* Converts IWDT division enum to log base 2 of the division value, used to shift the PCLKB frequency. */
-static const uint8_t g_wdt_division_lookup[] =
+static const uint8_t g_iwdt_division_lookup[] =
 {
     0U,                                // log base 2(1)    = 0
     2U,                                // log base 2(4)    = 2
@@ -130,10 +154,12 @@ static const uint8_t g_wdt_division_lookup[] =
     13U,                               // log base 2(8192) = 13
 };
 
-/* Global pointer to control structure for use by the NMI callback.  */
+/* Global pointer to control structure for use by the NMI callback. */
+#if IWDT_PRV_NMI_SUPPORTED
 static volatile iwdt_instance_ctrl_t * gp_iwdt_ctrl = NULL;
+#endif
 
-/* Watchdog implementation of IWDT Driver  */
+/* Watchdog implementation of IWDT Driver. */
 const wdt_api_t g_wdt_on_iwdt =
 {
     .open        = R_IWDT_Open,
@@ -143,7 +169,6 @@ const wdt_api_t g_wdt_on_iwdt =
     .counterGet  = R_IWDT_CounterGet,
     .timeoutGet  = R_IWDT_TimeoutGet,
     .callbackSet = R_IWDT_CallbackSet,
-    .versionGet  = R_IWDT_VersionGet,
 };
 
 /*******************************************************************************************************************//**
@@ -171,47 +196,47 @@ const wdt_api_t g_wdt_on_iwdt =
 fsp_err_t R_IWDT_Open (wdt_ctrl_t * const p_api_ctrl, wdt_cfg_t const * const p_cfg)
 {
     iwdt_instance_ctrl_t * p_ctrl = (iwdt_instance_ctrl_t *) p_api_ctrl;
-    FSP_PARAMETER_NOT_USED(p_cfg);
-    FSP_PARAMETER_NOT_USED(iwdt_nmi_internal_callback);
 
 #if IWDT_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_cfg);
-    FSP_ASSERT(NULL != p_ctrl);
- #if IWDT_PRV_NMI_SUPPORTED
-    FSP_ASSERT(NULL != p_cfg->p_callback);
- #endif
 
-    /* Ensure this module is in the same security state as the NMI */
- #if defined(BSP_TZ_NONSECURE_BUILD) && BSP_TZ_NONSECURE_BUILD
-    FSP_ERROR_RETURN(SCB->AIRCR & SCB_AIRCR_BFHFNMINS_Msk, FSP_ERR_INVALID_STATE);
- #elif defined(BSP_TZ_SECURE_BUILD) && BSP_TZ_SECURE_BUILD
-    FSP_ERROR_RETURN(!(SCB->AIRCR & SCB_AIRCR_BFHFNMINS_Msk), FSP_ERR_INVALID_STATE);
- #endif
-
-    /* Enum checking is done here because some enums in wdt_timeout_t are not supported by the IWDT peripheral (they are
-     * included for other implementations of the watchdog interface). */
-    FSP_ASSERT((p_cfg->timeout == WDT_TIMEOUT_128) || (p_cfg->timeout == WDT_TIMEOUT_512) || \
-               (p_cfg->timeout == WDT_TIMEOUT_1024) || (p_cfg->timeout == WDT_TIMEOUT_2048));
-
-    /* Check the IWDT is enabled. */
-    FSP_ERROR_RETURN((0U != (uint32_t) IWDT_PRV_AUTO_START_MODE), FSP_ERR_NOT_ENABLED);
-
-    /* Check to see IWDT is already configured */
-    FSP_ERROR_RETURN(IWDT_OPEN != p_ctrl->wdt_open, FSP_ERR_ALREADY_OPEN);
+    /* Check validity of the parameters */
+    fsp_err_t err = iwdt_parameter_checking(p_ctrl, p_cfg);
+    FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 #endif
 
-#if IWDT_PRV_NMI_SUPPORTED
+    /* Configuration only valid when IWDT operating in register-start mode. */
+#if IWDT_PRV_REGISTER_START_MODE
 
-    /* Initialize global pointer to IWDT for NMI callback use. */
-    gp_iwdt_ctrl = p_ctrl;
-    R_BSP_GroupIrqWrite(BSP_GRP_IRQ_IWDT_ERROR, iwdt_nmi_internal_callback);
+    /* Register-start mode. */
+ #if IWDT_PRV_NMI_SUPPORTED
+    if (p_cfg->reset_control == WDT_RESET_CONTROL_NMI)
+    {
+        /* Register callback with BSP NMI ISR. */
+        iwdt_nmi_initialize(p_ctrl, p_cfg);
+    }
+ #endif
 
-    p_ctrl->p_callback = p_cfg->p_callback;
-    p_ctrl->p_context  = p_cfg->p_context;
+    /* Set the configuration registers in register start mode. */
+    R_IWDT->IWDTRCR_b.RSTIRQS = p_cfg->reset_control == WDT_RESET_CONTROL_RESET;
 
-    /* Enable the IWDT underflow/refresh error interrupt to generate an NMI. NMIER bits cannot be cleared after reset,
-     * so no need to read-modify-write. */
-    R_ICU->NMIER = R_ICU_NMIER_IWDTEN_Msk;
+    uint32_t iwdtcr = IWDT_PRV_IWDTCR_SETTING_SET(TIMEOUT, (uint16_t) p_cfg->timeout);
+    iwdtcr |= IWDT_PRV_IWDTCR_SETTING_SET(CLOCK_DIVISION, (uint16_t) p_cfg->clock_division);
+    iwdtcr |= IWDT_PRV_IWDTCR_SETTING_SET(WINDOW_START, (uint16_t) p_cfg->window_start);
+    iwdtcr |= IWDT_PRV_IWDTCR_SETTING_SET(WINDOW_END, (uint16_t) p_cfg->window_end);
+
+    R_IWDT->IWDTCR             = (uint16_t) iwdtcr;
+    R_IWDT->IWDTCSTPR_b.SLCSTP = p_cfg->stop_control == WDT_STOP_CONTROL_ENABLE;
+#else
+
+    /* Auto start mode. */
+    /* Check for NMI output mode. */
+ #if IWDT_PRV_NMI_SUPPORTED
+
+    /* Register callback with BSP NMI ISR. */
+    iwdt_nmi_initialize(p_ctrl, p_cfg);
+ #else
+    FSP_PARAMETER_NOT_USED(p_cfg);
+ #endif
 #endif
 
     p_ctrl->wdt_open = IWDT_OPEN;
@@ -233,12 +258,12 @@ fsp_err_t R_IWDT_Open (wdt_ctrl_t * const p_api_ctrl, wdt_cfg_t const * const p_
  **********************************************************************************************************************/
 fsp_err_t R_IWDT_Refresh (wdt_ctrl_t * const p_api_ctrl)
 {
-    FSP_PARAMETER_NOT_USED(p_api_ctrl);
-
 #if (1 == IWDT_CFG_PARAM_CHECKING_ENABLE)
     iwdt_instance_ctrl_t * p_ctrl = (iwdt_instance_ctrl_t *) p_api_ctrl;
     FSP_ASSERT(p_ctrl != NULL);
     FSP_ERROR_RETURN((IWDT_OPEN == p_ctrl->wdt_open), FSP_ERR_NOT_OPEN);
+#else
+    FSP_PARAMETER_NOT_USED(p_api_ctrl);
 #endif
 
     /* Described in hardware manual (see Section 26.3.2
@@ -251,9 +276,6 @@ fsp_err_t R_IWDT_Refresh (wdt_ctrl_t * const p_api_ctrl)
 
 /*******************************************************************************************************************//**
  * Read the IWDT status flags.
- * When the IWDT is configured to output a reset on underflow or refresh error reading the status and error flags
- * can be read after reset to establish if the IWDT caused the reset.
- * Reading the status and error flags in NMI output mode indicates whether the IWDT generated the NMI interrupt.
  *
  * Indicates both status and error conditions.
  *
@@ -263,20 +285,34 @@ fsp_err_t R_IWDT_Refresh (wdt_ctrl_t * const p_api_ctrl)
  * @retval FSP_SUCCESS              IWDT status successfully read.
  * @retval FSP_ERR_ASSERTION        Null pointer as a parameter.
  * @retval FSP_ERR_NOT_OPEN         The driver has not been opened. Perform R_IWDT_Open() first.
+ * @retval FSP_ERR_UNSUPPORTED      This function is only valid if the IWDT generates an NMI when an error occurs.
+ *
+ * @note When the IWDT is configured to output a reset on underflow or refresh error reading the status and error flags
+ *       serves no purpose as they will always indicate that no underflow has occurred and there is no refresh error.
+ *       Reading the status and error flags is only valid when interrupt request output is enabled.
  **********************************************************************************************************************/
 fsp_err_t R_IWDT_StatusGet (wdt_ctrl_t * const p_api_ctrl, wdt_status_t * const p_status)
 {
-#if (1 == IWDT_CFG_PARAM_CHECKING_ENABLE)
+#if IWDT_PRV_NMI_SUPPORTED
+ #if (1 == IWDT_CFG_PARAM_CHECKING_ENABLE)
     iwdt_instance_ctrl_t * p_ctrl = (iwdt_instance_ctrl_t *) p_api_ctrl;
     FSP_ASSERT(p_ctrl != NULL);
     FSP_ASSERT(p_status != NULL);
     FSP_ERROR_RETURN((IWDT_OPEN == p_ctrl->wdt_open), FSP_ERR_NOT_OPEN);
-#endif
+ #else
     FSP_PARAMETER_NOT_USED(p_api_ctrl);
+ #endif
 
     *p_status = (wdt_status_t) (R_IWDT->IWDTSR >> (uint32_t) IWDT_PRV_STATUS_START_BIT);
 
     return FSP_SUCCESS;
+#else
+    FSP_PARAMETER_NOT_USED(p_api_ctrl);
+    FSP_PARAMETER_NOT_USED(p_status);
+
+    /* This function is only supported when the NMI is used. */
+    return FSP_ERR_UNSUPPORTED;
+#endif
 }
 
 /*******************************************************************************************************************//**
@@ -288,18 +324,27 @@ fsp_err_t R_IWDT_StatusGet (wdt_ctrl_t * const p_api_ctrl, wdt_status_t * const
  * @retval FSP_SUCCESS              IWDT flag(s) successfully cleared.
  * @retval FSP_ERR_ASSERTION        Null pointer as a parameter.
  * @retval FSP_ERR_NOT_OPEN         The driver has not been opened. Perform R_IWDT_Open() first.
+ * @retval FSP_ERR_UNSUPPORTED      This function is only valid if the IWDT generates an NMI when an error occurs.
+ *
+ * @note When the IWDT is configured to output a reset on underflow or refresh error reading the status and error flags
+ *       serves no purpose as they will always indicate that no underflow has occurred and there is no refresh error.
+ *       Reading the status and error flags is only valid when interrupt request output is enabled.
  **********************************************************************************************************************/
 fsp_err_t R_IWDT_StatusClear (wdt_ctrl_t * const p_api_ctrl, const wdt_status_t status)
 {
-#if (1 == IWDT_CFG_PARAM_CHECKING_ENABLE)
-    iwdt_instance_ctrl_t * p_ctrl = (iwdt_instance_ctrl_t *) p_api_ctrl;
-    FSP_ASSERT(p_ctrl != NULL);
-    FSP_ERROR_RETURN((IWDT_OPEN == p_ctrl->wdt_open), FSP_ERR_NOT_OPEN);
-#endif
-    FSP_PARAMETER_NOT_USED(p_api_ctrl);
+#if IWDT_PRV_NMI_SUPPORTED
     uint16_t value;
     uint16_t read_value;
 
+ #if (1 == IWDT_CFG_PARAM_CHECKING_ENABLE)
+    iwdt_instance_ctrl_t * p_ctrl = (iwdt_instance_ctrl_t *) p_api_ctrl;
+    FSP_ASSERT(p_ctrl != NULL);
+    FSP_ERROR_RETURN((IWDT_OPEN == p_ctrl->wdt_open), FSP_ERR_NOT_OPEN);
+ #else
+    FSP_PARAMETER_NOT_USED(p_api_ctrl);
+ #endif
+
+    /* Casts to uint16_t to ensure value is handled as unsigned. */
     value = (uint16_t) status;
 
     /* Write zero to clear flags */
@@ -318,6 +363,13 @@ fsp_err_t R_IWDT_StatusClear (wdt_ctrl_t * const p_api_ctrl, const wdt_status_t
     } while (read_value);
 
     return FSP_SUCCESS;
+#else
+    FSP_PARAMETER_NOT_USED(p_api_ctrl);
+    FSP_PARAMETER_NOT_USED(status);
+
+    /* This function is only supported when the NMI is used. */
+    return FSP_ERR_UNSUPPORTED;
+#endif
 }
 
 /*******************************************************************************************************************//**
@@ -337,8 +389,9 @@ fsp_err_t R_IWDT_CounterGet (wdt_ctrl_t * const p_api_ctrl, uint32_t * const p_c
     FSP_ASSERT(p_ctrl != NULL);
     FSP_ASSERT(p_count != NULL);
     FSP_ERROR_RETURN((IWDT_OPEN == p_ctrl->wdt_open), FSP_ERR_NOT_OPEN);
-#endif
+#else
     FSP_PARAMETER_NOT_USED(p_api_ctrl);
+#endif
 
     (*p_count) = (uint32_t) R_IWDT->IWDTSR & (uint32_t) IWDT_PRV_IWDTSR_COUNTER_MASK;
 
@@ -359,27 +412,32 @@ fsp_err_t R_IWDT_TimeoutGet (wdt_ctrl_t * const p_api_ctrl, wdt_timeout_values_t
     FSP_ASSERT(p_ctrl != NULL);
     FSP_ASSERT(p_timeout != NULL);
     FSP_ERROR_RETURN((IWDT_OPEN == p_ctrl->wdt_open), FSP_ERR_NOT_OPEN);
-#endif
+#else
     FSP_PARAMETER_NOT_USED(p_api_ctrl);
-    uint32_t frequency;
-    uint32_t shift;
-    uint8_t  index;
+#endif
 
-    for (index = 0U; index < (uint8_t) (sizeof(g_ofs0_timeout)); index++)
-    {
-        /* Get timeout value from OFS0 register. */
-        if (g_ofs0_timeout[index] == (uint8_t) ((uint32_t) BSP_CFG_ROM_REG_OFS0 & IWDT_PRV_OFS0_TIMEOUT_MASK))
-        {
-            p_timeout->timeout_clocks = g_wdt_timeout[index];
-        }
-    }
+    uint32_t             frequency;
+    uint32_t             shift;
+    uint32_t             timeout = 0;
+    wdt_clock_division_t clock_division;
+
+#if IWDT_PRV_REGISTER_START_MODE
+
+    /* Read the configuration of the watchdog */
+    uint32_t iwdtcr = R_IWDT->IWDTCR;
+    clock_division = (wdt_clock_division_t) IWDT_PRV_IWDTCR_SETTING_GET(CLOCK_DIVISION, iwdtcr);
+    timeout        = IWDT_PRV_IWDTCR_SETTING_GET(TIMEOUT, iwdtcr);
+#else                                  /* Auto start mode */
+    clock_division = (wdt_clock_division_t) IWDT_PRV_OFS0_SETTING_GET(CLOCK_DIVISION);
+    timeout        = IWDT_PRV_OFS0_SETTING_GET(TIMEOUT);
+#endif
+
+    p_timeout->timeout_clocks = g_iwdt_timeout[timeout];
 
     /* Get the frequency of the clock supplying the watchdog */
-    frequency = (uint32_t) IWDT_CLOCK_FREQUENCY;
+    frequency = (uint32_t) BSP_FEATURE_IWDT_CLOCK_FREQUENCY;
 
-    shift =
-        wdt_clock_divider_get((wdt_clock_division_t) (((uint32_t) BSP_CFG_ROM_REG_OFS0 &
-                                                       IWDT_PRV_OFS0_CLOCK_DIVIDER_MASK) >> 4));
+    shift = iwdt_clock_divider_get(clock_division);
 
     p_timeout->clock_frequency_hz = frequency >> shift;
 
@@ -437,23 +495,6 @@ fsp_err_t R_IWDT_CallbackSet (wdt_ctrl_t * const          p_ctrl,
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Return IWDT HAL driver version. Implements @ref wdt_api_t::versionGet.
- *
- * @retval          FSP_SUCCESS         Call successful.
- * @retval      FSP_ERR_ASSERTION       Null pointer passed as a parameter.
- **********************************************************************************************************************/
-fsp_err_t R_IWDT_VersionGet (fsp_version_t * const p_data)
-{
-#if (1 == IWDT_CFG_PARAM_CHECKING_ENABLE)
-    FSP_ASSERT(p_data != NULL);
-#endif
-
-    p_data->version_id = g_iwdt_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup IWDT)
  **********************************************************************************************************************/
@@ -468,6 +509,7 @@ fsp_err_t R_IWDT_VersionGet (fsp_version_t * const p_data)
  * @param[in]   irq     IRQ which has triggered the NMI interrupt.
  *
  **********************************************************************************************************************/
+#if IWDT_PRV_NMI_SUPPORTED
 static void iwdt_nmi_internal_callback (bsp_grp_irq_t irq)
 {
     FSP_PARAMETER_NOT_USED(irq);
@@ -490,7 +532,7 @@ static void iwdt_nmi_internal_callback (bsp_grp_irq_t irq)
 
     p_args->p_context = gp_iwdt_ctrl->p_context;
 
-#if BSP_TZ_SECURE_BUILD
+ #if BSP_TZ_SECURE_BUILD
 
     /* p_callback can point to a secure function or a non-secure function. */
     if (!cmse_is_nsfptr(gp_iwdt_ctrl->p_callback))
@@ -505,11 +547,11 @@ static void iwdt_nmi_internal_callback (bsp_grp_irq_t irq)
         p_callback(p_args);
     }
 
-#else
+ #else
 
     /* If the project is not Trustzone Secure, then it will never need to change security state in order to call the callback. */
     gp_iwdt_ctrl->p_callback(p_args);
-#endif
+ #endif
     if (NULL != gp_iwdt_ctrl->p_callback_memory)
     {
         /* Restore callback memory in case this is a nested interrupt. */
@@ -517,13 +559,15 @@ static void iwdt_nmi_internal_callback (bsp_grp_irq_t irq)
     }
 }
 
+#endif
+
 /*******************************************************************************************************************//**
  * Internal function to return timeout in terms of watchdog clocks from provided timeout setting.
  *
  * @param[in]   division    Watchdog division setting.
  *
  **********************************************************************************************************************/
-static uint32_t wdt_clock_divider_get (wdt_clock_division_t division)
+static uint32_t iwdt_clock_divider_get (wdt_clock_division_t division)
 {
     uint32_t shift;
 
@@ -533,12 +577,108 @@ static uint32_t wdt_clock_divider_get (wdt_clock_division_t division)
     }
     else
     {
-        shift = g_wdt_division_lookup[division];
+        shift = g_iwdt_division_lookup[division];
     }
 
     return shift;
 }
 
 /*******************************************************************************************************************//**
- * @} (end defgroup IWDT)
+ * Initialize the NMI.
+ *
+ * @param[in]    p_instance_ctrl   Pointer to instance control structure
+ * @param[in]    p_cfg             Pointer to configuration structure
  **********************************************************************************************************************/
+#if IWDT_PRV_NMI_SUPPORTED
+static void iwdt_nmi_initialize (iwdt_instance_ctrl_t * const p_instance_ctrl, wdt_cfg_t const * const p_cfg)
+{
+    /* Initialize global pointer to WDT for NMI callback use.  */
+    gp_iwdt_ctrl = p_instance_ctrl;
+
+    /* NMI output mode. */
+    R_BSP_GroupIrqWrite(BSP_GRP_IRQ_IWDT_ERROR, iwdt_nmi_internal_callback);
+
+    p_instance_ctrl->p_callback = p_cfg->p_callback;
+    p_instance_ctrl->p_context  = p_cfg->p_context;
+
+    /* Enable the IWDT underflow/refresh error interrupt to generate an NMI. NMIER bits cannot be cleared after reset,
+     * so no need to read-modify-write. */
+    R_ICU->NMIER = R_ICU_NMIER_IWDTEN_Msk;
+}
+
+#endif
+
+/*******************************************************************************************************************//**
+ * Parameter checking function for IWDT Open
+ *
+ * @param[in]    p_instance_ctrl   Pointer to instance control structure
+ * @param[in]    p_cfg             Pointer to configuration structure
+ *
+ * @retval FSP_SUCCESS              IWDT successfully configured.
+ * @retval FSP_ERR_NOT_ENABLED      An attempt to open the IWDT when the OFS0 register is not
+ *                                  configured for auto-start mode.
+ * @retval FSP_ERR_ASSERTION        Null pointer, or one or more configuration options is invalid.
+ * @retval FSP_ERR_ALREADY_OPEN     Module is already open.  This module can only be opened once.
+ * @retval FSP_ERR_INVALID_STATE    The security state of the NMI and the module do not match.
+ **********************************************************************************************************************/
+#if IWDT_CFG_PARAM_CHECKING_ENABLE
+static fsp_err_t iwdt_parameter_checking (iwdt_instance_ctrl_t * const p_instance_ctrl, wdt_cfg_t const * const p_cfg)
+{
+    /* Check that control and config structure pointers are valid. */
+    FSP_ASSERT(NULL != p_cfg);
+    FSP_ASSERT(NULL != p_instance_ctrl);
+    FSP_ERROR_RETURN(IWDT_OPEN != p_instance_ctrl->wdt_open, FSP_ERR_ALREADY_OPEN);
+
+    /* Ensure this module is in the same security state as the NMI */
+ #if defined(BSP_TZ_NONSECURE_BUILD) && BSP_TZ_NONSECURE_BUILD
+    FSP_ERROR_RETURN(SCB->AIRCR & SCB_AIRCR_BFHFNMINS_Msk, FSP_ERR_INVALID_STATE);
+ #elif defined(BSP_TZ_SECURE_BUILD) && BSP_TZ_SECURE_BUILD
+    FSP_ERROR_RETURN(!(SCB->AIRCR & SCB_AIRCR_BFHFNMINS_Msk), FSP_ERR_INVALID_STATE);
+ #endif
+
+    /* Check timeout parameter is supported by IWDT. */
+
+    /* Enum checking is done here because some enums in wdt_timeout_t are not supported by the IWDT peripheral (they are
+     * included for other implementations of the watchdog interface). */
+    FSP_ASSERT((p_cfg->timeout == WDT_TIMEOUT_128) || (p_cfg->timeout == WDT_TIMEOUT_512) || \
+               (p_cfg->timeout == WDT_TIMEOUT_1024) || (p_cfg->timeout == WDT_TIMEOUT_2048));
+
+ #if IWDT_PRV_REGISTER_START_MODE
+
+    /* Register-start mode. */
+
+  #if IWDT_PRV_NMI_SUPPORTED
+
+    /* Register callback with BSP NMI ISR. */
+    if (p_cfg->reset_control == WDT_RESET_CONTROL_NMI)
+    {
+        FSP_ASSERT(NULL != p_cfg->p_callback);
+    }
+    else
+    {
+        FSP_ASSERT(NULL == p_cfg->p_callback);
+    }
+
+  #else
+    FSP_ASSERT(p_cfg->reset_control == WDT_RESET_CONTROL_RESET);
+  #endif
+ #else
+
+    /* Auto start mode. */
+
+    /* Check the IWDT is enabled in auto start mode. */
+    FSP_ERROR_RETURN((0U != (uint32_t) IWDT_PRV_AUTO_START_MODE), FSP_ERR_NOT_ENABLED);
+
+  #if IWDT_PRV_NMI_SUPPORTED
+
+    /* NMI output mode. */
+    FSP_ASSERT(NULL != p_cfg->p_callback);
+  #else
+    FSP_ASSERT(NULL == p_cfg->p_callback);
+  #endif
+ #endif
+
+    return FSP_SUCCESS;
+}
+
+#endif
