@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -29,34 +29,40 @@
  * Macro definitions
  **********************************************************************************************************************/
 
+#define LPM_LPSCR_SYSTEM_ACTIVE                  (0x0U)
+#define LPM_LPSCR_SOFTWARE_STANDBY_MODE          (0x4U)
+#define LPM_LPSCR_DEEP_SOFTWARE_STANDBY_MODE1    (0x8U)
+#define LPM_LPSCR_DEEP_SOFTWARE_STANDBY_MODE2    (0x9U)
+#define LPM_LPSCR_DEEP_SOFTWARE_STANDBY_MODE3    (0xAU)
+
 /* Clock control register addresses */
-#define LPM_CLOCK_HOCOCR                     ((uint8_t *) 0x4001E036U)
-#define LPM_CLOCK_MOCOCR                     ((uint8_t *) 0x4001E038U)
-#define LPM_CLOCK_LOCOCR                     ((uint8_t *) 0x4001E490U)
-#define LPM_CLOCK_MOSCCR                     ((uint8_t *) 0x4001E032U)
-#define LPM_CLOCK_SOSCCR                     ((uint8_t *) 0x4001E480U)
-#define LPM_CLOCK_PLLCR                      ((uint8_t *) 0x4001E02AU)
-#define LPM_CLOCK_HOCO                       0 // The high speed on chip oscillator.
-#define LPM_CLOCK_MOCO                       1 // The middle speed on chip oscillator.
-#define LPM_CLOCK_LOCO                       2 // The low speed on chip oscillator.
-#define LPM_CLOCK_MAIN_OSC                   3 // The main oscillator.
-#define LPM_CLOCK_SUBCLOCK                   4 // The subclock oscillator.
-#define LPM_CLOCK_PLL                        5 // The PLL oscillator.
+#define LPM_CLOCK_HOCOCR                         ((uint8_t *) 0x4001E036U)
+#define LPM_CLOCK_MOCOCR                         ((uint8_t *) 0x4001E038U)
+#define LPM_CLOCK_LOCOCR                         ((uint8_t *) 0x4001E490U)
+#define LPM_CLOCK_MOSCCR                         ((uint8_t *) 0x4001E032U)
+#define LPM_CLOCK_SOSCCR                         ((uint8_t *) 0x4001E480U)
+#define LPM_CLOCK_PLLCR                          ((uint8_t *) 0x4001E02AU)
+#define LPM_CLOCK_PLL2CR                         ((uint8_t *) 0x4001E04AU)
+#define LPM_CLOCK_HOCO                           0 // The high speed on chip oscillator.
+#define LPM_CLOCK_MOCO                           1 // The middle speed on chip oscillator.
+#define LPM_CLOCK_LOCO                           2 // The low speed on chip oscillator.
+#define LPM_CLOCK_MAIN_OSC                       3 // The main oscillator.
+#define LPM_CLOCK_SUBCLOCK                       4 // The subclock oscillator.
+#define LPM_CLOCK_PLL                            5 // The PLL oscillator.
+#define LPM_CLOCK_PLL2                           6 // The PLL2 oscillator.
 
 /* From user's manual and discussions with hardware group,
  * using the maximum is safe for all MCUs, will be updated and restored in LPM when entering
  * low power mode on RA6 MCUs (lowPowerModeEnter())
  */
 
-#define LPM_SW_STANDBY_HOCOWTCR_HSTS         (0x6U)
-#define LPM_SW_STANDBY_HOCOWTCR_SCI0_HSTS    (0x2U)
-#define LPM_SW_STANDBY_STCONR                (0x0U)
-#define LPM_SW_STANDBY_WAKE_STCONR           (0x3U)
+#define LPM_SW_STANDBY_STCONR                    (0x0U)
+#define LPM_SW_STANDBY_WAKE_STCONR               (0x3U)
 
-#define LPM_SNZREQCR1_OFFSET                 (0x32ULL)
-#define LPM_WUPEN1_OFFSET                    (0x32ULL)
+#define LPM_SNZREQCR1_OFFSET                     (32ULL)
+#define LPM_WUPEN1_OFFSET                        (32ULL)
 
-#define LPM_OPEN                             (0x524c504d)
+#define LPM_OPEN                                 (0x524c504d)
 
 /***********************************************************************************************************************
  * Typedef definitions
@@ -66,14 +72,7 @@
  * Private global variables
  **********************************************************************************************************************/
 
-/** Version data structure used by error logger macro. */
-static const fsp_version_t g_lpm_version =
-{
-    .api_version_major  = LPM_API_VERSION_MAJOR,
-    .api_version_minor  = LPM_API_VERSION_MINOR,
-    .code_version_major = LPM_CODE_VERSION_MAJOR,
-    .code_version_minor = LPM_CODE_VERSION_MINOR
-};
+#if BSP_FEATURE_LPM_HAS_SNOOZE
 
 /* This array stores the address of the register containing the stop bit for each clock. All of these registers are
  * 8-bit registers and only bit 0 is valid.  All other bits are read as 0 and should be written to 0.  Bit 0 of each
@@ -86,10 +85,14 @@ static uint8_t volatile * const gp_lpm_clock_stp_registers[] =
     [LPM_CLOCK_LOCO]     = LPM_CLOCK_LOCOCR,
     [LPM_CLOCK_MAIN_OSC] = LPM_CLOCK_MOSCCR,
     [LPM_CLOCK_SUBCLOCK] = LPM_CLOCK_SOSCCR,
-#if BSP_FEATURE_CGC_HAS_PLL
+ #if BSP_FEATURE_CGC_HAS_PLL
     [LPM_CLOCK_PLL] = LPM_CLOCK_PLLCR,
-#endif
+ #endif
+ #if BSP_FEATURE_CGC_HAS_PLL2
+    [LPM_CLOCK_PLL2] = LPM_CLOCK_PLL2CR,
+ #endif
 };
+#endif
 
 /***********************************************************************************************************************
  * Global Variables
@@ -101,7 +104,6 @@ const lpm_api_t g_lpm_on_lpm =
     .lowPowerReconfigure = R_LPM_LowPowerReconfigure,
     .lowPowerModeEnter   = R_LPM_LowPowerModeEnter,
     .ioKeepClear         = R_LPM_IoKeepClear,
-    .versionGet          = R_LPM_VersionGet,
 };
 
 /***********************************************************************************************************************
@@ -113,9 +115,17 @@ const lpm_api_t g_lpm_on_lpm =
  **********************************************************************************************************************/
 static fsp_err_t r_lpm_configure(lpm_cfg_t const * const p_cfg);
 static fsp_err_t r_lpm_low_power_enter(lpm_instance_ctrl_t * const p_instance_ctrl);
-static fsp_err_t r_lpm_check_clocks(uint32_t clock_source);
-static void      r_lpm_wait_for_operating_mode_flags(void);
 
+#if BSP_FEATURE_LPM_HAS_SNOOZE
+static fsp_err_t r_lpm_check_clocks(uint32_t clock_source);
+
+#endif
+static void r_lpm_wait_for_operating_mode_flags(void);
+
+#if BSP_FEATURE_LPM_HAS_LPSCR
+static uint8_t r_lpm_lpscr_calculate(lpm_cfg_t const * p_cfg);
+
+#endif
 #if LPM_CFG_PARAM_CHECKING_ENABLE
 static fsp_err_t r_lpm_mcu_specific_low_power_check(lpm_cfg_t const * const p_cfg);
 
@@ -212,7 +222,7 @@ fsp_err_t R_LPM_LowPowerReconfigure (lpm_ctrl_t * const p_api_ctrl, lpm_cfg_t co
 }
 
 /*******************************************************************************************************************//**
- * Enter low power mode (sleep/standby/deep standby) using WFI macro.
+ * Enter low power mode (sleep/deep sleep/standby/deep standby) using WFI macro.
  *
  * Function will return after waking from low power mode.
  *
@@ -233,20 +243,52 @@ fsp_err_t R_LPM_LowPowerModeEnter (lpm_ctrl_t * const p_api_ctrl)
 #if LPM_CFG_PARAM_CHECKING_ENABLE
     FSP_ASSERT(NULL != p_ctrl);
     FSP_ERROR_RETURN(LPM_OPEN == p_ctrl->lpm_open, FSP_ERR_NOT_OPEN);
+
+ #if BSP_FEATURE_LPM_STANDBY_MOCO_REQUIRED
+
+    /* The MOCO must be running when entering standby mode. */
+    if (LPM_MODE_STANDBY <= p_ctrl->p_cfg->low_power_mode)
+    {
+        FSP_ERROR_RETURN(0 == R_SYSTEM->MOCOCR, FSP_ERR_INVALID_MODE);
+    }
+ #endif
 #endif
 
     /* Wait for ongoing operating mode transition (OPCMTSF, SOPCMTSF) */
     r_lpm_wait_for_operating_mode_flags();
 
+    /* Must enable writing to Low Power Mode register prior to entering Low Power Mode. */
+    R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_OM_LPC_BATT);
+#if LPM_CFG_STANDBY_LIMIT
+ #if BSP_FEATURE_LPM_HAS_LPSCR
+    R_SYSTEM->LPSCR = r_lpm_lpscr_calculate(p_ctrl->p_cfg);
+ #endif
+
+ #if BSP_FEATURE_LPM_HAS_SBYCR_SSBY
+    if (LPM_MODE_SLEEP != p_ctrl->p_cfg->low_power_mode)
+    {
+        R_SYSTEM->SBYCR |= (1U << R_SYSTEM_SBYCR_SSBY_Pos);
+    }
+ #endif
+#endif
+
     fsp_err_t err = r_lpm_low_power_enter(p_ctrl);
 
-#if BSP_FEATURE_LPM_HAS_DEEP_STANDBY
-    if (FSP_ERR_INVALID_MODE == err)
+#if LPM_CFG_STANDBY_LIMIT
+ #if BSP_FEATURE_LPM_HAS_LPSCR
+    if ((LPM_MODE_SLEEP != p_ctrl->p_cfg->low_power_mode) && (LPM_MODE_DEEP_SLEEP != p_ctrl->p_cfg->low_power_mode))
     {
-        R_BSP_RegisterProtectEnable(BSP_REG_PROTECT_OM_LPC_BATT);
-        R_BSP_RegisterProtectEnable(BSP_REG_PROTECT_CGC);
+        R_SYSTEM->LPSCR = 0;
     }
+ #endif
+ #if BSP_FEATURE_LPM_HAS_SBYCR_SSBY
+    if (LPM_MODE_SLEEP != p_ctrl->p_cfg->low_power_mode)
+    {
+        R_SYSTEM->SBYCR &= (uint16_t) (~(1U << R_SYSTEM_SBYCR_SSBY_Pos));
+    }
+ #endif
 #endif
+    R_BSP_RegisterProtectEnable(BSP_REG_PROTECT_OM_LPC_BATT);
 
     return err;
 }
@@ -294,23 +336,6 @@ fsp_err_t R_LPM_Close (lpm_ctrl_t * const p_api_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Get the driver version based on compile time macros.
- *
- * @retval     FSP_SUCCESS        Successfully got version.
- * @retval     FSP_ERR_ASSERTION  p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_LPM_VersionGet (fsp_version_t * const p_version)
-{
-#if LPM_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_lpm_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup LPM)
  **********************************************************************************************************************/
@@ -344,14 +369,27 @@ fsp_err_t R_LPM_VersionGet (fsp_version_t * const p_version)
  **********************************************************************************************************************/
 fsp_err_t r_lpm_mcu_specific_low_power_check (lpm_cfg_t const * const p_cfg)
 {
+ #if !BSP_FEATURE_LPM_HAS_DEEP_SLEEP
+    FSP_ERROR_RETURN(LPM_MODE_DEEP_SLEEP != p_cfg->low_power_mode, FSP_ERR_UNSUPPORTED)
+ #endif
+ #if !BSP_FEATURE_LPM_HAS_SNOOZE
+    FSP_ERROR_RETURN(LPM_MODE_STANDBY_SNOOZE != p_cfg->low_power_mode, FSP_ERR_UNSUPPORTED)
+ #endif
+
+ #if BSP_FEATURE_LPM_HAS_DEEP_SLEEP
+    if ((LPM_MODE_SLEEP != p_cfg->low_power_mode) && (LPM_MODE_DEEP_SLEEP != p_cfg->low_power_mode))
+ #else
     if (LPM_MODE_SLEEP != p_cfg->low_power_mode)
+ #endif
     {
         if (LPM_MODE_STANDBY_SNOOZE == p_cfg->low_power_mode)
         {
+ #if BSP_FEATURE_LPM_HAS_SNOOZE
             FSP_ERROR_RETURN(0U == ((uint64_t) p_cfg->snooze_request_source & (~BSP_FEATURE_LPM_SNZREQCR_MASK)),
                              FSP_ERR_INVALID_ARGUMENT);
             FSP_ERROR_RETURN(0U == ((uint32_t) p_cfg->snooze_end_sources & (~BSP_FEATURE_LPM_SNZEDCR_MASK)),
                              FSP_ERR_INVALID_ARGUMENT);
+ #endif
         }
         else if (LPM_MODE_DEEP == p_cfg->low_power_mode)
         {
@@ -422,12 +460,24 @@ fsp_err_t r_lpm_configure (lpm_cfg_t const * const p_cfg)
     fsp_err_t err = r_lpm_mcu_specific_low_power_check(p_cfg);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 #endif
+#if BSP_FEATURE_LPM_HAS_SNOOZE
     uint32_t snzcr = 0;
+#endif
     uint32_t sbycr = 0;
 #if BSP_FEATURE_LPM_HAS_DEEP_STANDBY
     uint32_t dpsbycr = 0;
 #endif
 
+#if BSP_FEATURE_LPM_HAS_LDO_CONTROL
+    if ((R_SYSTEM->PLL1LDOCR_b.SKEEP != p_cfg->ldo_standby_cfg.pll1_ldo) ||
+        (R_SYSTEM->PLL2LDOCR_b.SKEEP != p_cfg->ldo_standby_cfg.pll2_ldo) ||
+        (R_SYSTEM->HOCOLDOCR_b.SKEEP != p_cfg->ldo_standby_cfg.hoco_ldo))
+    {
+        /* Writing to PLL1LDOCR, PLL2LDOCR and HOCOLDOCR registers is only allowed in High Speed Mode. */
+        FSP_ERROR_RETURN(R_SYSTEM->OPCCR_b.OPCM == 0, FSP_ERR_INVALID_MODE);
+    }
+#endif
+
     R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_OM_LPC_BATT);
 
     /* Wait for ongoing operating mode transition (OPCMTSF, SOPCMTSF) */
@@ -450,14 +500,19 @@ fsp_err_t r_lpm_configure (lpm_cfg_t const * const p_cfg)
             R_SYSTEM->DPSIEGR1 = (uint8_t) (p_cfg->deep_standby_cancel_edge >> 8U);
             R_SYSTEM->DPSIEGR2 = (uint8_t) (p_cfg->deep_standby_cancel_edge >> 16U);
 
-            dpsbycr = (R_SYSTEM_DPSBYCR_DPSBY_Msk |
-                       (((uint32_t) p_cfg->io_port_state << R_SYSTEM_DPSBYCR_IOKEEP_Pos) &
-                        R_SYSTEM_DPSBYCR_IOKEEP_Msk) |
-                       (((uint32_t) p_cfg->power_supply_state << R_SYSTEM_DPSBYCR_DEEPCUT_Pos) &
-                        R_SYSTEM_DPSBYCR_DEEPCUT_Msk));
+ #if BSP_FEATURE_LPM_HAS_DPSBYCR_DPSBY
+            dpsbycr |= R_SYSTEM_DPSBYCR_DPSBY_Msk;
+ #endif
+ #if BSP_FEATURE_LPM_HAS_DPSBYCR_DEEPCUT
+            dpsbycr |= ((uint32_t) p_cfg->power_supply_state << R_SYSTEM_DPSBYCR_DEEPCUT_Pos) &
+                       R_SYSTEM_DPSBYCR_DEEPCUT_Msk;
+ #endif
+            dpsbycr |= ((uint32_t) p_cfg->io_port_state << R_SYSTEM_DPSBYCR_IOKEEP_Pos) & R_SYSTEM_DPSBYCR_IOKEEP_Msk;
         }
 #endif
 
+#if BSP_FEATURE_LPM_HAS_SNOOZE
+
         /* Configure Snooze registers */
         if (LPM_MODE_STANDBY_SNOOZE == p_cfg->low_power_mode)
         {
@@ -470,32 +525,88 @@ fsp_err_t r_lpm_configure (lpm_cfg_t const * const p_cfg)
             /* Set the request condition that can trigger entry in to snooze mode */
             R_SYSTEM->SNZREQCR = (uint32_t) p_cfg->snooze_request_source & UINT32_MAX;
 
-#if BSP_FEATURE_LPM_HAS_SNZREQCR1 == 1
+ #if BSP_FEATURE_LPM_HAS_SNZREQCR1 == 1
             R_SYSTEM->SNZREQCR1 = (uint32_t) (p_cfg->snooze_request_source >> LPM_SNZREQCR1_OFFSET) & UINT32_MAX;
-#endif
+ #endif
 
             /* Enable/disable DTC operation */
             snzcr |= (uint32_t) (p_cfg->dtc_state_in_snooze << R_SYSTEM_SNZCR_SNZDTCEN_Pos);
 
             /* Set the source that can cause an exit from snooze to normal mode */
-            R_ICU->SELSR0_b.SELS = (uint8_t) p_cfg->snooze_cancel_sources;
+            R_ICU->SELSR0_b.SELS = R_ICU_SELSR0_SELS_Msk & p_cfg->snooze_cancel_sources;
 
             /* Set all sources that can cause an exit from snooze mode to software standby. */
             R_SYSTEM->SNZEDCR = (uint8_t) p_cfg->snooze_end_sources & UINT8_MAX;
 
-#if BSP_FEATURE_LPM_HAS_SNZEDCR1 == 1
+ #if BSP_FEATURE_LPM_HAS_SNZEDCR1 == 1
             R_SYSTEM->SNZEDCR1 = (uint8_t) (p_cfg->snooze_end_sources >> 8U) & UINT8_MAX;
+ #endif
+        }
+#endif
+
+#if BSP_FEATURE_LPM_HAS_DEEP_SLEEP
+        if (LPM_MODE_DEEP_SLEEP != p_cfg->low_power_mode)
+#endif
+        {
+            /* Set SBYCR to Standby/Deep Standby. */
+#if BSP_FEATURE_LPM_HAS_SBYCR_OPE
+            sbycr = ((uint32_t) p_cfg->output_port_enable) << R_SYSTEM_SBYCR_OPE_Pos;
+#elif BSP_FEATURE_LPM_SBYCR_WRITE1_B14
+            sbycr = R_SYSTEM_SBYCR_OPE_Msk;
+#endif
+
+#if BSP_FEATURE_LPM_HAS_SBYCR_SSBY
+            sbycr |= R_SYSTEM_SBYCR_SSBY_Msk;
+#endif
+
+#if BSP_FEATURE_LPM_HAS_DPSBYCR_SRKEEP
+
+            /* Configure Standby RAM retention in software standby and deep software standby modes. */
+            dpsbycr |= (uint8_t) (p_cfg->ram_retention_cfg.standby_ram_retention << R_SYSTEM_DPSBYCR_SRKEEP_Pos);
 #endif
         }
 
-        /* Set SBYCR to Standby/Deep Standby. */
-#if BSP_FEATURE_LPM_HAS_SBYCR_OPE
-        sbycr = (((uint32_t) p_cfg->output_port_enable) << R_SYSTEM_SBYCR_OPE_Pos) | (1U << R_SYSTEM_SBYCR_SSBY_Pos);
-#elif BSP_FEATURE_LPM_SBYCR_WRITE1_B14
-        sbycr = (1U << R_SYSTEM_SBYCR_OPE_Pos) | (1U << R_SYSTEM_SBYCR_SSBY_Pos);
-#else
-        sbycr = (1U << R_SYSTEM_SBYCR_SSBY_Pos);
+        if ((LPM_MODE_DEEP_SLEEP == p_cfg->low_power_mode) || (LPM_MODE_STANDBY == p_cfg->low_power_mode))
+        {
+#if BSP_FEATURE_LPM_HAS_PDRAMSCR
+
+            /* Configure TCM retention settings in deep sleep or standby mode. */
+            R_SYSTEM->PDRAMSCR1 = p_cfg->ram_retention_cfg.tcm_retention;
 #endif
+        }
+
+        if (LPM_MODE_STANDBY == p_cfg->low_power_mode)
+        {
+#if BSP_FEATURE_LPM_HAS_PDRAMSCR
+
+            /* Configure RAM retention settings in standby mode. */
+            R_SYSTEM->PDRAMSCR0 = p_cfg->ram_retention_cfg.ram_retention;
+#endif
+
+#if BSP_FEATURE_LPM_HAS_LDO_CONTROL
+
+            /* PLL1LDOCR may only be written in High Speed Mode. If PLL1DOCR setting is not changed, then skip
+             * writing to it. */
+            if (R_SYSTEM->PLL1LDOCR_b.SKEEP != p_cfg->ldo_standby_cfg.pll1_ldo)
+            {
+                R_SYSTEM->PLL1LDOCR_b.SKEEP = (uint8_t) (p_cfg->ldo_standby_cfg.pll1_ldo & 0x01);
+            }
+
+            /* PLL2LDOCR may only be written in High Speed Mode. If PLL2DOCR setting is not changed, then skip
+             * writing to it. */
+            if (R_SYSTEM->PLL2LDOCR_b.SKEEP != p_cfg->ldo_standby_cfg.pll2_ldo)
+            {
+                R_SYSTEM->PLL2LDOCR_b.SKEEP = (uint8_t) (p_cfg->ldo_standby_cfg.pll2_ldo & 0x01);
+            }
+
+            /* HOCOLDOCR may only be written in High Speed Mode. If HOCOLDOCR setting is not changed, then skip
+             * writing to it. */
+            if (R_SYSTEM->HOCOLDOCR_b.SKEEP != p_cfg->ldo_standby_cfg.hoco_ldo)
+            {
+                R_SYSTEM->HOCOLDOCR_b.SKEEP = (uint8_t) (p_cfg->ldo_standby_cfg.hoco_ldo & 0x01);
+            }
+#endif
+        }
 
         R_ICU->WUPEN = (uint32_t) p_cfg->standby_wake_sources & UINT32_MAX;
 #if BSP_FEATURE_ICU_HAS_WUPEN1 == 1
@@ -512,8 +623,27 @@ fsp_err_t r_lpm_configure (lpm_cfg_t const * const p_cfg)
 #endif
     }
 
+#if BSP_FEATURE_LPM_HAS_SBYCR_SSBY
+ #if LPM_CFG_STANDBY_LIMIT
+    R_SYSTEM->SBYCR = (uint16_t) (sbycr & ~(1U << R_SYSTEM_SBYCR_SSBY_Pos));
+ #else
     R_SYSTEM->SBYCR = (uint16_t) sbycr;
+ #endif
+#else
+    R_SYSTEM->SBYCR = (uint8_t) sbycr;
+#endif
+
+#if BSP_FEATURE_LPM_HAS_LPSCR
+ #if !LPM_CFG_STANDBY_LIMIT
+    R_SYSTEM->LPSCR = r_lpm_lpscr_calculate(p_cfg);
+ #else
+    R_SYSTEM->LPSCR = 0;
+ #endif
+#endif
+
+#if BSP_FEATURE_LPM_HAS_SNOOZE
     R_SYSTEM->SNZCR = (uint8_t) snzcr;
+#endif
 
 #if BSP_FEATURE_LPM_HAS_DEEP_STANDBY
     R_SYSTEM->DPSBYCR = (uint8_t) dpsbycr;
@@ -524,6 +654,8 @@ fsp_err_t r_lpm_configure (lpm_cfg_t const * const p_cfg)
     return FSP_SUCCESS;
 }
 
+#if BSP_FEATURE_LPM_HAS_SNOOZE
+
 /*******************************************************************************************************************//**
  * Check the clock settings
  *
@@ -536,6 +668,7 @@ fsp_err_t r_lpm_configure (lpm_cfg_t const * const p_cfg)
  *                                           - MOCO was running when using snooze mode with SCI0/RXD0.
  *                                           - MAIN OSCILLATOR was running when using snooze mode with SCI0/RXD0.
  *                                           - PLL was running when using snooze mode with SCI0/RXD0.
+ *                                           - PLL2 was running when using snooze mode with SCI0/RXD0.
  **********************************************************************************************************************/
 fsp_err_t r_lpm_check_clocks (uint32_t clock_source)
 {
@@ -545,13 +678,18 @@ fsp_err_t r_lpm_check_clocks (uint32_t clock_source)
     /* Verify Moco, Main Osc and PLL are stopped. */
     FSP_ERROR_RETURN(1U == (*gp_lpm_clock_stp_registers[LPM_CLOCK_MOCO]), FSP_ERR_INVALID_MODE);
     FSP_ERROR_RETURN(1U == (*gp_lpm_clock_stp_registers[LPM_CLOCK_MAIN_OSC]), FSP_ERR_INVALID_MODE);
-#if BSP_FEATURE_CGC_HAS_PLL
+ #if BSP_FEATURE_CGC_HAS_PLL
     FSP_ERROR_RETURN(1U == (*gp_lpm_clock_stp_registers[LPM_CLOCK_PLL]), FSP_ERR_INVALID_MODE);
-#endif
+ #endif
+ #if BSP_FEATURE_CGC_HAS_PLL2
+    FSP_ERROR_RETURN(1U == (*gp_lpm_clock_stp_registers[LPM_CLOCK_PLL2]), FSP_ERR_INVALID_MODE);
+ #endif
 
     return FSP_SUCCESS;
 }
 
+#endif
+
 /*******************************************************************************************************************//**
  * Perform pre-WFI execution tasks, enter low power mode, Perform post-WFI execution tasks
  *
@@ -570,10 +708,12 @@ fsp_err_t r_lpm_check_clocks (uint32_t clock_source)
 fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
 {
 #if BSP_FEATURE_LPM_HAS_DEEP_STANDBY
-    uint32_t saved_opccr        = 0U;
-    uint32_t saved_sopccr       = 0U;
+    uint32_t saved_opccr = 0U;
+ #if BSP_FEATURE_CGC_HAS_SOPCCR
+    uint32_t saved_sopccr = 0U;
+ #endif
     uint32_t saved_ostdcr_ostde = 0U;
- #if BSP_FEATURE_CGC_HAS_HOCOWTCR == 1
+ #if BSP_FEATURE_CGC_HOCOWTCR_SCI_SNOOZE_VALUE > 0
     uint32_t saved_hocowtcr = 0U;
     uint32_t new_hocowtcr   = 0U;
  #endif
@@ -585,7 +725,11 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
     bsp_power_mode_t power_mode = BSP_POWER_MODE_LDO;
 #endif
 
+#if BSP_FEATURE_LPM_HAS_SBYCR_SSBY
     if (1U == R_SYSTEM->SBYCR_b.SSBY)
+#else
+    if (LPM_LPSCR_SOFTWARE_STANDBY_MODE <= R_SYSTEM->LPSCR)
+#endif
     {
         /* Execute pre-wfi standby tasks */
 
@@ -595,62 +739,77 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
         FSP_ERROR_RETURN(0U == R_SYSTEM->FLLCR1, FSP_ERR_INVALID_MODE);
 #endif
 
+#if BSP_FEATURE_LPM_HAS_SNOOZE
+
         /* Get system clock */
         uint32_t clock_source = R_SYSTEM->SCKSCR;
+#endif
 
 #if !BSP_FEATURE_LPM_HAS_DEEP_STANDBY
+ #if BSP_FEATURE_LPM_HAS_SNOOZE
         if (1U == R_SYSTEM->SNZCR_b.RXDREQEN)
         {
             /* Verify clock settings. */
             FSP_ERROR_RETURN(FSP_SUCCESS == r_lpm_check_clocks(clock_source), FSP_ERR_INVALID_MODE);
         }
+ #endif
 
-        /* Enable writing to CGC and Low Power Mode registers. */
-        R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_OM_LPC_BATT);
+        /* Enable writing to CGC register. */
         R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_CGC);
 #else
 
-        /* RA6 Series Only:
-         * Save the OPCCR and SOPCCR registers. When transitioning from Software Standby mode to Normal or Snooze mode
+        /* Save the OPCCR and SOPCCR registers. When transitioning from Software Standby mode to Normal or Snooze mode
          * these registers are overwritten. See Section 11.2.6 "Operating Power Control Register" in the RA6M3 manual
          * R01UM0004EU0110 */
-        saved_opccr  = R_SYSTEM->OPCCR_b.OPCM;
+        saved_opccr = R_SYSTEM->OPCCR_b.OPCM;
+ #if BSP_FEATURE_CGC_HAS_SOPCCR
         saved_sopccr = R_SYSTEM->SOPCCR_b.SOPCM;
+ #endif
 
- #if BSP_FEATURE_CGC_HAS_HOCOWTCR == 1
+ #if BSP_FEATURE_CGC_HOCOWTCR_SCI_SNOOZE_VALUE > 0
 
         /* Save HOCOWTCR_b.HSTS */
         saved_hocowtcr = R_SYSTEM->HOCOWTCR_b.HSTS;
  #endif
 
-        /* Enable writing to CGC and Low Power Mode registers. */
-        R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_OM_LPC_BATT);
-        R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_CGC);
-
+ #if BSP_FEATURE_LPM_HAS_SBYCR_SSBY
         if (0U == R_SYSTEM->DPSBYCR_b.DPSBY)
+ #else
+        if (LPM_LPSCR_DEEP_SOFTWARE_STANDBY_MODE1 > R_SYSTEM->LPSCR)
+ #endif
         {
-            /* RA6 Series Only:
-             * Check Snooze configuration settings. Set HOCOWTCR based on current configuration. See Section 11.2.1
+ #if BSP_FEATURE_LPM_HAS_SNOOZE
+
+            /* Check Snooze configuration settings. Set HOCOWTCR based on current configuration. See Section 11.2.1
              * "Standby Control Register" in the RA6M3 manual  R01UM0004EU0110 */
             if (1U == R_SYSTEM->SNZCR_b.RXDREQEN)
             {
                 /* Verify clock settings. */
                 FSP_ERROR_RETURN(FSP_SUCCESS == r_lpm_check_clocks(clock_source), FSP_ERR_INVALID_MODE);
- #if BSP_FEATURE_CGC_HAS_HOCOWTCR == 1
-                new_hocowtcr = LPM_SW_STANDBY_HOCOWTCR_SCI0_HSTS;
+  #if BSP_FEATURE_CGC_HOCOWTCR_SCI_SNOOZE_VALUE > 0
+                new_hocowtcr = BSP_FEATURE_CGC_HOCOWTCR_SCI_SNOOZE_VALUE;
             }
             else
             {
-                new_hocowtcr = LPM_SW_STANDBY_HOCOWTCR_HSTS;
- #endif
+                new_hocowtcr = BSP_FEATURE_CGC_HOCOWTCR_VALUE;
+  #endif
             }
 
+ #else
+  #if BSP_FEATURE_CGC_HAS_HOCOWTCR == 1
+            new_hocowtcr = LPM_SW_STANDBY_HOCOWTCR_HSTS;
+  #endif
+ #endif
+
+            /* Enable writing to CGC register. */
+            R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_CGC);
+
  #if BSP_FEATURE_LPM_HAS_STCONR == 1
 
             /* Set STCONR based on the current system clock. */
             if (LPM_CLOCK_HOCO == clock_source)
             {
-  #if BSP_FEATURE_CGC_HAS_HOCOWTCR == 1
+  #if BSP_FEATURE_CGC_HOCOWTCR_SCI_SNOOZE_VALUE > 0
 
                 /* Set HOCOWTCR_b.HSTS when using HOCO as the system clock */
                 R_SYSTEM->HOCOWTCR_b.HSTS = R_SYSTEM_HOCOWTCR_HSTS_Msk & (new_hocowtcr << R_SYSTEM_HOCOWTCR_HSTS_Pos);
@@ -666,6 +825,9 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
         }
         else
         {
+            /* Enable writing to CGC register. */
+            R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_CGC);
+
             /* Execute pre-wfi deep standby tasks */
             /* Clear the DOCDF flag to 0 before entering Deep Software Standby mode. */
             R_SYSTEM->SYOCDCR_b.DOCDF = 0U;
@@ -711,14 +873,9 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
 #endif
     }
 
+#if BSP_FEATURE_LPM_HAS_SNOOZE
     if (LPM_MODE_STANDBY_SNOOZE == p_instance_ctrl->p_cfg->low_power_mode)
     {
-#if !BSP_FEATURE_LPM_HAS_DEEP_STANDBY
-
-        /* Enable writing to CGC and Low Power Mode registers. */
-        R_BSP_RegisterProtectDisable(BSP_REG_PROTECT_OM_LPC_BATT);
-#endif
-
         /* Enable Snooze mode (SNZCR.SNZE = 1) immediately before entering to Software Standby mode.
          * See Section 11.8.2 "Canceling Snooze Mode" in the RA6M3 manual  R01UM0004EU0110 */
         R_SYSTEM->SNZCR_b.SNZE = 1;
@@ -727,6 +884,15 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
          * infocenter.arm.com/help/index.jsp?topic=/com.arm.doc.dai0321a/BIHICBGB.html */
         R_SYSTEM->SNZCR;
     }
+#endif
+
+#if BSP_FEATURE_LPM_HAS_DEEP_SLEEP
+    if (LPM_MODE_SLEEP != p_instance_ctrl->p_cfg->low_power_mode)
+    {
+        /* Set the SLEEPDEEP bit. */
+        SCB->SCR |= SCB_SCR_SLEEPDEEP_Msk;
+    }
+#endif
 
     /* DSB should be last instruction executed before WFI
      * infocenter.arm.com/help/index.jsp?topic=/com.arm.doc.dai0321a/BIHICBGB.html */
@@ -734,12 +900,27 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
 
     __WFI();
 
+#if BSP_FEATURE_LPM_HAS_DEEP_SLEEP
+    if (LPM_MODE_SLEEP != p_instance_ctrl->p_cfg->low_power_mode)
+    {
+        /* Clear the SLEEPDEEP bit. */
+        SCB->SCR &= ~SCB_SCR_SLEEPDEEP_Msk;
+    }
+#endif
+
+#if BSP_FEATURE_LPM_HAS_SNOOZE
+
     /* Disable Snooze mode (SNZCR.SNZE = 0) immediately after canceling Snooze mode.
      * See Section 11.8.2 "Canceling Snooze Mode" in the RA6M3 manual  R01UM0004EU0110 */
     R_SYSTEM->SNZCR_b.SNZE = 0;
+#endif
 
 #if BSP_FEATURE_LPM_HAS_DEEP_STANDBY || (BSP_PRV_POWER_USE_DCDC)
+ #if BSP_FEATURE_LPM_HAS_SBYCR_SSBY
     if (1U == R_SYSTEM->SBYCR_b.SSBY)
+ #else
+    if (LPM_LPSCR_SOFTWARE_STANDBY_MODE <= R_SYSTEM->LPSCR)
+ #endif
     {
  #if BSP_FEATURE_LPM_HAS_DEEP_STANDBY
 
@@ -747,15 +928,18 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
         r_lpm_wait_for_operating_mode_flags();
 
         /* Restore system registers to the values prior to entering standby. */
-        R_SYSTEM->OPCCR          = saved_opccr & R_SYSTEM_OPCCR_OPCM_Msk;
-        R_SYSTEM->SOPCCR         = saved_sopccr & R_SYSTEM_SOPCCR_SOPCM_Msk;
+        R_SYSTEM->OPCCR = saved_opccr & R_SYSTEM_OPCCR_OPCM_Msk;
+
+  #if BSP_FEATURE_CGC_HAS_SOPCCR
+        R_SYSTEM->SOPCCR = saved_sopccr & R_SYSTEM_SOPCCR_SOPCM_Msk;
+  #endif
+
         R_SYSTEM->OSTDCR_b.OSTDE = 0x1U & saved_ostdcr_ostde;
-  #if BSP_FEATURE_CGC_HAS_HOCOWTCR == 1
+  #if BSP_FEATURE_CGC_HOCOWTCR_SCI_SNOOZE_VALUE > 0
         R_SYSTEM->HOCOWTCR_b.HSTS = R_SYSTEM_HOCOWTCR_HSTS_Msk & (saved_hocowtcr << R_SYSTEM_HOCOWTCR_HSTS_Pos);
   #endif
 
-        /* Disable writing to CGC and Low Power Mode registers. */
-        R_BSP_RegisterProtectEnable(BSP_REG_PROTECT_OM_LPC_BATT);
+        /* Disable writing to CGC register. */
         R_BSP_RegisterProtectEnable(BSP_REG_PROTECT_CGC);
 
   #if BSP_FEATURE_BSP_POWER_CHANGE_MSTP_REQUIRED
@@ -770,13 +954,6 @@ fsp_err_t r_lpm_low_power_enter (lpm_instance_ctrl_t * const p_instance_ctrl)
         }
  #endif
     }
-
-#else
-    if (LPM_MODE_STANDBY_SNOOZE == p_instance_ctrl->p_cfg->low_power_mode)
-    {
-        /* Disable writing to CGC and Low Power Mode registers. */
-        R_BSP_RegisterProtectEnable(BSP_REG_PROTECT_OM_LPC_BATT);
-    }
 #endif
 
     return FSP_SUCCESS;
@@ -790,6 +967,56 @@ void r_lpm_wait_for_operating_mode_flags (void)
     /* Wait for transition to complete. */
     FSP_HARDWARE_REGISTER_WAIT(R_SYSTEM->OPCCR_b.OPCMTSF, 0U);
 
+#if BSP_FEATURE_CGC_HAS_SOPCCR
+
     /* Wait for transition to complete. */
     FSP_HARDWARE_REGISTER_WAIT(R_SYSTEM->SOPCCR_b.SOPCMTSF, 0U);
+#endif
 }
+
+#if BSP_FEATURE_LPM_HAS_LPSCR
+
+/*******************************************************************************************************************//**
+ * Calculate the correct value of LPSCR based on the mode.
+ **********************************************************************************************************************/
+static uint8_t r_lpm_lpscr_calculate (lpm_cfg_t const * p_cfg)
+{
+    uint8_t lpscr = 0;
+
+    switch (p_cfg->low_power_mode)
+    {
+        case LPM_MODE_SLEEP:
+        {
+            lpscr = LPM_LPSCR_SYSTEM_ACTIVE;
+            break;
+        }
+
+        case LPM_MODE_DEEP_SLEEP:
+        {
+            lpscr = LPM_LPSCR_SYSTEM_ACTIVE;
+            break;
+        }
+
+        case LPM_MODE_STANDBY:
+        {
+            lpscr = LPM_LPSCR_SOFTWARE_STANDBY_MODE;
+            break;
+        }
+
+        case LPM_MODE_DEEP:
+        {
+            lpscr  = LPM_LPSCR_DEEP_SOFTWARE_STANDBY_MODE1;
+            lpscr |= p_cfg->power_supply_state;
+            break;
+        }
+
+        default:
+        {
+            break;
+        }
+    }
+
+    return lpscr;
+}
+
+#endif
