@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -160,15 +160,6 @@ static void sci_i2c_enable_transfer_support_tx(sci_i2c_instance_ctrl_t * const p
  * Private global variables
  **********************************************************************************************************************/
 
-/* Version data structure used by error logger macro. */
-static fsp_version_t const g_sci_i2c_master_version =
-{
-    .api_version_major  = I2C_MASTER_API_VERSION_MAJOR,
-    .api_version_minor  = I2C_MASTER_API_VERSION_MINOR,
-    .code_version_minor = SCI_I2C_MASTER_CODE_VERSION_MINOR,
-    .code_version_major = SCI_I2C_MASTER_CODE_VERSION_MAJOR,
-};
-
 /* constant used as the source location for the DTC dummy write  */
 static const uint8_t g_dummy_write_data_for_read_op = SCI_I2C_PRV_DUMMY_WRITE_DATA_FOR_READ_OP;
 
@@ -185,8 +176,8 @@ i2c_master_api_t const g_i2c_master_on_sci =
     .abort           = R_SCI_I2C_Abort,
     .slaveAddressSet = R_SCI_I2C_SlaveAddressSet,
     .close           = R_SCI_I2C_Close,
-    .versionGet      = R_SCI_I2C_VersionGet,
-    .callbackSet     = R_SCI_I2C_CallbackSet
+    .callbackSet     = R_SCI_I2C_CallbackSet,
+    .statusGet       = R_SCI_I2C_StatusGet
 };
 
 /*******************************************************************************************************************//**
@@ -460,6 +451,26 @@ fsp_err_t R_SCI_I2C_CallbackSet (i2c_master_ctrl_t * const          p_api_ctrl,
     return FSP_SUCCESS;
 }
 
+/*******************************************************************************************************************//**
+ * Provides driver status.
+ *
+ * @retval     FSP_SUCCESS                   Status stored in p_status.
+ * @retval     FSP_ERR_ASSERTION             NULL pointer.
+ **********************************************************************************************************************/
+fsp_err_t R_SCI_I2C_StatusGet (i2c_master_ctrl_t * const p_api_ctrl, i2c_master_status_t * p_status)
+{
+    sci_i2c_instance_ctrl_t * p_ctrl = (sci_i2c_instance_ctrl_t *) p_api_ctrl;
+
+#if SCI_I2C_CFG_PARAM_CHECKING_ENABLE
+    FSP_ASSERT(p_ctrl != NULL);
+    FSP_ASSERT(p_status != NULL);
+#endif
+
+    p_status->open = (SCI_I2C_OPEN == p_ctrl->open);
+
+    return FSP_SUCCESS;
+}
+
 /******************************************************************************************************************//**
  * Closes the I2C device. Power down I2C peripheral.
  *
@@ -505,23 +516,6 @@ fsp_err_t R_SCI_I2C_Close (i2c_master_ctrl_t * const p_api_ctrl)
     return FSP_SUCCESS;
 }
 
-/**********************************************************************************************************************
- * DEPRECATED Sets driver version based on compile time macros.
- *
- * @retval  FSP_SUCCESS                 Successful version get.
- * @retval  FSP_ERR_ASSERTION           The parameter p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_SCI_I2C_VersionGet (fsp_version_t * const p_version)
-{
-#if SCI_I2C_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(p_version != NULL);
-#endif
-
-    p_version->version_id = g_sci_i2c_master_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /******************************************************************************************************************//**
  * @} (end defgroup SCI_I2C)
  **********************************************************************************************************************/
@@ -690,6 +684,7 @@ static void sci_i2c_abort_seq_master (sci_i2c_instance_ctrl_t * const p_ctrl)
     /* Update the transfer descriptor to show no longer in-progress and an error */
     p_ctrl->remain    = 0U;
     p_ctrl->restarted = false;
+    p_ctrl->restart   = false;
 
     /* Update the transfer descriptor to make sure interrupts no longer process */
     p_ctrl->addr_loaded = p_ctrl->addr_total;
@@ -836,15 +831,14 @@ static void sci_i2c_run_hw_master (sci_i2c_instance_ctrl_t * const p_ctrl)
 void sci_i2c_rxi_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
-
+    FSP_CONTEXT_SAVE
     /* This interrupt is invoked once DTC supported Read transfer is completed. Nothing to be done here. */
 
     /* Clear pending IRQ */
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 #endif
@@ -856,8 +850,7 @@ void sci_i2c_rxi_isr (void)
 void sci_i2c_txi_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
-
+    FSP_CONTEXT_SAVE
     /* Clear pending IRQ */
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
 
@@ -868,7 +861,7 @@ void sci_i2c_txi_isr (void)
     sci_i2c_txi_handler(p_ctrl);
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /******************************************************************************************************************//**
@@ -878,7 +871,7 @@ void sci_i2c_txi_isr (void)
 void sci_i2c_tei_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type                 irq    = R_FSP_CurrentIrqGet();
     sci_i2c_instance_ctrl_t * p_ctrl = (sci_i2c_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -890,7 +883,7 @@ void sci_i2c_tei_isr (void)
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /******************************************************************************************************************//**
@@ -1066,7 +1059,6 @@ static fsp_err_t sci_i2c_transfer_configure (sci_i2c_instance_ctrl_t       * p_c
                                              sci_i2c_dtc_interrupt_trigger_t trigger)
 {
     fsp_err_t err;
-    IRQn_Type irq;
 
     /* Set default transfer info and open receive transfer module, if enabled. */
  #if (SCI_I2C_CFG_PARAM_CHECKING_ENABLE)
@@ -1078,7 +1070,6 @@ static fsp_err_t sci_i2c_transfer_configure (sci_i2c_instance_ctrl_t       * p_c
     transfer_info_t * p_cfg = p_transfer->p_cfg->p_info;
     if (SCI_I2C_DTC_INTERRUPT_TRIGGER_RXI == trigger)
     {
-        irq = p_ctrl->p_cfg->rxi_irq;
         p_cfg->transfer_settings_word = SCI_I2C_PRV_DTC_RX_FOR_READ_TRANSFER_SETTINGS;
         p_cfg->p_src = (void *) (&(p_ctrl->p_reg->RDR));
     }
@@ -1089,18 +1080,13 @@ static fsp_err_t sci_i2c_transfer_configure (sci_i2c_instance_ctrl_t       * p_c
         /* Refer flow diagram of master reception as described in hardware manual (see Figure 34.68
          * 'Example flow of master reception in simple IIC mode with transmission interrupts and reception interrupts'
          *  of the RA6M3 manual R01UH0886EJ0100). */
-        irq = p_ctrl->p_cfg->txi_irq;
 
         /* In case of Write operation this will be reconfigured */
         p_cfg->transfer_settings_word = SCI_I2C_PRV_DTC_TX_FOR_READ_TRANSFER_SETTINGS;
         p_cfg->p_dest                 = (void *) (&(p_ctrl->p_reg->TDR));
     }
 
-    transfer_cfg_t       cfg = *(p_transfer->p_cfg);
-    dtc_extended_cfg_t * p_dtc_extended_configuration = (dtc_extended_cfg_t *) (cfg.p_extend);
-    p_dtc_extended_configuration->activation_source = irq;
-
-    err = p_transfer->p_api->open(p_transfer->p_ctrl, &cfg);
+    err = p_transfer->p_api->open(p_transfer->p_ctrl, p_transfer->p_cfg);
     FSP_ERROR_RETURN((FSP_SUCCESS == err), err);
 
     return FSP_SUCCESS;
