@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -110,15 +110,6 @@ void sdadc_adi_isr(void);
 void sdadc_scanend_isr(void);
 void sdadc_caliend_isr(void);
 
-/** Version data structure used by error logger macro. */
-static const fsp_version_t g_sdadc_version =
-{
-    .api_version_minor  = ADC_API_VERSION_MINOR,
-    .api_version_major  = ADC_API_VERSION_MAJOR,
-    .code_version_major = SDADC_CODE_VERSION_MAJOR,
-    .code_version_minor = SDADC_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global Variables
  **********************************************************************************************************************/
@@ -126,18 +117,18 @@ static const fsp_version_t g_sdadc_version =
 /** SDADC Implementation of ADC interface. */
 const adc_api_t g_adc_on_sdadc =
 {
-    .open          = R_SDADC_Open,
-    .scanCfg       = R_SDADC_ScanCfg,
-    .infoGet       = R_SDADC_InfoGet,
-    .scanStart     = R_SDADC_ScanStart,
-    .scanStop      = R_SDADC_ScanStop,
-    .scanStatusGet = R_SDADC_StatusGet,
-    .offsetSet     = R_SDADC_OffsetSet,
-    .read          = R_SDADC_Read,
-    .read32        = R_SDADC_Read32,
-    .calibrate     = R_SDADC_Calibrate,
-    .close         = R_SDADC_Close,
-    .versionGet    = R_SDADC_VersionGet
+    .open           = R_SDADC_Open,
+    .scanCfg        = R_SDADC_ScanCfg,
+    .infoGet        = R_SDADC_InfoGet,
+    .scanStart      = R_SDADC_ScanStart,
+    .scanGroupStart = R_SDADC_ScanGroupStart,
+    .scanStop       = R_SDADC_ScanStop,
+    .scanStatusGet  = R_SDADC_StatusGet,
+    .offsetSet      = R_SDADC_OffsetSet,
+    .read           = R_SDADC_Read,
+    .read32         = R_SDADC_Read32,
+    .calibrate      = R_SDADC_Calibrate,
+    .close          = R_SDADC_Close,
 };
 
 /*******************************************************************************************************************//**
@@ -244,7 +235,7 @@ fsp_err_t R_SDADC_Open (adc_ctrl_t * p_ctrl, adc_cfg_t const * const p_cfg)
             uint32_t pgac_register_value = p_cfg_extend->p_channel_cfgs[i]->pgac_setting;
 
             /* If differential mode is used and calibration during open is not skipped, enable calibration on this channel. */
-            if (SDADC_CHANNEL_INPUT_DIFFERENTIAL == p_cfg_extend->p_channel_cfgs[i]->input)
+            if (SDADC_CHANNEL_INPUT_DIFFERENTIAL == p_cfg_extend->p_channel_cfgs[i]->pgac_setting_b.input)
             {
                 pgac_register_value |= 1U << SDADC_PRIV_PGAC_PGACVE_SHIFT;
             }
@@ -417,6 +408,20 @@ fsp_err_t R_SDADC_ScanStart (adc_ctrl_t * p_ctrl)
     return err;
 }
 
+/*******************************************************************************************************************//**
+ * @ref adc_api_t::scanStart is not supported on the SDADC. Use scanStart instead.
+ *
+ * @retval FSP_ERR_UNSUPPORTED         Function not supported in this implementation.
+ **********************************************************************************************************************/
+fsp_err_t R_SDADC_ScanGroupStart (adc_ctrl_t * p_ctrl, adc_group_mask_t group_id)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+    FSP_PARAMETER_NOT_USED(group_id);
+
+    /* Return the unsupported error. */
+    return FSP_ERR_UNSUPPORTED;
+}
+
 /*******************************************************************************************************************//**
  * If the SDADC is configured for hardware triggers, disables hardware triggers.  Otherwise, stops any in-progress scan
  * started by software. Implements @ref adc_api_t::scanStop().
@@ -636,7 +641,7 @@ fsp_err_t R_SDADC_OffsetSet (adc_ctrl_t * const p_ctrl, adc_channel_t const reg_
  * @retval  FSP_ERR_IN_USE             A conversion or calibration is in progress.
  * @retval  FSP_ERR_NOT_OPEN           Instance control block is not open.
  **********************************************************************************************************************/
-fsp_err_t R_SDADC_Calibrate (adc_ctrl_t * const p_ctrl, void * const p_extend)
+fsp_err_t R_SDADC_Calibrate (adc_ctrl_t * const p_ctrl, void const * p_extend)
 {
     sdadc_instance_ctrl_t  * p_instance_ctrl = (sdadc_instance_ctrl_t *) p_ctrl;
     sdadc_calibrate_args_t * p_calibrate     = (sdadc_calibrate_args_t *) p_extend;
@@ -737,26 +742,6 @@ fsp_err_t R_SDADC_Close (adc_ctrl_t * p_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Gets the API and code version. Implements @ref adc_api_t::versionGet().
- *
- * @retval  FSP_SUCCESS        Version information available in p_version.
- * @retval  FSP_ERR_ASSERTION  The parameter p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_SDADC_VersionGet (fsp_version_t * const p_version)
-{
-#if (1 == SDADC_CFG_PARAM_CHECKING_ENABLE)
-
-    /* Verify the pointer is not NULL. */
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    /* Return the version number */
-    p_version->version_id = g_sdadc_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup SDADC)
  **********************************************************************************************************************/
@@ -785,11 +770,14 @@ static fsp_err_t r_sdadc_open_param_check_2 (adc_cfg_t const * const p_cfg)
         if (NULL != p_cfg_extend->p_channel_cfgs[i])
         {
             channels_configured++;
-            if (SDADC_CHANNEL_INPUT_SINGLE_ENDED == p_cfg_extend->p_channel_cfgs[i]->input)
+            if (SDADC_CHANNEL_INPUT_SINGLE_ENDED == p_cfg_extend->p_channel_cfgs[i]->pgac_setting_b.input)
             {
-                FSP_ASSERT(SDADC_CHANNEL_OVERSAMPLING_256 == p_cfg_extend->p_channel_cfgs[i]->oversampling);
-                FSP_ASSERT(SDADC_CHANNEL_STAGE_1_GAIN_1 == p_cfg_extend->p_channel_cfgs[i]->stage_1_gain);
-                FSP_ASSERT(SDADC_CHANNEL_STAGE_2_GAIN_1 == p_cfg_extend->p_channel_cfgs[i]->stage_2_gain);
+                FSP_ASSERT(
+                    SDADC_CHANNEL_OVERSAMPLING_256 == p_cfg_extend->p_channel_cfgs[i]->pgac_setting_b.oversampling);
+                FSP_ASSERT(SDADC_CHANNEL_STAGE_1_GAIN_1 ==
+                           p_cfg_extend->p_channel_cfgs[i]->pgac_setting_b.stage_1_gain);
+                FSP_ASSERT(SDADC_CHANNEL_STAGE_2_GAIN_1 ==
+                           p_cfg_extend->p_channel_cfgs[i]->pgac_setting_b.stage_2_gain);
             }
         }
     }
@@ -877,7 +865,7 @@ static fsp_err_t r_sdadc_open_irq_cfg (sdadc_instance_ctrl_t * const p_instance_
     {
         if (NULL != p_cfg_extend->p_channel_cfgs[i])
         {
-            if (SDADC_CHANNEL_INPUT_DIFFERENTIAL == p_cfg_extend->p_channel_cfgs[i]->input)
+            if (SDADC_CHANNEL_INPUT_DIFFERENTIAL == p_cfg_extend->p_channel_cfgs[i]->pgac_setting_b.input)
             {
                 FSP_ERROR_RETURN(FSP_INVALID_VECTOR != p_cfg->scan_end_b_irq, FSP_ERR_IRQ_BSP_DISABLED);
             }
@@ -1003,7 +991,7 @@ static void r_sdadc_disable_irq (IRQn_Type irq)
 void sdadc_scanend_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type               irq             = R_FSP_CurrentIrqGet();
     sdadc_instance_ctrl_t * p_instance_ctrl = (sdadc_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -1022,7 +1010,7 @@ void sdadc_scanend_isr (void)
     p_instance_ctrl->p_cfg->p_callback(&args);
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1031,7 +1019,7 @@ void sdadc_scanend_isr (void)
 void sdadc_adi_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type               irq             = R_FSP_CurrentIrqGet();
     sdadc_instance_ctrl_t * p_instance_ctrl = (sdadc_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -1083,7 +1071,7 @@ void sdadc_adi_isr (void)
     }
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1092,7 +1080,7 @@ void sdadc_adi_isr (void)
 void sdadc_caliend_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type               irq             = R_FSP_CurrentIrqGet();
     sdadc_instance_ctrl_t * p_instance_ctrl = (sdadc_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -1115,5 +1103,5 @@ void sdadc_caliend_isr (void)
     }
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
