@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -36,8 +36,6 @@
                                               ((uint32_t) R_SPI1 - (uint32_t) R_SPI0) * \
                                               (channel)))
 
-#define SPI_DTC_MAX_TRANSFER            (0x10000)
-
 #define SPI_DTC_RX_TRANSFER_SETTINGS    ((TRANSFER_MODE_NORMAL << TRANSFER_SETTINGS_MODE_BITS) |         \
                                          (TRANSFER_SIZE_1_BYTE << TRANSFER_SETTINGS_SIZE_BITS) |         \
                                          (TRANSFER_ADDR_MODE_FIXED << TRANSFER_SETTINGS_SRC_ADDR_BITS) | \
@@ -85,14 +83,6 @@ typedef void (BSP_CMSE_NONSECURE_CALL * spi_prv_ns_callback)(spi_callback_args_t
 typedef BSP_CMSE_NONSECURE_CALL void (*volatile spi_prv_ns_callback)(spi_callback_args_t * p_args);
 #endif
 
-/* Frame data length */
-typedef enum e_spi_spcmd_bit_length
-{
-    SPI_SPCMD_BIT_LENGTH_8  = (0x7),   /**< 0100 to 0111 = 8 bits data length */
-    SPI_SPCMD_BIT_LENGTH_16 = (0xF),   /**< 1111 = 16 bits data length */
-    SPI_SPCMD_BIT_LENGTH_32 = (0x3)    /**< 0011 = 32 bits data length */
-} spi_spcmd_bit_length_t;
-
 /***********************************************************************************************************************
  * Private function declarations
  **********************************************************************************************************************/
@@ -120,19 +110,13 @@ void spi_txi_isr(void);
 void spi_tei_isr(void);
 void spi_eri_isr(void);
 
+void spi_rx_dmac_callback(spi_instance_ctrl_t const * const p_ctrl);
+void spi_tx_dmac_callback(spi_instance_ctrl_t const * const p_ctrl);
+
 /***********************************************************************************************************************
  * Private global variables
  **********************************************************************************************************************/
 
-/* Version data structure used by error logger macro. */
-static const fsp_version_t module_version =
-{
-    .api_version_major  = SPI_API_VERSION_MAJOR,
-    .api_version_minor  = SPI_API_VERSION_MINOR,
-    .code_version_major = SPI_CODE_VERSION_MAJOR,
-    .code_version_minor = SPI_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global variables
  **********************************************************************************************************************/
@@ -145,7 +129,6 @@ const spi_api_t g_spi_on_spi =
     .write       = R_SPI_Write,
     .writeRead   = R_SPI_WriteRead,
     .close       = R_SPI_Close,
-    .versionGet  = R_SPI_VersionGet,
     .callbackSet = R_SPI_CallbackSet
 };
 
@@ -189,8 +172,6 @@ fsp_err_t R_SPI_Open (spi_ctrl_t * p_api_ctrl, spi_cfg_t const * const p_cfg)
     FSP_ASSERT(NULL != p_cfg->p_callback);
     FSP_ASSERT(NULL != p_cfg->p_extend);
     FSP_ERROR_RETURN(BSP_FEATURE_SPI_MAX_CHANNEL > p_cfg->channel, FSP_ERR_IP_CHANNEL_NOT_PRESENT);
-    FSP_ASSERT(p_cfg->rxi_irq >= 0);
-    FSP_ASSERT(p_cfg->txi_irq >= 0);
     FSP_ASSERT(p_cfg->tei_irq >= 0);
     FSP_ASSERT(p_cfg->eri_irq >= 0);
 
@@ -201,7 +182,7 @@ fsp_err_t R_SPI_Open (spi_ctrl_t * p_api_ctrl, spi_cfg_t const * const p_cfg)
         FSP_ERROR_RETURN(SPI_CLK_PHASE_EDGE_EVEN == p_cfg->clk_phase, FSP_ERR_UNSUPPORTED);
     }
 
- #if BSP_FEATURE_SPI_HAS_SSL_LEVEL_KEEP == 0 || BSP_FEATURE_SPI_HAS_BYTE_SWAP == 0 || SPI_TRANSMIT_FROM_RXI_ISR == 1
+ #if BSP_FEATURE_SPI_HAS_SSL_LEVEL_KEEP == 0 || SPI_TRANSMIT_FROM_RXI_ISR == 1
     spi_extended_cfg_t * p_extend = (spi_extended_cfg_t *) p_cfg->p_extend;
  #endif
  #if SPI_TRANSMIT_FROM_RXI_ISR == 1
@@ -217,9 +198,6 @@ fsp_err_t R_SPI_Open (spi_ctrl_t * p_api_ctrl, spi_cfg_t const * const p_cfg)
     }
  #endif
 
- #if BSP_FEATURE_SPI_HAS_BYTE_SWAP == 0
-    FSP_ERROR_RETURN(SPI_BYTE_SWAP_DISABLE == p_extend->byte_swap, FSP_ERR_UNSUPPORTED);
- #endif
  #if BSP_FEATURE_SPI_HAS_SSL_LEVEL_KEEP == 0
     if ((SPI_MODE_MASTER == p_cfg->operating_mode))
     {
@@ -393,7 +371,7 @@ fsp_err_t R_SPI_Close (spi_ctrl_t * const p_api_ctrl)
 
     p_ctrl->open = 0;
 
-#if SPI_DTC_SUPPORT_ENABLE == 1
+#if SPI_DMA_SUPPORT_ENABLE == 1
     if (NULL != p_ctrl->p_cfg->p_transfer_rx)
     {
         p_ctrl->p_cfg->p_transfer_rx->p_api->close(p_ctrl->p_cfg->p_transfer_rx->p_ctrl);
@@ -406,8 +384,16 @@ fsp_err_t R_SPI_Close (spi_ctrl_t * const p_api_ctrl)
 #endif
 
     /* Disable interrupts in NVIC. */
-    R_BSP_IrqDisable(p_ctrl->p_cfg->txi_irq);
-    R_BSP_IrqDisable(p_ctrl->p_cfg->rxi_irq);
+    if (p_ctrl->p_cfg->txi_irq >= 0)
+    {
+        R_BSP_IrqDisable(p_ctrl->p_cfg->txi_irq);
+    }
+
+    if (p_ctrl->p_cfg->rxi_irq >= 0)
+    {
+        R_BSP_IrqDisable(p_ctrl->p_cfg->rxi_irq);
+    }
+
     R_BSP_IrqDisable(p_ctrl->p_cfg->tei_irq);
     R_BSP_IrqDisable(p_ctrl->p_cfg->eri_irq);
 
@@ -424,23 +410,6 @@ fsp_err_t R_SPI_Close (spi_ctrl_t * const p_api_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED This function gets the version information of the underlying driver. Implements @ref spi_api_t::versionGet.
- *
- * @retval      FSP_SUCCESS            Successful version get.
- * @retval      FSP_ERR_ASSERTION      The parameter p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_SPI_VersionGet (fsp_version_t * p_version)
-{
-#if SPI_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(p_version != NULL);
-#endif
-
-    p_version->version_id = module_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * Calculates the SPBR register value and the BRDV bits for a desired bitrate.
  * If the desired bitrate is faster than the maximum bitrate, than the bitrate is set to the
@@ -532,7 +501,7 @@ static fsp_err_t r_spi_transfer_config (spi_cfg_t const * const p_cfg)
 {
     fsp_err_t err = FSP_SUCCESS;
 
-#if SPI_DTC_SUPPORT_ENABLE == 1
+#if SPI_DMA_SUPPORT_ENABLE == 1
     const transfer_instance_t * p_transfer_tx = p_cfg->p_transfer_tx;
     void * p_spdr = (void *) &(SPI_REG(p_cfg->channel)->SPDR);
     if (p_transfer_tx)
@@ -621,9 +590,11 @@ static void r_spi_hw_config (spi_instance_ctrl_t * p_ctrl)
     if (SPI_SSL_MODE_SPI == p_extend->spi_clksyn)
     {
 #if BSP_FEATURE_SPI_HAS_SSL_LEVEL_KEEP == 1
-
-        /* Configure SSL Level Keep Setting. */
-        spcmd0 |= R_SPI0_SPCMD0_SSLKP_Msk;
+        if ((1 << p_ctrl->p_cfg->channel) & BSP_FEATURE_SPI_SSL_LEVEL_KEEP_VALID_CHANNEL_MASK)
+        {
+            /* Configure SSL Level Keep Setting. */
+            spcmd0 |= (uint32_t) (!p_ctrl->p_cfg->operating_mode << R_SPI0_SPCMD0_SSLKP_Pos);
+        }
 #endif
 
         /* Configure 4-Wire Mode Setting. */
@@ -723,8 +694,16 @@ static void r_spi_hw_config (spi_instance_ctrl_t * p_ctrl)
  **********************************************************************************************************************/
 static void r_spi_nvic_config (spi_instance_ctrl_t * p_ctrl)
 {
-    R_BSP_IrqCfgEnable(p_ctrl->p_cfg->txi_irq, p_ctrl->p_cfg->txi_ipl, p_ctrl);
-    R_BSP_IrqCfgEnable(p_ctrl->p_cfg->rxi_irq, p_ctrl->p_cfg->rxi_ipl, p_ctrl);
+    if (p_ctrl->p_cfg->txi_irq >= 0)
+    {
+        R_BSP_IrqCfgEnable(p_ctrl->p_cfg->txi_irq, p_ctrl->p_cfg->txi_ipl, p_ctrl);
+    }
+
+    if (p_ctrl->p_cfg->rxi_irq >= 0)
+    {
+        R_BSP_IrqCfgEnable(p_ctrl->p_cfg->rxi_irq, p_ctrl->p_cfg->rxi_ipl, p_ctrl);
+    }
+
     R_BSP_IrqCfgEnable(p_ctrl->p_cfg->eri_irq, p_ctrl->p_cfg->eri_ipl, p_ctrl);
 
     R_BSP_IrqCfg(p_ctrl->p_cfg->tei_irq, p_ctrl->p_cfg->tei_ipl, p_ctrl);
@@ -746,34 +725,32 @@ static void r_spi_bit_width_config (spi_instance_ctrl_t * p_ctrl)
     uint32_t spdcr  = p_ctrl->p_regs->SPDCR;
     uint32_t spcmd0 = p_ctrl->p_regs->SPCMD[0];
 
-    if (SPI_BIT_WIDTH_8_BITS == p_ctrl->bit_width)
-    {
-        /* Set SPBYT so 8bit transfer works with the DTC/DMAC. */
-        spdcr |= R_SPI0_SPDCR_SPBYT_Msk;
-
-        /* Configure 8-Bit Mode.  */
-        spcmd0 &= ~R_SPI0_SPCMD0_SPB_Msk;
-        spcmd0 |= SPI_SPCMD_BIT_LENGTH_8 << R_SPI0_SPCMD0_SPB_Pos;
-    }
-    else if (SPI_BIT_WIDTH_16_BITS == p_ctrl->bit_width)
-    {
-        /* Configure Half-Word access to data register. */
-        spdcr &= ~(R_SPI0_SPDCR_SPBYT_Msk | R_SPI0_SPDCR_SPLW_Msk);
-
-        /* Configure 16-Bit Mode. */
-        spcmd0 &= ~R_SPI0_SPCMD0_SPB_Msk;
-        spcmd0 |= SPI_SPCMD_BIT_LENGTH_16 << R_SPI0_SPCMD0_SPB_Pos;
-    }
-    else                               /* SPI_BIT_WIDTH_32_BITS */
+    if (SPI_BIT_WIDTH_16_BITS < p_ctrl->bit_width) /* Bit Widths of 20, 24 or 32 bits */
     {
         /* Configure Word access to data register. */
         spdcr &= ~R_SPI0_SPDCR_SPBYT_Msk;
         spdcr |= R_SPI0_SPDCR_SPLW_Msk;
-
-        /* Configure 32-Bit Mode. */
-        spcmd0 &= ~R_SPI0_SPCMD0_SPB_Msk;
-        spcmd0 |= SPI_SPCMD_BIT_LENGTH_32 << R_SPI0_SPCMD0_SPB_Pos;
     }
+    else if (SPI_BIT_WIDTH_8_BITS >= p_ctrl->bit_width) /* Bit Width of 8 bits*/
+    {
+        /* Set SPBYT so 8bit transfer works with the DTC/DMAC. */
+        spdcr |= R_SPI0_SPDCR_SPBYT_Msk;
+    }
+    else                               /* Bit Widths of 9, 10, 11, 12, 13, 14, 15 or 16 bits */
+    {
+        /* Configure Half-Word access to data register. */
+        spdcr &= ~(R_SPI0_SPDCR_SPBYT_Msk | R_SPI0_SPDCR_SPLW_Msk);
+    }
+
+    /* Configure data length based on the selected bit width . */
+    uint32_t bit_width = p_ctrl->bit_width;
+    if (bit_width > SPI_BIT_WIDTH_16_BITS)
+    {
+        bit_width = ((bit_width + 1) >> 2) - 5;
+    }
+
+    spcmd0 &= ~R_SPI0_SPCMD0_SPB_Msk;
+    spcmd0 |= bit_width << R_SPI0_SPCMD0_SPB_Pos;
 
     p_ctrl->p_regs->SPDCR    = (uint8_t) spdcr;
     p_ctrl->p_regs->SPCMD[0] = (uint16_t) spcmd0;
@@ -816,14 +793,14 @@ static void r_spi_start_transfer (spi_instance_ctrl_t * p_ctrl)
     }
     else
     {
-        /* Enable the SPI Transfer. */
-        p_ctrl->p_regs->SPCR_b.SPE = 1;
+        /* Enable the SPI Transfer and TX buffer empty interrupt */
+        p_ctrl->p_regs->SPCR |= R_SPI0_SPCR_SPTIE_Msk | R_SPI0_SPCR_SPE_Msk;
     }
 
 #else
 
-    /* Enable the SPI Transfer. */
-    p_ctrl->p_regs->SPCR_b.SPE = 1;
+    /* Enable the SPI Transfer and TX buffer empty interrupt */
+    p_ctrl->p_regs->SPCR |= R_SPI0_SPCR_SPTIE_Msk | R_SPI0_SPCR_SPE_Msk;
 #endif
 }
 
@@ -856,10 +833,31 @@ static fsp_err_t r_spi_write_read_common (spi_ctrl_t * const    p_api_ctrl,
     FSP_ERROR_RETURN(SPI_OPEN == p_ctrl->open, FSP_ERR_NOT_OPEN);
     FSP_ASSERT(p_src || p_dest);
     FSP_ASSERT(0 != length);
-    if (p_ctrl->p_cfg->p_transfer_tx || p_ctrl->p_cfg->p_transfer_rx)
+
+ #if SPI_DMA_SUPPORT_ENABLE
+    if (NULL != p_ctrl->p_cfg->p_transfer_rx)
     {
-        FSP_ASSERT(length <= SPI_DTC_MAX_TRANSFER);
+        transfer_properties_t transfer_info;
+        fsp_err_t             err = p_ctrl->p_cfg->p_transfer_rx->p_api->infoGet(p_ctrl->p_cfg->p_transfer_rx->p_ctrl,
+                                                                                 &transfer_info);
+        FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
+        FSP_ASSERT(length <= transfer_info.transfer_length_max);
     }
+
+    if (NULL != p_ctrl->p_cfg->p_transfer_tx)
+    {
+        transfer_properties_t transfer_info;
+        fsp_err_t             err = p_ctrl->p_cfg->p_transfer_tx->p_api->infoGet(p_ctrl->p_cfg->p_transfer_tx->p_ctrl,
+                                                                                 &transfer_info);
+        FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
+        FSP_ASSERT(length <= transfer_info.transfer_length_max);
+    }
+ #endif
+
+    /* Reject bit width settings not compatible with R_SPI */
+    FSP_ASSERT(!((bit_width < SPI_BIT_WIDTH_8_BITS) ||
+                 ((bit_width > SPI_BIT_WIDTH_16_BITS) && ((bit_width + 1) & 0x3)) ||
+                 (bit_width == SPI_BIT_WIDTH_28_BITS)));
 #endif
 
     FSP_ERROR_RETURN(0 == (p_ctrl->p_regs->SPCR & R_SPI0_SPCR_SPE_Msk), FSP_ERR_IN_USE);
@@ -871,23 +869,37 @@ static fsp_err_t r_spi_write_read_common (spi_ctrl_t * const    p_api_ctrl,
     p_ctrl->count     = length;
     p_ctrl->bit_width = bit_width;
 
-#if SPI_DTC_SUPPORT_ENABLE == 1
+#if SPI_DMA_SUPPORT_ENABLE == 1
     if (p_ctrl->p_cfg->p_transfer_rx)
     {
         /* When the rxi interrupt is called, all transfers will be finished. */
         p_ctrl->rx_count = length;
 
         /* Configure the receive DMA instance. */
-        p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->size           = (transfer_size_t) ((uint32_t) bit_width >> 1U);
-        p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->dest_addr_mode = TRANSFER_ADDR_MODE_INCREMENTED;
-        p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->length         = (uint16_t) length;
-        p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->p_dest         = p_dest;
+        if (SPI_BIT_WIDTH_16_BITS < p_ctrl->bit_width)
+        {
+            p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->transfer_settings_word_b.size = TRANSFER_SIZE_4_BYTE;
+        }
+        else if (SPI_BIT_WIDTH_8_BITS >= p_ctrl->bit_width)
+        {
+            p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->transfer_settings_word_b.size = TRANSFER_SIZE_1_BYTE;
+        }
+        else
+        {
+            p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->transfer_settings_word_b.size = TRANSFER_SIZE_2_BYTE;
+        }
+
+        p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->transfer_settings_word_b.dest_addr_mode =
+            TRANSFER_ADDR_MODE_INCREMENTED;
+        p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->length = (uint16_t) length;
+        p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->p_dest = p_dest;
 
         if (NULL == p_dest)
         {
             static uint32_t dummy_rx;
-            p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->dest_addr_mode = TRANSFER_ADDR_MODE_FIXED;
-            p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->p_dest         = &dummy_rx;
+            p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->transfer_settings_word_b.dest_addr_mode =
+                TRANSFER_ADDR_MODE_FIXED;
+            p_ctrl->p_cfg->p_transfer_rx->p_cfg->p_info->p_dest = &dummy_rx;
         }
 
         fsp_err_t err = p_ctrl->p_cfg->p_transfer_rx->p_api->reconfigure(p_ctrl->p_cfg->p_transfer_rx->p_ctrl,
@@ -902,18 +914,35 @@ static fsp_err_t r_spi_write_read_common (spi_ctrl_t * const    p_api_ctrl,
         p_ctrl->tx_count = length;
 
         /* Configure the transmit DMA instance. */
-        p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->size          = (transfer_size_t) ((uint32_t) bit_width >> 1U);
-        p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->src_addr_mode = TRANSFER_ADDR_MODE_INCREMENTED;
-        p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->length        = (uint16_t) length;
-        p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->p_src         = p_src;
+        if (SPI_BIT_WIDTH_16_BITS < p_ctrl->bit_width)
+        {
+            p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->transfer_settings_word_b.size = TRANSFER_SIZE_4_BYTE;
+        }
+        else if (SPI_BIT_WIDTH_8_BITS >= p_ctrl->bit_width)
+        {
+            p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->transfer_settings_word_b.size = TRANSFER_SIZE_1_BYTE;
+        }
+        else
+        {
+            p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->transfer_settings_word_b.size = TRANSFER_SIZE_2_BYTE;
+        }
+
+        p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->transfer_settings_word_b.src_addr_mode =
+            TRANSFER_ADDR_MODE_INCREMENTED;
+        p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->length = (uint16_t) length;
+        p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->p_src  = p_src;
 
         if (NULL == p_src)
         {
             static uint32_t dummy_tx = 0;
-            p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->src_addr_mode = TRANSFER_ADDR_MODE_FIXED;
-            p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->p_src         = &dummy_tx;
+            p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->transfer_settings_word_b.src_addr_mode =
+                TRANSFER_ADDR_MODE_FIXED;
+            p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info->p_src = &dummy_tx;
         }
 
+        /* Disable the TX buffer empty interrupt before enabling transfer. */
+        p_ctrl->p_regs->SPCR_b.SPTIE = 0;
+
         fsp_err_t err = p_ctrl->p_cfg->p_transfer_tx->p_api->reconfigure(p_ctrl->p_cfg->p_transfer_tx->p_ctrl,
                                                                          p_ctrl->p_cfg->p_transfer_tx->p_cfg->p_info);
 
@@ -949,18 +978,18 @@ static void r_spi_receive (spi_instance_ctrl_t * p_ctrl)
     }
     else
     {
-        if (SPI_BIT_WIDTH_8_BITS == p_ctrl->bit_width)
+        if (SPI_BIT_WIDTH_16_BITS < p_ctrl->bit_width)      /* Bit Widths of 20, 24 or 32 bits */
+        {
+            ((uint32_t *) (p_ctrl->p_rx_data))[rx_count] = p_ctrl->p_regs->SPDR;
+        }
+        else if (SPI_BIT_WIDTH_8_BITS >= p_ctrl->bit_width) /* Bit Width of 8 bits*/
         {
             ((uint8_t *) (p_ctrl->p_rx_data))[rx_count] = p_ctrl->p_regs->SPDR_BY;
         }
-        else if (SPI_BIT_WIDTH_16_BITS == p_ctrl->bit_width)
+        else                                                /* Bit Widths of 9, 10, 11, 12, 13, 14, 15 or 16 bits */
         {
             ((uint16_t *) (p_ctrl->p_rx_data))[rx_count] = p_ctrl->p_regs->SPDR_HA;
         }
-        else                           /* SPI_BIT_WIDTH_32_BITS */
-        {
-            ((uint32_t *) (p_ctrl->p_rx_data))[rx_count] = p_ctrl->p_regs->SPDR;
-        }
     }
 
     p_ctrl->rx_count = rx_count + 1;
@@ -988,17 +1017,17 @@ static void r_spi_transmit (spi_instance_ctrl_t * p_ctrl)
     }
     else
     {
-        if (SPI_BIT_WIDTH_8_BITS == p_ctrl->bit_width)
+        if (SPI_BIT_WIDTH_16_BITS < p_ctrl->bit_width)      /* Bit Widths of 20, 24 or 32 bits */
         {
-            p_ctrl->p_regs->SPDR_BY = ((uint8_t *) p_ctrl->p_tx_data)[tx_count];;
+            p_ctrl->p_regs->SPDR = ((uint32_t *) p_ctrl->p_tx_data)[tx_count];
         }
-        else if (SPI_BIT_WIDTH_16_BITS == p_ctrl->bit_width)
+        else if (SPI_BIT_WIDTH_8_BITS >= p_ctrl->bit_width) /* Bit Width of 8 bits*/
         {
-            p_ctrl->p_regs->SPDR_HA = ((uint16_t *) p_ctrl->p_tx_data)[tx_count];;
+            p_ctrl->p_regs->SPDR_BY = ((uint8_t *) p_ctrl->p_tx_data)[tx_count];
         }
-        else                           /* SPI_BIT_WIDTH_32_BITS */
+        else                                                /* Bit Widths of 9, 10, 11, 12, 13, 14, 15 or 16 bits */
         {
-            p_ctrl->p_regs->SPDR = ((uint32_t *) p_ctrl->p_tx_data)[tx_count];;
+            p_ctrl->p_regs->SPDR_HA = ((uint16_t *) p_ctrl->p_tx_data)[tx_count];
         }
     }
 
@@ -1060,13 +1089,26 @@ static void r_spi_call_callback (spi_instance_ctrl_t * p_ctrl, spi_event_t event
     }
 }
 
+/*******************************************************************************************************************//**
+ * Callback that must be called after a RX DMAC transfer completes.
+ *
+ * @param[in]     p_ctrl     Pointer to SPI instance control block
+ **********************************************************************************************************************/
+void spi_rx_dmac_callback (spi_instance_ctrl_t const * const p_ctrl)
+{
+    /* If the transmit and receive ISRs are too slow to keep up at high bitrates,
+     * the hardware will generate an interrupt before all of the transfers are completed.
+     * By enabling the transfer end ISR here, all of the transfers are guaranteed to be completed. */
+    R_BSP_IrqEnableNoClear(p_ctrl->p_cfg->tei_irq);
+}
+
 /*******************************************************************************************************************//**
  * ISR called when data is loaded into SPI data register from the shift register.
  **********************************************************************************************************************/
 void spi_rxi_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     R_BSP_IrqStatusClear(irq);
@@ -1091,7 +1133,31 @@ void spi_rxi_isr (void)
     }
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
+}
+
+/*******************************************************************************************************************//**
+ * Callback that must be called after a TX DMAC transfer completes.
+ *
+ * @param[in]     p_ctrl     Pointer to SPI instance control block
+ **********************************************************************************************************************/
+void spi_tx_dmac_callback (spi_instance_ctrl_t const * const p_ctrl)
+{
+#if SPI_TRANSMIT_FROM_RXI_ISR == 0
+    spi_extended_cfg_t * p_extend = ((spi_extended_cfg_t *) p_ctrl->p_cfg->p_extend);
+    if (p_extend && (SPI_COMMUNICATION_TRANSMIT_ONLY == p_extend->spi_comm))
+    {
+        /* Only enable the transfer end ISR if there are no receive buffer full interrupts expected to be handled
+         * after this interrupt. */
+
+        /* If DMA is used to transmit data, enable the interrupt after all the data has been transfered, but do not
+         * clear the IRQ Pending Bit. */
+        R_BSP_IrqEnableNoClear(p_ctrl->p_cfg->tei_irq);
+    }
+
+#else
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+#endif
 }
 
 /*******************************************************************************************************************//**
@@ -1100,7 +1166,7 @@ void spi_rxi_isr (void)
 void spi_txi_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     R_BSP_IrqStatusClear(irq);
@@ -1137,7 +1203,7 @@ void spi_txi_isr (void)
 #endif
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1146,7 +1212,7 @@ void spi_txi_isr (void)
 void spi_tei_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     R_BSP_IrqStatusClear(irq);
@@ -1157,15 +1223,28 @@ void spi_tei_isr (void)
     {
         R_BSP_IrqDisable(irq);
 
+        /* Writing 0 to SPE generates a TXI IRQ. Disable the TXI IRQ.
+         * (See Section 38.2.1 SPI Control Register in the RA6M3 manual R01UH0886EJ0100). */
+        if (p_ctrl->p_cfg->txi_irq >= 0)
+        {
+            R_BSP_IrqDisable(p_ctrl->p_cfg->txi_irq);
+        }
+
         /* Disable the SPI Transfer. */
         p_ctrl->p_regs->SPCR_b.SPE = 0;
 
+        /* Re-enable the TXI IRQ and clear the pending IRQ. */
+        if (p_ctrl->p_cfg->txi_irq >= 0)
+        {
+            R_BSP_IrqEnable(p_ctrl->p_cfg->txi_irq);
+        }
+
         /* Signal that a transfer has completed. */
         r_spi_call_callback(p_ctrl, SPI_EVENT_TRANSFER_COMPLETE);
     }
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1174,14 +1253,27 @@ void spi_tei_isr (void)
 void spi_eri_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type             irq    = R_FSP_CurrentIrqGet();
     spi_instance_ctrl_t * p_ctrl = (spi_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
 
+    /* Writing 0 to SPE generatates a TXI IRQ. Disable the TXI IRQ.
+     * (See Section 38.2.1 SPI Control Register in the RA6M3 manual R01UH0886EJ0100). */
+    if (p_ctrl->p_cfg->txi_irq >= 0)
+    {
+        R_BSP_IrqDisable(p_ctrl->p_cfg->txi_irq);
+    }
+
     /* Disable the SPI Transfer. */
     p_ctrl->p_regs->SPCR_b.SPE = 0;
 
+    /* Re-enable the TXI IRQ and clear the pending IRQ. */
+    if (p_ctrl->p_cfg->txi_irq >= 0)
+    {
+        R_BSP_IrqEnable(p_ctrl->p_cfg->txi_irq);
+    }
+
     /* Read the status register. */
     uint8_t status = p_ctrl->p_regs->SPSR;
 
@@ -1213,7 +1305,7 @@ void spi_eri_isr (void)
     R_BSP_IrqStatusClear(irq);
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /* End of file R_SPI. */
