@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -21,6 +21,16 @@
 #define R_USB_EXTERN_H
 
 #include "r_usb_basic_api.h"
+#if defined(USB_CFG_OTG_USE)
+ #include "r_external_irq_api.h"
+#endif                                 /* defined(USB_CFG_OTG_USE) */
+
+#if (BSP_CFG_RTOS != 0)
+ #include "r_usb_cstd_rtos.h"
+#endif                                 /* #if (BSP_CFG_RTOS != 0) */
+
+/* Common macro for FSP header files. There is also a corresponding FSP_FOOTER macro at the end of this file. */
+FSP_HEADER
 
 /*****************************************************************************
  * Public Variables
@@ -35,17 +45,17 @@ extern uint16_t g_usb_change_device_state[USB_NUM_USBIP];
 
 #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
 extern usb_utr_t * g_p_usb_pstd_pipe[USB_MAX_PIPE_NO + 1U];
-extern uint32_t    g_usb_pstd_data_cnt[USB_MAX_PIPE_NO + 1U]; /* PIPEn Buffer counter */
-extern uint8_t   * gp_usb_pstd_data[USB_MAX_PIPE_NO + 1U];    /* PIPEn Buffer pointer(8bit) */
+extern uint32_t  g_usb_pstd_data_cnt[USB_MAX_PIPE_NO + 1U]; /* PIPEn Buffer counter */
+extern uint8_t * gp_usb_pstd_data[USB_MAX_PIPE_NO + 1U];    /* PIPEn Buffer pointer(8bit) */
 
 #endif  /* (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI */
 
 #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
 extern usb_utr_t * g_p_usb_hstd_pipe[][USB_MAX_PIPE_NO + 1U];           /* Message pipe */
-extern uint8_t   * gp_usb_hstd_data_ptr[][USB_MAX_PIPE_NO + 1U];        /* PIPEn Buffer pointer(8bit) */
-extern uint32_t    g_usb_hstd_data_cnt[][USB_MAX_PIPE_NO + 1U];         /* PIPEn Buffer counter */
-extern uint32_t    g_usb_hstd_data_cnt_pipe0[];                         /* PIPE0 Control transfer data stage receive size */
-extern uint16_t    g_usb_hstd_hs_enable[];                              /* Hi-speed enable */
+extern uint8_t * gp_usb_hstd_data_ptr[][USB_MAX_PIPE_NO + 1U];          /* PIPEn Buffer pointer(8bit) */
+extern uint32_t  g_usb_hstd_data_cnt[][USB_MAX_PIPE_NO + 1U];           /* PIPEn Buffer counter */
+extern uint32_t  g_usb_hstd_data_cnt_pipe0[];                           /* PIPE0 Control transfer data stage receive size */
+extern uint16_t  g_usb_hstd_hs_enable[];                                /* Hi-speed enable */
 
 /* r_usb_cinthandler_usbip0.c */
 extern usb_utr_t g_usb_cstd_int_msg[][USB_INTMSGMAX];                   /* Interrupt message */
@@ -56,9 +66,9 @@ extern uint16_t          g_usb_hstd_ignore_cnt[][USB_MAX_PIPE_NO + 1U]; /* Ignor
 extern usb_hcdreg_t      g_usb_hstd_device_drv[][USB_MAXDEVADDR + 1U];  /* Device driver (registration) */
 extern volatile uint16_t g_usb_hstd_device_info[][USB_MAXDEVADDR + 1U][8U];
 extern usb_ctrl_trans_t  g_usb_ctrl_request[USB_NUM_USBIP][USB_MAXDEVADDR + 1];
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
 extern usb_hdl_t g_usb_hstd_sus_res_task_id[];
- #endif                                                         /*  #if (BSP_CFG_RTOS == 2) */
+ #endif                                                         /*  #if (BSP_CFG_RTOS != 0) */
 
 /* port status, config num, interface class, speed, */
 extern uint16_t g_usb_hstd_remort_port[];
@@ -92,7 +102,7 @@ extern void            (* usb_hstd_bc_func[USB_BC_STATE_MAX][USB_BC_EVENT_MAX])(
 #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
 
 /* r_usb_pdriver.c */
-extern usb_cb_t     g_usb_pstd_stall_cb;                           /* Stall Callback function */
+extern usb_cb_t g_usb_pstd_stall_cb;                               /* Stall Callback function */
 extern uint16_t     g_usb_pstd_config_num;                         /* Configuration Number */
 extern uint16_t     g_usb_pstd_stall_pipe[USB_MAX_PIPE_NO + 1U];   /* Stall Pipe info */
 extern uint16_t     g_usb_pstd_alt_num[];                          /* Alternate */
@@ -133,12 +143,12 @@ extern usb_utr_t g_usb_pdata[USB_MAXPIPE_NUM + 1];
 
 #endif                                 /* ( (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI ) */
 
-#if (BSP_CFG_RTOS == 2)
+#if (BSP_CFG_RTOS != 0)
 extern usb_instance_ctrl_t g_usb_cstd_event[];
-extern usb_hdl_t           g_usb_cur_task_hdl[];
-#else                                  /* #if (BSP_CFG_RTOS == 2) */
+extern rtos_task_id_t      g_usb_cur_task_hdl[];
+#else                                  /* #if (BSP_CFG_RTOS != 0) */
 extern usb_event_t g_usb_cstd_event;
-#endif /*#if (BSP_CFG_RTOS == 2)*/
+#endif /* #if (BSP_CFG_RTOS != 0) */
 
 extern usb_pipe_table_t g_usb_pipe_table[USB_NUM_USBIP][USB_MAXPIPE_NUM + 1];
 extern uint16_t         g_usb_cstd_bemp_skip[USB_NUM_USBIP][USB_MAX_PIPE_NO + 1U];
@@ -149,12 +159,15 @@ extern uint16_t g_usb_hstd_use_pipe[];
 
 #endif                                 /* (USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST */
 
-#if (BSP_CFG_RTOS == 2)
-extern SemaphoreHandle_t g_usb_semaphore_hdl[];
+#if (BSP_CFG_RTOS != 0)
+extern rtos_sem_id_t g_usb_semaphore_hdl[];
 extern usb_utr_t * get_usb_int_buf(void);
 
 extern usb_callback_t * g_usb_apl_callback[USB_NUM_USBIP];
-#endif                                 /*#if (BSP_CFG_RTOS == 2)*/
+ #if (BSP_CFG_RTOS == 1)
+extern TX_SEMAPHORE g_usb_host_usbx_sem[USB_NUM_USBIP][USB_MAX_PIPE_NO + 1]; // usbx
+ #endif                                                                      /* #if (BSP_CFG_RTOS == 1) */
+#endif                                                                       /* #if (BSP_CFG_RTOS != 0) */
 
 /* r_usb_pbc.c */
 #if USB_CFG_BC == USB_CFG_ENABLE
@@ -171,6 +184,21 @@ extern uint8_t g_drive_search_que_cnt;
 
 #endif                                 /* defined(USB_CFG_HMSC_USE) */
 
+#if defined(USB_CFG_OTG_USE)
+extern uint8_t          g_usb_otg_hnp_process[USB_NUM_USBIP];
+extern uint8_t          g_is_A_device[USB_NUM_USBIP];
+extern uint8_t          g_is_A_cable_detach[USB_NUM_USBIP];
+extern void             (* g_p_otg_callback[USB_NUM_USBIP])(ULONG mode);
+extern volatile uint8_t g_usb_is_otg_attach_interrupt[USB_NUM_USBIP];
+
+extern TX_TIMER g_usb_otg_detach_timer;
+ #if USB_NUM_USBIP == 2
+extern TX_TIMER g_usb2_otg_detach_timer;
+ #endif                                /* USB_NUM_USBIP == 2 */
+extern volatile uint8_t g_usb_otg_hnp_counter;
+extern TX_TIMER         g_usb_otg_hnp_timer;
+#endif                                 /* defined(USB_CFG_OTG_USE) */
+
 /*****************************************************************************
  * Public Functions
  ******************************************************************************/
@@ -187,6 +215,7 @@ void Test_USB_Change_Info(usb_instance_ctrl_t * p_ctrl, uint16_t ifcls, uint16_t
 void Test_USB_Change_Pipe_flag(uint16_t data1, uint16_t data2, uint16_t pipe_no);
 
 fsp_err_t usb_module_start(uint8_t ip_type);
+fsp_err_t usb_module_register_clear(uint8_t usb_ip);
 fsp_err_t usb_module_stop(uint8_t ip_type);
 void      usb_cpu_delay_xms(uint16_t time);
 void      usb_cpu_delay_1us(uint16_t time);
@@ -217,10 +246,10 @@ void     usb_pstd_change_device_state(uint16_t state, uint16_t keyword, usb_cb_t
 void     usb_pstd_driver_registration(usb_pcdreg_t * registinfo);
 void     usb_pstd_driver_release(void);
 
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
 uint16_t usb_pstd_get_pipe_buf_value(uint16_t pipe_no);
 
- #endif                                /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif                                /* defined(USB_HIGH_SPEED_MODULE) */
 
 #endif                                 /* (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI */
 
@@ -248,10 +277,10 @@ uint8_t usb_hstd_make_pipe_reg_info(uint16_t               ip_no,
                                     uint8_t              * descriptor,
                                     usb_pipe_table_reg_t * pipe_table_work);
 
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
 uint16_t usb_hstd_get_pipe_buf_value(uint16_t pipe_no);
 
- #endif                                /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif                                /* defined(USB_HIGH_SPEED_MODULE) */
 
 #endif                                 /* (USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST */
 
@@ -369,17 +398,24 @@ uint8_t * usb_hstd_con_descriptor(usb_utr_t * ptr);
 void      usb_hstd_device_resume(usb_utr_t * ptr, uint16_t devaddr);
 usb_er_t  usb_hstd_hcd_snd_mbx(usb_utr_t * ptr, uint16_t msginfo, uint16_t dat, uint16_t * adr, usb_cb_t callback);
 void      usb_hstd_mgr_snd_mbx(usb_utr_t * ptr, uint16_t msginfo, uint16_t dat, uint16_t res);
-void      usb_hstd_hcd_task(void * stacd);
-usb_er_t  usb_hstd_transfer_start(usb_utr_t * ptr);
-usb_er_t  usb_hstd_transfer_start_req(usb_utr_t * ptr);
-void      usb_hstd_hcd_rel_mpl(usb_utr_t * ptr, uint16_t n);
-usb_er_t  usb_hstd_clr_stall(usb_utr_t * ptr, uint16_t pipe, usb_cb_t complete);
-usb_er_t  usb_hstd_clr_feature(usb_utr_t * ptr, uint16_t addr, uint16_t epnum, usb_cb_t complete);
-void      usb_hstd_suspend(usb_utr_t * ptr);
-void      usb_hstd_bus_int_disable(usb_utr_t * ptr);
-void      usb_class_request_complete(usb_utr_t * mess, uint16_t data1, uint16_t data2);
-void      usb_host_registration(usb_utr_t * ptr);
-void      usb_hstd_connect_err_event_set(uint16_t ip_no);
+
+ #if (BSP_CFG_RTOS == 1)
+void usb_hstd_hcd_task(ULONG entry_input);
+
+ #else                                 /* #if (BSP_CFG_RTOS == 1) */
+void usb_hstd_hcd_task(void * stacd);
+
+ #endif /* #if (BSP_CFG_RTOS == 1) */
+usb_er_t usb_hstd_transfer_start(usb_utr_t * ptr);
+usb_er_t usb_hstd_transfer_start_req(usb_utr_t * ptr);
+void     usb_hstd_hcd_rel_mpl(usb_utr_t * ptr, uint16_t n);
+usb_er_t usb_hstd_clr_stall(usb_utr_t * ptr, uint16_t pipe, usb_cb_t complete);
+usb_er_t usb_hstd_clr_feature(usb_utr_t * ptr, uint16_t addr, uint16_t epnum, usb_cb_t complete);
+void     usb_hstd_suspend(usb_utr_t * ptr);
+void     usb_hstd_bus_int_disable(usb_utr_t * ptr);
+void     usb_class_request_complete(usb_utr_t * mess, uint16_t data1, uint16_t data2);
+void     usb_host_registration(usb_utr_t * ptr);
+void     usb_hstd_connect_err_event_set(uint16_t ip_no);
 
 /* r_usb_hcontrolrw.c */
 uint16_t usb_hstd_ctrl_write_start(usb_utr_t * ptr, uint32_t bsize, uint8_t * table);
@@ -399,14 +435,14 @@ void usb_hstd_ls_connect_function(usb_utr_t * ptr);
 void usb_hstd_attach_function(void);
 void usb_hstd_ovrcr0function(usb_utr_t * ptr);
 
-void usb_hdriver_init(usb_utr_t * ptr, usb_cfg_t const * const cfg);
+void usb_hdriver_init(usb_utr_t * ptr);
 void usb_class_driver_start(usb_utr_t * ptr);
 
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
 void     class_trans_result(usb_utr_t * ptr, uint16_t data1, uint16_t data2);
 uint16_t class_trans_wait_tmo(usb_utr_t * ptr, uint16_t tmo);
 
- #endif                                /* #if (BSP_CFG_RTOS == 2) */
+ #endif                                /* #if (BSP_CFG_RTOS != 0) */
 
 /* r_usb_hreg_abs */
 void     usb_hstd_set_hub_port(usb_utr_t * ptr, uint16_t addr, uint16_t upphub, uint16_t hubport);
@@ -456,21 +492,34 @@ void usb_hstd_enum_set_address(usb_utr_t * ptr, uint16_t addr, uint16_t setaddr)
 void usb_hstd_enum_set_configuration(usb_utr_t * ptr, uint16_t addr, uint16_t confnum);
 void usb_hstd_enum_dummy_request(usb_utr_t * ptr, uint16_t addr, uint16_t cnt_value);
 void usb_hstd_electrical_test_mode(usb_utr_t * ptr, uint16_t product_id);
+
+ #if (BSP_CFG_RTOS == 1)
+void usb_hstd_mgr_task(ULONG entry_input);
+
+ #else                                 /* #if (BSP_CFG_RTOS == 1) */
 void usb_hstd_mgr_task(void * stacd);
 
+ #endif /* #if (BSP_CFG_RTOS == 1) */
+
 extern void (* g_usb_hstd_enumaration_process[])(usb_utr_t *, uint16_t, uint16_t);
 
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
 uint16_t usb_hstd_get_string_desc(usb_utr_t * ptr, uint16_t addr, uint16_t string);
 uint16_t usb_hstd_set_feature(usb_utr_t * ptr, uint16_t addr, uint16_t epnum);
 uint16_t usb_hstd_get_config_desc(usb_utr_t * ptr, uint16_t addr, uint16_t length);
 
- #else                                 /* #if (BSP_CFG_RTOS == 2) */
+  #if ((BSP_CFG_RTOS == 1) && defined(USB_CFG_HHID_USE))
+void usb_hid_set_protocol(usb_utr_t * ptr, uint16_t addr, uint16_t setaddr);
+void usb_hid_get_string_desc(usb_utr_t * ptr, uint16_t addr, uint16_t string);
+
+  #endif
+
+ #else                                 /* #if (BSP_CFG_RTOS != 0) */
 uint16_t usb_hstd_get_string_desc(usb_utr_t * ptr, uint16_t addr, uint16_t string, usb_cb_t complete);
 uint16_t usb_hstd_set_feature(usb_utr_t * ptr, uint16_t addr, uint16_t epnum, usb_cb_t complete);
 uint16_t usb_hstd_get_config_desc(usb_utr_t * ptr, uint16_t addr, uint16_t length, usb_cb_t complete);
 
- #endif                                /* #if (BSP_CFG_RTOS == 2) */
+ #endif                                /* #if (BSP_CFG_RTOS != 0) */
 
 void usb_hstd_submit_result(usb_utr_t * ptr, uint16_t data1, uint16_t data2);
 void usb_hstd_mgr_suspend(usb_utr_t * ptr, uint16_t info);
@@ -516,8 +565,6 @@ void usb_hstd_test_resume(usb_utr_t * ptr);
 /* r_usb_hscheduler.c */
 fsp_err_t usb_cstd_wai_msg(uint8_t id, usb_msg_t * mess, usb_tm_t times);
 void      usb_cstd_wait_scheduler(void);
-usb_er_t  usb_cstd_pget_blk(uint8_t id, usb_utr_t ** blk);
-usb_er_t  usb_cstd_rel_blk(uint8_t id, usb_utr_t * blk);
 void      usb_cstd_sche_init(void);
 fsp_err_t usb_cstd_check(usb_er_t err);
 uint8_t   usb_cstd_check_schedule(void);
@@ -526,6 +573,9 @@ void      usb_cstd_set_task_pri(uint8_t tasknum, uint8_t pri);
 
 #endif                                 /* (USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST */
 
+usb_er_t usb_cstd_pget_blk(uint8_t id, usb_utr_t ** blk);
+usb_er_t usb_cstd_rel_blk(uint8_t id, usb_utr_t * blk);
+
 /* r_usb_hscheduler.c */
 usb_er_t usb_cstd_snd_msg(uint8_t id, usb_msg_t * mess);
 usb_er_t usb_cstd_rec_msg(uint8_t id, usb_msg_t ** mess, usb_tm_t tm);
@@ -537,7 +587,13 @@ usb_er_t usb_cstd_isnd_msg(uint8_t id, usb_msg_t * mess);
 void usb_pstd_usb_handler(void);
 
 /* r_usb_pdriver.c */
-void     usb_pstd_pcd_task(void);
+ #if (BSP_CFG_RTOS == 1)
+void usb_pstd_pcd_task(ULONG entry_input);
+
+ #else                                 /* #if (BSP_CFG_RTOS == 1) */
+void usb_pstd_pcd_task(void);
+
+ #endif /* #if (BSP_CFG_RTOS == 1) */
 usb_er_t usb_pstd_set_submitutr(usb_utr_t * utrmsg);
 void     usb_pstd_clr_alt(void);
 void     usb_pstd_clr_mem(void);
@@ -594,7 +650,7 @@ void     usb_peri_registration(usb_instance_ctrl_t * ctrl, usb_cfg_t const * con
 void     usb_peri_devdefault(usb_utr_t * ptr, uint16_t mode, uint16_t data2);
 uint16_t usb_peri_pipe_info(uint8_t * table, uint16_t speed, uint16_t length, usb_utr_t * p_utr);
 void     usb_peri_configured(usb_utr_t * ptr, uint16_t data1, uint16_t data2);
-void     usb_peri_detach(usb_utr_t * ptr, uint16_t data1, uint16_t data2);
+void     usb_peri_detach(usb_utr_t * ptr, uint16_t usb_state, uint16_t data2);
 void     usb_peri_suspended(usb_utr_t * ptr, uint16_t data1, uint16_t data2);
 void     usb_peri_resume(usb_utr_t * ptr, uint16_t data1, uint16_t data2);
 void     usb_peri_interface(usb_utr_t * ptr, uint16_t data1, uint16_t data2);
@@ -621,6 +677,12 @@ extern void usb_pcdc_write_complete(usb_utr_t * mess, uint16_t data1, uint16_t d
 
 #endif                                 /* defined(USB_CFG_PCDC_USE) */
 
+#if defined(USB_CFG_PPRN_USE)
+extern void usb_pprn_read_complete(usb_utr_t * mess, uint16_t data1, uint16_t data2);
+extern void usb_pprn_write_complete(usb_utr_t * mess, uint16_t data1, uint16_t data2);
+
+#endif                                 /* defined(USB_CFG_PPRN_USE) */
+
 #if defined(USB_CFG_PHID_USE)
 extern void usb_phid_read_complete(usb_utr_t * mess, uint16_t data1, uint16_t data2);
 extern void usb_phid_write_complete(usb_utr_t * mess, uint16_t data1, uint16_t data2);
@@ -628,8 +690,10 @@ extern void usb_phid_write_complete(usb_utr_t * mess, uint16_t data1, uint16_t d
 #endif                                 /* defined(USB_CFG_PHID_USE) */
 
 #if defined(USB_CFG_PMSC_USE)
+ #if (BSP_CFG_RTOS != 1)
 extern void usb_pmsc_task(void);
 
+ #endif                                /* #if (BSP_CFG_RTOS != 1) */
 #endif                                 /* defined(USB_CFG_PMSC_USE) */
 
 #if defined(USB_CFG_HCDC_USE)
@@ -682,11 +746,6 @@ void     usb_hstd_device_information(usb_utr_t * ptr, uint16_t devaddr, uint16_t
 void     usb_pstd_device_information(usb_utr_t * ptr, uint16_t * tbl);
 usb_er_t usb_pstd_set_stall_clr_feature(usb_utr_t * ptr, usb_cb_t complete, uint16_t pipe);
 
-#if USB_CFG_COMPLIANCE == USB_CFG_ENABLE
-void usb_compliance_disp(void *);
-
-#endif                                 /* USB_CFG_COMPLIANCE == USB_CFG_ENABLE */
-
 #if USB_CFG_BC == USB_CFG_ENABLE
 
 /* BC State change function */
@@ -710,7 +769,7 @@ void usb_pstd_bc_detect_process(usb_utr_t * p_utr);
 
 #endif                                 /* USB_CFG_BC == USB_CFG_ENABLE */
 
-#if (BSP_CFG_RTOS == 2)
+#if (BSP_CFG_RTOS != 0)
 
 /* r_usb_cstd_rtos.c */
 void usb_cstd_pipe_msg_clear(usb_utr_t * ptr, uint16_t pipe_no);
@@ -720,7 +779,36 @@ void usb_cstd_pipe0_msg_re_forward(uint16_t ip_no);
 void usb_cstd_pipe_msg_forward(usb_utr_t * ptr, uint16_t pipe_no);
 void usb_cstd_pipe0_msg_forward(usb_utr_t * ptr, uint16_t dev_addr);
 
-#endif                                 /* #if (BSP_CFG_RTOS == 2) */
+#endif                                 /* #if (BSP_CFG_RTOS != 0) */
+
+#if (BSP_CFG_RTOS == 1)
+void usb_cstd_usbx_callback(usb_event_info_t * p_api_event, usb_hdl_t cur_task, usb_onoff_t usb_state);
+
+ #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
+void usb_host_usbx_registration(usb_utr_t * p_utr);
+void usb_host_usbx_attach_init(uint8_t module_number);
+
+ #endif                                /* #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST) */
+
+ #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
+uint32_t usb_peri_usbx_initialize_complete(void);
+
+ #endif                                /* #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI) */
+
+ #if defined(USB_CFG_OTG_USE)
+void usb_otg_irq_callback(external_irq_callback_args_t * p_args);
+void usb2_otg_irq_callback(external_irq_callback_args_t * p_args);
+VOID usb_otg_detach_timer(ULONG args);
+VOID usb2_otg_detach_timer(ULONG args);
+VOID usb_otg_chattering_timer(ULONG args);
+VOID usb_otg_hnp_timer(ULONG args);
+
+ #endif                                /* defined(USB_CFG_OTG_USE) */
+
+#endif                                 /* #if (BSP_CFG_RTOS == 1) */
+
+/* Common macro for FSP header files. There is also a corresponding FSP_HEADER macro at the top of this file. */
+FSP_FOOTER
 
 #endif                                 /* R_USB_EXTERN_H */
 
