@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -31,30 +31,60 @@
 #include "../hw/inc/r_usb_bitdefine.h"
 #include "../hw/inc/r_usb_reg_access.h"
 
-#if defined(USB_CFG_HCDC_USE)
- #include "r_usb_hcdc_cfg.h"
-#endif                                 /* defined(USB_CFG_HCDC_USE) */
+#if defined(USB_CFG_OTG_USE)
+ #if (defined(USB_CFG_HCDC_USE) | defined(USB_CFG_PCDC_USE))
+  #include "r_usb_otg_cdc_cfg.h"
+  #include "r_usb_pcdc_api.h"
+ #endif                                /* (defined(USB_CFG_HCDC_USE) | defined(USB_CFG_PCDC_USE)) */
+#else                                  /* defined(USB_CFG_OTG_USE) */
+ #if defined(USB_CFG_HCDC_USE)
+  #include "r_usb_hcdc_cfg.h"
+ #endif                                /* defined(USB_CFG_HCDC_USE) */
+ #if defined(USB_CFG_PCDC_USE)
+  #include "r_usb_pcdc_api.h"
+  #include "r_usb_pcdc_cfg.h"
+ #endif                                /* defined(USB_CFG_PCDC_USE) */
+#endif                                 /* defined(USB_CFG_OTG_USE) */
 
-#if defined(USB_CFG_PCDC_USE)
- #include "r_usb_pcdc_api.h"
- #include "r_usb_pcdc_cfg.h"
-#endif                                 /* defined(USB_CFG_PCDC_USE) */
+#if defined(USB_CFG_PPRN_USE)
+ #include "r_usb_pprn_api.h"
+ #if (BSP_CFG_RTOS != 1)
+  #include "r_usb_pprn_cfg.h"
+ #endif                                /* (BSP_CFG_RTOS != 1) */
+#endif                                 /* defined(USB_CFG_PPRN_USE) */
+
+#if defined(USB_CFG_HPRN_USE)
+ #include "r_usb_hprn_cfg.h"
+#endif                                 /* defined(USB_CFG_HPRN_USE) */
 
 #if defined(USB_CFG_PMSC_USE)
  #include "r_usb_pmsc_api.h"
 #endif                                 /* defined(USB_CFG_PMSC_USE) */
 
-#if defined(USB_CFG_PHID_USE)
+#if defined(USB_CFG_PHID_USE) && !defined(USB_CFG_OTG_USE)
  #include "r_usb_phid_api.h"
 #endif                                 /* defined(USB_CFG_PHID_USE) */
 
-#if defined(USB_CFG_HHID_USE)
- #include "r_usb_hhid_cfg.h"
-#endif                                 /* defined(USB_CFG_HHID_USE) */
+#if defined(USB_CFG_HHID_USE) && defined(USB_CFG_OTG_USE)
+ #include "r_usb_otg_hid_cfg.h"
+#else
+ #if defined(USB_CFG_HHID_USE)
+  #include "r_usb_hhid_cfg.h"
+ #endif                                /* defined(USB_CFG_HHID_USE) */
+#endif                                 /* defined(USB_CFG_HHID_USE) && defined(USB_CFG_OTG_USE) */
+#if (BSP_CFG_RTOS != 1)
+ #if defined(USB_CFG_HMSC_USE)
+  #include "r_usb_hmsc.h"
+ #endif                                /* defined(USB_CFG_HMSC_USE) */
+#else  /* #if (BSP_CFG_RTOS != 1) */
+ #if defined(USB_CFG_PAUD_USE)
+  #include "r_usb_paud_cfg.h"
+ #endif                                /* defined(USB_CFG_PAUD_USE) */
+ #if defined(USB_CFG_HUVC_USE)
+  #include "r_usb_huvc_cfg.h"
+ #endif                                /* defined(USB_CFG_HUVC_USE) */
 
-#if defined(USB_CFG_HMSC_USE)
- #include "r_usb_hmsc.h"
-#endif                                 /* defined(USB_CFG_HMSC_USE) */
+#endif /* #if (BSP_CFG_RTOS != 1) */
 
 #if ((USB_CFG_DTC == USB_CFG_ENABLE) || (USB_CFG_DMA == USB_CFG_ENABLE))
  #include "../hw/inc/r_usb_dmac.h"
@@ -104,7 +134,31 @@ static const uint8_t g_usb_pipe_host[] =
     USB_NULL,              USB_NULL,
     USB_NULL,              USB_NULL,
     USB_NULL,              USB_NULL,
- #endif                                /* defined(USB_CFG_HHID_USE) */
+ #endif                                           /* defined(USB_CFG_HHID_USE) */
+
+ #if defined(USB_CFG_HPRN_USE)
+    USB_CFG_HPRN_BULK_IN,  USB_CFG_HPRN_BULK_OUT, /* HPRN: Address 1 */
+    USB_CFG_HPRN_BULK_IN,  USB_CFG_HPRN_BULK_OUT, /* HPRN: Address 2 using Hub */
+    USB_NULL,              USB_NULL,              /* HPRN: Address 3 using Hub */
+    USB_NULL,              USB_NULL,              /* HPRN: Address 4 using Hub */
+ #else                                            /* defined(USB_CFG_HPRN_USE) */
+    USB_NULL,              USB_NULL,
+    USB_NULL,              USB_NULL,
+    USB_NULL,              USB_NULL,
+    USB_NULL,              USB_NULL,
+ #endif                                          /* defined(USB_CFG_HPRN_USE) */
+
+ #if defined(USB_CFG_HUVC_USE)
+    USB_CFG_HUVC_ISO_IN,   USB_CFG_HUVC_ISO_OUT, /* HPRN: Address 1 */
+    USB_CFG_HUVC_ISO_IN,   USB_CFG_HUVC_ISO_OUT, /* HPRN: Address 2 using Hub */
+    USB_NULL,              USB_NULL,             /* HPRN: Address 3 using Hub */
+    USB_NULL,              USB_NULL,             /* HPRN: Address 4 using Hub */
+ #else                                           /* defined(USB_CFG_HPRN_USE) */
+    USB_NULL,              USB_NULL,
+    USB_NULL,              USB_NULL,
+    USB_NULL,              USB_NULL,
+    USB_NULL,              USB_NULL,
+ #endif                                /* defined(USB_CFG_HPRN_USE) */
 };
 #endif  /* (USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST */
 
@@ -113,22 +167,43 @@ static const uint8_t g_usb_pipe_peri[] =
 {
     /* OUT pipe */          /* IN pipe */
  #if defined(USB_CFG_PCDC_USE)
-    USB_CFG_PCDC_BULK_OUT,  USB_CFG_PCDC_BULK_IN,  /* USB_PCDC */
-    USB_NULL,               USB_CFG_PCDC_INT_IN,   /* USB_PCDCC */
-    USB_CFG_PCDC_BULK_OUT2, USB_CFG_PCDC_BULK_IN2, /* USB_PCDC2 */
-    USB_NULL,               USB_CFG_PCDC_INT_IN2,  /* USB_PCDCC2 */
+    USB_CFG_PCDC_BULK_OUT,  USB_CFG_PCDC_BULK_IN,  /* USB_PCDC   (0) */
+    USB_NULL,               USB_CFG_PCDC_INT_IN,   /* USB_PCDCC  (1) */
+    USB_CFG_PCDC_BULK_OUT2, USB_CFG_PCDC_BULK_IN2, /* USB_PCDC2  (2) */
+    USB_NULL,               USB_CFG_PCDC_INT_IN2,  /* USB_PCDCC2 (3) */
  #else                                             /* defined(USB_CFG_PCDC_USE) */
     USB_NULL,               USB_NULL,
     USB_NULL,               USB_NULL,
     USB_NULL,               USB_NULL,
     USB_NULL,               USB_NULL,
- #endif                                          /* defined(USB_CFG_PCDC_USE) */
+ #endif                                           /* defined(USB_CFG_PCDC_USE) */
 
  #if defined(USB_CFG_PHID_USE)
-    USB_CFG_PHID_INT_OUT,   USB_CFG_PHID_INT_IN, /* USB_PHID */
- #else                                           /* defined(USB_CFG_PHID_USE) */
+  #if (BSP_CFG_RTOS != 1)
+    USB_CFG_PHID_INT_OUT,   USB_CFG_PHID_INT_IN,  /* USB_PHID  (4) */
+    USB_CFG_PHID_INT_OUT2,  USB_CFG_PHID_INT_IN2, /* USB_PHID2 (5) */
+  #else /* #if (BSP_CFG_RTOS != 1) */
+    USB_CFG_PHID_INT_OUT,   USB_CFG_PHID_INT_IN,  /* USB_PHID  (4) */
+    USB_NULL,               USB_NULL,             /* USB_PHID2 (5) */
+  #endif /* #if (BSP_CFG_RTOS != 1) */
+ #else                                            /* defined(USB_CFG_PHID_USE) */
     USB_NULL,               USB_NULL,
- #endif                                          /* defined(USB_CFG_PHID_USE) */
+    USB_NULL,               USB_NULL,
+ #endif                                           /* defined(USB_CFG_PHID_USE) */
+
+ #if defined(USB_CFG_PAUD_USE)
+    USB_CFG_PAUD_ISO_OUT,   USB_CFG_PAUD_ISO_IN,  /* USB_PAUD (6) */
+ #else                                            /* defined(USB_CFG_PAUD_USE) */
+    USB_NULL,               USB_NULL,
+ #endif                                           /* defined(USB_CFG_PAUD_USE) */
+
+ #if defined(USB_CFG_PPRN_USE)
+    USB_CFG_PPRN_BULK_OUT,  USB_CFG_PPRN_BULK_IN, /* USB_PPRN (7) */
+ #else                                            /* defined(USB_CFG_PPRN_USE) */
+    USB_NULL,               USB_NULL,
+ #endif                                           /* defined(USB_CFG_PPRN_USE) */
+
+    USB_NULL,               USB_NULL,             /* USB_DFU (8) */
 };
 #endif  /* (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI */
 
@@ -154,56 +229,111 @@ void (* g_usb_callback[])(usb_utr_t *, uint16_t, uint16_t) =
 {
     /* PCDC, PCDCC */
 #if defined(USB_CFG_PCDC_USE)
+ #if (BSP_CFG_RTOS == 1)
+    USB_NULL, USB_NULL,                              /* USB_PCDC  (0) */
+    USB_NULL, USB_NULL,                              /* USB_PCDCC (1) */
+    USB_NULL, USB_NULL,                              /* USB_PCDC2  (2) */
+    USB_NULL, USB_NULL,                              /* USB_PCDCC2 (3) */
+ #else  /* #if (BSP_CFG_RTOS == 1) */
     usb_pcdc_read_complete, usb_pcdc_write_complete, /* USB_PCDC  (0) */
     USB_NULL, usb_pcdc_write_complete,               /* USB_PCDCC (1) */
-    usb_pcdc_read_complete, usb_pcdc_write_complete, /* USB_PCDC2  (0) */
-    USB_NULL, usb_pcdc_write_complete,               /* USB_PCDCC2 (1) */
+    usb_pcdc_read_complete, usb_pcdc_write_complete, /* USB_PCDC2  (2) */
+    USB_NULL, usb_pcdc_write_complete,               /* USB_PCDCC2 (3) */
+ #endif /* #if (BSP_CFG_RTOS == 1) */
 #else
     USB_NULL, USB_NULL,                              /* USB_PCDC  (0) */
     USB_NULL, USB_NULL,                              /* USB_PCDCC (1) */
-    USB_NULL, USB_NULL,                              /* USB_PCDC2  (0) */
-    USB_NULL, USB_NULL,                              /* USB_PCDCC2 (1) */
+    USB_NULL, USB_NULL,                              /* USB_PCDC2  (2) */
+    USB_NULL, USB_NULL,                              /* USB_PCDCC2 (3) */
 #endif
 
     /* PHID */
 #if defined(USB_CFG_PHID_USE)
-    usb_phid_read_complete, usb_phid_write_complete, /* USB_PHID (2) */
+ #if (BSP_CFG_RTOS != 1)
+    usb_phid_read_complete, usb_phid_write_complete, /* USB_PHID (4) */
+    usb_phid_read_complete, usb_phid_write_complete, /* USB_PHID2 (5) */
+ #else /*  #if (BSP_CFG_RTOS == 1) */
+    USB_NULL, USB_NULL,                              /* USB_PHID (4) */
+    USB_NULL, USB_NULL,                              /* USB_PHID (5) */
+ #endif /*  #if (BSP_CFG_RTOS == 1) */
 #else
-    USB_NULL, USB_NULL,                              /* USB_PHID (2) */
+    USB_NULL, USB_NULL,                              /* USB_PHID (4) */
+    USB_NULL, USB_NULL,                              /* USB_PHID (5) */
 #endif
 
+    /* PAUD */
+    USB_NULL, USB_NULL,                              /* USB_PAUD (6) */
+
+    /* PPRN */
+#if defined(USB_CFG_PPRN_USE)
+ #if (BSP_CFG_RTOS != 1)
+    usb_pprn_read_complete, usb_pprn_write_complete, /* USB_PPRN (7) */
+ #else  /* BSP_CFG_RTOS != 1 */
+    USB_NULL, USB_NULL,                              /* USB_PPRN (7) */
+ #endif /* BSP_CFG_RTOS != 1 */
+#else                                                /* defined(USB_CFG_PPRN_USE) */
+    USB_NULL, USB_NULL,                              /* USB_PPRN (7) */
+#endif /* defined(USB_CFG_PPRN_USE) */
+
+    /* DFU */
+    USB_NULL, USB_NULL,                              /* USB_DFU (8) */
+
     /* PVND */
-    USB_NULL, USB_NULL,                              /* USB_PVND  (3) */
+    USB_NULL, USB_NULL,                              /* USB_PVND (9) */
 
     /* HCDC, HCDCC */
 #if defined(USB_CFG_HCDC_USE)
-    usb_hcdc_read_complete, usb_hcdc_write_complete, /* USB_HCDC  (4) */
-    usb_hcdc_read_complete, USB_NULL,                /* USB_HCDCC (5) */
+ #if (BSP_CFG_RTOS == 1)
+    USB_NULL, USB_NULL,                              /* USB_HCDC  (10) */
+    USB_NULL, USB_NULL,                              /* USB_HCDCC (11) */
+ #else  /* #if (BSP_CFG_RTOS == 1) */
+    usb_hcdc_read_complete, usb_hcdc_write_complete, /* USB_HCDC  (10) */
+    usb_hcdc_read_complete, USB_NULL,                /* USB_HCDCC (11) */
+ #endif /* #if (BSP_CFG_RTOS == 1) */
 #else
-    USB_NULL, USB_NULL,                              /* USB_HCDC  (4) */
-    USB_NULL, USB_NULL,                              /* USB_HCDCC (5) */
+    USB_NULL, USB_NULL,                              /* USB_HCDC  (10) */
+    USB_NULL, USB_NULL,                              /* USB_HCDCC (11) */
 #endif
 
     /* HHID */
 #if defined(USB_CFG_HHID_USE)
-    usb_hhid_read_complete, usb_hhid_write_complete, /* USB_HHID  (6) */
+ #if (BSP_CFG_RTOS == 1)
+    USB_NULL, USB_NULL,                              /* USB_HHID (12) */
+ #else                                               /* #if (BSP_CFG_RTOS == 1) */
+    usb_hhid_read_complete, usb_hhid_write_complete, /* USB_HHID  (12) */
+ #endif /* #if (BSP_CFG_RTOS == 1) */
 #else
-    USB_NULL, USB_NULL,                              /* USB_HHID  (6) */
+    USB_NULL, USB_NULL,                              /* USB_HHID  (12) */
 #endif
 
     /* HVND */
 #if defined(USB_CFG_HVND_USE)
-    usb_hvnd_read_complete, usb_hvnd_write_complete, /* USB_HVND  (7) */
+    usb_hvnd_read_complete, usb_hvnd_write_complete, /* USB_HVND  (13) */
 #else
-    USB_NULL, USB_NULL,                              /* USB_HVND  (7) */
+    USB_NULL, USB_NULL,                              /* USB_HVND  (13) */
 #endif
 
     /* HMSC */
-    USB_NULL, USB_NULL,                              /* USB_HMSC  (8) */
+    USB_NULL, USB_NULL,                              /* USB_HMSC  (14) */
 
     /* PMSC */
-    USB_NULL, USB_NULL,                              /* USB_PMSC  (9) */
-};                                                   /* const void (g_usb_callback[])(usb_utr_t *, uint16_t, uint16_t) */
+    USB_NULL, USB_NULL,                              /* USB_PMSC  (15) */
+
+    /* HPRN */
+#if defined(USB_CFG_HPRN_USE)
+ #if (BSP_CFG_RTOS == 1)
+    USB_NULL, USB_NULL,                              /* USB_HPRN (16) */
+ #else                                               /* #if (BSP_CFG_RTOS == 1) */
+    usb_hprn_read_complete, usb_hprn_write_complete, /* USB_HPRN (16) */
+ #endif /* #if (BSP_CFG_RTOS == 1) */
+#else
+    USB_NULL, USB_NULL,                              /* USB_HPRN (16) */
+#endif
+
+    /* HUVC */
+
+    USB_NULL, USB_NULL,                /* USB_HUVC (17) */
+};                                     /* const void (g_usb_callback[])(usb_utr_t *, uint16_t, uint16_t) */
 
 #if defined(USB_CFG_PCDC_USE)
 
@@ -260,17 +390,17 @@ usb_er_t usb_ctrl_read (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t si
  #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
     usb_er_t    err;
     usb_utr_t * p_tran_data;
-  #if (BSP_CFG_RTOS == 2)
+  #if (BSP_CFG_RTOS != 0)
     usb_utr_t tran_data_host;
-  #endif                               /* #if (BSP_CFG_RTOS == 2) */
+  #endif                               /* #if (BSP_CFG_RTOS != 0) */
 
     if (USB_MODE_HOST == g_usb_usbmode[p_ctrl->module_number])
     {
-  #if (BSP_CFG_RTOS == 2)
+  #if (BSP_CFG_RTOS != 0)
         p_tran_data = &tran_data_host;
-  #else                                        /* #if (BSP_CFG_RTOS == 2) */
+  #else                                        /* #if (BSP_CFG_RTOS != 0) */
         p_tran_data = &g_usb_hdata[p_ctrl->module_number][USB_PIPE0];
-  #endif /* #if (BSP_CFG_RTOS == 2) */
+  #endif /* #if (BSP_CFG_RTOS != 0) */
 
         p_tran_data->read_req_len = size;      /* Save Read Request Length */
         p_tran_data->keyword      = USB_PIPE0; /* Pipe No */
@@ -292,7 +422,7 @@ usb_er_t usb_ctrl_read (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t si
 
         return err;
     }
- #endif
+ #endif                                /* (USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST */
  #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
     usb_utr_t tran_data_peri;
 
@@ -308,6 +438,7 @@ usb_er_t usb_ctrl_read (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t si
         usb_pstd_ctrl_write(size, buf, &tran_data_peri);
     }
  #endif                                /* (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI */
+
     return USB_OK;
 } /* End of function usb_ctrl_read() */
 
@@ -324,17 +455,17 @@ usb_er_t usb_ctrl_write (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t s
  #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
     usb_er_t    err;
     usb_utr_t * p_tran_data;
-  #if (BSP_CFG_RTOS == 2)
+  #if (BSP_CFG_RTOS != 0)
     usb_utr_t tran_data_host;
-  #endif                               /* #if (BSP_CFG_RTOS == 2) */
+  #endif                               /* #if (BSP_CFG_RTOS != 0) */
 
     if (USB_MODE_HOST == g_usb_usbmode[p_ctrl->module_number])
     {
-  #if (BSP_CFG_RTOS == 2)
+  #if (BSP_CFG_RTOS != 0)
         p_tran_data = &tran_data_host;
-  #else                                     /* #if (BSP_CFG_RTOS == 2) */
+  #else                                     /* #if (BSP_CFG_RTOS != 0) */
         p_tran_data = &g_usb_hdata[p_ctrl->module_number][USB_PIPE0];
-  #endif /* #if (BSP_CFG_RTOS == 2) */
+  #endif /* #if (BSP_CFG_RTOS != 0) */
 
         p_tran_data->read_req_len = size;   /* Save Read Request Length */
 
@@ -357,7 +488,7 @@ usb_er_t usb_ctrl_write (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t s
 
         return err;
     }
- #endif
+ #endif                                /* (USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST */
  #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
     usb_instance_ctrl_t ctrl;
     usb_utr_t           tran_data_peri;
@@ -382,9 +513,11 @@ usb_er_t usb_ctrl_write (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t s
             ctrl.data_size     = 0;
             ctrl.status        = USB_SETUP_STATUS_ACK;
             ctrl.type          = USB_CLASS_REQUEST;
-  #if (BSP_CFG_RTOS == 2)
+  #if (BSP_CFG_RTOS == 1)
+            ctrl.p_data = (void *) tx_thread_identify();
+  #elif (BSP_CFG_RTOS == 2)
             ctrl.p_data = (void *) xTaskGetCurrentTaskHandle();
-  #endif                               /* #if (BSP_CFG_RTOS == 2) */
+  #endif                               /* #if (BSP_CFG_RTOS == 1) */
             usb_set_event(USB_STATUS_REQUEST_COMPLETE, &ctrl);
         }
         else
@@ -450,20 +583,20 @@ usb_er_t usb_data_read (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t si
     uint8_t     pipe;
     usb_er_t    err = USB_OK;
     usb_utr_t * p_tran_data;
-#if (BSP_CFG_RTOS == 2)
+#if (BSP_CFG_RTOS != 0)
     usb_utr_t tran_data;
-#endif                                 /* #if (BSP_CFG_RTOS == 2) */
+#endif                                 /* #if (BSP_CFG_RTOS != 0) */
 
     pipe = usb_get_usepipe(p_ctrl, USB_TRANSFER_READ);
 
     if (USB_CLASS_INTERNAL_PVND < (usb_class_internal_t) (p_ctrl->type))
     {
 #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
         p_tran_data = &tran_data;
- #else                                                             /* #if (BSP_CFG_RTOS == 2) */
+ #else                                                             /* #if (BSP_CFG_RTOS != 0) */
         p_tran_data = &g_usb_hdata[p_ctrl->module_number][pipe];
- #endif /* #if (BSP_CFG_RTOS == 2) */
+ #endif /* #if (BSP_CFG_RTOS != 0) */
 
         p_tran_data->read_req_len = size;                          /* Save Read Request Length */
 
@@ -499,11 +632,11 @@ usb_er_t usb_data_read (usb_instance_ctrl_t * p_ctrl, uint8_t * buf, uint32_t si
     else
     {
 #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
         p_tran_data = &tran_data;
- #else                                                                        /* #if (BSP_CFG_RTOS == 2) */
+ #else                                                                        /* #if (BSP_CFG_RTOS != 0) */
         p_tran_data = &g_usb_pdata[pipe];
- #endif /* #if (BSP_CFG_RTOS == 2) */
+ #endif /* #if (BSP_CFG_RTOS != 0) */
 
         p_tran_data->read_req_len = size;                                     /* Save Read Request Length */
 
@@ -551,20 +684,20 @@ usb_er_t usb_data_write (usb_instance_ctrl_t * p_ctrl, uint8_t const * const buf
     uint8_t     pipe;
     usb_er_t    err = USB_OK;
     usb_utr_t * p_tran_data;
-#if (BSP_CFG_RTOS == 2)
+#if (BSP_CFG_RTOS != 0)
     usb_utr_t tran_data;
-#endif                                 /* #if (BSP_CFG_RTOS == 2) */
+#endif                                 /* #if (BSP_CFG_RTOS != 0) */
 
     pipe = usb_get_usepipe(p_ctrl, USB_TRANSFER_WRITE);
 
     if (USB_CLASS_INTERNAL_PVND < (usb_class_internal_t) (p_ctrl->type))
     {
 #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
         p_tran_data = &tran_data;
- #else                                                                   /* #if (BSP_CFG_RTOS == 2) */
+ #else                                                                   /* #if (BSP_CFG_RTOS != 0) */
         p_tran_data = &g_usb_hdata[p_ctrl->module_number][pipe];
- #endif /* #if (BSP_CFG_RTOS == 2) */
+ #endif /* #if (BSP_CFG_RTOS != 0) */
 
         p_tran_data->keyword   = pipe;                                   /* Pipe No */
         p_tran_data->p_tranadr = buf;                                    /* Data address */
@@ -593,16 +726,16 @@ usb_er_t usb_data_write (usb_instance_ctrl_t * p_ctrl, uint8_t const * const buf
         }
  #endif
         err = usb_hstd_transfer_start(p_tran_data);
-#endif
+#endif                                 /* ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST) */
     }
     else
     {
 #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
         p_tran_data = &tran_data;
- #else                                 /* #if (BSP_CFG_RTOS == 2) */
+ #else                                 /* #if (BSP_CFG_RTOS != 0) */
         p_tran_data = &g_usb_pdata[pipe];
- #endif /* #if (BSP_CFG_RTOS == 2) */
+ #endif /* #if (BSP_CFG_RTOS != 0) */
 
  #if defined(USB_CFG_PCDC_USE)
         if (USB_CFG_PCDC_INT_IN != pipe)
