@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -321,14 +321,14 @@ void hw_usb_hset_enb_sacke (usb_utr_t * ptr)
  ******************************************************************************/
 void hw_usb_hset_enb_pddetinte (usb_utr_t * ptr)
 {
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
     if (USB_IP1 == ptr->ip)
     {
         ptr->ipp1->INTENB1 |= USB_PDDETINTE;
     }
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
     (void) *ptr;
- #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif /* defined (USB_HIGH_SPEED_MODULE) */
 }
 
 /******************************************************************************
@@ -458,14 +458,14 @@ void hw_usb_hclear_sts_sack (usb_utr_t * ptr)
  ******************************************************************************/
 void hw_usb_hclear_sts_pddetint (usb_utr_t * ptr)
 {
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
     if (USB_IP1 == ptr->ip)
     {
         ptr->ipp1->INTSTS1 = (uint16_t) ((~USB_PDDETINT) & INTSTS1_MASK);
     }
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
     (void) *ptr;
- #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif /* defined (USB_HIGH_SPEED_MODULE) */
 }
 
 /******************************************************************************
@@ -675,14 +675,14 @@ void hw_usb_hset_usbspd (usb_utr_t * ptr, uint16_t devsel, uint16_t data)
  ******************************************************************************/
 void hw_usb_hset_dcpmode (usb_utr_t * ptr)
 {
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
     if (USB_IP1 == ptr->ip)
     {
         ptr->ipp1->BCCTRL |= USB_DCPMODE;
     }
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
     (void) *ptr;
- #endif/* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif/* defined (USB_HIGH_SPEED_MODULE) */
 }
 
 /******************************************************************************
@@ -690,18 +690,66 @@ void hw_usb_hset_dcpmode (usb_utr_t * ptr)
  ******************************************************************************/
 
 /******************************************************************************
- * Function Name   : hw_usb_hmodule_init
- * Description     : USB module initialization for USB Host mode
- * Arguments       : usb_utr_t *ptr   : Pointer to usb_utr_t structure
+ * Function Name   : hw_usb_hmodule_otg_init
+ * Description     : USB OTG module initialization for USB Host mode
+ * Arguments       : uint8_t usb_ip   : USB module number
  * Return value    : none
  ******************************************************************************/
-void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
+void hw_usb_hmodule_otg_init (uint8_t usb_ip)
 {
-    usb_instance_ctrl_t * p_ctrl = (usb_instance_ctrl_t *) p_api_ctrl;
+    if (USB_IP0 == usb_ip)
+    {
+        USB_M0->DVSTCTR0 |= USB_USBRST;
+        usb_cpu_delay_xms((uint16_t) USB_VALUE_50); /* Need to wait greater equal 10ms in USB spec */
+        USB_M0->DVSTCTR0 = (uint16_t) (USB_M0->DVSTCTR0 & (~USB_USBRST));
 
+        /* WAIT_LOOP */
+        while (USB_HSPROC == (USB_M0->DVSTCTR0 & USB_HSPROC))
+        {
+            /* HSPROC = 0100b */
+        }
+
+        USB_M0->DVSTCTR0 |= USB_UACT;
+
+        USB_M0->INTSTS1 &= ((~USB_OVRCRE) & INTSTS1_MASK);
+        USB_M0->INTENB1 |= (USB_OVRCRE);
+    }
+    else
+    {
+        USB_M1->DVSTCTR0 |= USB_USBRST;
+
+        usb_cpu_delay_xms((uint16_t) USB_VALUE_50); /* Need to wait greater equal 10ms in USB spec */
+
+        USB_M1->DVSTCTR0 = (uint16_t) (USB_M1->DVSTCTR0 & (~USB_USBRST));
+
+        /* WAIT_LOOP */
+        while (USB_HSPROC == (USB_M1->DVSTCTR0 & USB_HSPROC))
+        {
+            /* Wait for USB reset handshake in progress */
+        }
+
+        USB_M1->DVSTCTR0 |= USB_UACT;
+
+        USB_M1->INTSTS1 &= (~USB_OVRCRE & INTSTS1_MASK);
+        USB_M1->INTENB1 |= (USB_OVRCRE);
+    }
+}
+
+/******************************************************************************
+ * End of function hw_usb_hmodule_otg_init
+ ******************************************************************************/
+
+/******************************************************************************
+ * Function Name   : hw_usb_hmodule_init
+ * Description     : USB module initialization for USB Host mode
+ * Arguments       : uint8_t usb_ip   : USB module number
+ * Return value    : none
+ ******************************************************************************/
+void hw_usb_hmodule_init (uint8_t usb_ip)
+{
     uint16_t sts;
 
-    if (USB_IP0 == p_ctrl->module_number)
+    if (USB_IP0 == usb_ip)
     {
         USB_M0->SYSCFG |= USB_SCKE;
 
@@ -711,18 +759,28 @@ void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
             /* none */
         }
 
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
-        USB_M0->PHYSLEW = 0x5;
- #endif                                /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #if defined(USB_SUPPORT_PHYSLEW)
+        USB_M0->PHYSLEW = USB_PHYSLEW_VALUE;
+ #endif                                /* defined(USB_SUPPORT_PHYSLEW) */
 
         USB_M0->SYSCFG |= USB_DCFM;
 
         USB_M0->SYSCFG |= USB_DRPD;
 
+        USB_M0->SYSCFG &= (uint16_t) ~USB_DPRPU;
+
         sts = usb_chattaring((uint16_t *) &USB_M0->SYSSTS0);
 
         USB_M0->SYSCFG |= USB_USBE;
 
+ #if defined(USB_SUPPORT_HOCO_MODULE)
+        if (0 == (R_SYSTEM->SCKSCR & R_SYSTEM_SCKSCR_CKSEL_Msk))
+        {
+            /* Use HOCO */
+            hw_usb_set_uckselc();
+        }
+ #endif                                /* defined(USB_SUPPORT_HOCO_MODULE) */
+
         USB_M0->CFIFOSEL  = USB0_CFIFO_MBW;
         USB_M0->D0FIFOSEL = USB0_D0FIFO_MBW;
         USB_M0->D1FIFOSEL = USB0_D1FIFO_MBW;
@@ -759,7 +817,9 @@ void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
 
             case USB_SE0:              /* USB device no connected */
             {
+ #if !defined(USB_CFG_OTG_USE)
                 USB_M0->INTENB1 = USB_ATTCH;
+ #endif /* !defined (USB_CFG_OTG_USE) */
                 break;
             }
 
@@ -769,15 +829,31 @@ void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
             }
         }
 
-        USB_M0->INTSTS1 &= ((~USB_OVRCRE) & INTSTS1_MASK);
-        USB_M0->INTENB0  = ((USB_BEMPE | USB_NRDYE) | USB_BRDYE);
-        USB_M0->INTENB1  = (USB_OVRCRE | USB_ATTCH);
+        /*
+         *  When R_USB_Open function was called immediately after calling R_USB_Close function,
+         *  D+ line keeps High level since VBUS shifts to High level before USB Periheral Device recognizes VBUS Low,
+         *  The Attach interrupt is genrated since D+ line keeps High level.
+         *  When "INTSTS1 = 0" is described code, the Attach interrupt is canceled. "INTSTS1 = 0" is NG.
+         *  The following code(INTSTS1) is correct.
+         */
+        USB_M0->INTSTS1 = ((~USB_OVRCRE) & INTSTS1_MASK);
+
+        USB_M0->INTENB0 = ((USB_BEMPE | USB_NRDYE) | USB_BRDYE);
+ #if !defined(USB_CFG_OTG_USE)
+        USB_M0->INTENB1 = (USB_OVRCRE | USB_ATTCH);
+ #endif                                /* !defined (USB_CFG_OTG_USE) */
     }
 
  #if USB_NUM_USBIP == 2
     else
     {
-  #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+  #if defined(USB_HIGH_SPEED_MODULE)
+        USB_M1->PHYSET = (USB_DIRPD | USB_PLLRESET | USB_CLKSEL);
+
+   #if USB_CFG_CLKSEL == USB_CFG_24MHZ
+        USB_M1->PHYSET &= (uint16_t) ~USB_HSEB;
+   #endif                              /* USB_CFG_CLKSEL == USB_CFG_24MHZ */
+
    #if USB_CFG_CLKSEL == USB_CFG_20MHZ
         USB_M1->PHYSET &= (uint16_t) ~USB_CLKSEL;
         USB_M1->PHYSET |= USB_CLKSEL_20;
@@ -815,19 +891,22 @@ void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
         ;
    #endif                              /* (USB_CFG_CLKSEL == USB_CFG_12MHZ) || (USB_CFG_CLKSEL == USB_CFG_20MHZ) || (USB_CFG_CLKSEL == USB_CFG_24MHZ) */
 
+        USB_M1->SYSCFG |= USB_DCFM;
+
         USB_M1->SYSCFG |= USB_DRPD;
 
+        USB_M1->SYSCFG &= (uint16_t) (~(uint16_t) USB_DPRPU);
+
         USB_M1->SYSCFG |= USB_CNEN;
 
         USB_M1->BUSWAIT = (USB_CFG_BUSWAIT | USB_VALUE_0F00H);
         usb_cpu_delay_1us((uint16_t) 1); /* wait 1usec */
-  #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #endif /* defined (USB_HIGH_SPEED_MODULE) */
 
         USB_M1->SOFCFG |= USB_INTL;
 
-        USB_M1->SYSCFG |= USB_DCFM;
-
-        sts = usb_chattaring((uint16_t *) &USB_M1->SYSCFG);
+// sts = usb_chattaring((uint16_t *) &USB_M1->SYSCFG);
+        sts = usb_chattaring((uint16_t *) &USB_M1->SYSSTS0);
 
         USB_M1->SYSCFG |= USB_USBE;
 
@@ -840,16 +919,12 @@ void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
         USB_M1->D0FIFOSEL |= USB_BIGEND;
         USB_M1->D1FIFOSEL |= USB_BIGEND;
   #endif
+
         switch (sts)
         {
             case USB_FS_JSTS:          /* USB device already connected */
             case USB_LS_JSTS:
             {
-                if (USB_FS_JSTS == sts)
-                {
-                    USB_M1->SYSCFG |= USB_HSE;
-                }
-
                 USB_M1->DVSTCTR0 |= USB_USBRST;
 
                 usb_cpu_delay_xms((uint16_t) USB_VALUE_50); /* Need to wait greater equal 10ms in USB spec */
@@ -875,9 +950,9 @@ void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
 
             case USB_SE0:              /* USB device no connected */
             {
-  #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+  #if defined(USB_HIGH_SPEED_MODULE)
                 USB_M1->INTENB1 = USB_ATTCH;
-  #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #endif /* defined (USB_HIGH_SPEED_MODULE) */
                 break;
             }
 
@@ -887,11 +962,19 @@ void hw_usb_hmodule_init (usb_ctrl_t * p_api_ctrl)
             }
         }
 
-        USB_M1->INTSTS1 &= (~USB_OVRCRE & INTSTS1_MASK);
-        USB_M1->INTENB0  = (USB_BEMPE | USB_NRDYE | USB_BRDYE);
-  #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+        /*
+         *  When R_USB_Open function was called immediately after calling R_USB_Close function,
+         *  D+ line keeps High level since VBUS shifts to High level before USB Periheral Device recognizes VBUS Low,
+         *  The Attach interrupt is genrated since D+ line keeps High level.
+         *  When "INTSTS1 = 0" is described code, the Attach interrupt is canceled. "INTSTS1 = 0" is NG.
+         *  The following code(INTSTS1) is correct.
+         */
+        USB_M1->INTSTS1 = (~USB_OVRCRE & INTSTS1_MASK);
+
+        USB_M1->INTENB0 = (USB_BEMPE | USB_NRDYE | USB_BRDYE);
+  #if defined(USB_HIGH_SPEED_MODULE)
         USB_M1->INTENB1 = (USB_OVRCRE | USB_ATTCH);
-  #endif                               /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #endif                               /* defined (USB_HIGH_SPEED_MODULE) */
     }
  #endif                                /* USB_NUM_USBIP == 2 */
 
