@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -125,15 +125,6 @@ static void r_wdt_nmi_initialize(wdt_instance_ctrl_t * const p_instance_ctrl, wd
  * Private global variables
  **********************************************************************************************************************/
 
-/* Version data structure. */
-static const fsp_version_t g_wdt_version =
-{
-    .api_version_minor  = WDT_API_VERSION_MINOR,
-    .api_version_major  = WDT_API_VERSION_MAJOR,
-    .code_version_major = WDT_CODE_VERSION_MAJOR,
-    .code_version_minor = WDT_CODE_VERSION_MINOR
-};
-
 static const uint8_t g_wdtcr_timeout[] =
 {
     0xFFU,                             // WDTCR value for WDT_TIMEOUT_128 (not supported by WDT).
@@ -188,7 +179,6 @@ const wdt_api_t g_wdt_on_wdt =
     .counterGet  = R_WDT_CounterGet,
     .timeoutGet  = R_WDT_TimeoutGet,
     .callbackSet = R_WDT_CallbackSet,
-    .versionGet  = R_WDT_VersionGet,
 };
 
 /*******************************************************************************************************************//**
@@ -532,23 +522,6 @@ fsp_err_t R_WDT_CallbackSet (wdt_ctrl_t * const          p_ctrl,
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Return WDT HAL driver version. Implements @ref wdt_api_t::versionGet.
- *
- * @retval      FSP_SUCCESS             Version information successfully read.
- * @retval      FSP_ERR_ASSERTION       Null pointer passed as a parameter
- **********************************************************************************************************************/
-fsp_err_t R_WDT_VersionGet (fsp_version_t * const p_version)
-{
-#if WDT_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_wdt_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup WDT)
  **********************************************************************************************************************/
