@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -32,16 +32,18 @@
  * Macro definitions
  **********************************************************************************************************************/
 
-#define     MOTOR_CURRENT_OPEN        (0X4D435043L)
+#define     MOTOR_CURRENT_OPEN         (0X4D435043L)
 
-#define     MOTOR_CURRENT_FLG_CLR     (0)                           /* For flag clear */
-#define     MOTOR_CURRENT_FLG_SET     (1)                           /* For flag set */
+#define     MOTOR_CURRENT_FLG_CLR      (0)                           /* For flag clear */
+#define     MOTOR_CURRENT_FLG_SET      (1)                           /* For flag set */
 
-#define     MOTOR_CURRENT_TWOPI       (3.14159265358979F * 2.0F)
-#define     MOTOR_CURRENT_60_TWOPI    (60.0F / MOTOR_CURRENT_TWOPI) /* To translate rad/s => rpm */
-#define     MOTOR_CURRENT_SQRT_2      (1.41421356F)                 /* Sqrt(2) */
-#define     MOTOR_CURRENT_SQRT_3      (1.7320508F)                  /* Sqrt(3) */
-#define     MOTOR_CURRENT_DIV_KHZ     (0.001F)
+#define     MOTOR_CURRENT_TWOPI        (3.14159265358979F * 2.0F)
+#define     MOTOR_CURRENT_60_TWOPI     (60.0F / MOTOR_CURRENT_TWOPI) /* To translate rad/s => rpm */
+#define     MOTOR_CURRENT_SQRT_2       (1.41421356F)                 /* Sqrt(2) */
+#define     MOTOR_CURRENT_SQRT_3       (1.7320508F)                  /* Sqrt(3) */
+#define     MOTOR_CURRENT_DIV_KHZ      (0.001F)
+
+#define     MOTOR_CURRENT_MAGNITUDE    (1.0F)
 
 #ifndef MOTOR_CURRENT_ERROR_RETURN
  #define    MOTOR_CURRENT_ERROR_RETURN(a, err)    FSP_ERROR_RETURN((a), (err))
@@ -76,19 +78,12 @@ static void motor_current_voltage_limit(motor_current_instance_ctrl_t * p_ctrl);
 static void motor_current_transform_uvw_dq_abs(const float f_angle, const float * f_uvw, float * f_dq);
 static void motor_current_transform_dq_uvw_abs(const float f_angle, const float * f_dq, float * f_uvw);
 
+static float motor_current_sample_delay_compensation(float f4_angle_rad, float f4_speed_rad, float f4_ctrl_period);
+
 /***********************************************************************************************************************
  * Private global variables
  **********************************************************************************************************************/
 
-/* Version data structure. */
-static const fsp_version_t g_motor_current_version =
-{
-    .api_version_minor  = MOTOR_CURRENT_API_VERSION_MINOR,
-    .api_version_major  = MOTOR_CURRENT_API_VERSION_MAJOR,
-    .code_version_major = MOTOR_CURRENT_CODE_VERSION_MAJOR,
-    .code_version_minor = MOTOR_CURRENT_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global variables
  **********************************************************************************************************************/
@@ -106,7 +101,6 @@ const motor_current_api_t g_motor_current_on_motor_current =
     .currentGet          = RM_MOTOR_CURRENT_CurrentGet,
     .phaseVoltageGet     = RM_MOTOR_CURRENT_PhaseVoltageGet,
     .parameterUpdate     = RM_MOTOR_CURRENT_ParameterUpdate,
-    .versionGet          = RM_MOTOR_CURRENT_VersionGet
 };
 
 /*******************************************************************************************************************//**
@@ -138,17 +132,19 @@ fsp_err_t RM_MOTOR_CURRENT_Open (motor_current_ctrl_t * const p_ctrl, motor_curr
 
     motor_current_extended_cfg_t * p_extended_cfg = (motor_current_extended_cfg_t *) p_cfg->p_extend;
 
+    p_instance_ctrl->p_driver_instance = p_cfg->p_motor_driver_instance;
+    p_instance_ctrl->p_angle_instance  = p_cfg->p_motor_angle_instance;
+
 #if MOTOR_CURRENT_CFG_PARAM_CHECKING_ENABLE
     FSP_ASSERT(NULL != p_extended_cfg);
+    FSP_ASSERT(NULL != p_instance_ctrl->p_driver_instance);
+    FSP_ASSERT(NULL != p_instance_ctrl->p_angle_instance);
     float check_period = 0.0F;
     check_period = p_extended_cfg->f_current_ctrl_period * MOTOR_CURRENT_DIV_KHZ;
 
     MOTOR_CURRENT_ERROR_RETURN(check_period >= 0.0F, FSP_ERR_INVALID_ARGUMENT);
 #endif
 
-    p_instance_ctrl->p_driver_instance = p_cfg->p_motor_driver_instance;
-    p_instance_ctrl->p_angle_instance  = p_cfg->p_motor_angle_instance;
-
     FSP_ERROR_RETURN(MOTOR_CURRENT_OPEN != p_instance_ctrl->open, FSP_ERR_ALREADY_OPEN);
 
     p_instance_ctrl->p_cfg = p_cfg;
@@ -217,13 +213,13 @@ fsp_err_t RM_MOTOR_CURRENT_Close (motor_current_ctrl_t * const p_ctrl)
 
     rm_motor_voltage_error_compensation_init(&(p_instance_ctrl->st_vcomp));
 
-    /* close motor driver access */
+    /* Close motor driver access */
     if (p_instance_ctrl->p_driver_instance != NULL)
     {
         p_instance_ctrl->p_driver_instance->p_api->close(p_instance_ctrl->p_driver_instance->p_ctrl);
     }
 
-    /* close motor angle */
+    /* Close motor angle */
     if (p_instance_ctrl->p_angle_instance != NULL)
     {
         p_instance_ctrl->p_angle_instance->p_api->close(p_instance_ctrl->p_angle_instance->p_ctrl);
@@ -253,7 +249,7 @@ fsp_err_t RM_MOTOR_CURRENT_Reset (motor_current_ctrl_t * const p_ctrl)
 
     p_instance_ctrl->u1_active = MOTOR_CURRENT_FLG_CLR;
 
-    /* reset motor driver access */
+    /* Reset motor driver access */
     if (p_instance_ctrl->p_driver_instance != NULL)
     {
         p_instance_ctrl->p_driver_instance->p_api->reset(p_instance_ctrl->p_driver_instance->p_ctrl);
@@ -263,7 +259,7 @@ fsp_err_t RM_MOTOR_CURRENT_Reset (motor_current_ctrl_t * const p_ctrl)
 
     rm_motor_voltage_error_compensation_reset(&(p_instance_ctrl->st_vcomp));
 
-    /* reset motor angle */
+    /* Reset motor angle */
     if (p_instance_ctrl->p_angle_instance != NULL)
     {
         p_instance_ctrl->p_angle_instance->p_api->reset(p_instance_ctrl->p_angle_instance->p_ctrl);
@@ -420,6 +416,9 @@ fsp_err_t RM_MOTOR_CURRENT_ParameterGet (motor_current_ctrl_t * const   p_ctrl,
     motor_current_extended_cfg_t * p_extended_cfg =
         (motor_current_extended_cfg_t *) p_instance_ctrl->p_cfg->p_extend;
 
+    motor_angle_instance_t const * p_angle = p_instance_ctrl->p_angle_instance;
+    motor_angle_encoder_info_t     temp_info;
+
     p_st_output->f_id        = p_instance_ctrl->f_id_ad;
     p_st_output->f_iq        = p_instance_ctrl->f_iq_ad;
     p_st_output->f_vamax     = p_instance_ctrl->f_va_max;
@@ -427,11 +426,33 @@ fsp_err_t RM_MOTOR_CURRENT_ParameterGet (motor_current_ctrl_t * const   p_ctrl,
     p_st_output->f_speed_rpm = p_instance_ctrl->f_speed_rad / p_extended_cfg->p_motor_parameter->u2_mtr_pp *
                                MOTOR_CURRENT_60_TWOPI;
     p_st_output->f_rotor_angle    = p_instance_ctrl->f_rotor_angle;
+    p_st_output->f_position_rad   = p_instance_ctrl->f_position_rad;
     p_st_output->f_ed             = p_instance_ctrl->f_ed;
     p_st_output->f_eq             = p_instance_ctrl->f_eq;
     p_st_output->f_phase_err_rad  = p_instance_ctrl->f_phase_err;
     p_st_output->u1_flag_get_iref = p_instance_ctrl->u1_flag_crnt_offset;
 
+    if (MOTOR_CURRENT_CONTROL_TYPE_ENCODER == p_extended_cfg->u1_control_type)
+    {
+        p_angle->p_api->infoGet(p_angle->p_ctrl, &temp_info);
+        p_st_output->u1_adjust_status     = (uint8_t) temp_info.e_adjust_status;
+        p_st_output->u1_adjust_count_full = temp_info.u1_adjust_count_full;
+    }
+    else if (MOTOR_CURRENT_CONTROL_TYPE_INDUCTION == p_extended_cfg->u1_control_type)
+    {
+        p_angle->p_api->infoGet(p_angle->p_ctrl, &temp_info);
+        p_st_output->u1_adjust_status     = (uint8_t) temp_info.e_adjust_status;
+        p_st_output->u1_adjust_count_full = temp_info.u1_adjust_count_full;
+
+        p_st_output->u1_openloop_status = (uint8_t) temp_info.e_open_loop_status;
+        p_st_output->f_openloop_speed   = temp_info.f_openloop_speed;
+        p_st_output->f_openloop_id_ref  = temp_info.f_openloop_id_ref;
+    }
+    else
+    {
+        /* Do nothing */
+    }
+
     return err;
 }
 
@@ -455,8 +476,7 @@ fsp_err_t RM_MOTOR_CURRENT_CurrentGet (motor_current_ctrl_t * const p_ctrl, floa
     MOTOR_CURRENT_ERROR_RETURN(p_iq != NULL, FSP_ERR_INVALID_ARGUMENT);
 #endif
 
-    motor_current_transform_uvw_dq_abs(p_instance_ctrl->f_rotor_angle,
-                                       &(p_instance_ctrl->f_iu_ad),
+    motor_current_transform_uvw_dq_abs(p_instance_ctrl->f_rotor_angle, &(p_instance_ctrl->f_iu_ad),
                                        &(p_instance_ctrl->f_id_ad));
 
     *p_id = p_instance_ctrl->f_id_ad;
@@ -489,33 +509,31 @@ fsp_err_t RM_MOTOR_CURRENT_PhaseVoltageGet (motor_current_ctrl_t * const
     motor_current_extended_cfg_t * p_extended_cfg =
         (motor_current_extended_cfg_t *) p_instance_ctrl->p_cfg->p_extend;
 
-    /*====================================*/
-    /*     Feedback control (Current)     */
-    /*====================================*/
+    /* Feedback control (Current) */
     motor_current_pi_calculation(p_instance_ctrl);
 
-    /*============================*/
-    /*     Decoupling control     */
-    /*============================*/
+    /* Decoupling control */
     motor_current_decoupling(p_instance_ctrl, p_instance_ctrl->f_speed_rad, p_extended_cfg->p_motor_parameter);
 
-    /*============================*/
-    /*    Limit voltage vector    */
-    /*============================*/
+    /* Limit voltage vector */
     motor_current_voltage_limit(p_instance_ctrl);
     p_voltage->vd_reference = p_instance_ctrl->f_vd_ref;
     p_voltage->vq_reference = p_instance_ctrl->f_vq_ref;
 
-    /*=================================================*/
-    /*    Coordinate transformation (dq->uvw)          */
-    /*=================================================*/
-    motor_current_transform_dq_uvw_abs(p_instance_ctrl->f_rotor_angle,
-                                       &(p_instance_ctrl->f_vd_ref),
+    // Encoder New Process (Angle Update by sample delay compensation)
+    if (MOTOR_CURRENT_SAMPLE_DELAY_COMPENSATION_ENABLE == p_extended_cfg->u1_sample_delay_comp_enable)
+    {
+        p_instance_ctrl->f_rotor_angle =
+            motor_current_sample_delay_compensation(p_instance_ctrl->f_rotor_angle,
+                                                    p_instance_ctrl->f_speed_rad,
+                                                    p_extended_cfg->f_current_ctrl_period * MOTOR_CURRENT_DIV_KHZ);
+    }
+
+    /* Coordinate transformation (dq->uvw) */
+    motor_current_transform_dq_uvw_abs(p_instance_ctrl->f_rotor_angle, &(p_instance_ctrl->f_vd_ref),
                                        &(p_instance_ctrl->f_refu));
 
-    /*====================================*/
-    /*     Voltage error compensation     */
-    /*====================================*/
+    /* Voltage error compensation */
     motor_current_transform_dq_uvw_abs(p_instance_ctrl->f_rotor_angle, &(p_instance_ctrl->f_id_ref), &(f4_iuvw_ref[0]));
 
     rm_motor_voltage_error_compensation_main(&(p_instance_ctrl->st_vcomp),
@@ -566,25 +584,6 @@ fsp_err_t RM_MOTOR_CURRENT_ParameterUpdate (motor_current_ctrl_t * const      p_
     return err;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Return Motor Speed Control module version. Implements @ref motor_current_api_t::versionGet.
- *
- * @retval      FSP_SUCCESS             Version information successfully read.
- * @retval      FSP_ERR_ASSERTION       Null pointer passed as a parameter
- **********************************************************************************************************************/
-fsp_err_t RM_MOTOR_CURRENT_VersionGet (fsp_version_t * const p_version)
-{
-#if MOTOR_CURRENT_CFG_PARAM_CHECKING_ENABLE
-
-    /* Verify parameters are valid */
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_motor_current_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup MOTOR_CURRENT)
  **********************************************************************************************************************/
@@ -593,6 +592,68 @@ fsp_err_t RM_MOTOR_CURRENT_VersionGet (fsp_version_t * const p_version)
  * Private Functions
  **********************************************************************************************************************/
 
+/***********************************************************************************************************************
+ * Function Name : rm_motor_current_encoder_cyclic
+ * Description   : Wrapper Cyclic Process of Encoder Control by Current Control
+ * Arguments     : p_ctrl - The pointer to current control
+ * Return Value  : None
+ **********************************************************************************************************************/
+void rm_motor_current_encoder_cyclic (motor_current_instance_t const * p_ctrl)
+{
+    motor_current_instance_ctrl_t * p_instance_ctrl  = (motor_current_instance_ctrl_t *) p_ctrl->p_ctrl;
+    motor_angle_instance_t const  * p_angle_instance = p_instance_ctrl->p_angle_instance;
+
+    p_angle_instance->p_api->cyclicProcess(p_angle_instance->p_ctrl);
+}
+
+/***********************************************************************************************************************
+ * Function Name : rm_motor_current_encoder_angle_adjust
+ * Description   : Wrapper Angle Adjustment Process of Encoder Control by Current Control
+ * Arguments     : p_ctrl - The pointer to current control
+ * Return Value  : None
+ **********************************************************************************************************************/
+void rm_motor_current_encoder_angle_adjust (motor_current_instance_t const * p_ctrl)
+{
+    motor_current_instance_ctrl_t * p_instance_ctrl  = (motor_current_instance_ctrl_t *) p_ctrl->p_ctrl;
+    motor_angle_instance_t const  * p_angle_instance = p_instance_ctrl->p_angle_instance;
+
+    if (MOTOR_CURRENT_FLG_SET == p_instance_ctrl->u1_active)
+    {
+        p_angle_instance->p_api->angleAdjust(p_angle_instance->p_ctrl);
+    }
+}
+
+/***********************************************************************************************************************
+ * Function Name : rm_motor_current_induction_cyclic
+ * Description   : Wrapper Cyclic Process of Induction sensor Control by Current Control
+ * Arguments     : p_ctrl - The pointer to current control
+ * Return Value  : None
+ **********************************************************************************************************************/
+void rm_motor_current_induction_cyclic (motor_current_instance_t const * p_ctrl)
+{
+    motor_current_instance_ctrl_t * p_instance_ctrl  = (motor_current_instance_ctrl_t *) p_ctrl->p_ctrl;
+    motor_angle_instance_t const  * p_angle_instance = p_instance_ctrl->p_angle_instance;
+
+    p_angle_instance->p_api->cyclicProcess(p_angle_instance->p_ctrl);
+}
+
+/***********************************************************************************************************************
+ * Function Name : rm_motor_current_induction_angle_adjust
+ * Description   : Wrapper Angle Adjustment Process of Induction sensor Control by Current Control
+ * Arguments     : p_ctrl - The pointer to current control
+ * Return Value  : None
+ **********************************************************************************************************************/
+void rm_motor_current_induction_angle_adjust (motor_current_instance_t const * p_ctrl)
+{
+    motor_current_instance_ctrl_t * p_instance_ctrl  = (motor_current_instance_ctrl_t *) p_ctrl->p_ctrl;
+    motor_angle_instance_t const  * p_angle_instance = p_instance_ctrl->p_angle_instance;
+
+    if (MOTOR_CURRENT_FLG_SET == p_instance_ctrl->u1_active)
+    {
+        p_angle_instance->p_api->angleAdjust(p_angle_instance->p_ctrl);
+    }
+}
+
 /***********************************************************************************************************************
  * Function Name : rm_motor_current_cyclic
  * Description   : Cyclic Process of Current Control (Performed at ADC Finish Interrupt)
@@ -608,8 +669,12 @@ void rm_motor_current_cyclic (motor_driver_callback_args_t * p_args)
     float f_ref[3] = {0.0F};
     motor_driver_current_get_t temp_drv_crnt_get;
 
-    motor_current_instance_t      * p_instance        = (motor_current_instance_t *) p_args->p_context;
-    motor_current_instance_ctrl_t * p_instance_ctrl   = (motor_current_instance_ctrl_t *) p_instance->p_ctrl;
+    motor_current_instance_t      * p_instance      = (motor_current_instance_t *) p_args->p_context;
+    motor_current_instance_ctrl_t * p_instance_ctrl = (motor_current_instance_ctrl_t *) p_instance->p_ctrl;
+
+    motor_current_extended_cfg_t * p_extended_cfg =
+        (motor_current_extended_cfg_t *) p_instance_ctrl->p_cfg->p_extend;
+
     motor_driver_instance_t const * p_driver_instance = p_instance_ctrl->p_driver_instance;
 
     motor_current_callback_args_t temp_args_t;
@@ -636,18 +701,25 @@ void rm_motor_current_cyclic (motor_driver_callback_args_t * p_args)
         /* Current Control Timing */
         case MOTOR_DRIVER_EVENT_CURRENT:
         {
-            /* Get A/D coverted data */
+            /* Get A/D converted data */
             p_driver_instance->p_api->currentGet(p_driver_instance->p_ctrl, &temp_drv_crnt_get);
             f_iu_ad  = temp_drv_crnt_get.iu;
             f_iw_ad  = temp_drv_crnt_get.iw;
             f_vdc_ad = temp_drv_crnt_get.vdc;
-            p_instance_ctrl->f_va_max = temp_drv_crnt_get.va_max;
+            p_instance_ctrl->f_va_max      = temp_drv_crnt_get.va_max;
+            p_instance_ctrl->f_sin_ad_data = temp_drv_crnt_get.sin_ad;
+            p_instance_ctrl->f_cos_ad_data = temp_drv_crnt_get.cos_ad;
 
-            f_iv_ad = -(f_iu_ad + f_iw_ad);
+            if (MOTOR_CURRENT_SHUNT_TYPE_2_SHUNT == p_extended_cfg->shunt)
+            {
+                f_iv_ad = -(f_iu_ad + f_iw_ad);
+            }
+            else
+            {
+                f_iv_ad = temp_drv_crnt_get.iv;
+            }
 
-            /**********************************/
-            /*     Active Current Control     */
-            /**********************************/
+            /* Active Current Control */
             if (MOTOR_CURRENT_FLG_SET == p_instance_ctrl->u1_active)
             {
                 /* Measure current offset values */
@@ -665,9 +737,7 @@ void rm_motor_current_cyclic (motor_driver_callback_args_t * p_args)
                         (p_instance->p_cfg->p_callback)(&temp_args_t);
                     }
 
-                    /*=============================================*/
-                    /*       Coordinate transformation (UVW->dq)   */
-                    /*=============================================*/
+                    /* Coordinate transformation (UVW->dq) */
                     temp_input_current.iu     = f_iu_ad;
                     temp_input_current.iv     = f_iv_ad;
                     temp_input_current.iw     = f_iw_ad;
@@ -676,22 +746,13 @@ void rm_motor_current_cyclic (motor_driver_callback_args_t * p_args)
 
                     p_instance->p_api->currentSet(p_instance_ctrl, &temp_input_current, &temp_input_voltage);
 
-                    p_instance->p_api->currentGet(p_instance_ctrl,
-                                                  &(p_instance_ctrl->f_id_ad),
+                    p_instance->p_api->currentGet(p_instance_ctrl, &(p_instance_ctrl->f_id_ad),
                                                   &(p_instance_ctrl->f_iq_ad));
 
-                    /*==============================*/
-                    /*     Angle & speed process    */
-                    /*==============================*/
+                    /* Angle & speed process */
                     motor_current_angle_cyclic(p_instance);
 
-                    p_instance->p_api->speedPhaseSet(p_instance_ctrl,
-                                                     p_instance_ctrl->f_speed_rad,
-                                                     p_instance_ctrl->f_rotor_angle);
-
-                    /*=========================*/
-                    /*     Current control     */
-                    /*=========================*/
+                    /* Current control */
                     p_instance->p_api->currentReferenceSet(p_instance_ctrl,
                                                            p_instance_ctrl->st_input.f_id_ref,
                                                            p_instance_ctrl->st_input.f_iq_ref);
@@ -702,9 +763,7 @@ void rm_motor_current_cyclic (motor_driver_callback_args_t * p_args)
                     f_ref[1] = temp_get_voltage.v_voltage;
                     f_ref[2] = temp_get_voltage.w_voltage;
 
-                    /*===============================*/
-                    /*    Space vector modulation    */
-                    /*===============================*/
+                    /* Space vector modulation */
                     p_driver_instance->p_api->phaseVoltageSet(p_driver_instance->p_ctrl, f_ref[0], f_ref[1], f_ref[2]);
                 }
             }
@@ -742,25 +801,65 @@ static void motor_current_angle_cyclic (motor_current_instance_t * p_instance)
 {
     motor_current_instance_ctrl_t * p_ctrl = (motor_current_instance_ctrl_t *) p_instance->p_ctrl;
 
-    motor_angle_instance_t const  * p_angle = p_ctrl->p_angle_instance;
-    motor_angle_current_t           temp_current;
-    motor_angle_voltage_reference_t temp_vol_ref;
+    motor_current_extended_cfg_t * p_extended_cfg =
+        (motor_current_extended_cfg_t *) p_ctrl->p_cfg->p_extend;
 
-    temp_current.id = p_ctrl->f_id_ad;
-    temp_current.iq = p_ctrl->f_iq_ad;
-    temp_vol_ref.vd = p_ctrl->f_vd_ref;
-    temp_vol_ref.vq = p_ctrl->f_vq_ref;
+    motor_angle_instance_t const * p_angle = p_ctrl->p_angle_instance;
 
-    p_angle->p_api->flagPiCtrlSet(p_angle->p_ctrl, p_ctrl->st_input.u1_flag_pi);
-    p_angle->p_api->speedSet(p_angle->p_ctrl,
-                             p_ctrl->st_input.f_ref_speed_rad_ctrl,
-                             p_ctrl->st_input.f_damp_comp_speed);
-    p_angle->p_api->currentSet(p_angle->p_ctrl, &temp_current, &temp_vol_ref);
-    p_angle->p_api->angleSpeedGet(p_angle->p_ctrl,
-                                  &(p_ctrl->f_rotor_angle),
-                                  &(p_ctrl->f_speed_rad),
-                                  &(p_ctrl->f_phase_err));
-    p_angle->p_api->estimatedComponentGet(p_angle->p_ctrl, &(p_ctrl->f_ed), &(p_ctrl->f_eq));
+    if (MOTOR_CURRENT_CONTROL_TYPE_SENSORLESS == p_extended_cfg->u1_control_type)
+    {
+        motor_angle_current_t           temp_current;
+        motor_angle_voltage_reference_t temp_vol_ref;
+
+        temp_current.id = p_ctrl->f_id_ad;
+        temp_current.iq = p_ctrl->f_iq_ad;
+        temp_vol_ref.vd = p_ctrl->f_vd_ref;
+        temp_vol_ref.vq = p_ctrl->f_vq_ref;
+
+        p_angle->p_api->flagPiCtrlSet(p_angle->p_ctrl, p_ctrl->st_input.u1_flag_pi);
+        p_angle->p_api->speedSet(p_angle->p_ctrl,
+                                 p_ctrl->st_input.f_ref_speed_rad_ctrl,
+                                 p_ctrl->st_input.f_damp_comp_speed);
+        p_angle->p_api->currentSet(p_angle->p_ctrl, &temp_current, &temp_vol_ref);
+        p_angle->p_api->angleSpeedGet(p_angle->p_ctrl, &(p_ctrl->f_rotor_angle), &(p_ctrl->f_speed_rad),
+                                      &(p_ctrl->f_phase_err));
+        p_angle->p_api->estimatedComponentGet(p_angle->p_ctrl, &(p_ctrl->f_ed), &(p_ctrl->f_eq));
+    }
+    else if (MOTOR_CURRENT_CONTROL_TYPE_ENCODER == p_extended_cfg->u1_control_type)
+    {
+        /* Position & speed calculation */
+        p_angle->p_api->internalCalculate(p_angle->p_ctrl);
+
+        /* Speed & angle detection */
+        p_angle->p_api->angleSpeedGet(p_angle->p_ctrl, &(p_ctrl->f_rotor_angle), &(p_ctrl->f_speed_rad),
+                                      &(p_ctrl->f_position_rad));
+    }
+    else if (MOTOR_CURRENT_CONTROL_TYPE_HALL == p_extended_cfg->u1_control_type)
+    {
+        /* Speed & angle detection */
+        p_angle->p_api->angleSpeedGet(p_angle->p_ctrl, &(p_ctrl->f_rotor_angle), &(p_ctrl->f_speed_rad),
+                                      &(p_ctrl->f_phase_err));
+    }
+    else if (MOTOR_CURRENT_CONTROL_TYPE_INDUCTION == p_extended_cfg->u1_control_type)
+    {
+        motor_angle_ad_data_t temp_ad_data;
+        temp_ad_data.sin_ad_data = p_ctrl->f_sin_ad_data;
+        temp_ad_data.cos_ad_data = p_ctrl->f_cos_ad_data;
+
+        /* Set induction sensor output */
+        p_angle->p_api->sensorDataSet(p_angle->p_ctrl, &temp_ad_data);
+
+        /* Position & speed calculation */
+        p_angle->p_api->internalCalculate(p_angle->p_ctrl);
+
+        /* Speed & angle detection */
+        p_angle->p_api->angleSpeedGet(p_angle->p_ctrl, &(p_ctrl->f_rotor_angle), &(p_ctrl->f_speed_rad),
+                                      &(p_ctrl->f_position_rad));
+    }
+    else
+    {
+        /* Do nothing */
+    }
 }                                      /* End of function motor_current_angle_cyclic */
 
 /***********************************************************************************************************************
@@ -802,7 +901,7 @@ static void motor_current_reset (motor_current_instance_ctrl_t * p_ctrl)
  **********************************************************************************************************************/
 static float motor_current_limit_abs (float f4_value, float f4_limit_value)
 {
-    float f4_temp0;
+    float f4_temp0 = 0.0F;
 
     f4_temp0 = fabsf(f4_value);
     if (f4_temp0 > f4_limit_value)
@@ -856,7 +955,7 @@ static float motor_current_pi_control (motor_current_pi_params_t * pi_ctrl)
     f4_refp  = f4_err * f4_kp;         /* Proportional part */
     f4_refi += (f4_err * f4_ki);       /* Integral part */
 
-    /*** Integral part limit ***/
+    /* Integral part limit */
     f4_refi         = motor_current_limit_abs(f4_refi, f4_ilimit);
     pi_ctrl->f_refi = f4_refi;
 
@@ -877,7 +976,7 @@ static void motor_current_decoupling (motor_current_instance_ctrl_t         * p_
                                       float                                   f_speed_rad,
                                       const motor_current_motor_parameter_t * p_mtr)
 {
-    float f4_temp0;
+    float f4_temp0 = 0.0F;
 
     f4_temp0          = p_mtr->f4_mtr_lq * p_ctrl->f_iq_ad; /* Lq * Iq */
     f4_temp0          = f_speed_rad * f4_temp0;             /* Speed * Lq * Iq */
@@ -897,9 +996,9 @@ static void motor_current_decoupling (motor_current_instance_ctrl_t         * p_
  **********************************************************************************************************************/
 static void motor_current_voltage_limit (motor_current_instance_ctrl_t * p_ctrl)
 {
-    float f4_vq_lim;
-    float f4_vd_ref;
-    float f4_va_max;
+    float f4_vq_lim = 0.0F;
+    float f4_vd_ref = 0.0F;
+    float f4_va_max = 0.0F;
 
     f4_vd_ref = p_ctrl->f_vd_ref;
     f4_va_max = p_ctrl->f_va_max;
@@ -933,10 +1032,10 @@ static void motor_current_voltage_limit (motor_current_instance_ctrl_t * p_ctrl)
  **********************************************************************************************************************/
 static void motor_current_transform_uvw_dq_abs (const float f_angle, const float * f_uvw, float * f_dq)
 {
-    float f4_temp0;
-    float f4_temp1;
-    float f4_temp2;
-    float f4_temp3;
+    float f4_temp0   = 0.0F;
+    float f4_temp1   = 0.0F;
+    float f4_temp2   = 0.0F;
+    float f4_temp3   = 0.0F;
     float f4_u       = f_uvw[0];
     float f4_v_sub_w = f_uvw[1] - f_uvw[2];
     float f4_cos     = cosf(f_angle);
@@ -960,14 +1059,14 @@ static void motor_current_transform_uvw_dq_abs (const float f_angle, const float
  **********************************************************************************************************************/
 static void motor_current_transform_dq_uvw_abs (const float f_angle, const float * f_dq, float * f_uvw)
 {
-    float f4_cos_div_sqrt3;
-    float f4_sin_div_sqrt3;
-    float f4_output_d;
-    float f4_output_q;
-    float f4_input_d = f_dq[0];
-    float f4_input_q = f_dq[1];
-    float f4_cos     = cosf(f_angle);
-    float f4_sin     = sinf(f_angle);
+    float f4_cos_div_sqrt3 = 0.0F;
+    float f4_sin_div_sqrt3 = 0.0F;
+    float f4_output_d      = 0.0F;
+    float f4_output_q      = 0.0F;
+    float f4_input_d       = f_dq[0];
+    float f4_input_q       = f_dq[1];
+    float f4_cos           = cosf(f_angle);
+    float f4_sin           = sinf(f_angle);
 
     f4_cos_div_sqrt3 = f4_cos * (1.0F / MOTOR_CURRENT_SQRT_3);
     f4_sin_div_sqrt3 = f4_sin * (1.0F / MOTOR_CURRENT_SQRT_3);
@@ -982,3 +1081,35 @@ static void motor_current_transform_dq_uvw_abs (const float f_angle, const float
     f4_output_q = (f4_sin_div_sqrt3 - f4_cos) * f4_input_q;
     f_uvw[2]    = (f4_output_d + f4_output_q) * (1.0F / MOTOR_CURRENT_SQRT_2);
 }                                      /* End of function motor_current_transform_dq_uvw_abs */
+
+/***********************************************************************************************************************
+ * Function Name: motor_current_sample_delay_compensation
+ * Description  : current control sampling delay compensation
+ * Arguments    : f4_angle_rad   - motor angle (electrical) [rad]
+ *              : f4_speed_rad   - motor speed (electrical) [rad/s]
+ *              : f4_ctrl_period - motor current control period
+ * Return Value : motor angle (electrical) [rad/s]
+ **********************************************************************************************************************/
+static float motor_current_sample_delay_compensation (float f4_angle_rad, float f4_speed_rad, float f4_ctrl_period)
+{
+    float f4_comp_angle_rad = 0.0F;
+
+    f4_comp_angle_rad = f4_speed_rad * f4_ctrl_period * MOTOR_CURRENT_MAGNITUDE;
+    f4_comp_angle_rad = f4_angle_rad + f4_comp_angle_rad;
+
+    /* Limit angle value of one rotation */
+    if (f4_comp_angle_rad >= MOTOR_CURRENT_TWOPI)
+    {
+        f4_comp_angle_rad -= MOTOR_CURRENT_TWOPI;
+    }
+    else if (f4_comp_angle_rad < 0.0F)
+    {
+        f4_comp_angle_rad += MOTOR_CURRENT_TWOPI;
+    }
+    else
+    {
+        /* Do nothing */
+    }
+
+    return f4_comp_angle_rad;
+}                                      /* End of function motor_current_sample_delay_compensation */
