@@ -43,12 +43,8 @@
 
 #ifndef MBEDTLS_CTR_DRBG_ALT_H
  #define MBEDTLS_CTR_DRBG_ALT_H
-
- #if !defined(MBEDTLS_CONFIG_FILE)
-  #include "mbedtls/config.h"
- #else
-  #include MBEDTLS_CONFIG_FILE
- #endif
+#if defined(MBEDTLS_CTR_DRBG_C_ALT)
+ #include "common.h"
 
  #include "aes_alt.h"
 
@@ -571,5 +567,5 @@ void sw_aes_256_enc_test(void);
  #ifdef __cplusplus
 }
  #endif
-
-#endif                                 /* ctr_drbg.h */
+#endif /* defined(MBEDTLS_CTR_DRBG_C_ALT */
+#endif /* MBEDTLS_CTR_DRBG_ALT_H*/
