@@ -524,13 +524,13 @@ class BMI270:
         # Sanity checks
         if not self._use_i2c:
             raise ValueError("SPI mode is not supported")
-        if not gyro_odr in ODR:
+        if gyro_odr not in ODR:
             raise ValueError("Invalid gyro sampling rate: %d" % gyro_odr)
-        if not gyro_scale in GYRO_SCALE:
+        if gyro_scale not in GYRO_SCALE:
             raise ValueError("Invalid gyro scaling: %d" % gyro_scale)
-        if not accel_odr in ODR:
+        if accel_odr not in ODR:
             raise ValueError("Invalid accelerometer sampling rate: %d" % accel_odr)
-        if not accel_scale in ACCEL_SCALE:
+        if accel_scale not in ACCEL_SCALE:
             raise ValueError("Invalid accelerometer scaling: %d" % accel_scale)
         if self._read_reg(_CHIP_ID) != 0x24:
             raise OSError("No BMI270 device was found at address 0x%x" % (self.address))
@@ -598,7 +598,7 @@ class BMI270:
     def _write_burst(self, reg, data, chunk=16):
         self._write_reg(_INIT_ADDR_0, 0)
         self._write_reg(_INIT_ADDR_1, 0)
-        for i in range(0, len(data) // chunk):
+        for i in range(len(data) // chunk):
             offs = i * chunk
             self._write_reg(reg, data[offs : offs + chunk])
             init_addr = ((i + 1) * chunk) // 2
@@ -606,7 +606,7 @@ class BMI270:
             self._write_reg(_INIT_ADDR_1, (init_addr >> 4) & 0xFF)
 
     def _poll_reg(self, reg, mask, retry=10, delay=100):
-        for i in range(0, retry):
+        for i in range(retry):
             if self._read_reg(reg) & mask:
                 return True
             time.sleep_ms(delay)
