@@ -28,7 +28,7 @@ static inline bool bt_mesh_lpn_established(void)
 #endif
 }
 
-static inline bool bt_mesh_lpn_match(u16_t addr)
+static inline bool bt_mesh_lpn_match(uint16_t addr)
 {
 #if (MYNEWT_VAL(BLE_MESH_LOW_POWER))
 	if (bt_mesh_lpn_established()) {
@@ -58,8 +58,8 @@ static inline bool bt_mesh_lpn_timer(void)
 
 void bt_mesh_lpn_msg_received(struct bt_mesh_net_rx *rx);
 
-void bt_mesh_lpn_group_add(u16_t group);
-void bt_mesh_lpn_group_del(u16_t *groups, size_t group_count);
+void bt_mesh_lpn_group_add(uint16_t group);
+void bt_mesh_lpn_group_del(uint16_t *groups, size_t group_count);
 
 void bt_mesh_lpn_disable(bool force);
 
