@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 - 2019 NXP
+ * Copyright 2017 - 2021 NXP
  * All rights reserved.
  *
  * SPDX-License-Identifier: BSD-3-Clause
@@ -18,7 +18,7 @@ achieve better performance, it is depend on the IDE Floating point settings, if
 in IDE, clock_64b_t will switch to double type automatically. only support IAR and MDK here */
 #if __FPU_USED
 
-#if ((defined(__ICCARM__)) || (defined(__GNUC__)))
+#if (defined(__ICCARM__))
 
 #if (__ARMVFP__ >= __ARMFPV5__) && \
     (__ARM_FP == 0xE) /*0xe implies support for half, single and double precision operations*/
@@ -27,6 +27,14 @@ typedef double clock_64b_t;
 typedef uint64_t clock_64b_t;
 #endif
 
+#elif (defined(__GNUC__))
+
+#if (__ARM_FP == 0xE) /*0xe implies support for half, single and double precision operations*/
+typedef double clock_64b_t;
+#else
+typedef uint64_t clock_64b_t;
+#endif
+
 #elif defined(__CC_ARM) || defined(__ARMCC_VERSION)
 
 #if defined __TARGET_FPU_FPV5_D16
@@ -63,6 +71,13 @@ volatile uint32_t g_rtcXtalFreq;
  */
 static uint32_t CLOCK_GetPeriphClkFreq(void);
 
+/*!
+ * @brief Get the frequency of PLL USB1 software clock.
+ *
+ * @return The frequency of PLL USB1 software clock.
+ */
+static uint32_t CLOCK_GetPllUsb1SWFreq(void);
+
 /*******************************************************************************
  * Code
  ******************************************************************************/
@@ -72,7 +87,7 @@ static uint32_t CLOCK_GetPeriphClkFreq(void)
     uint32_t freq;
 
     /* Periph_clk2_clk ---> Periph_clk */
-    if (CCM->CBCDR & CCM_CBCDR_PERIPH_CLK_SEL_MASK)
+    if ((CCM->CBCDR & CCM_CBCDR_PERIPH_CLK_SEL_MASK) != 0U)
     {
         switch (CCM->CBCMR & CCM_CBCMR_PERIPH_CLK2_SEL_MASK)
         {
@@ -133,6 +148,30 @@ static uint32_t CLOCK_GetPeriphClkFreq(void)
     return freq;
 }
 
+static uint32_t CLOCK_GetPllUsb1SWFreq(void)
+{
+    uint32_t freq;
+
+    switch ((CCM->CCSR & CCM_CCSR_PLL3_SW_CLK_SEL_MASK) >> CCM_CCSR_PLL3_SW_CLK_SEL_SHIFT)
+    {
+        case 0:
+        {
+            freq = CLOCK_GetPllFreq(kCLOCK_PllUsb1);
+            break;
+        }
+        case 1:
+        {
+            freq = 24000000UL;
+            break;
+        }
+        default:
+            freq = 0UL;
+            break;
+    }
+
+    return freq;
+}
+
 /*!
  * brief Initialize the external 24MHz clock.
  *
@@ -153,11 +192,11 @@ void CLOCK_InitExternalClk(bool bypassXtalOsc)
     assert(!bypassXtalOsc);
 
     CCM_ANALOG->MISC0_CLR = CCM_ANALOG_MISC0_XTAL_24M_PWD_MASK; /* Power up */
-    while ((XTALOSC24M->LOWPWR_CTRL & XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT_MASK) == 0)
+    while ((XTALOSC24M->LOWPWR_CTRL & XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT_MASK) == 0U)
     {
     }
     CCM_ANALOG->MISC0_SET = CCM_ANALOG_MISC0_OSC_XTALOK_EN_MASK; /* detect freq */
-    while ((CCM_ANALOG->MISC0 & CCM_ANALOG_MISC0_OSC_XTALOK_MASK) == 0)
+    while ((CCM_ANALOG->MISC0 & CCM_ANALOG_MISC0_OSC_XTALOK_MASK) == 0UL)
     {
     }
     CCM_ANALOG->MISC0_CLR = CCM_ANALOG_MISC0_OSC_XTALOK_EN_MASK;
@@ -186,9 +225,13 @@ void CLOCK_DeinitExternalClk(void)
 void CLOCK_SwitchOsc(clock_osc_t osc)
 {
     if (osc == kCLOCK_RcOsc)
+    {
         XTALOSC24M->LOWPWR_CTRL_SET = XTALOSC24M_LOWPWR_CTRL_SET_OSC_SEL_MASK;
+    }
     else
+    {
         XTALOSC24M->LOWPWR_CTRL_CLR = XTALOSC24M_LOWPWR_CTRL_CLR_OSC_SEL_MASK;
+    }
 }
 
 /*!
@@ -227,10 +270,10 @@ uint32_t CLOCK_GetSemcFreq(void)
     uint32_t freq;
 
     /* SEMC alternative clock ---> SEMC Clock */
-    if (CCM->CBCDR & CCM_CBCDR_SEMC_CLK_SEL_MASK)
+    if ((CCM->CBCDR & CCM_CBCDR_SEMC_CLK_SEL_MASK) != 0U)
     {
         /* PLL3 PFD1 ---> SEMC alternative clock ---> SEMC Clock */
-        if (CCM->CBCDR & CCM_CBCDR_SEMC_ALT_CLK_SEL_MASK)
+        if ((CCM->CBCDR & CCM_CBCDR_SEMC_ALT_CLK_SEL_MASK) != 0U)
         {
             freq = CLOCK_GetUsb1PfdFreq(kCLOCK_Pfd1);
         }
@@ -271,14 +314,14 @@ uint32_t CLOCK_GetPerClkFreq(void)
     uint32_t freq;
 
     /* Osc_clk ---> PER Clock*/
-    if (CCM->CSCMR1 & CCM_CSCMR1_PERCLK_CLK_SEL_MASK)
+    if ((CCM->CSCMR1 & CCM_CSCMR1_PERCLK_CLK_SEL_MASK) != 0U)
     {
         freq = CLOCK_GetOscFreq();
     }
     /* Periph_clk ---> AHB Clock ---> IPG Clock ---> PER Clock */
     else
     {
-        freq = CLOCK_GetFreq(kCLOCK_IpgClk);
+        freq = CLOCK_GetIpgFreq();
     }
 
     freq /= (((CCM->CSCMR1 & CCM_CSCMR1_PERCLK_PODF_MASK) >> CCM_CSCMR1_PERCLK_PODF_SHIFT) + 1U);
@@ -342,6 +385,18 @@ uint32_t CLOCK_GetFreq(clock_name_t name)
         case kCLOCK_Usb1PllPfd3Clk:
             freq = CLOCK_GetUsb1PfdFreq(kCLOCK_Pfd3);
             break;
+        case kCLOCK_Usb1SwClk:
+            freq = CLOCK_GetPllUsb1SWFreq();
+            break;
+        case kCLOCK_Usb1Sw120MClk:
+            freq = CLOCK_GetPllUsb1SWFreq() / 4UL;
+            break;
+        case kCLOCK_Usb1Sw60MClk:
+            freq = CLOCK_GetPllUsb1SWFreq() / 8UL;
+            break;
+        case kCLOCK_Usb1Sw80MClk:
+            freq = CLOCK_GetPllUsb1SWFreq() / 6UL;
+            break;
         case kCLOCK_Usb2PllClk:
             freq = CLOCK_GetPllFreq(kCLOCK_PllUsb2);
             break;
@@ -380,6 +435,45 @@ uint32_t CLOCK_GetFreq(clock_name_t name)
     return freq;
 }
 
+/*!
+ * brief Gets the frequency of selected clock root.
+ *
+ * param clockRoot The clock root used to get the frequency, please refer to @ref clock_root_t.
+ * return The frequency of selected clock root.
+ */
+uint32_t CLOCK_GetClockRootFreq(clock_root_t clockRoot)
+{
+    static const clock_name_t clockRootSourceArray[][6]  = CLOCK_ROOT_SOUCE;
+    static const clock_mux_t clockRootMuxTupleArray[]    = CLOCK_ROOT_MUX_TUPLE;
+    static const clock_div_t clockRootDivTupleArray[][2] = CLOCK_ROOT_DIV_TUPLE;
+    uint32_t freq                                        = 0UL;
+    clock_mux_t clockRootMuxTuple                        = clockRootMuxTupleArray[(uint8_t)clockRoot];
+    clock_div_t clockRootPreDivTuple                     = clockRootDivTupleArray[(uint8_t)clockRoot][0];
+    clock_div_t clockRootPostDivTuple                    = clockRootDivTupleArray[(uint8_t)clockRoot][1];
+    uint32_t clockRootMuxValue = (CCM_TUPLE_REG(CCM, clockRootMuxTuple) & CCM_TUPLE_MASK(clockRootMuxTuple)) >>
+                                 CCM_TUPLE_SHIFT(clockRootMuxTuple);
+    clock_name_t clockSourceName;
+
+    clockSourceName = clockRootSourceArray[(uint8_t)clockRoot][clockRootMuxValue];
+
+    assert(clockSourceName != kCLOCK_NoneName);
+
+    freq = CLOCK_GetFreq(clockSourceName);
+
+    if (clockRootPreDivTuple != kCLOCK_NonePreDiv)
+    {
+        freq /= ((CCM_TUPLE_REG(CCM, clockRootPreDivTuple) & CCM_TUPLE_MASK(clockRootPreDivTuple)) >>
+                 CCM_TUPLE_SHIFT(clockRootPreDivTuple)) +
+                1UL;
+    }
+
+    freq /= ((CCM_TUPLE_REG(CCM, clockRootPostDivTuple) & CCM_TUPLE_MASK(clockRootPostDivTuple)) >>
+             CCM_TUPLE_SHIFT(clockRootPostDivTuple)) +
+            1UL;
+
+    return freq;
+}
+
 /*! brief Enable USB HS clock.
  *
  * This function only enables the access to USB HS prepheral, upper layer
@@ -393,10 +487,12 @@ uint32_t CLOCK_GetFreq(clock_name_t name)
  */
 bool CLOCK_EnableUsbhs0Clock(clock_usb_src_t src, uint32_t freq)
 {
+    uint32_t i;
     CCM->CCGR6 |= CCM_CCGR6_CG0_MASK;
     USB1->USBCMD |= USBHS_USBCMD_RST_MASK;
-    for (volatile uint32_t i = 0; i < 400000;
-         i++) /* Add a delay between RST and RS so make sure there is a DP pullup sequence*/
+
+    /* Add a delay between RST and RS so make sure there is a DP pullup sequence*/
+    for (i = 0; i < 400000U; i++)
     {
         __ASM("nop");
     }
@@ -418,10 +514,12 @@ bool CLOCK_EnableUsbhs0Clock(clock_usb_src_t src, uint32_t freq)
  */
 bool CLOCK_EnableUsbhs1Clock(clock_usb_src_t src, uint32_t freq)
 {
+    uint32_t i = 0;
     CCM->CCGR6 |= CCM_CCGR6_CG0_MASK;
     USB2->USBCMD |= USBHS_USBCMD_RST_MASK;
-    for (volatile uint32_t i = 0; i < 400000;
-         i++) /* Add a delay between RST and RS so make sure there is a DP pullup sequence*/
+
+    /* Add a delay between RST and RS so make sure there is a DP pullup sequence*/
+    for (i = 0; i < 400000U; i++)
     {
         __ASM("nop");
     }
@@ -441,8 +539,8 @@ bool CLOCK_EnableUsbhs1Clock(clock_usb_src_t src, uint32_t freq)
  */
 bool CLOCK_EnableUsbhs0PhyPllClock(clock_usb_phy_src_t src, uint32_t freq)
 {
-    const clock_usb_pll_config_t g_ccmConfigUsbPll = {.loopDivider = 0U};
-    if (CCM_ANALOG->PLL_USB1 & CCM_ANALOG_PLL_USB1_ENABLE_MASK)
+    static const clock_usb_pll_config_t g_ccmConfigUsbPll = {.loopDivider = 0U};
+    if ((CCM_ANALOG->PLL_USB1 & CCM_ANALOG_PLL_USB1_ENABLE_MASK) != 0U)
     {
         CCM_ANALOG->PLL_USB1 |= CCM_ANALOG_PLL_USB1_EN_USB_CLKS_MASK;
     }
@@ -486,7 +584,7 @@ void CLOCK_InitArmPll(const clock_arm_pll_config_t *config)
         (CCM_ANALOG->PLL_ARM & (~(CCM_ANALOG_PLL_ARM_DIV_SELECT_MASK | CCM_ANALOG_PLL_ARM_POWERDOWN_MASK))) |
         CCM_ANALOG_PLL_ARM_ENABLE_MASK | CCM_ANALOG_PLL_ARM_DIV_SELECT(config->loopDivider);
 
-    while ((CCM_ANALOG->PLL_ARM & CCM_ANALOG_PLL_ARM_LOCK_MASK) == 0)
+    while ((CCM_ANALOG->PLL_ARM & CCM_ANALOG_PLL_ARM_LOCK_MASK) == 0UL)
     {
     }
 
@@ -528,7 +626,7 @@ void CLOCK_InitSysPll(const clock_sys_pll_config_t *config)
                              CCM_ANALOG_PLL_SYS_SS_ENABLE(config->ss_enable) |
                              CCM_ANALOG_PLL_SYS_SS_STOP(config->ss_stop);
 
-    while ((CCM_ANALOG->PLL_SYS & CCM_ANALOG_PLL_SYS_LOCK_MASK) == 0)
+    while ((CCM_ANALOG->PLL_SYS & CCM_ANALOG_PLL_SYS_LOCK_MASK) == 0UL)
     {
     }
 
@@ -561,7 +659,7 @@ void CLOCK_InitUsb1Pll(const clock_usb_pll_config_t *config)
                            CCM_ANALOG_PLL_USB1_ENABLE_MASK | CCM_ANALOG_PLL_USB1_POWER_MASK |
                            CCM_ANALOG_PLL_USB1_EN_USB_CLKS_MASK | CCM_ANALOG_PLL_USB1_DIV_SELECT(config->loopDivider);
 
-    while ((CCM_ANALOG->PLL_USB1 & CCM_ANALOG_PLL_USB1_LOCK_MASK) == 0)
+    while ((CCM_ANALOG->PLL_USB1 & CCM_ANALOG_PLL_USB1_LOCK_MASK) == 0UL)
     {
     }
 
@@ -594,7 +692,7 @@ void CLOCK_InitUsb2Pll(const clock_usb_pll_config_t *config)
                            CCM_ANALOG_PLL_USB2_ENABLE_MASK | CCM_ANALOG_PLL_USB2_POWER_MASK |
                            CCM_ANALOG_PLL_USB2_EN_USB_CLKS_MASK | CCM_ANALOG_PLL_USB2_DIV_SELECT(config->loopDivider);
 
-    while ((CCM_ANALOG->PLL_USB2 & CCM_ANALOG_PLL_USB2_LOCK_MASK) == 0)
+    while ((CCM_ANALOG->PLL_USB2 & CCM_ANALOG_PLL_USB2_LOCK_MASK) == 0UL)
     {
     }
 
@@ -681,7 +779,7 @@ void CLOCK_InitAudioPll(const clock_audio_pll_config_t *config)
 
     CCM_ANALOG->PLL_AUDIO = pllAudio;
 
-    while ((CCM_ANALOG->PLL_AUDIO & CCM_ANALOG_PLL_AUDIO_LOCK_MASK) == 0)
+    while ((CCM_ANALOG->PLL_AUDIO & CCM_ANALOG_PLL_AUDIO_LOCK_MASK) == 0UL)
     {
     }
 
@@ -694,7 +792,7 @@ void CLOCK_InitAudioPll(const clock_audio_pll_config_t *config)
  */
 void CLOCK_DeinitAudioPll(void)
 {
-    CCM_ANALOG->PLL_AUDIO = CCM_ANALOG_PLL_AUDIO_POWERDOWN_MASK;
+    CCM_ANALOG->PLL_AUDIO = (uint32_t)CCM_ANALOG_PLL_AUDIO_POWERDOWN_MASK;
 }
 
 /*!
@@ -767,7 +865,7 @@ void CLOCK_InitVideoPll(const clock_video_pll_config_t *config)
 
     CCM_ANALOG->PLL_VIDEO = pllVideo;
 
-    while ((CCM_ANALOG->PLL_VIDEO & CCM_ANALOG_PLL_VIDEO_LOCK_MASK) == 0)
+    while ((CCM_ANALOG->PLL_VIDEO & CCM_ANALOG_PLL_VIDEO_LOCK_MASK) == 0UL)
     {
     }
 
@@ -812,7 +910,7 @@ void CLOCK_InitEnetPll(const clock_enet_pll_config_t *config)
         enet_pll;
 
     /* Wait for stable */
-    while ((CCM_ANALOG->PLL_ENET & CCM_ANALOG_PLL_ENET_LOCK_MASK) == 0)
+    while ((CCM_ANALOG->PLL_ENET & CCM_ANALOG_PLL_ENET_LOCK_MASK) == 0UL)
     {
     }
 
@@ -844,7 +942,7 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
     uint32_t divSelect;
     clock_64b_t freqTmp;
 
-    const uint32_t enetRefClkFreq[] = {
+    static const uint32_t enetRefClkFreq[] = {
         25000000U,  /* 25M */
         50000000U,  /* 50M */
         100000000U, /* 100M */
@@ -875,10 +973,10 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
             break;
         case kCLOCK_PllSys:
             /* PLL output frequency = Fref * (DIV_SELECT + NUM/DENOM). */
-            freqTmp = ((clock_64b_t)freq * ((clock_64b_t)(CCM_ANALOG->PLL_SYS_NUM))) /
-                      ((clock_64b_t)(CCM_ANALOG->PLL_SYS_DENOM));
+            freqTmp = ((clock_64b_t)freq * ((clock_64b_t)(CCM_ANALOG->PLL_SYS_NUM)));
+            freqTmp /= ((clock_64b_t)(CCM_ANALOG->PLL_SYS_DENOM));
 
-            if (CCM_ANALOG->PLL_SYS & CCM_ANALOG_PLL_SYS_DIV_SELECT_MASK)
+            if ((CCM_ANALOG->PLL_SYS & CCM_ANALOG_PLL_SYS_DIV_SELECT_MASK) != 0U)
             {
                 freq *= 22U;
             }
@@ -891,7 +989,7 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
             break;
 
         case kCLOCK_PllUsb1:
-            freq = (freq * ((CCM_ANALOG->PLL_USB1 & CCM_ANALOG_PLL_USB1_DIV_SELECT_MASK) ? 22U : 20U));
+            freq = (freq * (((CCM_ANALOG->PLL_USB1 & CCM_ANALOG_PLL_USB1_DIV_SELECT_MASK) != 0UL) ? 22U : 20U));
             break;
 
         case kCLOCK_PllAudio:
@@ -899,8 +997,8 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
             divSelect =
                 (CCM_ANALOG->PLL_AUDIO & CCM_ANALOG_PLL_AUDIO_DIV_SELECT_MASK) >> CCM_ANALOG_PLL_AUDIO_DIV_SELECT_SHIFT;
 
-            freqTmp = ((clock_64b_t)freq * ((clock_64b_t)(CCM_ANALOG->PLL_AUDIO_NUM))) /
-                      ((clock_64b_t)(CCM_ANALOG->PLL_AUDIO_DENOM));
+            freqTmp = ((clock_64b_t)freq * ((clock_64b_t)(CCM_ANALOG->PLL_AUDIO_NUM)));
+            freqTmp /= ((clock_64b_t)(CCM_ANALOG->PLL_AUDIO_DENOM));
 
             freq = freq * divSelect + (uint32_t)freqTmp;
 
@@ -930,7 +1028,12 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
                     freq = freq >> 1U;
                     break;
 
+                case CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT(2U):
+                    freq = freq >> 0U;
+                    break;
+
                 default:
+                    assert(false);
                     break;
             }
 
@@ -944,7 +1047,13 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
                     freq >>= 1U;
                     break;
 
+                case CCM_ANALOG_MISC2_AUDIO_DIV_MSB(0) | CCM_ANALOG_MISC2_AUDIO_DIV_LSB(0):
+                case CCM_ANALOG_MISC2_AUDIO_DIV_MSB(1) | CCM_ANALOG_MISC2_AUDIO_DIV_LSB(0):
+                    freq >>= 0U;
+                    break;
+
                 default:
+                    assert(false);
                     break;
             }
             break;
@@ -954,9 +1063,8 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
             divSelect =
                 (CCM_ANALOG->PLL_VIDEO & CCM_ANALOG_PLL_VIDEO_DIV_SELECT_MASK) >> CCM_ANALOG_PLL_VIDEO_DIV_SELECT_SHIFT;
 
-            freqTmp = ((clock_64b_t)freq * ((clock_64b_t)(CCM_ANALOG->PLL_VIDEO_NUM))) /
-                      ((clock_64b_t)(CCM_ANALOG->PLL_VIDEO_DENOM));
-
+            freqTmp = ((clock_64b_t)freq * ((clock_64b_t)(CCM_ANALOG->PLL_VIDEO_NUM)));
+            freqTmp /= ((clock_64b_t)(CCM_ANALOG->PLL_VIDEO_DENOM));
             freq = freq * divSelect + (uint32_t)freqTmp;
 
             /* VIDEO PLL output = PLL output frequency / POSTDIV. */
@@ -985,21 +1093,32 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
                     freq = freq >> 1U;
                     break;
 
+                case CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT(2U):
+                    freq = freq >> 0U;
+                    break;
+
                 default:
+                    assert(false);
                     break;
             }
 
             switch (CCM_ANALOG->MISC2 & CCM_ANALOG_MISC2_VIDEO_DIV_MASK)
             {
-                case CCM_ANALOG_MISC2_VIDEO_DIV(3):
+                case CCM_ANALOG_MISC2_VIDEO_DIV(3U):
                     freq >>= 2U;
                     break;
 
-                case CCM_ANALOG_MISC2_VIDEO_DIV(1):
+                case CCM_ANALOG_MISC2_VIDEO_DIV(1U):
                     freq >>= 1U;
                     break;
 
+                case CCM_ANALOG_MISC2_VIDEO_DIV(0U):
+                case CCM_ANALOG_MISC2_VIDEO_DIV(2U):
+                    freq >>= 0U;
+                    break;
+
                 default:
+                    assert(false);
                     break;
             }
             break;
@@ -1015,7 +1134,7 @@ uint32_t CLOCK_GetPllFreq(clock_pll_t pll)
             break;
 
         case kCLOCK_PllUsb2:
-            freq = (freq * ((CCM_ANALOG->PLL_USB2 & CCM_ANALOG_PLL_USB2_DIV_SELECT_MASK) ? 22U : 20U));
+            freq = (freq * (((CCM_ANALOG->PLL_USB2 & CCM_ANALOG_PLL_USB2_DIV_SELECT_MASK) != 0U) ? 22U : 20U));
             break;
         default:
             freq = 0U;
@@ -1041,13 +1160,14 @@ void CLOCK_InitSysPfd(clock_pfd_t pfd, uint8_t pfdFrac)
     uint32_t pfd528;
 
     pfd528 = CCM_ANALOG->PFD_528 &
-             ~((CCM_ANALOG_PFD_528_PFD0_CLKGATE_MASK | CCM_ANALOG_PFD_528_PFD0_FRAC_MASK) << (8 * pfdIndex));
+             ~(((uint32_t)((uint32_t)CCM_ANALOG_PFD_528_PFD0_CLKGATE_MASK | CCM_ANALOG_PFD_528_PFD0_FRAC_MASK)
+                << (8UL * pfdIndex)));
 
     /* Disable the clock output first. */
-    CCM_ANALOG->PFD_528 = pfd528 | (CCM_ANALOG_PFD_528_PFD0_CLKGATE_MASK << (8 * pfdIndex));
+    CCM_ANALOG->PFD_528 = pfd528 | ((uint32_t)CCM_ANALOG_PFD_528_PFD0_CLKGATE_MASK << (8UL * pfdIndex));
 
     /* Set the new value and enable output. */
-    CCM_ANALOG->PFD_528 = pfd528 | (CCM_ANALOG_PFD_528_PFD0_FRAC(pfdFrac) << (8 * pfdIndex));
+    CCM_ANALOG->PFD_528 = pfd528 | (CCM_ANALOG_PFD_528_PFD0_FRAC(pfdFrac) << (8UL * pfdIndex));
 }
 
 /*!
@@ -1059,7 +1179,20 @@ void CLOCK_InitSysPfd(clock_pfd_t pfd, uint8_t pfdFrac)
  */
 void CLOCK_DeinitSysPfd(clock_pfd_t pfd)
 {
-    CCM_ANALOG->PFD_528 |= CCM_ANALOG_PFD_528_PFD0_CLKGATE_MASK << (8 * pfd);
+    CCM_ANALOG->PFD_528 |= (uint32_t)CCM_ANALOG_PFD_528_PFD0_CLKGATE_MASK << (8U * (uint8_t)pfd);
+}
+
+/*!
+ * brief Check if Sys PFD is enabled
+ *
+ * param pfd PFD control name
+ * return PFD bypass status.
+ *         - true: power on.
+ *         - false: power off.
+ */
+bool CLOCK_IsSysPfdEnabled(clock_pfd_t pfd)
+{
+    return ((CCM_ANALOG->PFD_528 & (uint32_t)CCM_ANALOG_PFD_528_PFD0_CLKGATE_MASK << (8UL * (uint8_t)pfd)) == 0U);
 }
 
 /*!
@@ -1078,13 +1211,14 @@ void CLOCK_InitUsb1Pfd(clock_pfd_t pfd, uint8_t pfdFrac)
     uint32_t pfd480;
 
     pfd480 = CCM_ANALOG->PFD_480 &
-             ~((CCM_ANALOG_PFD_480_PFD0_CLKGATE_MASK | CCM_ANALOG_PFD_480_PFD0_FRAC_MASK) << (8 * pfdIndex));
+             ~(((uint32_t)((uint32_t)CCM_ANALOG_PFD_480_PFD0_CLKGATE_MASK | CCM_ANALOG_PFD_480_PFD0_FRAC_MASK)
+                << (8UL * pfdIndex)));
 
     /* Disable the clock output first. */
-    CCM_ANALOG->PFD_480 = pfd480 | (CCM_ANALOG_PFD_480_PFD0_CLKGATE_MASK << (8 * pfdIndex));
+    CCM_ANALOG->PFD_480 = pfd480 | ((uint32_t)CCM_ANALOG_PFD_480_PFD0_CLKGATE_MASK << (8UL * pfdIndex));
 
     /* Set the new value and enable output. */
-    CCM_ANALOG->PFD_480 = pfd480 | (CCM_ANALOG_PFD_480_PFD0_FRAC(pfdFrac) << (8 * pfdIndex));
+    CCM_ANALOG->PFD_480 = pfd480 | (CCM_ANALOG_PFD_480_PFD0_FRAC(pfdFrac) << (8UL * pfdIndex));
 }
 
 /*!
@@ -1096,7 +1230,20 @@ void CLOCK_InitUsb1Pfd(clock_pfd_t pfd, uint8_t pfdFrac)
  */
 void CLOCK_DeinitUsb1Pfd(clock_pfd_t pfd)
 {
-    CCM_ANALOG->PFD_480 |= CCM_ANALOG_PFD_480_PFD0_CLKGATE_MASK << (8 * pfd);
+    CCM_ANALOG->PFD_480 |= (uint32_t)CCM_ANALOG_PFD_480_PFD0_CLKGATE_MASK << (8UL * (uint8_t)pfd);
+}
+
+/*!
+ * brief Check if Usb1 PFD is enabled
+ *
+ * param pfd PFD control name.
+ * return PFD bypass status.
+ *         - true: power on.
+ *         - false: power off.
+ */
+bool CLOCK_IsUsb1PfdEnabled(clock_pfd_t pfd)
+{
+    return ((CCM_ANALOG->PFD_480 & (uint32_t)CCM_ANALOG_PFD_480_PFD0_CLKGATE_MASK << (8UL * (uint8_t)pfd)) == 0U);
 }
 
 /*!
@@ -1188,7 +1335,7 @@ uint32_t CLOCK_GetUsb1PfdFreq(clock_pfd_t pfd)
  */
 bool CLOCK_EnableUsbhs1PhyPllClock(clock_usb_phy_src_t src, uint32_t freq)
 {
-    const clock_usb_pll_config_t g_ccmConfigUsbPll = {.loopDivider = 0U};
+    static const clock_usb_pll_config_t g_ccmConfigUsbPll = {.loopDivider = 0U};
     CLOCK_InitUsb2Pll(&g_ccmConfigUsbPll);
     USBPHY2->CTRL &= ~USBPHY_CTRL_SFTRST_MASK; /* release PHY from reset */
     USBPHY2->CTRL &= ~USBPHY_CTRL_CLKGATE_MASK;
@@ -1211,49 +1358,178 @@ void CLOCK_DisableUsbhs1PhyPllClock(void)
 }
 
 /*!
- * brief Use DWT to delay at least for some time.
- * Please note that, this API will calculate the microsecond period with the maximum devices
- * supported CPU frequency, so this API will only delay for at least the given microseconds, if precise
- * delay count was needed, please implement a new timer count to achieve this function.
+ * brief Set the clock source and the divider of the clock output1.
  *
- * param delay_us  Delay time in unit of microsecond.
+ * param selection The clock source to be output, please refer to clock_output1_selection_t.
+ * param divider The divider of the output clock signal, please refer to clock_output_divider_t.
  */
-__attribute__((weak)) void SDK_DelayAtLeastUs(uint32_t delay_us)
+void CLOCK_SetClockOutput1(clock_output1_selection_t selection, clock_output_divider_t divider)
 {
-    assert(0U != delay_us);
-    uint64_t count  = 0U;
-    uint32_t period = SDK_DEVICE_MAXIMUM_CPU_CLOCK_FREQUENCY / 1000000;
+    uint32_t tmp32;
 
-    /* Make sure the DWT trace fucntion is enabled. */
-    if (CoreDebug_DEMCR_TRCENA_Msk != (CoreDebug_DEMCR_TRCENA_Msk & CoreDebug->DEMCR))
+    tmp32 = CCM->CCOSR;
+    if (selection == kCLOCK_DisableClockOutput1)
     {
-        CoreDebug->DEMCR |= CoreDebug_DEMCR_TRCENA_Msk;
+        tmp32 &= ~CCM_CCOSR_CLKO1_EN_MASK;
     }
-
-    /* CYCCNT not supported on this device. */
-    assert(DWT_CTRL_NOCYCCNT_Msk != (DWT->CTRL & DWT_CTRL_NOCYCCNT_Msk));
-
-    /* If CYCCENT has already been enabled, read directly, otherwise, need enable it. */
-    if (DWT_CTRL_CYCCNTENA_Msk != (DWT_CTRL_CYCCNTENA_Msk & DWT->CTRL))
-    {
-        DWT->CTRL |= DWT_CTRL_CYCCNTENA_Msk;
-    }
-
-    /* Calculate the count ticks. */
-    count = DWT->CYCCNT;
-    count += (uint64_t)period * delay_us;
-
-    if (count > 0xFFFFFFFFUL)
-    {
-        count -= 0xFFFFFFFFUL;
-        /* wait for cyccnt overflow. */
-        while (count < DWT->CYCCNT)
-        {
-        }
-    }
-
-    /* Wait for cyccnt reach count value. */
-    while (count > DWT->CYCCNT)
+    else
     {
+        tmp32 |= CCM_CCOSR_CLKO1_EN_MASK;
+        tmp32 &= ~(CCM_CCOSR_CLKO1_SEL_MASK | CCM_CCOSR_CLKO1_DIV_MASK);
+        tmp32 |= CCM_CCOSR_CLKO1_SEL(selection) | CCM_CCOSR_CLKO1_DIV(divider);
     }
+    CCM->CCOSR = tmp32;
+}
+
+/*!
+ * brief Set the clock source and the divider of the clock output2.
+ *
+ * param selection The clock source to be output, please refer to clock_output2_selection_t.
+ * param divider The divider of the output clock signal, please refer to clock_output_divider_t.
+ */
+void CLOCK_SetClockOutput2(clock_output2_selection_t selection, clock_output_divider_t divider)
+{
+    uint32_t tmp32;
+
+    tmp32 = CCM->CCOSR;
+    if (selection == kCLOCK_DisableClockOutput2)
+    {
+        tmp32 &= CCM_CCOSR_CLKO2_EN_MASK;
+    }
+    else
+    {
+        tmp32 |= CCM_CCOSR_CLKO2_EN_MASK;
+        tmp32 &= ~(CCM_CCOSR_CLKO2_SEL_MASK | CCM_CCOSR_CLKO2_DIV_MASK);
+        tmp32 |= CCM_CCOSR_CLKO2_SEL(selection) | CCM_CCOSR_CLKO2_DIV(divider);
+    }
+
+    CCM->CCOSR = tmp32;
+}
+
+/*!
+ * brief Get the frequency of clock output1 clock signal.
+ *
+ * return The frequency of clock output1 clock signal.
+ */
+uint32_t CLOCK_GetClockOutCLKO1Freq(void)
+{
+    uint32_t freq = 0U;
+    uint32_t tmp32;
+
+    tmp32 = CCM->CCOSR;
+
+    if ((tmp32 & CCM_CCOSR_CLKO1_EN_MASK) != 0UL)
+    {
+        switch ((tmp32 & CCM_CCOSR_CLKO1_SEL_MASK) >> CCM_CCOSR_CLKO1_SEL_SHIFT)
+        {
+            case (uint32_t)kCLOCK_OutputPllUsb1:
+                freq = CLOCK_GetPllFreq(kCLOCK_PllUsb1) / 2U;
+                break;
+            case (uint32_t)kCLOCK_OutputPllSys:
+                freq = CLOCK_GetPllFreq(kCLOCK_PllSys) / 2U;
+                break;
+            case (uint32_t)kCLOCK_OutputPllVideo:
+                freq = CLOCK_GetPllFreq(kCLOCK_PllVideo) / 2U;
+                break;
+            case (uint32_t)kCLOCK_OutputSemcClk:
+                freq = CLOCK_GetSemcFreq();
+                break;
+            case (uint32_t)kCLOCK_OutputLcdifPixClk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_LcdifClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputAhbClk:
+                freq = CLOCK_GetAhbFreq();
+                break;
+            case (uint32_t)kCLOCK_OutputIpgClk:
+                freq = CLOCK_GetIpgFreq();
+                break;
+            case (uint32_t)kCLOCK_OutputPerClk:
+                freq = CLOCK_GetPerClkFreq();
+                break;
+            case (uint32_t)kCLOCK_OutputCkilSyncClk:
+                freq = CLOCK_GetRtcFreq();
+                break;
+            case (uint32_t)kCLOCK_OutputPll4MainClk:
+                freq = CLOCK_GetPllFreq(kCLOCK_PllAudio);
+                break;
+            default:
+                /* This branch should never be hit. */
+                break;
+        }
+
+        freq /= (((tmp32 & CCM_CCOSR_CLKO1_DIV_MASK) >> CCM_CCOSR_CLKO1_DIV_SHIFT) + 1U);
+    }
+    else
+    {
+        freq = 0UL;
+    }
+
+    return freq;
+}
+
+/*!
+ * brief Get the frequency of clock output2 clock signal.
+ *
+ * return The frequency of clock output2 clock signal.
+ */
+uint32_t CLOCK_GetClockOutClkO2Freq(void)
+{
+    uint32_t freq = 0U;
+    uint32_t tmp32;
+
+    tmp32 = CCM->CCOSR;
+
+    if ((tmp32 & CCM_CCOSR_CLKO2_EN_MASK) != 0UL)
+    {
+        switch ((tmp32 & CCM_CCOSR_CLKO2_SEL_MASK) >> CCM_CCOSR_CLKO2_SEL_SHIFT)
+        {
+            case (uint32_t)kCLOCK_OutputUsdhc1Clk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_Usdhc1ClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputLpi2cClk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_Lpi2cClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputCsiClk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_CsiClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputOscClk:
+                freq = CLOCK_GetOscFreq();
+                break;
+            case (uint32_t)kCLOCK_OutputUsdhc2Clk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_Usdhc2ClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputSai1Clk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_Sai1ClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputSai2Clk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_Sai2ClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputSai3Clk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_Sai3ClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputCanClk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_CanClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputFlexspiClk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_FlexspiClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputUartClk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_UartClkRoot);
+                break;
+            case (uint32_t)kCLOCK_OutputSpdif0Clk:
+                freq = CLOCK_GetClockRootFreq(kCLOCK_SpdifClkRoot);
+                break;
+            default:
+                /* This branch should never be hit. */
+                break;
+        }
+
+        freq /= (((tmp32 & CCM_CCOSR_CLKO2_DIV_MASK) >> CCM_CCOSR_CLKO2_DIV_SHIFT) + 1U);
+    }
+    else
+    {
+        freq = 0UL;
+    }
+
+    return freq;
 }
