@@ -160,11 +160,14 @@ void dfu_moded_reset(uint8_t rhport)
   reset_state();
 }
 
-void dfu_moded_init(void)
-{
+void dfu_moded_init(void) {
   dfu_moded_reset(0);
 }
 
+bool dfu_moded_deinit(void) {
+  return true;
+}
+
 uint16_t dfu_moded_open(uint8_t rhport, tusb_desc_interface_t const * itf_desc, uint16_t max_len)
 {
   (void) rhport;
