@@ -41,4 +41,6 @@
 #define MICROPY_DEBUG_PARSE_RULE_NAME  (1)
 #define MICROPY_TRACKED_ALLOC          (1)
 #define MICROPY_WARNINGS_CATEGORY      (1)
-#define MICROPY_PY_UCRYPTOLIB_CTR      (1)
+#undef MICROPY_VFS_ROM_IOCTL
+#define MICROPY_VFS_ROM_IOCTL          (1)
+#define MICROPY_PY_CRYPTOLIB_CTR       (1)
